# BEGIN COPYRIGHT
# *************************************************************************
# Licensed Materials - Property of IBM 
# 5724-L01, 5655-N53, 5724-I82, 5655-R15,5724-M23,5724-M24 
# (C) Copyright IBM Corporation 2008. All rights reserved. 
# US Government Users Restricted Rights - Use, duplication, or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
# *************************************************************************
# END COPYRIGHT

import java 
import sys
import string
from java.lang import *;
import java.io.File as File;

# get line separator 
lineSeparator = java.lang.System.getProperty('line.separator') 

def wsadminToList(inStr):
        outList=[]
        if (len(inStr)>0 and inStr[0]=='[' and inStr[-1]==']'):
                tmpList = inStr[1:-1].split() #splits space-separated lists,
        else:
                tmpList = inStr.split("\n")   #splits for Windows or Linux
        for item in tmpList:
                item = item.rstrip();         #removes any Windows "\r"
                if (len(item)>0):
                        outList.append(item)
        return outList
#endDef

S_COMMON_DB_DERBY_EMBEDDED = "DERBY_EMBEDDED"
S_COMMON_DB_DB2 = "DB2_UNIVERSAL"
S_COMMON_DB_DB2UDBISERIES_TOOLBOX = "DB2UDBISERIES_TOOLBOX"
S_COMMON_DB_DB2UDBISERIES_NATIVE = "DB2UDBISERIES_NATIVE"
S_COMMON_DB_ORACLE_10g = "ORACLE10G"
S_COMMON_DB_ORACLE_10g_MONITOR = "ORACLE_10G"
S_COMMON_DB_ORACLE_11g = "ORACLE11G"
S_COMMON_DB_ORACLE_11g_MONITOR = "ORACLE_11G"
S_COMMON_DB_ORACLE = "ORACLE"
S_COMMON_DB_DB2_ZOS_8 = "DB2UDBOS390_V8_1"
S_COMMON_DB_DB2_ZOS_9 = "DB2UDBOS390_V9_1"
S_COMMON_DB_DERBY_NETWORKSERVER = "DERBY_NETWORKSERVER"
S_COMMON_DB_SQLSERVER_MICROSOFT = "MSSQLSERVER_MICROSOFT"
S_COMMON_DB_SQLSERVER_DATADIRECT = "MSSQLSERVER_DATADIRECT"

def environment(cellName, nodeName, serverName, varName, varValue, varDescription):
    print "INFO:  Entering environment"
    print "INFO:  varName="+varName+",varValue="+varValue+",varDescription="+varDescription
    
    id = None
    variableMapNodeId = None
    if(nodeName == None):    
        id = AdminConfig.getid("/Cell:"+cellName+"/" )
        variableMapNodeId = AdminConfig.getid("/Cell:"+cellName+"/VariableMap:/" )
        print "INFO:  WebSphere Environment Variables for /Cell:"+cellName+"/"
    else:
        id = AdminConfig.getid("/Cell:"+cellName+"/Node:"+nodeName+"/" )
        variableMapNodeId = AdminConfig.getid("/Cell:"+cellName+"/Node:"+nodeName+"/VariableMap:/" )
        print "INFO:  WebSphere Environment Variables for /Cell:"+cellName+"/Node:"+nodeName+"/"
               
    wasVarDescription = ["description", varDescription]
    wasVarName = ["symbolicName", varName]
    wasVarValue = '[value "'+varValue+'"]'
    wasVarAttrs = [wasVarDescription, wasVarName, wasVarValue]
    if(cmp(varDescription,"") ==0):
        wasVarAttrs = [wasVarName, wasVarValue]
    #endif    
    installed    = "false"
    modified     = "false"

    varList = AdminConfig.list("VariableSubstitutionEntry", id )
    for tmpEntryId in wsadminToList(varList):
        #For Cell scope, we skip nodes
        if(nodeName == None):
            if(str(tmpEntryId).find("/nodes/") != -1):
                continue
            
        name = AdminConfig.showAttribute(tmpEntryId, "symbolicName")
        value = AdminConfig.showAttribute(tmpEntryId, "value")
        if (value != ""):
            print "%35s :  %-50s" % (name, value) 
        #endIf 
        if (cmp(name, varName) == 0):
            installed = "true"
            if (cmp(value, varValue) != 0):
                print "INFO: "+varName+" needs to be changed"
                AdminConfig.modify(tmpEntryId, wasVarAttrs )
                value = AdminConfig.showAttribute(tmpEntryId, "value" )
                modified = "true"
            #endIf 
            break
        #endIf 
    #endFor 
    flagOk = "false"
    if (cmp(modified, "false") == 0):
        if (cmp(installed, "true") == 0):
            flagOk = "true"
            print "INFO: "+varName+" with the correct value is already there, no action taken."
        else:
            print "INFO:  "+varName+" needs to be created"
            variableEntryId = AdminConfig.create("VariableSubstitutionEntry", variableMapNodeId, wasVarAttrs )
            name = AdminConfig.showAttribute(variableEntryId, "symbolicName" )
            value = AdminConfig.showAttribute(variableEntryId, "value" )
        #endElse 
    #endIf 

    # Check for success
    if (cmp(modified, "true") == 0 or cmp(installed, "false") == 0):
        varList = AdminConfig.list("VariableSubstitutionEntry", id )
        for tmpEntryId in wsadminToList(varList):
            #For Cell scope, we skip nodes
            if(nodeName == None):
                if(str(tmpEntryId).find("/nodes/") != -1):
                    continue
            name = AdminConfig.showAttribute(tmpEntryId, "symbolicName" )
            value = AdminConfig.showAttribute(tmpEntryId, "value" )
            if (cmp(name, varName) == 0):
                if (cmp(value, varValue) == 0):
                    flagOk = "true"
                #endIf 
                break
            #endIf 
        #endFor 
    #endIf         
    if (cmp(flagOk, "true") == 0):
        AdminConfig.save( )
        print "INFO: "+varName+" successfully created/modified."
    else:
        print "ERROR: WebSphere Environment Variable "+varName+" could not be created/modified."
    #endElse 
    print "INFO:  Exiting environment"
    return
#endDef

def removeEnvironment(cellName, nodeName, serverName, varName):
    # Remove a WebSphere environment variable
    print "INFO:  Entering remove environment"
    print "INFO:  varName="+varName
    
    id = None
    if(nodeName == None):    
        id = AdminConfig.getid("/Cell:"+cellName+"/" )
        print "INFO:  WebSphere Environment Variables for /Cell:"+cellName+"/"
    else:
        id = AdminConfig.getid("/Cell:"+cellName+"/Node:"+nodeName+"/" )
        print "INFO:  WebSphere Environment Variables for /Cell:"+cellName+"/Node:"+nodeName+"/"

    found = "false"
    varList = AdminConfig.list("VariableSubstitutionEntry", id )
    for tmpEntryId in wsadminToList(varList):
        #For Cell scope, we skip nodes
        if(nodeName == None):
            if(str(tmpEntryId).find("/nodes/") != -1):
                continue
            
        name = AdminConfig.showAttribute(tmpEntryId, "symbolicName")
        if (cmp(name, varName) == 0):
            print "Removing "+str(tmpEntryId)
            AdminConfig.remove(tmpEntryId)
            found = "true"
        #endIf 
    #endFor 
    
    if (cmp(found, "true") == 0):
        AdminConfig.save( )

    return

class Scope:
    CLUSTER_SCOPE = 1
    CELL_SCOPE = 2
    NODE_SCOPE = 3
    SERVER_SCOPE = 4
# instance variables are...
#    cell
#    node
#    server
#    cluster
    
    def __init__(self, cluster, cell, node, server):
        self.cluster = cluster
        self.cell = cell
        self.node = node
        self.server = server
        
        self.containmentPathMap = {}
        self.containmentPathMap[Scope.CLUSTER_SCOPE] = "/Cell:" + cell + "/Cluster:" + cluster + "/"
        self.containmentPathMap[Scope.CELL_SCOPE] = "/Cell:" + cell + "/"
        self.containmentPathMap[Scope.NODE_SCOPE] = "/Cell:" + cell + "/Node:" + node + "/"
        self.containmentPathMap[Scope.SERVER_SCOPE] = "/Cell:" + cell + "/Node:" + node + "/Server:" + server + "/"

    def getConfigId(self, scopeLevel):
    	print self
    	print self.getContainmentPath(scopeLevel)
        return AdminConfig.getid(self.getContainmentPath(scopeLevel))

    def getContainmentPath(self, scopeLevel):
        return self.containmentPathMap[scopeLevel]

class AuthAliasInfo:
# instance variables are.... They are created in __init__ so they don't end up Class variables
#    name
#    desc
#    userId
#    password
    
    def __init__(self, name, desc, userId, password):
        print  "--- parms for datasourceAuthAliasInfo"
        print  "datasourceAuthAliasName         =  " + name
        print  "datasourceAuthAliasDesc         =  " + desc
        print  "datasourceAuthAliasUsername     =  " + userId
        # print  "datasourceAuthAliasPassword     =  " + password
        self.name = name
        self.desc = desc
        self.userId = userId
        self.password = password

class JdbcProviderInfo:
# instance variables are.... They are created in __init__ so they don't end up Class variables
#    name
#    desc
#    implClass
#    driverFile
    
    def __init__(self, name, providerType, desc, implClass, driverFile):
        print  "--- parms for jdbcProviderInfo"
        print  "jdbcProviderName                =  " + name
        print  "jdbcProviderType                =  " + providerType
        print  "jdbcProviderDesc                =  " + desc
        print  "jdbcProviderImplClass           =  " + implClass
        print  "jdbcProviderClasspath           =  " + driverFile
        self.name = name
        self.providerType = providerType
        self.desc = desc
        self.implClass = implClass
        self.driverFile = driverFile

class DatasourceInfo:
# instance variables are.... They are created in __init__ so they don't end up Class variables
#    name
#    desc
#    jndiName
#    helperClassname
#    maxConnections
#    props #map
#    providerName
#    authAliasName
    
    def __init__(self, name, desc, jndiName, helperClassname, maxConnections, props, providerName, authAliasName, templateId):
        print  "--- parms for DatasourceInfo"
        print  "datasourceName                 =  " + name
        print  "datasourceDesc                 =  " + desc
        print  "datasourceJndi                 =  " + jndiName
        print  "datasourceHelperClassname      =  " + helperClassname
        print  "datasourceMaxConnections       =  " + maxConnections
        #print  "datasourceProps               =  " + props
        print  "jdbcProviderName               =  " + providerName
        print  "datasourceAuthAliasName        =  " + authAliasName
        self.name = name
        self.desc = desc
        self.jndiName = jndiName
        self.helperClassname = helperClassname
        self.maxConnections = maxConnections
        self.props = props
        self.providerName = providerName
        self.authAliasName = authAliasName
        self.templateId = templateId
    
    def getProps(self):
        ret = []
        nameValPairs = self.props.items()
        for i in range(len(nameValPairs)):
            ret.append([["name", nameValPairs[i][0]], ["value", nameValPairs[i][1]]])
        return ret

def getJdbcProviderConfigId(scope, scopeLevel, providerName):
    print scope
    print "providerName Instance :" +providerName
    print scopeLevel
    print scope.getContainmentPath(scopeLevel)
    providerConfigId = AdminConfig.getid(scope.getContainmentPath(scopeLevel) + "JDBCProvider:" + providerName + "/")
    
    if (providerConfigId == ""):
        print "Did not find JDBC Provider: " + providerName
        return None
    else:
        print "Found JDBC Provider: " + providerConfigId
        return providerConfigId

def createJdbcProvider(scope, scopeLevel, providerInfo):
    print providerInfo
    providerConfigId = getJdbcProviderConfigId(scope, scopeLevel, providerInfo.name)
    
    if (providerConfigId == None): # go ahead and create it
        db2ProviderImplClass = "com.ibm.db2.jcc.DB2XADataSource"
        providerCreateArgs = None
        if (providerInfo.implClass == db2ProviderImplClass):
            if(providerInfo.providerType == "DB2 Universal JDBC Driver Provider"):
                providerCreateArgs = [["name", providerInfo.name], ["providerType", providerInfo.providerType], ["description", providerInfo.desc], ["implementationClassName", providerInfo.implClass], ["classpath", providerInfo.driverFile], ["nativepath", "${DB2UNIVERSAL_JDBC_DRIVER_NATIVEPATH}"]]
            else:
                providerCreateArgs = [["name", providerInfo.name], ["providerType", providerInfo.providerType], ["description", providerInfo.desc], ["implementationClassName", providerInfo.implClass], ["xa", "true"], ["classpath", providerInfo.driverFile], ["nativepath", "${DB2UNIVERSAL_JDBC_DRIVER_NATIVEPATH}"]]
        else:
            if(providerInfo.providerType == "DB2 Universal JDBC Driver Provider"):
                providerCreateArgs = [["name", providerInfo.name], ["providerType", providerInfo.providerType], ["description", providerInfo.desc], ["implementationClassName", providerInfo.implClass], ["classpath", providerInfo.driverFile]]
            else:
                providerCreateArgs = [["name", providerInfo.name], ["providerType", providerInfo.providerType], ["description", providerInfo.desc], ["implementationClassName", providerInfo.implClass], ["xa", "true"], ["classpath", providerInfo.driverFile]]
        parent = scope.getConfigId(scopeLevel)     
        print "Create JDBC Provider with:", providerCreateArgs
        print "creating"
        providerConfigId = AdminConfig.create("JDBCProvider",parent,providerCreateArgs)
    	print providerConfigId
    return providerConfigId

def getAuthenticationAliasConfigId(aliasName):
    print "List all Aliases"
    allAuthAliasString = AdminConfig.list("JAASAuthData")
    allAuthAliasArray = allAuthAliasString.split(lineSeparator)
    aliasConfigId = None
    
    print "Checking Aliases for a match to " + aliasName
    for i in range(len(allAuthAliasArray)):
        print "allAuthAliasArray[i]="+str(allAuthAliasArray[i])
        if(len(allAuthAliasArray[i]) > 0):
            if (AdminConfig.showAttribute(allAuthAliasArray[i], "alias") == aliasName):
                print "Found Alias: " + allAuthAliasArray[i]
                aliasConfigId = allAuthAliasArray[i]
    
    return aliasConfigId

def createAuthenticationAlias(authAliasInfo):
    aliasConfigId = getAuthenticationAliasConfigId(authAliasInfo.name)
    
    if (aliasConfigId == None): # go ahead and create it
        aliasCreateArgs = '[[alias "'+authAliasInfo.name+'"] [description "'+authAliasInfo.desc+'"] [userId "'+authAliasInfo.userId+'"] [password "'+authAliasInfo.password+'"]]'
        parent = AdminConfig.getid("/Security:/")
        print "Create Alias with: alias: " + authAliasInfo.name + " description: " + authAliasInfo.desc + " userId: " + authAliasInfo.userId
        aliasConfigId = AdminConfig.create("JAASAuthData", parent, aliasCreateArgs)
    
    return aliasConfigId

# Queries WAS for datasource existance
def getDatasourceConfigId(scope, scopeLevel, providerName, datasourceName):
    datasourceConfigId = AdminConfig.getid(scope.getContainmentPath(scopeLevel) + "JDBCProvider:" + providerName + "/DataSource:" + datasourceName + "/")
    if (datasourceConfigId == ""):
        print "Did not find Datasource: " + datasourceName + " under " + providerName
        return None
    else:
        print "Found Datasource: " + datasourceConfigId + " under " + providerName
        return datasourceConfigId
def setProp(propSet, propName, propValue, prop):
    allPropsString = AdminConfig.list("J2EEResourceProperty", propSet)
    allPropsArray = allPropsString.split(lineSeparator)
    for i in range(len(allPropsArray)):
        if (allPropsArray[i] == ""):
            continue
        currentName = AdminConfig.showAttribute(allPropsArray[i], "name")
        if (cmp(propName[1],currentName) == 0):
            AdminConfig.modify(allPropsArray[i], '[[value "'+propValue[1]+'"]]')
            return None
        #endif
    #endfor
    AdminConfig.create("J2EEResourceProperty", propSet, prop)
def createDatasource(scope, scopeLevel, datasourceInfo):
    print ">> createDatasource"
    datasourceConfigId = getDatasourceConfigId(scope, scopeLevel, datasourceInfo.providerName, datasourceInfo.name)
    
    if (datasourceConfigId == None): # go ahead and create it
        nameAttr = ["name", datasourceInfo.name]
        descAttr = ["description", datasourceInfo.desc]
        jndiAttr = ["jndiName", datasourceInfo.jndiName]
        statementCacheSizeAttr = ["statementCacheSize","100"]
        helpAttr = ["datasourceHelperClassname", datasourceInfo.helperClassname]
        authAttr = ["authDataAlias", datasourceInfo.authAliasName]
        authMechAttr = ["authMechanismPreference", "BASIC_PASSWORD"]
        mappingAttr = ["mapping", [["authDataAlias", datasourceInfo.authAliasName], ["mappingConfigAlias", "DefaultPrincipalMapping"]]]
        
        datasourceCreateArgs = [nameAttr, descAttr, jndiAttr, statementCacheSizeAttr, helpAttr, authAttr, authMechAttr, mappingAttr]
        
        providerId = getJdbcProviderConfigId(scope, scopeLevel, datasourceInfo.providerName)
        if (providerId != None):
            print "Got the provider"
            print "Create Datasource with:", datasourceCreateArgs
            datasourceConfigId = AdminConfig.createUsingTemplate('DataSource', providerId, datasourceCreateArgs, datasourceInfo.templateId)
            
            # now update the pool
            print "Update the pool for:", datasourceCreateArgs
            datasourcePool = AdminConfig.list("ConnectionPool", datasourceConfigId)
            AdminConfig.modify(datasourcePool, [["maxConnections", datasourceInfo.maxConnections]])
            
            # now update the properties
            print "Update the properties for:", datasourceCreateArgs
            propSet = AdminConfig.showAttribute(datasourceConfigId, "propertySet")
            props = datasourceInfo.getProps()
	    for i in range(len(props)):
                setProp(propSet, props[i][0], props[i][1], props[i])

def setSystemProperties(scope, props):
    if (props == None):
        return
    
    serverCfgId = scope.getConfigId(Scope.SERVER_SCOPE)
    myJVM = AdminConfig.list("JavaVirtualMachine", serverCfgId)
    
    if (myJVM == None):
        print "No suitable JVM was found for Cell=" + scope.cell + ", Node=" + scope.node + ", Server=" + scope.server
    else:
        nameValPairs = props.items()
        for i in range(len(nameValPairs)):
            currProperty = [["name", nameValPairs[i][0]], ["value", nameValPairs[i][1]]]

            allPropsString = AdminConfig.list("TypedProperty", myJVM)
            allPropsArray = allPropsString.split(lineSeparator)
        
            print "Checking", allPropsArray, " for a match to",  props
            matched = "false"
            for j in range(len(allPropsArray)):
                if (allPropsArray[j] == ""):
                    continue
            
                systemPropertyName = AdminConfig.showAttribute(allPropsArray[j], "name")
                currPropertyName = nameValPairs[i][0]
                print "Checking: " + systemPropertyName + " against " + currPropertyName
                if (currPropertyName == systemPropertyName ):
                    print "Matched"
                    matched = "true"
                    print "Modifying: ", currProperty
                    AdminConfig.modify(allPropsArray[j],currProperty)
                    break
            
            if(matched != "true"):
                print "Creating:", currProperty
                AdminConfig.create("TypedProperty", myJVM, currProperty)
        
        AdminConfig.save()
def removeSystemProperties(scope, props):
    if (props == None):
        return
    
    serverCfgId = scope.getConfigId(Scope.SERVER_SCOPE)
    myJVM = AdminConfig.list("JavaVirtualMachine", serverCfgId)
    
    if (myJVM == None):
        print "No suitable JVM was found for Cell=" + scope.cell + ", Node=" + scope.node + ", Server=" + scope.server
    else:
        allPropsString = AdminConfig.list("TypedProperty", myJVM)
        allPropsArray = allPropsString.split(lineSeparator)
        propConfigId = None
        
        nameValPairs = props.items()
        print "Checking", allPropsArray, " for a match to",  props
        for i in range(len(allPropsArray)):
            if (allPropsArray[i] == ""):
                continue
            
            currPropertyName = AdminConfig.showAttribute(allPropsArray[i], "name")
            for j in range(len(nameValPairs)):
                currCheckPropertyName = nameValPairs[j][0]
                print "Checking: " + currPropertyName + " against " + currCheckPropertyName
                if (currPropertyName == currCheckPropertyName):
                    print "Matched"
                    AdminConfig.remove(allPropsArray[i])


def createJDBCProviderComponent(scopeString,cellName,nodeName,serverName,dbType,jdbcProviderName,jdbcProviderDesc,JDBC_DRIVER_PATH,dbDriverType,dbDriverVersion):
    print "scopeString  " +scopeString
    scope = Scope("clusterName", cellName, nodeName, serverName)
  
    print "Scope Instance is :" +scope.containmentPathMap[1]
    print "Scope Instance is :" +scope.containmentPathMap[2]
    print "Scope Instance is :" +scope.containmentPathMap[3]
    print "Scope Instance is :" +scope.containmentPathMap[4]
  
    jdbcProviderImplClass = None
    jdbcProviderClassPath = None
    WAS_INSTALL_ROOT = java.lang.System.getProperty('was.install.root')
    UNIVERSAL_DRIVER_PATH = "${WAS_INSTALL_ROOT}"+File.separator+"universalDriver"+File.separator+"lib";
    UNIVERSAL_DRIVER_PATH = UNIVERSAL_DRIVER_PATH.replace('\\',"/");
    
    print dbType
    print dbDriverType
    print dbDriverVersion
    print JDBC_DRIVER_PATH
    print UNIVERSAL_DRIVER_PATH
    
    if (string.upper(dbType) == S_COMMON_DB_DERBY_EMBEDDED):
        jdbcProviderImplClass = "org.apache.derby.jdbc.EmbeddedXADataSource"
        jdbcProviderClassPath = "${DERBY_JDBC_DRIVER_PATH}/derby.jar"
        jdbcProviderType = "Derby JDBC Provider (XA)"
        environment(cellName,nodeName,serverName,"DERBY_JDBC_DRIVER_PATH",JDBC_DRIVER_PATH,"")
        if(scopeString == "CELL"):
            environment(cellName,None,serverName,"DERBY_JDBC_DRIVER_PATH",JDBC_DRIVER_PATH,"")
    elif(string.upper(dbType) == S_COMMON_DB_DERBY_NETWORKSERVER):
        jdbcProviderImplClass = "org.apache.derby.jdbc.ClientXADataSource"
        jdbcProviderClassPath = "${DERBY_JDBC_DRIVER_PATH}/derbyclient.jar"
        jdbcProviderType = "Derby Network Server Using Derby Client (XA)"
        environment(cellName,nodeName,serverName,"DERBY_JDBC_DRIVER_PATH",JDBC_DRIVER_PATH,"")
        if(scopeString == "CELL"):
            environment(cellName,None,serverName,"DERBY_JDBC_DRIVER_PATH",JDBC_DRIVER_PATH,"")
    elif(string.upper(dbType) == S_COMMON_DB_DB2 or string.upper(dbType) == S_COMMON_DB_DB2_ZOS_8 or string.upper(dbType) == S_COMMON_DB_DB2_ZOS_9):
        if(string.upper(dbDriverType) == "2"):
        	jdbcProviderImplClass = "com.ibm.db2.jcc.DB2ConnectionPoolDataSource"
        	jdbcProviderType = "DB2 Universal JDBC Driver Provider"
        	NATIVE_DRIVER_PATH = JDBC_DRIVER_PATH+File.separator+".."+File.separator+"lib";
        	print NATIVE_DRIVER_PATH
        	environment(cellName,nodeName,serverName,"DB2UNIVERSAL_JDBC_DRIVER_NATIVEPATH",NATIVE_DRIVER_PATH,"")
        else:
        	jdbcProviderImplClass = "com.ibm.db2.jcc.DB2XADataSource"
        	jdbcProviderType = "DB2 Universal JDBC Driver Provider (XA)"
        	NATIVE_DRIVER_PATH = "";
        	print NATIVE_DRIVER_PATH
        	environment(cellName,nodeName,serverName,"DB2UNIVERSAL_JDBC_DRIVER_NATIVEPATH",NATIVE_DRIVER_PATH,"")
        jdbcProviderClassPath = "${DB2UNIVERSAL_JDBC_DRIVER_PATH}/db2jcc.jar;${UNIVERSAL_JDBC_DRIVER_PATH}/db2jcc_license_cu.jar;${DB2UNIVERSAL_JDBC_DRIVER_PATH}/db2jcc_license_cisuz.jar"
        environment(cellName,nodeName,serverName,"DB2UNIVERSAL_JDBC_DRIVER_PATH",JDBC_DRIVER_PATH,"")
        environment(cellName,nodeName,serverName,"UNIVERSAL_JDBC_DRIVER_PATH",UNIVERSAL_DRIVER_PATH,"")
        environment(cellName,nodeName,serverName,"DB2390_JDBC_DRIVER_PATH",JDBC_DRIVER_PATH,"")
        environment(cellName,nodeName,serverName,"DB2_JDBC_DRIVER_PATH",JDBC_DRIVER_PATH,"")
        if(scopeString == "CELL"):
            environment(cellName,None,serverName,"DB2UNIVERSAL_JDBC_DRIVER_PATH",JDBC_DRIVER_PATH,"")
            environment(cellName,None,serverName,"UNIVERSAL_JDBC_DRIVER_PATH",UNIVERSAL_DRIVER_PATH,"")
            environment(cellName,None,serverName,"DB2390_JDBC_DRIVER_PATH",JDBC_DRIVER_PATH,"")
            environment(cellName,None,serverName,"DB2_JDBC_DRIVER_PATH",JDBC_DRIVER_PATH,"")
    elif(string.upper(dbType) == string.upper(dbType) == S_COMMON_DB_DB2UDBISERIES_NATIVE):
        jdbcProviderImplClass = "com.ibm.db2.jdbc.app.UDBXADataSource"
        jdbcProviderClassPath = "${OS400_NATIVE_JDBC_DRIVER_PATH}/db2_classes.jar"
        jdbcProviderType = "DB2 UDB for iSeries (Native XA)"
        environment(cellName,nodeName,serverName,"OS400_NATIVE_JDBC_DRIVER_PATH",JDBC_DRIVER_PATH,"")
        if(scopeString == "CELL"):
            environment(cellName,None,serverName,"OS400_NATIVE_JDBC_DRIVER_PATH",JDBC_DRIVER_PATH,"")
    
    elif(string.upper(dbType) == S_COMMON_DB_DB2UDBISERIES_TOOLBOX):
        jdbcProviderImplClass = "com.ibm.as400.access.AS400JDBCXADataSource"
        jdbcProviderClassPath = "${OS400_TOOLBOX_JDBC_DRIVER_PATH}/jt400.jar"
        jdbcProviderType = "DB2 UDB for iSeries (Toolbox XA)"
        environment(cellName,nodeName,serverName,"OS400_TOOLBOX_JDBC_DRIVER_PATH",JDBC_DRIVER_PATH,"")
        if(scopeString == "CELL"):
            environment(cellName,None,serverName,"OS400_TOOLBOX_JDBC_DRIVER_PATH",JDBC_DRIVER_PATH,"")
    elif((string.upper(dbType) == S_COMMON_DB_ORACLE) or (string.upper(dbType) == S_COMMON_DB_ORACLE_10g) or (string.upper(dbType) == S_COMMON_DB_ORACLE_10g_MONITOR) or (string.upper(dbType) == S_COMMON_DB_ORACLE_11g) or (string.upper(dbType) == S_COMMON_DB_ORACLE_11g_MONITOR)):
        jdbcProviderImplClass = "oracle.jdbc.xa.client.OracleXADataSource"
        jdbcProviderClassPath = "${ORACLE_JDBC_DRIVER_PATH}/ojdbc6.jar"
        jdbcProviderType = "Oracle JDBC Driver (XA)"
        environment(cellName,nodeName,serverName,"ORACLE_JDBC_DRIVER_PATH",JDBC_DRIVER_PATH,"")
        if(scopeString == "CELL"):
            environment(cellName,None,serverName,"ORACLE_JDBC_DRIVER_PATH",JDBC_DRIVER_PATH,"")
    elif(string.upper(dbType) == S_COMMON_DB_SQLSERVER_MICROSOFT):
    	if(string.upper(dbDriverVersion) == "2.0"):
       		jdbcProviderImplClass = "com.microsoft.sqlserver.jdbc.SQLServerXADataSource"
        	jdbcProviderClassPath = "${SQLSERVER_JDBC_DRIVER_PATH}/sqljdbc4.jar"
        	jdbcProviderType = "Microsoft SQL Server JDBC Driver (XA)"
        	environment(cellName,nodeName,serverName,"SQLSERVER_JDBC_DRIVER_PATH",JDBC_DRIVER_PATH,"")
        	if(scopeString == "CELL"):
           		environment(cellName,None,serverName,"SQLSERVER_JDBC_DRIVER_PATH",JDBC_DRIVER_PATH,"")
    
    	elif(string.upper(dbDriverVersion) == "1.2"):
    		jdbcProviderImplClass = "com.microsoft.sqlserver.jdbc.SQLServerXADataSource"
        	jdbcProviderClassPath = "${SQLSERVER_JDBC_DRIVER_PATH}/sqljdbc.jar"
        	jdbcProviderType = "Microsoft SQL Server JDBC Driver (XA)"
        	environment(cellName,nodeName,serverName,"SQLSERVER_JDBC_DRIVER_PATH",JDBC_DRIVER_PATH,"")
        	if(scopeString == "CELL"):
           		environment(cellName,None,serverName,"SQLSERVER_JDBC_DRIVER_PATH",JDBC_DRIVER_PATH,"")
           		
    elif(string.upper(dbType) == S_COMMON_DB_SQLSERVER_DATADIRECT):
        jdbcProviderImplClass = "com.ddtek.jdbcx.sqlserver.SQLServerDataSource"
        jdbcProviderClassPath = "${CONNECTJDBC_JDBC_DRIVER_PATH}/sqlserver.jar"
        jdbcProviderType = "DataDirect ConnectJDBC type 4 driver for MS SQL Server (XA)"
        environment(cellName,nodeName,serverName,"CONNECTJDBC_JDBC_DRIVER_PATH",JDBC_DRIVER_PATH,"")
        if(scopeString == "CELL"):
           environment(cellName,None,serverName,"CONNECTJDBC_JDBC_DRIVER_PATH",JDBC_DRIVER_PATH,"")
           
           
    jdbcProviderInfo = JdbcProviderInfo(jdbcProviderName, jdbcProviderType, jdbcProviderDesc, jdbcProviderImplClass, jdbcProviderClassPath)
    
    print scope
    print "jdbcProviderInfo Instance :" +jdbcProviderInfo.name
    print "jdbcProviderInfo Instance :" +jdbcProviderInfo.providerType
    print "jdbcProviderInfo Instance :" +jdbcProviderInfo.desc
    print "jdbcProviderInfo Instance :" +jdbcProviderInfo.implClass
    print "jdbcProviderInfo Instance :" +jdbcProviderInfo.driverFile
    print "jdbcProviderInfo :" +Scope.CELL_SCOPE.toString()
    
    # Creates the JDBC Provider.
    if(scopeString =="CELL"):
    	print "Creating Provider at: "+scopeString
        providerConfigId = createJdbcProvider(scope, Scope.CELL_SCOPE, jdbcProviderInfo)
    elif(scopeString =="NODE"):
    	print "Creating Provider at: "+scopeString
        providerConfigId = createJdbcProvider(scope, Scope.NODE_SCOPE, jdbcProviderInfo)
    elif(scopeString =="SERVER"):
    	print "Creating Provider at: "+scopeString
        providerConfigId = createJdbcProvider(scope, Scope.SERVER_SCOPE, jdbcProviderInfo)
    
    AdminConfig.save()
    
def createJDBCAuthAlias(datasourceAuthAliasName,datasourceAuthAliasDesc,datasourceAuthAliasUsername,datasourceAuthAliasPassword):
    datasourceAuthAliasInfo = AuthAliasInfo(datasourceAuthAliasName, datasourceAuthAliasDesc, datasourceAuthAliasUsername, datasourceAuthAliasPassword)
    print "Create " + datasourceAuthAliasInfo.name + " if needed"
    createAuthenticationAlias(datasourceAuthAliasInfo)
    AdminConfig.save()

def createJDBCDatasource(scopeString,cellName,nodeName,serverName,dbType, jdbcProviderName, datasourceAuthAliasName, datasourceName, datasourceDesc, datasourceJndi, datasourceProps, datasourceMaxConnections):
    scope = Scope("clusterName", cellName, nodeName, serverName)
    
    datasourceHelperClassname = None
    if (string.upper(dbType) == S_COMMON_DB_DERBY_EMBEDDED):
        datasourceHelperClassname = "com.ibm.websphere.rsadapter.DerbyDataStoreHelper"
    elif(string.upper(dbType) == S_COMMON_DB_DERBY_NETWORKSERVER):
        datasourceHelperClassname = "com.ibm.websphere.rsadapter.DerbyNetworkServerDataStoreHelper"
    elif(string.upper(dbType) == S_COMMON_DB_DB2 or string.upper(dbType) == S_COMMON_DB_DB2_ZOS_8 or string.upper(dbType) == S_COMMON_DB_DB2_ZOS_9):
        datasourceHelperClassname = "com.ibm.websphere.rsadapter.DB2UniversalDataStoreHelper"
    elif(string.upper(dbType) == S_COMMON_DB_DB2UDBISERIES_TOOLBOX or string.upper(dbType) == S_COMMON_DB_DB2UDBISERIES_NATIVE):
            datasourceHelperClassname = "com.ibm.websphere.rsadapter.DB2AS400DataStoreHelper"
    elif((string.upper(dbType) == S_COMMON_DB_ORACLE_10g) or (string.upper(dbType) == S_COMMON_DB_ORACLE_10g_MONITOR)):
        datasourceHelperClassname = "com.ibm.websphere.rsadapter.Oracle11gDataStoreHelper"
    elif((string.upper(dbType) == S_COMMON_DB_ORACLE_11g) or (string.upper(dbType) == S_COMMON_DB_ORACLE_11g_MONITOR) or (string.upper(dbType) == S_COMMON_DB_ORACLE)):
        datasourceHelperClassname = "com.ibm.websphere.rsadapter.Oracle11gDataStoreHelper"
    elif(string.upper(dbType) == S_COMMON_DB_SQLSERVER_MICROSOFT):
        datasourceHelperClassname = "com.ibm.websphere.rsadapter.MicrosoftSQLServerDataStoreHelper"
    elif(string.upper(dbType) == S_COMMON_DB_SQLSERVER_DATADIRECT):
        datasourceHelperClassname = "com.ibm.websphere.rsadapter.ConnectJDBCDataStoreHelper"
    
    # Get Datasource template for dbType
    if (string.upper(dbType) == "DB2_Universal".upper()):
        templateId = AdminConfig.listTemplates("DataSource", "DB2 Universal JDBC Driver XA")
    
    elif(string.upper(dbType) == "DB2UDBOS390_V9_1".upper() or string.upper(dbType) == "DB2UDBOS390_V8_1".upper() or string.upper(dbType) == "DB2UDBOS390_V7_1".upper()):
        driverType = datasourceProps["driverType"]
        if (string.upper(driverType) == "4"):
            templateId = AdminConfig.listTemplates("DataSource", "DB2 Universal JDBC Driver XA DataSource")
            print "DataSource Template for zSeries using XA"
        else:
            templateId = AdminConfig.listTemplates("DataSource", "DB2 Universal JDBC Driver DataSource")
            print "DataSource Template for zSeries using Connection Pool"
    
    elif(string.upper(dbType) == "DB2UDBISERIES_TOOLBOX".upper()):
        templateId = AdminConfig.listTemplates("DataSource", "DB2 UDB for iSeries (Toolbox XA) DataSource")
             
    elif(string.upper(dbType) == "DB2UDBISERIES_NATIVE".upper()):
        templateId = AdminConfig.listTemplates("DataSource", "DB2 UDB for iSeries (Native XA) DataSource")

    elif(string.upper(dbType) == "DB2_CLI".upper()):
        templateId = AdminConfig.listTemplates("DataSource", "DB2 Legacy CLI-based JDBC Driver XA")

    elif(string.upper(dbType) == "cloudscape".upper()):
        templateId = AdminConfig.listTemplates("DataSource", "Cloudscape JDBC Driver XA")

    elif(string.upper(dbType) == "DERBY_EMBEDDED".upper()):
        templateId = AdminConfig.listTemplates("DataSource", "Derby JDBC Driver XA DataSource(")
    
    elif(string.upper(dbType) == "DERBY_NETWORKSERVER".upper()):
        templateId = AdminConfig.listTemplates("DataSource", "Derby Network Server XA DS using Derby Client(")

    elif((string.upper(dbType) == S_COMMON_DB_ORACLE_10g) or (string.upper(dbType) == S_COMMON_DB_ORACLE_10g_MONITOR) or (string.upper(dbType) == S_COMMON_DB_ORACLE_11g) or (string.upper(dbType) == S_COMMON_DB_ORACLE_11g_MONITOR) or (string.upper(dbType) == S_COMMON_DB_ORACLE)):
        templateId = AdminConfig.listTemplates("DataSource", "Oracle JDBC Driver XA")
        
    elif(string.upper(dbType) == "MSSQLSERVER_Embedded".upper()):
        templateId = AdminConfig.listTemplates("DataSource", "WebSphere embedded ConnectJDBC for SQL Server XA")

    elif(string.upper(dbType) == "MSSQLSERVER_DataDirect".upper()):
        templateId = AdminConfig.listTemplates("DataSource", "DataDirect ConnectJDBC for SQL Server XA")
        
    elif(string.upper(dbType) == "MSSQLSERVER_MICROSOFT".upper()):
        templateId = AdminConfig.listTemplates("DataSource", "Microsoft SQL Server JDBC Driver - XA")
	
    elif(string.upper(dbType) == "sybase".upper()):
        templateId = AdminConfig.listTemplates("DataSource", "Sybase JDBC Driver XA")

    elif(string.upper(dbType) == "informix".upper()):
        templateId = AdminConfig.listTemplates("DataSource", "Informix JDBC Driver XA")
                
    print "templateId: "+templateId
    
    datasourceInfo =  DatasourceInfo(datasourceName, datasourceDesc, datasourceJndi, datasourceHelperClassname, datasourceMaxConnections, datasourceProps, jdbcProviderName, datasourceAuthAliasName, templateId)
    
    # Creates the JDBC datasource.
    if(scopeString =="CELL"):
        datasourceConfigId = createDatasource(scope, Scope.CELL_SCOPE, datasourceInfo)
    elif(scopeString =="NODE"):
        datasourceConfigId = createDatasource(scope, Scope.NODE_SCOPE, datasourceInfo)
    elif(scopeString =="SERVER"):
        datasourceConfigId = createDatasource(scope, Scope.SERVER_SCOPE, datasourceInfo)

    AdminConfig.save()

def getDatasourceProps(dbType, databaseName, datasourceDriverType, datasourceServerName, datasourcePortNumber, datasourceSchemaName):
    #Add custom property for webSphereDefaultIsolationLevel:2 (Cursor Stability (CS))
    datasourceProps = {"webSphereDefaultIsolationLevel":"2"}
    if(string.upper(dbType) == S_COMMON_DB_DERBY_EMBEDDED):
        datasourceProps["databaseName"] = databaseName
    if(string.upper(dbType) == S_COMMON_DB_DERBY_NETWORKSERVER):
        datasourceProps["databaseName"] = databaseName
        datasourceProps["serverName"] = datasourceServerName
        datasourceProps["portNumber"] = datasourcePortNumber
    if(string.upper(dbType) == S_COMMON_DB_DB2):
    	if(datasourceDriverType == "2"):
    		datasourceProps["fullyMaterializeLobData"] = "false"
        datasourceProps["databaseName"] = databaseName
        datasourceProps["driverType"] = datasourceDriverType
        datasourceProps["serverName"] = datasourceServerName
        datasourceProps["portNumber"] = datasourcePortNumber      
    if(string.upper(dbType) == S_COMMON_DB_DB2_ZOS_8 or string.upper(dbType) == S_COMMON_DB_DB2_ZOS_9):
    	if(datasourceDriverType == "2"):
    		datasourceProps["fullyMaterializeLobData"] = "false"
        datasourceProps["databaseName"] = databaseName
        datasourceProps["driverType"] = datasourceDriverType
        datasourceProps["serverName"] = datasourceServerName
        datasourceProps["portNumber"] = datasourcePortNumber
        # datasourceProps["currentSQLID"] = datasourceSchemaName
    if(string.upper(dbType) == S_COMMON_DB_DB2UDBISERIES_NATIVE):
        datasourceProps["databaseName"] = databaseName
        datasourceProps["libraries"] = datasourceSchemaName
    if(string.upper(dbType) == S_COMMON_DB_DB2UDBISERIES_TOOLBOX):
        datasourceProps["databaseName"] = databaseName
        datasourceProps["serverName"] = datasourceServerName
        datasourceProps["libraries"] = datasourceSchemaName                 
    if(string.upper(dbType) == S_COMMON_DB_SQLSERVER_MICROSOFT):
        datasourceProps["databaseName"] = databaseName
        datasourceProps["serverName"] = datasourceServerName
        datasourceProps["portNumber"] = datasourcePortNumber        
    if(string.upper(dbType) == S_COMMON_DB_SQLSERVER_DATADIRECT):
        datasourceProps["databaseName"] = databaseName
        datasourceProps["serverName"] = datasourceServerName
        datasourceProps["portNumber"] = datasourcePortNumber
    if ((string.upper(dbType) == S_COMMON_DB_ORACLE_10g) or (string.upper(dbType) == S_COMMON_DB_ORACLE_10g_MONITOR)  or (string.upper(dbType) == S_COMMON_DB_ORACLE_11g)  or (string.upper(dbType) == S_COMMON_DB_ORACLE_11g_MONITOR)  or (string.upper(dbType) == S_COMMON_DB_ORACLE)):
        #type 2 = OCI, type 4 = thin.  
        if(datasourceDriverType == "2" or ( string.upper(datasourceDriverType) == "ORACLE_OCI") ):
            datasourceProps["URL"] = "jdbc:oracle:oci:@"+datasourceServerName+":"+datasourcePortNumber+":"+databaseName
            datasourceProps["databaseName"] = databaseName
        else:
            datasourceProps["URL"] = "jdbc:oracle:thin:@"+datasourceServerName+":"+datasourcePortNumber+":"+databaseName
            datasourceProps["databaseName"] = databaseName
    return datasourceProps
    
def updateBSpaceWCCM(scopeString,cellName,nodeName,serverName,bspaceSchemaName):
    scope = Scope("clusterName", cellName, nodeName, serverName)
    
    if(scopeString == "SERVER"):
        print "Setting schema in WCCM:"+scopeString
        serverlist = AdminConfig.list('Server').split(lineSeparator)
        for currID in serverlist:
            currName = AdminConfig.showAttribute(currID ,'name')
            if(currName == serverName):
                server = currID
        attrs1 = []
        bspaceconfig = AdminConfig.create('BusinessSpaceConfigurationExtension', server, attrs1)
        schemaAttr = ["schemaName", bspaceSchemaName]
        attrs2 = [schemaAttr]
        bspaceserver = AdminConfig.create('BusinessSpaceServer',  bspaceconfig, attrs2)

    AdminConfig.save()    
    
    

#############################################
#            MAIN METHOD                    #
#############################################
FileName = "jdbcBSpaceUtilsManager.py"

print "entry"
#============================================
# Display usage if input parameters incorrect 
#============================================ 
if (len(sys.argv) < 1):
        print " "
        print "================================================================="
        print "Usage for file: "+FileName
        print ""
        print "Input Parameters: <command> <scopeString> <cellName> <nodeName> <serverName> <dbType> <jdbcProviderName> <jdbcProviderDesc> <jdbcProviderClassPath>"
        print ""
        print "<command> is a command to execute. Valid commands are createJDBCProvider, createJDBCAuthAlias, createJDBCDatasource"
        print "<scopeString> is the string of CELL, NODE or SERVER."
        print "<cellName> is the WebSphere Application Server cell name."
        print "<nodeName> is the WebSphere Application Server node name."
        print "<serverName> is the name of the server in WebSphere Application Server."
        print "<dbType> is the type of databae product."
        print "<jdbcProviderName> is the name of the JDBC provider."
        print "<jdbcProviderDesc> is the description of the JDBC provider."
        print "<jdbcProviderClassPath> is the path of the folder where JDBC driver jars sit."
        print ""
        print "================================================================="
        raise RuntimeError, "Invalid number of parameters."
#endIf 

command = sys.argv[0]

if(command == "createJDBCProvider"):
    print "Run createJDBCProvider command."
    scopeString = sys.argv[1]
    cellName = sys.argv[2]
    nodeName = sys.argv[3]
    serverName = sys.argv[4]
    dbType = sys.argv[5]
    jdbcProviderName = sys.argv[6]
    jdbcProviderDesc = sys.argv[7]
    dbJDBCClasspath = sys.argv[8]
    dbDriverType = sys.argv[9]
    dbDriverVersion = sys.argv[10]
    
    #scopeString = "SERVER"
    #cellName = "WBIDev-BGMNode01Cell"
    #nodeName = "WPSNode"
    #serverName = "server1"
    #jdbcProviderName = "Business Space JDBC Provider"
    
    #DERBY
    #dbType = "derby_embedded"
    #jdbcProviderDesc = "Business Space Derby JDBC Provider (XA)"
    #dbJDBCClasspath = "C:/WASX/derby/lib"
    #DB2
    #dbType = "db2_universal"
    #jdbcProviderDesc = "Business Space DB2 JDBC Provider (XA)"
    #dbJDBCClasspath = "C:\WASX\universalDriver_wbi\lib"
    #oracle
    #dbType = "oracle10g"
    #jdbcProviderDesc = "Business Space Oracle 10g JDBC Provider (XA)"
    #dbJDBCClasspath = "C:\WASX\universalDriver_wbi\lib"
    
    #derby_networkserver
    #dbType = "derby_networkserver"
    #jdbcProviderDesc = "Derby Network Server Using Derby Client (XA)"
    #dbJDBCClasspath = "C:/WASX/derby/lib"
    

    createJDBCProviderComponent(scopeString,cellName,nodeName,serverName,dbType,jdbcProviderName,jdbcProviderDesc,dbJDBCClasspath,dbDriverType,dbDriverVersion)

elif(command == "deleteJDBCProvider"):
    print "Run deleteJDBCProvider command."
    scopeString = sys.argv[1]
    cellName = sys.argv[2]
    nodeName = sys.argv[3]
    serverName = sys.argv[4]
    jdbcProviderName = sys.argv[5]
    
    #scopeString = "SERVER"
    #cellName = "WBIDev-BGMNode01Cell"
    #nodeName = "WPSNode"
    #serverName = "server1"
    #jdbcProviderName = "Business Space JDBC Provider"

    print "Removing Datasource Provider: " + jdbcProviderName
    scope = Scope("clusterName", cellName, nodeName, serverName)

    configId = None
    if(scopeString =="CELL"):
        configId = getJdbcProviderConfigId(scope, Scope.CELL_SCOPE, jdbcProviderName)
    elif(scopeString =="NODE"):
        configId = getJdbcProviderConfigId(scope, Scope.NODE_SCOPE, jdbcProviderName)
    elif(scopeString =="SERVER"):
        configId = getJdbcProviderConfigId(scope, Scope.SERVER_SCOPE, jdbcProviderName)

    if (configId == None):
        print "JDBCProvider not present.  Continuing"
    else:
        AdminConfig.remove(configId)
        print "JDBCProvider removed"
        AdminConfig.save()
            
elif(command == "createJDBCAuthAlias"):
    print "Run createJDBCAuthAlias command."
    datasourceAuthAliasName = sys.argv[1]
    datasourceAuthAliasDesc = sys.argv[2]
    datasourceAuthAliasUsername = sys.argv[3]
    
    f=open(sys.argv[4], 'r')
    line=f.readline()
    f.close()
    f=open(sys.argv[4], 'w')
    f.write('none')
    f.close()
    datasourceAuthAliasPassword = line[5:]

    createJDBCAuthAlias(datasourceAuthAliasName,datasourceAuthAliasDesc,datasourceAuthAliasUsername,datasourceAuthAliasPassword)

elif(command == "deleteJDBCAuthAlias"):
    print "Run deleteJDBCAuthAlias command."
    datasourceAuthAliasName = sys.argv[1]
    print "Removing Authentication Alias: " + datasourceAuthAliasName
    configId = getAuthenticationAliasConfigId(datasourceAuthAliasName)
    if (configId == None):
        print "Authentication Alias not present.  Continuing"
    else:
        AdminConfig.remove(configId)
        print "Authentication Alias removed"
        AdminConfig.save()
        
elif(command == "createJDBCDatasource"):
    print "Run createJDBCDatasource command."
    scopeString = sys.argv[1]
    cellName = sys.argv[2]
    nodeName = sys.argv[3]
    serverName = sys.argv[4]
    dbType = sys.argv[5]
    jdbcProviderName = sys.argv[6]
    datasourceAuthAliasName = sys.argv[7]
    datasourceName = sys.argv[8]
    datasourceDesc = sys.argv[9]
    datasourceJndi = sys.argv[10]
    databaseName = sys.argv[11]
    datasourceDriverType = sys.argv[12]
    datasourceServerName = sys.argv[13]
    datasourcePortNumber = sys.argv[14]
    datasourceMaxConnections = sys.argv[15]
    datasourceSchemaName = sys.argv[16]
    
    datasourceProps = getDatasourceProps(dbType, databaseName, datasourceDriverType, datasourceServerName, datasourcePortNumber, datasourceSchemaName)
    createJDBCDatasource(scopeString,cellName,nodeName,serverName,dbType, jdbcProviderName, datasourceAuthAliasName, datasourceName, datasourceDesc, datasourceJndi, datasourceProps, datasourceMaxConnections)

elif(command == "updateBSpaceWCCM"):
    print "Run updateBSpaceWCCM command."
    scopeString = sys.argv[1]
    cellName = sys.argv[2]
    nodeName = sys.argv[3]
    serverName = sys.argv[4]
    bspaceSchemaName = sys.argv[5]
    updateBSpaceWCCM(scopeString,cellName,nodeName,serverName,bspaceSchemaName)
        
else:
    print "Invalid command:"+command
    
AdminConfig.save()