-- *****************************************************************
--
-- Licensed Materials - Property of IBM
--                                      
-- 5724-U69                             
--                                      
-- Copyright IBM Corp. 2001, 2006  All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
--
-- *****************************************************************

-- Mashup DB2zOSV8 Script for creating tables, keys, indexes

-- *****************************************************************
--
-- SCHEMA VERSION (100)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.VERSION_INFO(
    OID VARCHAR(64)    NOT NULL,
    VERSION_MAJOR   INTEGER,
    VERSION_MINOR   INTEGER,
    VERSION_RELEASE INTEGER,
    VERSION_DEV     INTEGER,
    VERSION_TIME    DECIMAL(19,0),
    DESCRIPTION     VARCHAR(254),
    CONSTRAINT PK100 PRIMARY KEY (OID)
) IN @DB_NAME@.@TSPRE@RTP1
;

CREATE UNIQUE INDEX @SCHEMA@.VERSION_INFO_PK
	ON @SCHEMA@.VERSION_INFO (OID) 
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;

-- *****************************************************************
--
-- CATALOG (300)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.CATALOG (
    OID         VARCHAR(64)       NOT NULL,
    ACCOUNT_OID VARCHAR(1024)     NOT NULL,
    UNIQUE_NAME VARCHAR(255)      NOT NULL,
    CREATED     DECIMAL(19,0)            NOT NULL,
    MODIFIED    DECIMAL(19,0)            NOT NULL,
    STATE       INTEGER DEFAULT 1 NOT NULL,
    CONSTRAINT PK300 PRIMARY KEY (OID)
) IN @DB_NAME@.@TSPRE@RTP1
;

CREATE UNIQUE INDEX @SCHEMA@.CATALOG_PK
	ON @SCHEMA@.CATALOG (OID) 
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;

CREATE TABLE @SCHEMA@.CATALOG_LOD (
    RESOURCE_OID VARCHAR(64)       NOT NULL,
    LOCALE       VARCHAR(64)    NOT NULL,
    TITLE        VARCHAR(255)   NOT NULL,
    DESCRIPTION  VARCHAR(1024)  ,
    CONSTRAINT PK301 PRIMARY KEY (RESOURCE_OID, LOCALE),
    CONSTRAINT FK302 FOREIGN KEY (RESOURCE_OID) REFERENCES
      @SCHEMA@.CATALOG (OID) ON DELETE CASCADE
) IN @DB_NAME@.@TSPRE@RTP1;

CREATE UNIQUE INDEX @SCHEMA@.CATALOG_LOD_PK
	ON @SCHEMA@.CATALOG_LOD (RESOURCE_OID, LOCALE) 
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;

-- *****************************************************************
--
-- CATALOG ENTRY (310)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.CATALOG_ENTRY (
    OID            			VARCHAR(64)        NOT NULL,
    CATALOG_OID    			VARCHAR(64)        NOT NULL,
    CATEGORY_OID   			VARCHAR(64)        NOT NULL,
    DEFINITION_URL 			VARCHAR(2500)      NOT NULL,
    CONTENT_URL    			VARCHAR(2500)      ,
    PREVIEW_URL    			VARCHAR(2500)      ,
    PREVIEW_THUMBNAIL_URL	VARCHAR(2500)      ,
    HELP_URL       			VARCHAR(2500)      ,    
    ICON_URL       			VARCHAR(2500)      ,
    HUB_ENTRY_URL  			VARCHAR(2500)      ,
    DEF_URL_TYPE   			INTEGER            ,
    ICON_URL_TYPE  			INTEGER            ,
    CREATED        			DECIMAL(19,0)             NOT NULL,
    MODIFIED       			DECIMAL(19,0)             NOT NULL,
    STATE          			INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT PK310 PRIMARY KEY (OID)
) IN @DB_NAME@.@TSPRE@RTP1
;

CREATE UNIQUE INDEX @SCHEMA@.CATALOG_ENTRY_PK
	ON @SCHEMA@.CATALOG_ENTRY (OID) 
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;

CREATE TABLE @SCHEMA@.CATALOG_ENTRY_LOD (
    RESOURCE_OID  		VARCHAR(64)    NOT NULL,
    LOCALE        		VARCHAR(64)    NOT NULL,
    TITLE         		VARCHAR(255)   NOT NULL,
    DESCRIPTION   		VARCHAR(1024)  ,
    SHORT_DESCRIPTION   VARCHAR(255)   ,    
    CONSTRAINT PK311 PRIMARY KEY (RESOURCE_OID, LOCALE),
    CONSTRAINT FK311 FOREIGN KEY (RESOURCE_OID) REFERENCES
      @SCHEMA@.CATALOG_ENTRY (OID) ON DELETE CASCADE
) IN @DB_NAME@.@TSPRE@RTP1
;

CREATE UNIQUE INDEX @SCHEMA@.CATALOG_ENTRY_LOD_PK
	ON @SCHEMA@.CATALOG_ENTRY_LOD (RESOURCE_OID, LOCALE) 
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;

CREATE TABLE @SCHEMA@.CATALOG_ENTRY_DD (
    RESOURCE_OID  VARCHAR(64)    NOT NULL,
    NAME          VARCHAR(255)   NOT NULL,
    VALUE         VARCHAR(3000)  NOT NULL,
    CONSTRAINT PK312 PRIMARY KEY (RESOURCE_OID, NAME),
    CONSTRAINT FK312 FOREIGN KEY (RESOURCE_OID) REFERENCES
      @SCHEMA@.CATALOG_ENTRY (OID) ON DELETE CASCADE
) IN @DB_NAME@.@TSPRE@RTP1
;

CREATE UNIQUE INDEX @SCHEMA@.CATALOG_ENTRY_DD_PK
	ON @SCHEMA@.CATALOG_ENTRY_DD (RESOURCE_OID, NAME) 
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;

-- *****************************************************************
--
-- CATALOG CATEGORY (320)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.CATALOG_CATEGORY (
    OID         VARCHAR(64)         NOT NULL,
    CATALOG_OID VARCHAR(64)         NOT NULL,
    NAME        VARCHAR(255)        ,
    CREATED     DECIMAL(19,0)              NOT NULL,
    MODIFIED    DECIMAL(19,0)              NOT NULL,
    STATE       INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT PK320 PRIMARY KEY (OID),
    CONSTRAINT FK320 FOREIGN KEY (CATALOG_OID) REFERENCES
      @SCHEMA@.CATALOG (OID) ON DELETE CASCADE
) IN @DB_NAME@.@TSPRE@RTP1
;

CREATE UNIQUE INDEX @SCHEMA@.CATALOG_CATEGORY_PK
	ON @SCHEMA@.CATALOG_CATEGORY (OID) 
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;

CREATE TABLE @SCHEMA@.CATALOG_CATEGORY_LOD (
    RESOURCE_OID VARCHAR(64)    NOT NULL,
    LOCALE       VARCHAR(64)    NOT NULL,
    TITLE        VARCHAR(255)   NOT NULL,
    DESCRIPTION  VARCHAR(1024)  ,
    CONSTRAINT PK321 PRIMARY KEY (RESOURCE_OID, LOCALE),
    CONSTRAINT FK321 FOREIGN KEY (RESOURCE_OID) REFERENCES
      @SCHEMA@.CATALOG_CATEGORY (OID) ON DELETE CASCADE
) IN @DB_NAME@.@TSPRE@RTP1
;

CREATE UNIQUE INDEX @SCHEMA@.CATALOG_CATEGORY_LOD_PK
	ON @SCHEMA@.CATALOG_CATEGORY_LOD (RESOURCE_OID, LOCALE) 
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;


-- *****************************************************************
--
-- CATALOG CATEGORY INCLUDES (330)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.CATALOG_CATEGORY_INC (
    OID          		VARCHAR(64)       NOT NULL,
    CATALOG_OID  		VARCHAR(64)       NOT NULL,
    CATEGORY_OID 		VARCHAR(64)       NOT NULL,
    INCLUDE_CAT  		VARCHAR(255)  	  NOT NULL,
    INCLUDE_CATEGORY	VARCHAR(255)      NOT NULL,
    CONSTRAINT PK330 PRIMARY KEY (OID)
) IN @DB_NAME@.@TSPRE@RTP1
;

CREATE UNIQUE INDEX @SCHEMA@.CATALOG_CATEGORY_INC_PK
	ON @SCHEMA@.CATALOG_CATEGORY_INC (OID) 
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;

-- *****************************************************************
--
-- CATALOG INCLUDES (340)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.CATALOG_INC (
    OID          		VARCHAR(64)       NOT NULL,
    CATALOG_OID  		VARCHAR(64)       NOT NULL,
    INCLUDE_CAT  		VARCHAR(255)  	  NOT NULL,
    CONSTRAINT PK340 PRIMARY KEY (OID)
) IN @DB_NAME@.@TSPRE@RTP1
;

CREATE UNIQUE INDEX @SCHEMA@.CATALOG_INC_PK
	ON @SCHEMA@.CATALOG_INC (OID) 
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;
	
-- *****************************************************************
--
-- PREFERENCE (400)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.PREFERENCE (
    OID          VARCHAR(64)        NOT NULL,
    UNIQUE_NAME  VARCHAR(255)       NOT NULL,
    PARENT_OID   VARCHAR(64)        NOT NULL,
    TYPE         INTEGER            NOT NULL,
    WDGT_INST_ID VARCHAR(255)       NOT NULL,
    ACCOUNT_ID   VARCHAR(1024)      NOT NULL,
    PAGE_ID      VARCHAR(255)       NOT NULL,
    CREATED      DECIMAL(19,0)             NOT NULL,
    MODIFIED     DECIMAL(19,0)             NOT NULL,
    STATE        INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT PK401 PRIMARY KEY (OID)
) IN @DB_NAME@.@TSPRE@RTP1
;

CREATE UNIQUE INDEX @SCHEMA@.PREFERENCE_PK
	ON @SCHEMA@.PREFERENCE (OID) 
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;

-- *****************************************************************
--
-- PREFERENCE NODE VALUE (410)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.PREFERENCE_VALUE (
    OID           VARCHAR(64)        NOT NULL,
    PREF_OID      VARCHAR(64)        NOT NULL,
    NAME          VARCHAR(255)       NOT NULL,
    READ_ONLY     INTEGER DEFAULT 0  NOT NULL,
    IS_LARGE      INTEGER DEFAULT 0  NOT NULL,
    HAS_LIST      INTEGER DEFAULT 0  NOT NULL,
    VALUE         VARCHAR(1024)      ,
    LARGE_VALUE   CLOB(1M)           ,
    STATE         INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT PK410 PRIMARY KEY (OID),
    CONSTRAINT FK410 FOREIGN KEY (PREF_OID) REFERENCES
      @SCHEMA@.PREFERENCE (OID) ON DELETE CASCADE
) IN @DB_NAME@.@TSPRE@RTP1
;

CREATE UNIQUE INDEX @SCHEMA@.PREFERENCE_VALUE_PK
	ON @SCHEMA@.PREFERENCE_VALUE (OID) 
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;

CREATE AUX TABLE @SCHEMA@.LARGE_VALUE_LOB_A
	IN @DB_NAME@.@TSPRE@LTP1 
	STORES @SCHEMA@.PREFERENCE_VALUE 
	COLUMN LARGE_VALUE;

CREATE INDEX @SCHEMA@.LARGE_VALUE_LOB_I 
	ON @SCHEMA@.LARGE_VALUE_LOB_A 
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;

-- *****************************************************************
--
-- NAVIGATION NODE (500)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.NAVNODE (
    OID            VARCHAR(64)        NOT NULL,
    OWNER_OID      VARCHAR(1024)      NOT NULL,
    THEME_ID       VARCHAR(255)       NOT NULL,
    THEME_NAME     VARCHAR(255)       NOT NULL,
    CONTENT        BLOB(1M)           ,
    BYTE_COUNT     INTEGER            ,
    IS_ZIPPED      INTEGER DEFAULT 0  NOT NULL,
    COMMUNITY_OID  VARCHAR(64)        ,
    SPACE_OID      VARCHAR(64)        ,
    CREATED        DECIMAL(19,0)             NOT NULL,
    MODIFIED       DECIMAL(19,0)             NOT NULL,
    STATE          INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT PK500 PRIMARY KEY (OID, OWNER_OID)
) IN @DB_NAME@.@TSPRE@RTP1
;

CREATE UNIQUE INDEX @SCHEMA@.NAVNODE_PK
	ON @SCHEMA@.NAVNODE (OID, OWNER_OID) 
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;

CREATE AUX TABLE @SCHEMA@.CONTENT_LOB_A
	IN @DB_NAME@.@TSPRE@LTP2 
	STORES @SCHEMA@.NAVNODE 
	COLUMN CONTENT;

CREATE INDEX @SCHEMA@.CONTENT_LOB_I 
	ON @SCHEMA@.CONTENT_LOB_A
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;

CREATE TABLE @SCHEMA@.NAVNODE_LOD (
    RESOURCE_OID  VARCHAR(64)    NOT NULL,
    OWNER_OID     VARCHAR(1024)  NOT NULL,
    LOCALE        VARCHAR(64)    NOT NULL,
    TITLE         VARCHAR(255)   NOT NULL,
    DESCRIPTION   VARCHAR(1024)          ,
    CONSTRAINT FK500 FOREIGN KEY (RESOURCE_OID,OWNER_OID)
      REFERENCES @SCHEMA@.NAVNODE (OID,OWNER_OID) 
      ON DELETE CASCADE
) IN @DB_NAME@.@TSPRE@RTP1
;

CREATE TABLE @SCHEMA@.NAVNODE_DD (
    RESOURCE_OID  VARCHAR(64)    NOT NULL,
    OWNER_OID     VARCHAR(1024)  NOT NULL,
    NAME          VARCHAR(255)   NOT NULL,
    VALUE         VARCHAR(3000)  NOT NULL,
    CONSTRAINT PK502 PRIMARY KEY (RESOURCE_OID,OWNER_OID,NAME),
    CONSTRAINT FK502 FOREIGN KEY (RESOURCE_OID,OWNER_OID)
      REFERENCES @SCHEMA@.NAVNODE (OID,OWNER_OID)
        ON DELETE CASCADE
) IN @DB_NAME@.@TSPRE@RTP1;

CREATE UNIQUE INDEX @SCHEMA@.NAVNODE_DD_PK
	ON @SCHEMA@.NAVNODE_DD (RESOURCE_OID,OWNER_OID,NAME) 
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;


-- *****************************************************************
--
-- NAVIGATION TREE (510)
--
-- *****************************************************************

CREATE TABLE @SCHEMA@.NAV_TREE (
    OWNER_OID    VARCHAR(1024)       NOT NULL,
    PAGE_OID     VARCHAR(64)         NOT NULL,
    PARENT_OID   VARCHAR(64)         NOT NULL,
    ORDINAL      INTEGER  DEFAULT 1  ,
    IS_VIRTUAL   INTEGER  DEFAULT 0  ,
    CONSTRAINT PK510 PRIMARY KEY (OWNER_OID, PAGE_OID)
) IN @DB_NAME@.@TSPRE@RTP1
;

CREATE UNIQUE INDEX @SCHEMA@.NAV_TREE_PK
	ON @SCHEMA@.NAV_TREE (OWNER_OID, PAGE_OID) 
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;

-- *****************************************************************
--
-- ACCESS CONTROL (600)
--
-- *****************************************************************

CREATE TABLE @SCHEMA@.COMMUNITY_DEF (
    OID            VARCHAR(64)        NOT NULL,
    OWNER_UID      VARCHAR(1024)      NOT NULL,
    RESOURCE_OID   VARCHAR(64)        NOT NULL,
    RESOURCE_TYPE  VARCHAR(32)        NOT NULL,
    CREATED        DECIMAL(19,0)             NOT NULL,
    MODIFIED       DECIMAL(19,0)             NOT NULL,
    STATE          INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT PK600 PRIMARY KEY( OID )
) IN @DB_NAME@.@TSPRE@RTP1
;

CREATE UNIQUE INDEX @SCHEMA@.COMMUNITY_DEF_PK
	ON @SCHEMA@.COMMUNITY_DEF (OID) 
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;

-- UNIQUE CONSTRAINT
-- ALTER TABLE @SCHEMA@.COMMUNITY_DEF
-- 	 ADD CONSTRAINT UQ600 UNIQUE (OID,RESOURCE_OID);

CREATE TABLE @SCHEMA@.ACL (
    COMMUNITY_OID     VARCHAR(64)        NOT NULL,
    PARTICIPANT_UID   VARCHAR(1024)      NOT NULL,
    PARTICIPANT_TYPE  INTEGER            NOT NULL,
    PERMISSIONS       VARCHAR(255)       NOT NULL,
    CREATED           DECIMAL(19,0)             NOT NULL,
    MODIFIED          DECIMAL(19,0)             NOT NULL,
    STATE             INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT PK610 PRIMARY KEY (COMMUNITY_OID,PARTICIPANT_UID),
    CONSTRAINT FK611 FOREIGN KEY (COMMUNITY_OID)
      REFERENCES @SCHEMA@.COMMUNITY_DEF (OID)
        ON DELETE CASCADE
) IN @DB_NAME@.@TSPRE@RTP1
;

CREATE UNIQUE INDEX @SCHEMA@.ACL_PK
	ON @SCHEMA@.ACL (COMMUNITY_OID,PARTICIPANT_UID) 
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;

-- *****************************************************************
--
-- SPACES (700)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.SPACENODE (
    OID            VARCHAR(64)        NOT NULL,
    OWNER_OID      VARCHAR(1024)      NOT NULL,
    ROOTNAV_OID    VARCHAR(64)        ,
    TEMPLATE_OID   VARCHAR(64)        ,
    CREATED        DECIMAL(19,0)             NOT NULL,
    MODIFIED       DECIMAL(19,0)             NOT NULL,
    STATE          INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT PK700 PRIMARY KEY (OID, OWNER_OID)
)  IN @DB_NAME@.@TSPRE@RTP1
;

CREATE UNIQUE INDEX @SCHEMA@.SPACENODE_PK
	ON @SCHEMA@.SPACENODE (OID, OWNER_OID) 
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;

CREATE TABLE @SCHEMA@.SPACENODE_LOD (
    RESOURCE_OID  VARCHAR(64)    NOT NULL,
    OWNER_OID     VARCHAR(1024)  NOT NULL,
    LOCALE        VARCHAR(64)    NOT NULL,
    TITLE         VARCHAR(255)   NOT NULL,
    DESCRIPTION   VARCHAR(1024)          ,
    CONSTRAINT PK701 PRIMARY KEY (RESOURCE_OID,OWNER_OID,LOCALE),
    CONSTRAINT FK701 FOREIGN KEY (RESOURCE_OID,OWNER_OID)
      REFERENCES @SCHEMA@.SPACENODE (OID,OWNER_OID)
        ON DELETE CASCADE
)  IN @DB_NAME@.@TSPRE@RTP1
;

CREATE UNIQUE INDEX @SCHEMA@.SPACENODE_LOD_PK
	ON @SCHEMA@.SPACENODE_LOD (RESOURCE_OID,OWNER_OID,LOCALE) 
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;

CREATE TABLE @SCHEMA@.SPACENODE_DD (
    RESOURCE_OID  VARCHAR(64)    NOT NULL,
    OWNER_OID     VARCHAR(1024)  NOT NULL,
    NAME          VARCHAR(255)   NOT NULL,
    VALUE         VARCHAR(3000)  NOT NULL,
    CONSTRAINT PK702 PRIMARY KEY (RESOURCE_OID,OWNER_OID,NAME),
    CONSTRAINT FK702 FOREIGN KEY (RESOURCE_OID,OWNER_OID)
      REFERENCES @SCHEMA@.SPACENODE (OID,OWNER_OID)
        ON DELETE CASCADE
)  IN @DB_NAME@.@TSPRE@RTP1
;

CREATE UNIQUE INDEX @SCHEMA@.SPACENODE_DD_PK
	ON @SCHEMA@.SPACENODE_DD (RESOURCE_OID,OWNER_OID,NAME) 
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;


-- *****************************************************************
--
-- TEMPLATES (800)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.TEMPLATENODE (
    OID            VARCHAR(64)        NOT NULL,
    OWNER_OID      VARCHAR(1024)      ,
    CONTENT        BLOB(1M)           ,
    BYTE_COUNT     INTEGER            ,
    TEMPLATE_TYPE  VARCHAR(64)        ,
    CREATED        DECIMAL(19,0)             NOT NULL,
    MODIFIED       DECIMAL(19,0)             NOT NULL,
    STATE          INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT PK800 PRIMARY KEY (OID)
)  IN @DB_NAME@.@TSPRE@RTP1
;

CREATE UNIQUE INDEX @SCHEMA@.TEMPLATENODE_PK
	ON @SCHEMA@.TEMPLATENODE (OID) 
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;

CREATE AUX TABLE @SCHEMA@.CONTENT_LOB_B
	IN @DB_NAME@.@TSPRE@LTP4 
	STORES @SCHEMA@.TEMPLATENODE 
	COLUMN CONTENT;

CREATE INDEX @SCHEMA@.CONTENT_LOB_J 
	ON @SCHEMA@.CONTENT_LOB_B
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;

CREATE TABLE @SCHEMA@.TEMPLATENODE_LOD (
    RESOURCE_OID  VARCHAR(64)    NOT NULL,
    LOCALE        VARCHAR(64)    NOT NULL,
    TITLE         VARCHAR(255)   NOT NULL,
    DESCRIPTION   VARCHAR(1024)          ,
    CONSTRAINT PK801 PRIMARY KEY (RESOURCE_OID,LOCALE),
    CONSTRAINT FK801 FOREIGN KEY (RESOURCE_OID)
      REFERENCES @SCHEMA@.TEMPLATENODE (OID)
        ON DELETE CASCADE
)  IN @DB_NAME@.@TSPRE@RTP1
;

CREATE UNIQUE INDEX @SCHEMA@.TEMPLATENODE_LOD_PK
	ON @SCHEMA@.TEMPLATENODE_LOD (RESOURCE_OID,LOCALE) 
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;


-- *****************************************************************
--
-- ACCESS CONTROL RESOURCES (900)
--
-- *****************************************************************

CREATE TABLE @SCHEMA@.AC_RESOURCE (
    OID            VARCHAR(64)        NOT NULL,
    OWNER_UID      VARCHAR(1024)      NOT NULL,
    RESOURCE_OID   VARCHAR(64)        NOT NULL,
    RESOURCE_TYPE  VARCHAR(32)        NOT NULL,
    ROLE_BLOCKS    VARCHAR(1024)              ,
    CREATED        DECIMAL(19,0)             NOT NULL,
    MODIFIED       DECIMAL(19,0)             NOT NULL,
    STATE          INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT PK900 PRIMARY KEY( RESOURCE_OID )
) IN @DB_NAME@.@TSPRE@RTP1;

CREATE UNIQUE INDEX @SCHEMA@.AC_RESOURCE_PK
	ON @SCHEMA@.AC_RESOURCE (RESOURCE_OID) 
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;

CREATE TABLE @SCHEMA@.AC_ROLE (
    AC_RESOURCE_OID   VARCHAR(64)        NOT NULL,
    ROLE_OID          VARCHAR(64)        NOT NULL,
    ROLE_NAME         VARCHAR(1024)      NOT NULL,
    ROLE_TYPE         VARCHAR(1024)              ,
    CREATED        DECIMAL(19,0)             NOT NULL,
    MODIFIED       DECIMAL(19,0)             NOT NULL,
    STATE          INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT PK910 PRIMARY KEY( ROLE_OID ),
    CONSTRAINT FK911 FOREIGN KEY (AC_RESOURCE_OID)
      REFERENCES @SCHEMA@.AC_RESOURCE (RESOURCE_OID)
        ON DELETE CASCADE
) IN @DB_NAME@.@TSPRE@RTP1;

CREATE UNIQUE INDEX @SCHEMA@.AC_ROLE_PK
	ON @SCHEMA@.AC_ROLE (ROLE_OID) 
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;

CREATE TABLE @SCHEMA@.AC_MEMBER (
    ROLE_OID          VARCHAR(64)        NOT NULL,
    MEMBER_UID        VARCHAR(1024)      NOT NULL,
    MEMBER_TYPE       DECIMAL(19,0)            NOT NULL,
    CONSTRAINT PK920 PRIMARY KEY (ROLE_OID,MEMBER_UID),
    CONSTRAINT FK921 FOREIGN KEY (ROLE_OID)
      REFERENCES @SCHEMA@.AC_ROLE (ROLE_OID)
        ON DELETE CASCADE
) IN @DB_NAME@.@TSPRE@RTP1;

CREATE UNIQUE INDEX @SCHEMA@.AC_MEMBER_PK
	ON @SCHEMA@.AC_MEMBER (ROLE_OID,MEMBER_UID) 
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;

CREATE TABLE @SCHEMA@.FILESTORE_PATH (
    OID         VARCHAR(64)           NOT NULL,
    PARENT_OID  VARCHAR(64)           NOT NULL,
    NAME        VARCHAR(255)          NOT NULL,
    PATH        VARCHAR(255)          NOT NULL,
    LOCKED      VARCHAR(64)           , 
    OWNER       VARCHAR(64)           ,             
    CREATED     DECIMAL(19,0)                NOT NULL,
    MODIFIED    DECIMAL(19,0)                NOT NULL,
    COLL_TYPE   DECIMAL(19,0) DEFAULT 1     NOT NULL,
    CONSTRAINT PK1010 PRIMARY KEY (OID)
) IN @DB_NAME@.@TSPRE@RTP1;

CREATE UNIQUE INDEX @SCHEMA@.FILESTORE_PATH_PK
	ON @SCHEMA@.FILESTORE_PATH (OID) 
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;

CREATE TABLE @SCHEMA@.FILESTORE_FILE (
    OID         VARCHAR(64)           NOT NULL,           
    F_SIZE      DECIMAL(19,0)               NOT NULL,
    CONTENT        BLOB(1G)           ,
    CONSTRAINT PK1000 PRIMARY KEY (OID),
    CONSTRAINT FK1001 FOREIGN KEY (OID)
      REFERENCES @SCHEMA@.FILESTORE_PATH (OID)
        ON DELETE CASCADE
) IN @DB_NAME@.@TSPRE@RTP1;

CREATE UNIQUE INDEX @SCHEMA@.FILESTORE_FILE_PK
	ON @SCHEMA@.FILESTORE_FILE (OID) 
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;

CREATE AUX TABLE @SCHEMA@.CONTENT_LOB_C
	IN @DB_NAME@.@TSPRE@LTP3 
	STORES @SCHEMA@.FILESTORE_FILE 
	COLUMN CONTENT;

CREATE INDEX @SCHEMA@.CONTENT_LOB_K 
	ON @SCHEMA@.CONTENT_LOB_C
	USING STOGROUP @STOGRP@
	BUFFERPOOL @BPINDEX@;

--*****************************************************************
--
-- Indexing
--
--*****************************************************************
-- Catalog
CREATE INDEX @SCHEMA@.CATACCT      ON 
  @SCHEMA@.CATALOG(ACCOUNT_OID) 
    USING STOGROUP @STOGRP@
    BUFFERPOOL @BPINDEX@;
CREATE INDEX @SCHEMA@.ENTRYCATGOID ON 
  @SCHEMA@.CATALOG_ENTRY(CATALOG_OID, CATEGORY_OID) 
    USING STOGROUP @STOGRP@
    BUFFERPOOL @BPINDEX@;
CREATE INDEX @SCHEMA@.CATGCATOID   ON 
  @SCHEMA@.CATALOG_CATEGORY(CATALOG_OID) 
    USING STOGROUP @STOGRP@
    BUFFERPOOL @BPINDEX@;
CREATE INDEX @SCHEMA@.CATINTCATOID ON 
  @SCHEMA@.CATALOG_INC(CATALOG_OID) 
    USING STOGROUP @STOGRP@
    BUFFERPOOL @BPINDEX@;

-- Preferences
CREATE INDEX @SCHEMA@.PREFPARENT ON 
  @SCHEMA@.PREFERENCE(PARENT_OID,ACCOUNT_ID) 
    USING STOGROUP @STOGRP@
    BUFFERPOOL @BPINDEX@;
CREATE INDEX @SCHEMA@.PREFTYPE   ON 
  @SCHEMA@.PREFERENCE(TYPE) 
    USING STOGROUP @STOGRP@
    BUFFERPOOL @BPINDEX@;

-- Navigation
CREATE INDEX @SCHEMA@.PAGECOMM     ON 
  @SCHEMA@.NAVNODE(COMMUNITY_OID) 
    USING STOGROUP @STOGRP@
    BUFFERPOOL @BPINDEX@;
CREATE INDEX @SCHEMA@.PAGELODOWNRS ON 
  @SCHEMA@.NAVNODE_LOD(OWNER_OID,RESOURCE_OID) 
    USING STOGROUP @STOGRP@
    BUFFERPOOL @BPINDEX@;
CREATE INDEX @SCHEMA@.TREEOWPAR    ON 
  @SCHEMA@.NAV_TREE(OWNER_OID,PARENT_OID) 
    USING STOGROUP @STOGRP@
    BUFFERPOOL @BPINDEX@;

-- Acl
CREATE INDEX @SCHEMA@.COMMOWNPAR ON 
  @SCHEMA@.COMMUNITY_DEF(OWNER_UID) 
    USING STOGROUP @STOGRP@
    BUFFERPOOL @BPINDEX@;
CREATE INDEX @SCHEMA@.PRTTYUID   ON 
  @SCHEMA@.ACL(PARTICIPANT_TYPE,PARTICIPANT_UID) 
    USING STOGROUP @STOGRP@
    BUFFERPOOL @BPINDEX@;
CREATE INDEX @SCHEMA@.PRTUID     ON 
  @SCHEMA@.ACL(PARTICIPANT_UID) 
    USING STOGROUP @STOGRP@
    BUFFERPOOL @BPINDEX@;

-- AC
CREATE INDEX @SCHEMA@.AC_ROLE_RESOURCE ON 
  @SCHEMA@.AC_ROLE(AC_RESOURCE_OID) 
    USING STOGROUP @STOGRP@
    BUFFERPOOL @BPINDEX@;
CREATE INDEX @SCHEMA@.AC_MEMBER_UID ON 
  @SCHEMA@.AC_MEMBER(MEMBER_UID) 
    USING STOGROUP @STOGRP@
    BUFFERPOOL @BPINDEX@;
CREATE INDEX @SCHEMA@.AC_RESOURCE_OWNER ON 
  @SCHEMA@.AC_RESOURCE(OWNER_UID,RESOURCE_OID) 
    USING STOGROUP @STOGRP@
    BUFFERPOOL @BPINDEX@;

--*****************************************************************
--
-- Initialization
--
--*****************************************************************
-- Schema version (leave this here to faciliate version checking)

INSERT INTO @SCHEMA@.VERSION_INFO 
(OID,VERSION_MAJOR,VERSION_MINOR,VERSION_RELEASE,
VERSION_DEV,VERSION_TIME,DESCRIPTION)
VALUES ('458202233263219661970198300000000000',
1,0,0,13,0,'Initialization from install script');

  
