/* Copyright IBM Corp. 2010  All Rights Reserved.                    */
dojo.require("com.ibm.mm.builder.iwidget.wiringscreen.AutoWiringNotification");
dojo.require("com.ibm.mm.builder.iwidget.wiringscreen.AutoWiringDisabledTip");
dojo.require("com.ibm.mm.builder.iwidget.wiringscreen.WiringCanvas");
dojo.require("com.ibm.mm.builder.utils.userUtil");

dojo.declare("com.ibm.mm.builder.systemwidget.autoWiringManager", null, {
	
	disabledTip: null,
	
	hwcBtnPos:null,
	
	displaySuccessNotification: false,
	
    onLoad: function(){
		var widgetCtx=this.iContext;
		this.LOGGER = com.ibm.mashups.enabler.logging.Logger.getLogger("com.ibm.mm.builder.systemwidget.autoWiringManager");
    },
	
	onWireInterfaceDisplay:function(iEvent){
    	var widgetId = iEvent.payload;
		if(!widgetId || widgetId == "")
			return;
		
		var currentPage = com.ibm.mashups.builder.model.Factory.getRuntimeModel().getCurrentPage();
		var isAWEnabled = currentPage.getAutoWiringEnablement();
		if(isAWEnabled)
			return;
	},
	
	autoWiringWidget:function(iEvent){
		var widgetId = iEvent.payload;
		if(!widgetId || widgetId == "")
			return;
		
		var currentPage = com.ibm.mashups.builder.model.Factory.getRuntimeModel().getCurrentPage();
		var isAWEnabled = currentPage.getAutoWiringEnablement();
		if(isAWEnabled) {	
			var autoWiringResult = com.ibm.mm.builder.utils.wireUtil.setupAutoWiring(widgetId);
			this.initAutoWiringSettings();
			if(autoWiringResult.hasAutoWire && this.displaySuccessNotification) {
				var location = this.getDialogLocation(widgetId);
				var notiDlg = new com.ibm.mm.builder.iwidget.wiringscreen.AutoWiringNotification();
				notiDlg.showAutoWiringResult(widgetId,autoWiringResult,location);
			}
		}
		
	},
	
	onQuickWireCreate:function(iEvent) {
		var wireInfo = iEvent.payload;
		/*
    	 * The payload passed by should be a JSON object like
    	 * {
    	 *     sourceWidgetId: id of the widget which is dropped onto another widget
    	 *     targetWidgetId: id of the widget  which another widget is dropped on
    	 * }
    	 */
		var sourceId = wireInfo.sourceWidgetId;
		var targetId = wireInfo.targetWidgetId;
		if(sourceId && targetId) {
			var widgetUtil = com.ibm.mm.builder.utils.iwidgetUtil;
			var sourceTitle = widgetUtil.getWidgetInstanceTitle(sourceId) || com.ibm.mm.builder.utils.toolboxUtil.getWidgetDefinition(sourceId);
			var targetTitle = widgetUtil.getWidgetInstanceTitle(targetId);
			
			if(com.ibm.mm.builder.utils.wireUtil.isWidgetCompatible(sourceId,targetId)) {
				var sourceEvent = com.ibm.mashups.iwidget.model.Factory.getGlobalWidgetModel().find(sourceId).getWidgetPublishedEvents()[0].name;
				var targetEvent = com.ibm.mashups.iwidget.model.Factory.getGlobalWidgetModel().find(targetId).getWidgetHandledEvents()[0].name;
				var wireInfo = {
					"sourceWidgetId": sourceId,
					"sourceEvent": sourceEvent,
					"targetWidgetId": targetId,
					"targetEvent": targetEvent
				};
				com.ibm.mashups.services.ServiceManager.getService("eventService").broadcastEvent("com.ibm.mashups.builder.addNewWire", wireInfo);
				com.ibm.mashups.services.ServiceManager.getService("eventService").broadcastEvent("com.ibm.mashups.builder.quickWireCreated", {"sourceWidgetId":sourceId,"targetWidgetId":targetId});
			}else {
				var editBar = dijit.byId(sourceId + com.ibm.mm.builder.constant.editbarDragHandler);
				editBar && editBar.hide();
				
				var widgetUtil = com.ibm.mm.builder.utils.iwidgetUtil;
				var widgetIcon =widgetUtil.getWidgetInstanceIcon(sourceId);
				var dialogParam = {
					nodeWidth: "486px",
					title: com.ibm.mm.builder.coreWidgetsStrings.I_WIRING_NAME,
					titleIconUrl: widgetIcon,
					leftBarWidth: "18px",
					rightBarWidth: "12px",
					displayCloseButton: true,
					hasRightBottomResizer: false
				}
				var payload = {
			    	widgetTypeId: "wireInterface",
			        eventName:  "com.ibm.mashups.builder.editWire",
			        eventPayload:  sourceId,
			        dialogParam:  dialogParam,
			        requestRefresh: true
				};
				com.ibm.mashups.services.ServiceManager.getService("eventService").broadcastEvent("com.ibm.mashups.builder.displayInMashupDialog", payload);
				this.LOGGER.info("onAutoWireCreate",dojo.string.substitute(com.ibm.mm.builder.coreWidgetsMessages.I_NO_AUTO_WIRING_2, [sourceTitle, targetTitle]));
			}
		}
	},
	
	initAutoWiringSettings:function(){
		var user = com.ibm.mm.builder.utils.userUtil.getCurrentUser();
		var lookaside = com.ibm.mm.builder.utils.userUtil.isLookasideEnabled("com.ibm.mashups.user.AUTO_WIRE_ENABLED_NOTIFICATIONS");
		if (!lookaside) { //lookaside is disabled
			this.displaySuccessNotification = false;
		}
		else {
			var v1 = user.getAttribute("com.ibm.mashups.user.AUTO_WIRE_ENABLED_NOTIFICATIONS");
			this.displaySuccessNotification = eval(v1);
		}
	},
	
	onHWCPositionPublished:function(iEvent){
		this.hwcBtnPos = iEvent.payload;
	},
	
	getDialogLocation:function(widgetId){
		var widgetSpan = dojo.byId(widgetId);
		if(!widgetSpan)
			return;
		
		var x = 0;
		var y = 0;
		var inNVA = false;
		
		var skinId = widgetSpan.getAttribute(com.ibm.mm.builder.constant.widget_span_attr_skin);
		var nvaSkin = com.ibm.mm.builder.utils.skinUtil.getNVANode();
		if(nvaSkin.getID() == skinId) {
			x = 100;
			y = 115;
			inNVA = true;
		}
		else {
			var coords = dojo.coords(widgetSpan);
			x = coords.x + 15;
			y = coords.y + 15;
		}
		var location = {
				x:x,
				y:y,
				inNVA:inNVA
		}
		return location;
	},
    
	onWireGraphDisplay:function(iEvent){
		var widgetId = iEvent.payload;
		this.displayWireGraph(widgetId,true);
	},
	
	/**
	 * Display the wire graph according to the widget id
	 */
	displayWireGraph:function(widgetId,alone){
		var existingCanvas = dijit.byId(widgetId + "_wiringCanvas");
		existingCanvas && existingCanvas.destroy();
		
		this.wiringCanvas = new com.ibm.mm.builder.iwidget.wiringscreen.WiringCanvas({
			id: widgetId + "_wiringCanvas",
			selectedWidgetId: widgetId,
			alone: alone,
			iContext: this.iContext
		});
		this.wiringCanvas.showGraph();
	},
	
	onUnload:function(){
		if (this.wiringCanvas) {
			this.wiringCanvas.destroy();
			this.wiringCanvas = null;
		}
	}
});
