dojo.provide("com.ibm.mm.builder.systemwidget.Navigation");
dojo.require("com.ibm.mm.builder.navigationHelper");
dojo.require("dojo.dnd.Source");
dojo.require("dijit.form.ValidationTextBox");
dojo.require("com.ibm.dnd.PageCreator");
dojo.require("com.ibm.widgets.NavigationWidget");
dojo.require("com.ibm.widgets.NewPageDialog");
dojo.require("dojo.i18n");
dojo.require("com.ibm.domUtilities");
dojo.requireLocalization("com.ibm.bundles", "NavWidget");
dojo.requireLocalization("com.ibm.mm.builder", "coreWidgetsMessages");

dojo.declare("com.ibm.mm.builder.systemwidget.Navigation", null, {
	
	globalPageOpened:null,
	isSwitching:false,
	globalPageLoaded:false,
	openGlobalPageAgain:false,

	onLoad: function(){
		// required to initialize models if not already loaded
		if(!com.ibm.mm.builder.navigationHelper.loaded)	com.ibm.mm.builder.navigationHelper.init();
		
		this.navigationUtil = com.ibm.mm.builder.utils.navigationUtil;
		this.pageUtil = com.ibm.mm.builder.utils.pageUtil;
		this.themeUtil = com.ibm.mm.builder.utils.themeUtil;
		this.spaceUtil = com.ibm.mm.builder.utils.spaceUtil;
		this.navigationModel = this.navigationUtil.getNavigationModel();	
		
		com.ibm.mashups.iwidget.services.ServiceManager.getService("eventService")
			.subscribeEvent("com.ibm.mashups.enabler.model.state.onNavStateUpdated", this, function(){
				var cid = this.pageUtil.getCurrentPageId();
				var newId = this.pageUtil.getPageIdFromSpace();
				if (cid !== newId && !this.isSwitching && (!this.globalPageLoaded || this.openGlobalPageAgain)) {
					if (this.openGlobalPageAgain) {this.openGlobalPageAgain=false;}
					this.onSwitchPage({payload: newId});
				}					
			});
		
		this._initNavigation();
		
		this.LOGGER = com.ibm.mashups.enabler.logging.Logger.getLogger("com.ibm.mm.builder.systemwidget.Navigation");
	},
	_initNavigation: function(){
		this.startTabLevel = parseInt(this.iContext.getiWidgetAttributes().getItemValue('startLevel'));
		var bundle = dojo.i18n.getLocalization("com.ibm.bundles", "NavWidget");
		var currentPageNode = this.pageUtil.getCurrentPageNode();
		
		this.tabNavigation = new com.ibm.widgets.NavigationWidget({
			model: com.ibm.mm.builder.navigationHelper.getTreeModel(),
			item: currentPageNode,
			openDelay: 0,
			selectionModel: com.ibm.mm.builder.navigationHelper.getSelectionModel(),
			tiedToSelection: true,
			level: this.startTabLevel,
			closeDelay: 500,
			popupDelay: 0,
			dndEnabled: this.pageUtil.canEdit(currentPageNode),
			dndType: "cmNode",
			dndAccept: "cmNode",
			dndCreator: com.ibm.dnd.PAGE_CREATOR.creator,
			showInlineEditor: !com.ibm.mm.builder.utils.userUtil.isLockedDownAnonymousMode() && (this.spaceUtil.canEdit(this.spaceUtil.getCurrentSpaceNode()) || this.spaceUtil.isPersonalSpace()),
			inlineEditorLabel: bundle["nav_new_page_label"],
			inlineEditorDefaultValue: bundle["nav_new_page_default_value"],
			nestedInlineEditorLabel: bundle["nav_new_page_nested_label"],
			emptyContentsInlineEditorLabel: bundle["nav_new_page_empty_nested_label"],
			inlineEditorTitle: bundle["nav_new_page_title"],
			embeddedEditorPopup: "com.ibm.widgets.NewPageDialog",
			embeddedEditorPopupParams: {
				showMakePrivate: false,
				showFriendlyURL: false,
				blankImg: ibmConfig.themeBasePath + "css/images/blank.gif"
			},
			baseClass: "",
			tabListClass: "lotusTabs",
			tabClass: "",
			selectedClass: "lotusSelected",
			setupInlineEditor: function() {
                // SHESMER - This is not allowed. Please ping me
				if(this.item.hasRole("Privileged User") || 
					this.item.hasRole("Editor")) {
					this.inherited("setupInlineEditor", arguments);
				}
			},
			onModelItemClick: function(widget, item) {
				var cb = dojo.hitch(this, function(){
					var es = com.ibm.mashups.iwidget.services.ServiceManager.getService("eventService");
					es.broadcastEvent("com.ibm.mashups.builder.switchPage", this.model.getIdentity(item));
				});
				com.ibm.mm.builder.utils.pageUtil.savePageWithConfirm(cb);
			}
	
		}, "navigationContainer");
		this.tabNavigation.startup();
		com.ibm.mm.builder.TabbedNavigationDelegate = this;
	},
		
	onSwitchPage:function(iEvent){
		this.tabNavigation.disableDnd();
		// global page check
		if (this.globalPageLoaded && iEvent.payload && com.ibm.mm.builder.utils.spaceUtil.getSpaceIdByPageId(iEvent.payload)!=this.globalPageLoadedSpaceId){
			//switch to a page with global page opened, and the target space is not current space");
			if (iEvent.payload != this.globalPageOpened){
				//to clear global page
				this.onClearGlobalPage();
			}else{
				//we should never enter here, because the global page is a hidden page, user can't navigate to it.
				//just go ahead and open the global page
			}
		}
		// end check
		var cb = dojo.hitch(this, function(){
			this.isSwitching = true;
			try{
				this.tabNavigation.level = com.ibm.mm.builder.utils.spaceUtil.getCurrentSpaceId() ? this.startTabLevel+1 : this.startTabLevel;
				this.pageUtil.updatePageTitle();
				this.refresh(iEvent.payload, true);
			}catch(e){
				var msg = dojo.string.substitute(com.ibm.mm.builder.coreWidgetsMessages.E_NAV_PANE_POSTCREATE_1,[e.message]);
				this.LOGGER.severe("onSwitchPage",msg);
			}
			this.isSwitching = false;
			this.handleOnSwitchPage(iEvent);
		});
		
		com.ibm.mm.builder.utils.pageUtil.savePageWithConfirm(cb);	
	},
	
	//callback to extend onSwitchPage method
	handleOnSwitchPage: function(iEvent){
		
	},
	
	onRefreshNavigation:function(iEvent){
		try{
			this.refresh(iEvent.payload);
		}catch(e){
			var msg = dojo.string.substitute(com.ibm.mm.builder.coreWidgetsMessages.E_NAV_REFRESH_NAVIGATION_1,[e.message]);
			this.LOGGER.severe("onRefreshNavigation",msg);
		}
	},
	refresh: function(pid, isPageSwitch){
		// global page check
		if ((pid!=null) && (pid===this.globalPageOpened) && (com.ibm.mm.builder.utils.spaceUtil.getCurrentSpaceId()===this.globalPageLoadedSpaceId)) {
			var node = this.navigationModel.find(pid).start();
			this.tabNavigation.selectionModel.changeSelection(node);
			this.tabNavigation.reload();
			if (this.pageUtil.canEdit(node)) this.tabNavigation.setupDnd();
			if(isPageSwitch){
				//Here we do not change the nav state, need more unit test about this change.
				this.pageUtil.setPageId(pid);
				com.ibm.mashups.builder.model.Factory.getRuntimeModel().getCurrentPage().setID(pid);
				com.ibm.mashups.iwidget.services.ServiceManager.getService("eventService").broadcastEvent("com.ibm.mashups.builder.pageSwitched", pid);
			}
			this.globalPageLoaded = true;
			// end global page check
		}else{
			var currentPageIDBeforeRefresh = this.pageUtil.getCurrentPageId();
			//build models and render
			var isNavCreated = this._isNavigationCreated(pid);
			var locationBeforeRefresh = location.href;
			if (isNavCreated){
				//reload theme if the page has new theme
				if (this.themeUtil.getThemeId() != this.themeUtil.getCurrentThemeId()) {
					var cpid = this.pageUtil.getCurrentPageId();
					this.pageUtil.setPageId(cpid);
					var redirectAddress = this.navigationUtil.getRedirectAddress();
					setTimeout(function(){
						//if only pid is changed, reload the page.
						if(redirectAddress === locationBeforeRefresh.replace(/pid=([^&]*)/, "pid=" + cpid)){
							location.reload();
						}else{
							location.href = redirectAddress;
						}
					}, 10)
					return;
				}
				
				//if there is no page before refresh and new page is added, switch to new page
				if(!currentPageIDBeforeRefresh){
					isPageSwitch = true;
				}
			}else{
				if (this.themeUtil.getCurrentSpaceThemeId() != this.themeUtil.getCurrentThemeId()) {
					this.pageUtil.setPageId();
					setTimeout(function(){
						window.location.reload();
					}, 10)
					return;
				}
			}

			if(pid == null){
				pid = com.ibm.mashups.builder.model.Factory.getRuntimeModel().getCurrentPage().getID();
				if(!pid){
					var spaceId = this.spaceUtil.getCurrentSpaceId();
					pid = spaceId ? this.pageUtil.getFirstPageInSpace(spaceId) : this.pageUtil.getFirstRootPageId();
				}
			}
			
			// the nav must be reloaded on every refresh because deleting 
			// a page is handled the same as switching the page.  Since there
			// is no way to tell whether a page has been deleted we must
			// reload the nav to make sure the page is removed from the markup.
			// This will be fixed once Mashups created a deletePage iEvent.

			if(pid != null){
				var node = this.navigationModel.find(pid).start();
				com.ibm.mm.builder.navigationHelper.getSelectionModel().changeSelection(node);
				this.tabNavigation.showInlineEditor =  this.spaceUtil.canEdit(this.spaceUtil.getCurrentSpaceNode());	
				this.tabNavigation.reload();
			}else{
				this.tabNavigation.selectionModel.selectionPath = [this.spaceUtil.getCurrentSpaceNode(), this.navigationUtil.getNavigationRootNode()];
				var item = this.spaceUtil.getCurrentSpaceNode();
				this.tabNavigation.item = item;
				this.tabNavigation.reload();
			}
			if(isPageSwitch){
				com.ibm.mashups.builder.model.Factory.getRuntimeModel().getCurrentPage().setDirty(false);
				this.pageUtil.setPageId(pid);
				com.ibm.mashups.iwidget.services.ServiceManager.getService("eventService").broadcastEvent("com.ibm.mashups.builder.pageSwitched", pid);
			}	
		}
		if (this.pageUtil.canEdit(node)) this.tabNavigation.setupDnd();		
	},
	_isNavigationCreated: function(pid){
		//if parameter pid is null, used current page id;
		//if current page is null, try to find first page under root
		var isCreated = false;
		var currentPage = com.ibm.mashups.builder.model.Factory.getRuntimeModel().getCurrentPage();
		pid = pid || currentPage.getID();
		if(!pid){
			var spaceId = this.spaceUtil.getCurrentSpaceId();
			pid = spaceId ? this.pageUtil.getFirstPageInSpace(spaceId) : this.pageUtil.getFirstRootPageId();
		}
		//if current page still is null, this means no page exists.
		if(!pid) { return null; }
		
		//update current page id and space id
		currentPage.setID(pid);
		var spaceId = this.spaceUtil.getSpaceIdByPageId(pid);
		if (spaceId !== this.spaceUtil.getCurrentSpaceId()) {
			this.spaceUtil.setSpaceId(spaceId);
		}
		//try to build model array
		var menuModelArrays = [];
		var navModel = this.navigationUtil.getNavigationModel();
		var currentModel = navModel.find(pid).start();
		var rootId = this.navigationUtil.getNavigationRootNodeId();
		var currentSpaceRootId = this.navigationUtil.getNavigationRootNodeId(this.spaceUtil.getCurrentSpaceId());
		//Loop to root to build the menuModelArrays array that holds all the models of the item that need to be rendered
		while(currentModel && currentModel.getID() !== rootId && currentModel.getID() !== currentSpaceRootId) {
			menuModelArrays.push(currentModel);
			currentModel = navModel.getParent(currentModel.getID()).start();
		}
		if(menuModelArrays.length === 0){ return false; } //means no any page under root
		return true;
	},
	
	onOpenPage: function(iEvent){
		// there are two kinds of payload format for ievent com.ibm.mashups.builder.openPage
		// 1. payload is a string : the page id, just switch to the page.
		// 2. payload is a JSON object : {"pid":"123456",eventsArray:{{"targetEvent": targetEvent1, "payload": payload1, "payloadType": payloadType1},{"targetEvent": targetEvent2, "payload": payload2, "payloadType": payloadType2}}}
		var es = com.ibm.mashups.iwidget.services.ServiceManager.getService("eventService");
		var cb = dojo.hitch(this, function(){
			if (this.globalPageOpened){
				// already have a global page opened. 
				if (this.globalPageOpened == (iEvent.payload || iEvent.payload.pid)){
					// if the opened global page is the same one as requested in the onOpenPage iEvent payload, reload it.
					if (this.globalPageOpened == com.ibm.mashups.builder.model.Factory.getRuntimeModel().getCurrentPage().getID()){
						console.log("Error: you are now already in the global page you want to open");
						return;
					}
					this.openGlobalPageAgain = true;
					
					var cb = dojo.hitch(this, function(){
						com.ibm.mm.builder.utils.pageUtil.changePageMode("view");
						es.broadcastEvents(iEvent.payload.eventsArray || [],this.lastVisitedPage,this.globalPageOpened);
					});
					com.ibm.mm.builder.utils.pageUtil.savePageWithConfirm(cb);
				
				} else {
					// the opened global page is not the one requested in onOpenPage iEvent payload, 
					// close the current global page, pass the onOpenPage payload to closePage, so to open it after the current one is closed.
					var payload = {
						closePageId:this.globalPageOpened,
						openPagePayload: iEvent.payload
					}
					es.broadcastEvent("com.ibm.mashups.builder.closePage", payload);
				}									
			}else{
				if (dojo.cookie(com.ibm.mm.builder.constant.cookieKey_previous_pid)){
					this.lastVisitedPage = dojo.cookie(com.ibm.mm.builder.constant.cookieKey_previous_pid);
				}else{
					this.lastVisitedPage = com.ibm.mm.builder.utils.pageUtil.getCurrentPageId();
				}
				this.globalPageLoadedSpaceId = com.ibm.mm.builder.utils.spaceUtil.getCurrentSpaceId();			
				//create new tab in the tabbed navigation, and navigate to the new tab, with event broadcast to the page.
				if (iEvent.payload.pid){
					this.globalPageOpened = iEvent.payload.pid;	
				}else{
					this.globalPageOpened = iEvent.payload;
				}
				dojo.cookie(com.ibm.mm.builder.constant.cookieKey_globalPageId,this.globalPageOpened);
				dojo.cookie(com.ibm.mm.builder.constant.cookieKey_previous_pid,this.lastVisitedPage,{expires:3652});
				dojo.cookie(com.ibm.mm.builder.constant.cookieKey_globalPageOpenedSpaceId,this.globalPageLoadedSpaceId);
				if (this.lastVisitedPage === this.globalPageOpened){
					console.log("Error: you already in global page, please close it.");
					return;
				}
				var openPage = com.ibm.mm.builder.utils.pageUtil.getPageNode(this.globalPageOpened);
				
				var treeModel = this.tabNavigation.model;
				var treeRoot;
				var onItem = function(item){
					treeRoot = item;
				}
				var onError = function(){};
				treeModel.getRoot(onItem,onError);
							
				var args = { 
					title:openPage.getTitle(dojo.locale),
					pageLoadedSpaceId:this.globalPageLoadedSpaceId,
					openPageId:this.globalPageOpened
				};
				if (iEvent.payload.pid){
					args.eventsArray = iEvent.payload.eventsArray;
					args.lastVisitedPage = this.lastVisitedPage;
				}
				// TODO: The global page only support the sibling node, we only need to support page in one level in BSpace.
				treeModel.newItem(args,treeModel.getParent(treeRoot));				
			}
		});	
		
		com.ibm.mm.builder.utils.pageUtil.savePageWithConfirm(cb);
	},
	
	onClosePage: function(iEvent){
		var closePageId = null;
		if (iEvent.payload.closePageId){
			closePageId = iEvent.payload.closePageId;
		}else{
			closePageId = iEvent.payload;
		}		
		if (closePageId != this.globalPageOpened){
			console.log("Error: you are closing a global page not opened now!");
			return;
		}
		if (this.globalPageOpened) {
			var openedPage = com.ibm.mm.builder.utils.pageUtil.getPageNode(this.globalPageOpened);
			var treeModel = this.tabNavigation.model;
			var args = {"lastVisitedPage":this.lastVisitedPage};
			if (iEvent.payload.openPagePayload){
				args.openPagePayload = iEvent.payload.openPagePayload;
			}
			this.globalPageOpened = null;
			this.lastVisitedPage = null;
			this.globalPageLoadedSpaceId = null;		
			this.globalPageLoaded = false;	
			treeModel.deleteItem(args,openedPage);
			dojo.cookie(com.ibm.mm.builder.constant.cookieKey_globalPageId, null, {expires: -1});
			dojo.cookie(com.ibm.mm.builder.constant.cookieKey_globalPageOpenedSpaceId, null, {expires: -1});
			if (args.openPagePayload){
				this.tabNavigation.reload();
				var es = com.ibm.mashups.iwidget.services.ServiceManager.getService("eventService");
				es.broadcastEvent("com.ibm.mashups.builder.openPage", args.openPagePayload);
			}else{
				dojo.cookie(com.ibm.mm.builder.constant.cookieKey_previous_pid, null, {expires: -1});
			}			
		}else{
			console.log("Error: the global page is not open, can't close it.");
		}
	},
	
	onClearGlobalPage:function(){
		if (this.globalPageOpened) {
			var openedPage = com.ibm.mm.builder.utils.pageUtil.getPageNode(this.globalPageOpened);
			var treeModel = this.tabNavigation.model;
			this.globalPageOpened = null;
			this.lastVisitedPage = null;
			this.globalPageLoadedSpaceId = null;		
			this.globalPageLoaded = false;	
			var args = {"lastVisitedPage":this.lastVisitedPage};
			treeModel.clearGlobalPageItem(args,openedPage);
			dojo.cookie(com.ibm.mm.builder.constant.cookieKey_globalPageId, null, {expires: -1});
			dojo.cookie(com.ibm.mm.builder.constant.cookieKey_globalPageOpenedSpaceId, null, {expires: -1});
			dojo.cookie(com.ibm.mm.builder.constant.cookieKey_previous_pid, null, {expires: -1});
		}
	},
		
	onUnLoad: function(){
	    if (this.tabNavigation != null) {
			this.tabNavigation.destroy();
	        this.tabNavigation = null;
	    } 
	}	
});