/* Copyright IBM Corp. 2010  All Rights Reserved.                    */
/**
 * @author Jarod (zhangpy@cn.ibm.com)
 */
dojo.require("com.ibm.mm.builder.widget.ShadowMenu");

dojo.declare("com.ibm.mm.builder.systemwidget.pageActionMenu", com.ibm.mm.builder.iwidget.SystemTemplatedWidget, {

	pageActionMenu:null,
	currentPageMode: null,
	currentPageId: null,
	publishPageConfirmDialog: null,
	
	_pageUtil: com.ibm.mm.builder.utils.pageUtil,
	_htmlUtil: com.ibm.mm.builder.utils.htmlUtil,
	_navigationUtil: com.ibm.mm.builder.utils.navigationUtil,
	_userUtil: com.ibm.mm.builder.utils.userUtil,
	
	onView: function(){
		this.inherited(arguments);
		this.pageActionImg.src = builderConfig.builderPath + "/images/pageaction/pageMenu.png";
	},
	
	onPageModeChanged: function(iEvent){
		var mode = iEvent.payload;
		if(mode == "view" || mode == "edit"){
			this.currentPageMode = mode;
			this.pageActionMenu && this.currentPageId && this._refreshMenu();
		}
	},
	
	onPageSwitched: function(iEvent){
		this.currentPageId = iEvent.payload;
		if (!this.currentPageId || this._userUtil.isLockedDownAnonymousMode()) {
			this.pageActionDiv.style.display = "none";
		} else{
			this.pageActionDiv.style.display = "";
			this.pageActionMenu && this.pageActionMenu.destroyRecursive();
			this.createMenu();
		}
	},
	
	renderMenu: function(evt){
		if (!this.pageActionMenu) {
			this.createMenu();
			this._refreshMenu();
		}
		this.pageActionMenu._openMyself(evt);
	},
	
	_onKeyPress: function(evt){
		switch (evt.keyCode || evt.charCode) {
			case dojo.keys.UP_ARROW:
			case dojo.keys.DOWN_ARROW:
			case dojo.keys.ENTER:
			case dojo.keys.SPACE:
				this.renderMenu(evt);
				break;
		}
	},
	
	_onClick: function(evt){
		this.renderMenu(evt);
	},
	
	createMenu: function(){
		this.initialized = false;
		
		var self = this;
		this.pageActionMenu = new com.ibm.mm.builder.widget.ShadowMenu({
			targetNodeIds: [this.pageActionImg],
			offset_y: 3,
			prepareData: function(){
				self.initMenu();
			}
		});
		dojo.addClass(this.pageActionMenu.domNode, "pageActionMenu");
	},
	
	initMenu: function(){
		
		var mycontextmenu = com.ibm.mashups.builder.model.Factory.getRuntimeModel().getCurrentContextMenu();
		
		this.currentPageId = this.currentPageId ||
			com.ibm.mashups.builder.model.Factory.getRuntimeModel().getCurrentPage().getID();
		var pageMenus = mycontextmenu.getContextMenu("ContextMenu.page", this.currentPageId, null, {
			context: this
		});
		for (var i = 0; i < pageMenus.length; ++i) {
			if (pageMenus[i].isSeparator) {
				this.pageActionMenu.addChild(new dijit.MenuSeparator())
				continue;
			}
			this.pageActionMenu.addChild(new dijit.MenuItem({
				label: pageMenus[i].title,
				iconClass: pageMenus[i].iconClass,
				disabled: pageMenus[i].enabled == "disabled",
				onClick: pageMenus[i].actionCallBackFunction,
				pageActionType: pageMenus[i].id
			}));
		}
		this._refreshMenu();
	},
	
	/**
	 * enable or disable page action menu items according to mode value
	 * @param {String} mode, "view" or "edit" mode
	 */
	_refreshMenu: function(){
		var navigationModel = this._navigationUtil.getNavigationModel();
		var pageNode = this._pageUtil.getPageNode(this.currentPageId);
		var layoutModel = this._pageUtil.getPageLayoutModel(this.currentPageId);
		var layoutNode = this._pageUtil.getPageLayoutNode(this.currentPageId);
		
		dojo.forEach(this.pageActionMenu.getChildren(), function(menuItem){
			switch (menuItem.pageActionType) {
				case "editPage":
					var canEdit = this.currentPageMode === "edit";
					menuItem.attr("disabled", !canEdit);
					break;
				case "deletePage":
					var canRemove = navigationModel.confirmRemove(pageNode);
					if (canRemove && layoutModel.confirmRemove(layoutNode)) {
						menuItem.attr("label", this.cws.I_COMMON_DELETE);
					} else if (canRemove) {
						menuItem.attr("label", this.cws.I_COMMON_REMOVE);
					} else {
						menuItem.attr("disabled", true);
					}
					break;
			}
		}, this);
	},
	
	onUnload: function(){
		this.pageActionMenu && this.pageActionMenu.destroyRecursive() && delete this.pageActionMenu;
	}
});
