/* Copyright IBM Corp. 2010  All Rights Reserved.                    */
/**
 * @author Jarod(zhangpy@cn.ibm.com)
 */
dojo.require("com.ibm.mm.builder.iwidget.SystemWidget");
dojo.require("com.ibm.mm.enabler.model.url");
dojo.require("com.ibm.mm.catalog.hubUtil");

/**
 * @version 2.0, refactory with SystemTemplatedWidget.
 */
dojo.declare("com.ibm.mm.builder.publishWidget", com.ibm.mm.builder.iwidget.SystemTemplatedWidget,{	
	
	WID: null,

	space: null,
	
	LOGGER: com.ibm.mashups.enabler.logging.Logger.getLogger(this.declaredClass),
	
	onLoad: function(){
		var widgetId = this.iContext.widgetId;
		this.WID = "_"+ widgetId + "_";
		
	},
	
	onView: function(){
		this.inherited(arguments);
	},

	onPublishPage:function(iEvent){
		//set default value for publish option
		this.permPageRadio.checked = true;
		this.smRadio.checked = true;
		
		var pagediv = dojo.byId(this.WID+"pageRoot");
		var spaceDiv = dojo.byId(this.WID+"spaceRoot");
		dojo.style(pagediv, "display", "block");
		dojo.style(spaceDiv, "display", "none");
		
		if(iEvent.payload) {
			this.pageId = iEvent.payload;
			this.updatePageUI();
		}
	},
	
	onPublishSpace : function(iEvent) {
		//set default value for publish option
		this.permRadio.checked = true;
		
		var pagediv = dojo.byId(this.WID+"pageRoot");

		var spacediv = dojo.byId(this.WID+"spaceRoot");
		dojo.style(spacediv, "display", "block");
		dojo.style(pagediv, "display", "none");
		
		var spaceID = null;
		if (iEvent.payload) {
			spaceID = iEvent.payload;
			var spaceUtil = com.ibm.mm.builder.utils.spaceUtil;
			this.spaceModel = spaceUtil.getSpaceModel();
			
			// find the selected node
			this.space = this.spaceModel.find(spaceID).start();
			
			this.updateSpaceUI();
		}
	},
	
	updatePageUI:function(){
		var pu = com.ibm.mm.builder.utils.pageUtil;
		
		this.pageName = pu.getUnescapedPageTitle(this.pageId);
		this.titlePageInput.value=this.pageName;
        this.descPageInput.value = pu.getPageDescription(this.pageId) || "";
        //todo read version before hardcode
		this.versionPageInput.value="1.0";
        this.tagPageInput.value="";
        this.pageStatusDiv.innerHTML="";
		this._enableSaveButton();
	},

	showPageErrorMsg:function(str){
		this.pageStatusDiv.innerHTML="<font color=red>"+str+"</font>"; //todo don't use font tag here instead of classname
	},
	
	showPageInfoMsg:function(str){
		this.pageStatusDiv.innerHTML="<font color=gray>"+str+"</font>";
	},
	
	showSpaceErrorMsg:function(str){
		this.spaceStatusDiv.innerHTML="<font color=red>"+str+"</font>"; //todo don't use font tag here instead of classname
	},
	
	showSpaceInfoMsg:function(str){
		this.spaceStatusDiv.innerHTML="<font color=gray>"+str+"</font>";
	},
	
	_validatePageInput: function(title, description, version){
		if(!(title && description && version)){
			this.showPageErrorMsg(this.cws.E_PUBLISH_PAGE_REQUIRED_FIELDS_EMPTY_0);
			return false;
		}
		if (!com.ibm.mm.builder.utils.pageUtil.validatePageName(title)) {
			return false;
		}
		return true;
	},
	
	_savePublishPageWithKey: function(e) {
		if (e.charCode == dojo.keys.SPACE || e.keyCode == dojo.keys.ENTER) {
			this.savePublishPage();
		}
	},
	
    savePublishPage: function(){
        var title = dojo.trim(this.titlePageInput.value);
        var description = dojo.trim(this.descPageInput.value);
        var version = dojo.trim(this.versionPageInput.value);
        var tags = dojo.trim(this.tagPageInput.value);
		
        var permissionFlag = this.permPageRadio.checked;
        var sharingMethodFlag = !this.smRadio.checked;
		
        if (!this._validatePageInput(title, description, version)) return;
        
        this._disableSaveButton();

        // use URL to resource feed provided with navigation node
		var exportURL = null;
		var page = com.ibm.mm.builder.utils.pageUtil.getPageNode(this.pageId);
		if (page != null) {
			var resourceLink = page.getExportPageURL();
			if (resourceLink != null) {
				exportURL = resourceLink;
			}
		}
		// fall back to constructed URL
		if (exportURL == null) {
	        var cs = com.ibm.mashups.services.ServiceManager.getService(com.ibm.mashups.enabler.services.ConfigService.SERVICE_NAME);
	        exportURL = cs.getValue(cs.CONTEXT_ROOT_MAIN) + "/mycontenthandler?uri=resource:" + this.pageId;
		}

		this._publishPageToCatalog(exportURL, title, description, version, tags, sharingMethodFlag, permissionFlag);
        
    },
	
    _publishPageToCatalog: function(exportURL, title, description, version, tags, sharingMethod, permission){
		var atom = this._buildPageAtomXmlToPost(exportURL, title, description, version, tags, sharingMethod, permission);
		var hubURL = com.ibm.mm.catalog.hubUtil.getDefaultHubUrl() + "/atom?collection=pages";
        this.showPageInfoMsg("Connecting to " + hubURL);
		
        dojo.rawXhrPost({
            headers: { "Content-Type": "application/xml" },
            url: this.iContext.io.rewriteURI(hubURL),
            load: dojo.hitch(this, function(data, ioArgs){
                this.LOGGER.info("_publishPageToCatalog", dojo.string.substitute(this.cwm.I_PUBLISH_PAGE_1, [title]));
				this.hide();
            }),
            error: dojo.hitch(this, function(error, ioArgs){
                var errorStr = this.cws.E_PUBLISH_PAGE_PUBLISH_FAILED_MSG_0;
				this.showPageErrorMsg(errorStr);
            }),
            postData: atom,
            handleAs: "text"
        });
    },
	
    _getPageDefinition: function(exportURL){
        var infoStr = dojo.string.substitute(this.cws.I_PUBLISH_PAGE_EXPORTING_PAGE_1, [exportURL]);
        this.showPageInfoMsg(infoStr);
		
		var pageDefinition = ""; 
        dojo.xhrGet({
            url: exportURL,
            load: dojo.hitch(this, function(data, ioArgs){
                this.showPageInfoMsg("");
				pageDefinition = com.ibm.mm.builder.utils.pageUtil.encodeBase64(data);
            }),
            error: dojo.hitch(this, function(data, ioArgs){
                this.LOGGER.severe("_buildPageAtomXmlToPost", dojo.string.substitute(this.cwm.E_PUBLISH_PAGE_EXPLORTING_PAGE_1, [ioArgs]));
                return data;
            }),
            sync: true,
            handleAs: "text"
        });
		
		return pageDefinition;
    },
	
	_buildPageAtomXmlToPost: function(exportURL,title,description,version,tags,sharingMethod,permission){
		var stringBuf=[];
        var escapeXML = function(str) {
		    return (typeof str == "undefined") ? "" : str.toString().replace(/&/gm, "&amp;").replace(/</gm, "&lt;").replace(/>/gm, "&gt;").replace(/"/gm, "&quot;").replace(/'/gm, "&#39;").replace(/\[/gm, "&#91;").replace(/\]/gm, "&#93;");
        }
		tags = tags.replace(/\s+/g, ",");
		//todo why need so many xml ns? should open a bug to builder or server side
		return dojo.string.substitute(
			'<?xml version="1.0" encoding="UTF-8"?>'+
			'<entry xmlns="http://www.w3.org/2005/Atom">'+
				'<id>urn:id:0</id>'+
				'<category term="mashuppage"></category>'+
				'<content type="application/xml">'+
					'<catalog:mashuppage xmlns:catalog="http://www.ibm.com/xmlns/atom/opensearch/mashuppage/1.0/">'+
						'<catalog:version xmlns:catalog="http://www.ibm.com/xmlns/atom/opensearch/mashuppage/1.0/">${0}</catalog:version>'+
						'<catalog:name xmlns:catalog="http://www.ibm.com/xmlns/atom/opensearch/mashuppage/1.0/">${1}</catalog:name>'+
						'<catalog:author xmlns:catalog="http://www.ibm.com/xmlns/atom/opensearch/mashuppage/1.0/">${2}</catalog:author>'+
						'<catalog:description xmlns:catalog="http://www.ibm.com/xmlns/atom/opensearch/mashuppage/1.0/">${3}</catalog:description>'+
						'<catalog:tags xmlns:catalog="http://www.ibm.com/xmlns/atom/opensearch/mashuppage/1.0/">${4}</catalog:tags>'+
						'<catalog:documentation xmlns:catalog="http://www.ibm.com/xmlns/atom/opensearch/mashuppage/1.0/"></catalog:documentation>'+
						'<catalog:documentationURL xmlns:catalog="http://www.ibm.com/xmlns/atom/opensearch/mashuppage/1.0/"></catalog:documentationURL>'+
						'${5}'+
						'<catalog:permission xmlns:catalog="http://www.ibm.com/xmlns/atom/opensearch/mashuppage/1.0/">'+
							(permission ? 'public' : 'private')+
					   '</catalog:permission>'+
					'</catalog:mashuppage>'+
				'</content>'+
				'<author><name>Mashuphub Search Feed</name></author>'+
				'<title type="html">new page</title>'+
			'</entry>',
			[ 
				escapeXML(version), 
			  	escapeXML(title), 
			  	escapeXML(this.iContext.getUserProfile().user.getID()),
				escapeXML(description),
				(tags ? dojo.map(tags.split(","), function(tag){ 
							return tag ? '<catalog:tag xmlns:catalog="http://www.ibm.com/xmlns/atom/opensearch/mashuppage/1.0/">'+
						 				escapeXML(tag) + '</catalog:tag>' : ""}
					   ).join("") : ""),
				(sharingMethod ? '<catalog:definitionURL xmlns:catalog="http://www.ibm.com/xmlns/atom/opensearch/mashuppage/1.0/">'+
									escapeXML(com.ibm.mm.builder.utils.navigationUtil.getRedirectAddress())+
						   		 '</catalog:definitionURL>' : 
								 '<catalog:archive mimetype="application/xml" filename="'+escapeXML(title)+'.xml" xmlns:catalog="http://www.ibm.com/xmlns/atom/opensearch/mashuppage/1.0/">'+
                					this._getPageDefinition(exportURL)+
                				 '</catalog:archive>')
			]);
	},
	
	
	
	_getSpaceOwnerId: function(){
		this.acModel = com.ibm.mashups.enabler.ac.AccessControlModelFactory.getAccessControlModel(this.space);
		if(this.acModel.getOwner())
			return this.acModel.getOwner().getID();
		else
			return null;
	},
	
	updateSpaceUI: function(){
	
		//todo limit the title length
		
		this.titleInput.value = this.space.getTitle(dojo.locale) || "";
        
        this.descInput.value = this.space.getDescription(dojo.locale) || "";
		
		
        //todo read version before hardcode
		this.versionInput.value="1.0";
        this.tagInput.value="";
      
		this._enableSaveButton();
		this.spaceStatusDiv.innerHTML="";
	},
	
	_validateInput: function(title, description, version){
		if(!(title && description && version)){
			this.showSpaceErrorMsg(this.cws.E_PUBLISH_SPACE_REQUIRED_FIELDS_EMPTY_0);
			return false;
		}
		if (!com.ibm.mm.builder.utils.spaceUtil.validateSpaceName(title)) {
			return false;
		}
		return true;
	},
	
    savePublishSpace: function(){
        
		var title = dojo.trim(this.titleInput.value);
        var description = dojo.trim(this.descInput.value);
        var version = dojo.trim(this.versionInput.value);
        var tags = dojo.trim(this.tagInput.value);
		
        var permissionFlag = this.permRadio.checked;
	
 		
        if (!this._validateInput(title, description, version)) return;
        
        this._disableSaveButton();

        // use URL to resource feed provided with navigation node
		var exportURL = this.space.getExportTemplateURL();
		
		// use absolute url
		var modelURL = com.ibm.mm.enabler.model.UrlFactory.getModelUrl(exportURL, com.ibm.mm.builder.utils.spaceUtil.getSpaceModel());
		this._publishToCatalog(modelURL.getAbsoluteURL(), title, description, version, tags, permissionFlag);        
    },
	
    _publishToCatalog: function(exportURL, title, description, version, tags, permission){
		var atom = this._buildAtomXmlToPost(exportURL, title, description, version, tags, permission);
		var hubURL = com.ibm.mm.catalog.hubUtil.getDefaultHubUrl() + "/atom?collection=spaces";
		
        dojo.rawXhrPost({
            headers: { "Content-Type": "application/xml" },
            url: this.iContext.io.rewriteURI(hubURL),
            load: dojo.hitch(this, function(data, ioArgs){
                this.LOGGER.info("_publishToCatalog", dojo.string.substitute(this.cwm.I_PUBLISH_SPACE_1, [title]));
				this.hide();
            }),
            error: dojo.hitch(this, function(error, ioArgs){
                var errorStr = this.cws.E_PUBLISH_PAGE_PUBLISH_FAILED_MSG_0;
                this.showSpaceErrorMsg(errorStr);
            }),
            postData: atom,
            handleAs: "text"
        });
    },
	
 	
	_buildAtomXmlToPost: function(exportURL,title,description,version,tags,permission){
		var stringBuf=[];
        var escapeXML = function(str) {
		    return (typeof str == "undefined") ? "" : str.toString().replace(/&/gm, "&amp;").replace(/</gm, "&lt;").replace(/>/gm, "&gt;").replace(/"/gm, "&quot;").replace(/'/gm, "&#39;").replace(/\[/gm, "&#91;").replace(/\]/gm, "&#93;");
        }
		var sharingMethod = false;

		var ownerId = this._getSpaceOwnerId();
		if(ownerId == null)
			ownerId = "";		
		tags = tags.replace(/\s+/g, ",");
		
		//todo why need so many xml ns? should open a bug to builder or server side
		return dojo.string.substitute(
			'<?xml version="1.0" encoding="UTF-8"?>'+
			'<entry xmlns="http://www.w3.org/2005/Atom">'+
				'<id>urn:id:0</id>'+
				'<category term="spacetemplate"></category>'+
				'<content type="application/xml">'+
					'<catalog:spacetemplate xmlns:catalog="http://www.ibm.com/xmlns/atom/opensearch/spacetemplate/1.0/">'+
						'<catalog:version xmlns:catalog="http://www.ibm.com/xmlns/atom/opensearch/spacetemplate/1.0/">${0}</catalog:version>'+
						'<catalog:name xmlns:catalog="http://www.ibm.com/xmlns/atom/opensearch/spacetemplate/1.0/">${1}</catalog:name>'+
						'<catalog:author xmlns:catalog="http://www.ibm.com/xmlns/atom/opensearch/spacetemplate/1.0/">${2}</catalog:author>'+
						'<catalog:description xmlns:catalog="http://www.ibm.com/xmlns/atom/opensearch/spacetemplate/1.0/">${3}</catalog:description>'+
						'<catalog:tags xmlns:catalog="http://www.ibm.com/xmlns/atom/opensearch/spacetemplate/1.0/">${4}</catalog:tags>'+
						'<catalog:documentation xmlns:catalog="http://www.ibm.com/xmlns/atom/opensearch/spacetemplate/1.0/"></catalog:documentation>'+
						'<catalog:documentationURL xmlns:catalog="http://www.ibm.com/xmlns/atom/opensearch/spacetemplate/1.0/"></catalog:documentationURL>'+
						'<catalog:packageURL xmlns:catalog="http://www.ibm.com/xmlns/atom/opensearch/spacetemplate/1.0/">${5}</catalog:packageURL>'+
						'<catalog:permission xmlns:catalog="http://www.ibm.com/xmlns/atom/opensearch/spacetemplate/1.0/">'+
							(permission ? 'public' : 'private')+
					   '</catalog:permission>'+
					'</catalog:spacetemplate>'+
				'</content>'+
				'<author><name>Mashuphub Search Feed</name></author>'+
				'<title type="html">new space</title>'+
			'</entry>',
			[ 
				escapeXML(version), 
			  	escapeXML(title), 
			  	escapeXML(ownerId),
				escapeXML(description),
				(tags ? dojo.map(tags.split(","), function(tag){ 
							return tag ? '<catalog:tag xmlns:catalog=\"http://www.ibm.com/xmlns/atom/opensearch/spacetemplate/1.0/">'+
						 				escapeXML(tag) + '</catalog:tag>' : ""}
					   ).join("") : ""),
				escapeXML(exportURL)
			]);
	},
	
	_getTags: function(tags){
   		var str = tags.replace(/\S/g, ",")
    	
   		var tagsArr = str.split(",");
	   	var strTagStart = "<catalog:tag xmlns:catalog=\"http://www.ibm.com/xmlns/atom/opensearch/spacetemplate/1.0/\">";
   		var strTagEnd = "<\/catalog:tag>";
   		var strTags = "";
   		for(var i=0; i<tagsArr.length; i++) {
   			strTags = strTags + strTagStart + tagsArr[i] + strTagEnd;
   		}
		return strTags;		
		
	},
	
	_hideWithKey: function(e) {
		if (e.charCode == dojo.keys.SPACE || e.keyCode == dojo.keys.ENTER) {
			this.hide();
		}
	},	
	
	hide:function() {
		this.eventService.broadcastEvent("com.ibm.mashups.builder.closeMashupDialog", this.iContext.widgetId);
	},
	
	_disableSaveButton: function() {
		this.savePageButton.disabled = true;
	},
	
	_enableSaveButton: function() {
		this.savePageButton.disabled = false;
	}
});
