/* Copyright IBM Corp. 2010  All Rights Reserved.                    */
dojo.provide("com.ibm.mm.builder.spaceCreateWidget");

dojo.require("dojo.string");
dojo.require("com.ibm.mm.builder.iwidget.spacemanager.widget.ThemesListControl");
dojo.require("com.ibm.mm.catalog.opensearch.ResultParser");
dojo.require("com.ibm.mm.builder.dialog.DialogFooter");
dojo.require("com.ibm.mm.builder.iwidget.spacemanager.SpaceManagerActions");
dojo.require("com.ibm.mm.builder.iwidget.spacemanager.SpaceManagerConstants");

dojo.declare("com.ibm.mm.builder.spaceCreateWidget", null, {

    WID: null,
    
    SPACE_CREATE_TYPE_TEMPLATE: "from_template",
    
    SPACE_CREATE_TYPE_SPACE: "from_space",
    
    resourceBundle: null,
    
    resourceMessage: null,
    
    canSetFavorite: true,
    
    templatesFromHub: true,
    
    eventService: com.ibm.mashups.services.ServiceManager.getService("eventService"),
    
    LOGGER: com.ibm.mashups.enabler.logging.Logger.getLogger("com.ibm.mm.builder.spaceCreateWidget"),
	
	_templateList: null,
    
    onLoad: function() {
    
        this.widgetId = this.iContext.widgetId;
        this.WID = "_" + this.widgetId + "_";
        
        this.resourceBundle = com.ibm.mm.builder.coreWidgetsStrings;
        this.resourceMessage = com.ibm.mm.builder.coreWidgetsMessages;
        
        this.cs = com.ibm.mashups.services.ServiceManager.getService(com.ibm.mashups.enabler.services.ConfigService.SERVICE_NAME);
        
        if (builderConfig.createSpaceOnTemplateMode) {            
            if (builderConfig.hasHub) {
                this.templatesFromHub = true;
            } else {
                this.templatesFromHub = false;
            }

        } else {
            this.templatesFromHub = false;
        }
        
        this.themesNode = dojo.byId(this.WID + "themesContainer");
        
        this.themesListControl = new com.ibm.mm.builder.iwidget.spacemanager.widget.ThemesListControl({
            widgetId: this.widgetId
        }, this.themesNode);
        
        this._messageClass = "com.ibm.lotus.oneui.v100.messages";
        
        dojo.registerModulePath(this._messageClass, this.iContext.io.rewriteURI("../dijit-library/oneUI.versionized/messages"));
        dojo.require(this._messageClass + ".Message");
		
		this.enablerUtil = com.ibm.mm.builder.utils.enablerUtil;
        
		this.iWidgetAttributes = this.iContext.getiWidgetAttributes();
		this.defaultTemplateENTitle = this.iWidgetAttributes.getItemValue("defaultTemplateENTitle");
    },
    
    onView: function() {
        dojo.parser.parse(this.iContext.getRootElement());
		
		this._templateList = dojo.byId(this.WID + "templateList");
		dojo.attr(this._templateList,"title",this.resourceBundle.CREATE_SPACE_AVAILABEL_SPACE_TEMPLATES);		
		
        dojo.byId(this.WID + "space_name_label").innerHTML = this.resourceBundle.CREATE_SPACE_NAME;
        dojo.byId(this.WID + "space_desc_label").innerHTML = this.resourceBundle.CREATE_SPACE_DESC;
        dojo.byId(this.WID + "fromTemplate_label").innerHTML = this.resourceBundle.CREATE_SPACE_FROM_TEMPLATE;
		dojo.attr(dojo.byId(this.WID + "fromTemplate"),'aria-label',this.resourceBundle.CREATE_SPACE_FROM_TEMPLATE);
		
        dojo.byId(this.WID + "fromSpace_label").innerHTML = this.resourceBundle.CREATE_SPACE_FROM_SPACE;
		dojo.attr(dojo.byId(this.WID + "fromSpace"),'aria-label',this.resourceBundle.CREATE_SPACE_FROM_SPACE);
        dojo.byId(this.WID + "choose_theme_label").innerHTML = this.resourceBundle.CREATE_SPACE_CHOOSE_THEME;
        
        dojo.byId(this.WID + "makeFavorite_label").innerHTML = this.resourceBundle.CREATE_SPACE_MAKE_FAVORITE;
		dojo.attr(dojo.byId(this.WID + "makeFavorite"),'aria-label',this.resourceBundle.CREATE_SPACE_MAKE_FAVORITE);
        dojo.byId(this.WID + "limitHint").innerHTML = dojo.string.substitute(this.resourceBundle.CREATE_SPACE_FAVORITE_LIMIT, [builderConfig.favoriteSpacesMaximumNumber]);
        
    },
    
    onCreateSpace: function(iEvent) {
        this.createSpaceFromSpaceManager = iEvent.payload.createSpaceFromSpaceManager;
        this.cleanUI();
        this.checkFavSpacesCount();
        this.loadExistingTemplates();
        this.loadExistingSpaces();
        this.loadThemes();
    },
    
    checkFavSpacesCount: function() {
    
        var spaceUtil = com.ibm.mm.builder.utils.spaceUtil;
        var spaceModel = spaceUtil.getSpaceModel();
        
        var iterator = spaceModel.findFavorites();
        iterator.start();
        var favCount = parseInt(iterator.size().start(), 10);
        
        var limit = parseInt(builderConfig.favoriteSpacesMaximumNumber, 10);
        
		var makeFavoriteCheck = dojo.byId(this.WID + "makeFavorite");
		
        if (favCount >= limit) {
            makeFavoriteCheck.disabled = true;
            makeFavoriteCheck.checked = false;
            dojo.style(this.WID + "makeFavorite_label", "color", "#999");
            dojo.style(this.WID + "limitHint", "display", "block");
            this.canSetFavorite = false;
            
        } else {
            makeFavoriteCheck.disabled = false;
            makeFavoriteCheck.checked = true;
            dojo.style(this.WID + "makeFavorite_label", "color", "black");
            dojo.style(this.WID + "limitHint", "display", "none");
            this.canSetFavorite = true;
        }
        
        
    },
    
    _getCatalogTemplatesSearchUrl: function() {
        var url = null;
        try {
            url = com.ibm.mm.catalog.hubUtil.getHubOpenSearchUrl();
        } catch (e) {
        }
        if (url) {
            url = new com.ibm.mm.enabler.utilities.HttpUrl(url);
            url = url.toProxifiedString();
			var queryKeyword = builderConfig.spaceTemplateQueryKeyword || "*",
				queryCount = builderConfig.spaceTemplateQueryCount || "50";
            return url + "?collection=spaces&searchTerms=" + queryKeyword + "&count=" + queryCount;
        }
        return null;
    },
    _truncateTitle: function(title) { 
 		if (title.length > 35) {
 			return title.substring(0, 32) + "...";
 		} else {
 			return title;
 		}
 	},
    loadExistingTemplates: function() {
    
        var templateList = this._templateList;
        templateList.options.length = 0;
        
        if (this.templatesFromHub) {
            this.loadTemplatesFromHub();
            
        } else {
            this.loadTemplatesFromEnabler();
        }
        
    },
    
    xmlToString: function(node) {
        if (dojo.isIE) 
            return node.xml;
        else {
            var s = new XMLSerializer();
            return s.serializeToString(node);
        }
    },
    
    escapeXML: function(str) {
        if (!dojo.isString(str)) 
            return str;
        return str.replace(/&/gm, "&amp;").replace(/</gm, "&lt;").replace(/>/gm, "&gt;").replace(/"/gm, "&quot;").replace(/'/gm, "&#39;");
    },
    
    unescapeXML: function(str) {
        if (!dojo.isString(str)) 
            return str;
        
        return str.replace(/&lt;/gm, "<").replace(/&gt;/gm, ">").replace(/&quot;/gm, "\\\"").replace(/&amp;/gm, "&");
        
    },
    
    loadTemplatesFromHub: function() {
    
        var templateList = this._templateList;
        
        //at least, should get one template from Hub
        var url = this._getCatalogTemplatesSearchUrl();
        
        dojo.xhrGet({
            url: url,
            handleAs: "text",
            preventCache: true,
            load: dojo.hitch(this, function(data) {
                
				var doc = dojox.data.dom.createDocument(data);
                
                var parser = com.ibm.mm.catalog.opensearch.ResultParserManager.mashuphub;
                var results = parser.parse(doc).getResults();
                var listTitle = [];
				
                for (var i = 0, n = results.length; i < n; i++) {
					var resultT = results[i];
					var op = new Option(this._truncateTitle(resultT.name), resultT.importServiceURL);
					dojo.attr(op, "title", resultT.name);					
                    templateList.options.add(op);
					
					listTitle.push(resultT.name);
                }
            }),
            error: dojo.hitch(this, function() { })
        });
        
        dojo.connect(templateList, "onclick", dojo.hitch(this, function() {
            dojo.byId(this.WID + "fromTemplate").checked = true
        }));
        
    },
    
    loadTemplatesFromEnabler: function() {
    
        var templateList = this._templateList;
        
        var templateModel = com.ibm.mashups.enabler.model.Factory.getTemplateModel();
        templateModel.setStrategy(new com.ibm.mashups.enabler.strategy.ListLoadAheadStrategy(5));
        var listTitle = [];
		
        //at least, should get one template from enabler api
        while (templateModel.hasNext()) {
            var node = templateModel.next();
			var nodeTitle = this.enablerUtil.getNodeTitle(node);
			var title = this._truncateTitle(nodeTitle);
			var op = new Option(title || this.resourceBundle.I_SPACE_MANAGER_NO_TITLE, node.getID());
			dojo.attr(op, "title", nodeTitle || this.resourceBundle.I_SPACE_MANAGER_NO_TITLE);
            templateList.options.add(op);
			if(this.defaultTemplateENTitle === node.getTitle("en")){
				op.selected = "selected";
			}
			listTitle.push(nodeTitle || this.resourceBundle.I_SPACE_MANAGER_NO_TITLE);
        }
    },
    
    loadExistingSpaces: function() {
    
        var spaceList = dojo.byId(this.WID + "spaceList");
        spaceList.options.length = 0;
        dojo.attr(spaceList, "title", this.resourceBundle.CREATE_SPACE_EXISTING_SPACE);
        
        var spaceUtil = com.ibm.mm.builder.utils.spaceUtil;
        var spaceModel = spaceUtil.getSpaceModel();
        spaceModel.setCursorPosition(0);
		
		var hasSpaces = spaceModel.hasNext();
		var listTitle = [];
		
		if(hasSpaces) {
	        while (spaceModel.hasNext()) {
	        	var node = spaceModel.next();
		        if (com.ibm.mm.builder.commonActions.canCopySpace(node.getID())) {
	        		var nodeTitle = this.enablerUtil.getNodeTitle(node);
					var title = this._truncateTitle(nodeTitle);
	        		var op = new Option(title || this.resourceBundle.I_SPACE_MANAGER_NO_TITLE, node.getID());
	        		dojo.attr(op, "title", nodeTitle || this.resourceBundle.I_SPACE_MANAGER_NO_TITLE);				
	        		spaceList.options.add(op);
				
	        		listTitle.push(nodeTitle || this.resourceBundle.I_SPACE_MANAGER_NO_TITLE);	
	        	}
	        }			
		}
		dojo.attr(dojo.byId(this.WID + "fromSpace"),'disabled',!hasSpaces);
    },
    
    loadThemes: function() {
        this.themesListControl.refresh();
    },
    
    cleanUI: function() {
    
        dojo.byId(this.WID + "SpaceName").value = "";
        dojo.byId(this.WID + "SpaceDesc").value = "";
        
        dojo.byId(this.WID + "fromTemplate").checked = true;
        this._templateList.disabled = false;
        dojo.byId(this.WID + "spaceList").disabled = true;
        if (this.messageControl) {
            this.messageControl.hide();
        }
        
        if (dojo.isIE == 6) {
            dojo.style(this.WID + "themesContainer", "width", "300px");
        }
        
        dojo.attr(this.WID + "btn_save", "disabled", false);
        
        dojo.connect(dojo.byId(this.WID + "fromTemplate"), "onclick", dojo.hitch(this, function() {
            this._templateList.disabled = false;
            dojo.byId(this.WID + "spaceList").disabled = true;
        }));
        dojo.connect(dojo.byId(this.WID + "fromSpace"), "onclick", dojo.hitch(this, function() {
            this._templateList.disabled = true;
            dojo.byId(this.WID + "spaceList").disabled = false;
        }));
    },
    
    hide: function() {
        this.eventService.broadcastEvent("com.ibm.mashups.builder.closeMashupDialog", this.iContext.widgetId);
    },
    
    _getTitle: function() {
        return dojo.byId(this.WID + "SpaceName").value;
    },
    
    _getDescription: function() {
        return dojo.byId(this.WID + "SpaceDesc").value;
    },
    
    _getSpaceCreateType: function() {
    
        if (dojo.byId(this.WID + "fromTemplate").checked) 
            return this.SPACE_CREATE_TYPE_TEMPLATE;
        else             
            return this.SPACE_CREATE_TYPE_SPACE;
    },
    
    _getSelectedTheme: function() {
        return this.themesListControl.selectedTheme;
    },
    
    _setTheme: function(space, theme) {
        if (!space) {
            return;
        }
        var navigationModel = com.ibm.mm.builder.utils.navigationUtil.getNavigationModel();
        
        var navRootNode = navigationModel.find(space.getRootNavigation()).start();
        navRootNode.setTheme(theme);
        
        navigationModel.commit().start();
    },
    
    _createSpaceFromTemplate: function(title, description, theme) {
    
        var templateList = this._templateList;
        if (templateList.options.length == 0) {
            this.messageControl.attr("message", this.resourceMessage.E_SPACE_MANAGER_NO_TEMPLATE_FOR_SPACE_CREATION_0);
            this.messageControl.show();
            return;
        }
        
        dojo.attr(this.WID + "btn_save", "disabled", true);
        if (this.templatesFromHub) {
            this._createSpaceFromHubTemplate(title, description, theme);
            
        } else {
            this._createSpaceFromEnablerTemplate(title, description, theme);
        }
        
    },
    
    _createSpaceWithTemplateID: function(title, description, theme, templateId) {
    
        var spaceUtil = com.ibm.mm.builder.utils.spaceUtil;
        var spaceModel = spaceUtil.getSpaceModel();
        
        var space = spaceModel.create({
            "templateID": templateId
        });

        space.setTitle(title, builderConfig.locale);
        space.setDescription(description, builderConfig.locale);
		
		spaceUtil.setSpaceIconURL(space, this.defaultIcon());
        this._setFavorite(space);
        
        spaceModel.insert(space);
        
        var deferred = spaceModel.commit();
        deferred.setOperationCallback(dojo.hitch(this, function(newSpace) {
        
            if (newSpace && newSpace.getID()) {
                var payload = newSpace.getID();
                
                this._setTheme(newSpace, theme);
                
                if (this._needSetAsFavorite(newSpace)) 
                    dojo.publish(com.ibm.mm.builder.iwidget.spacemanager.SpaceManagerConstants.Topic.Space.addToFavorite, [newSpace]);
                this.eventService.broadcastEvent("com.ibm.mashups.builder.spacemanager.spaceCreated", payload)
                
                if (!this.createSpaceFromSpaceManager) {
                    this.eventService.broadcastEvent("com.ibm.mashups.builder.switchSpace", payload);
                }
                
                this.messageControl.hide();
                this.hide();
            } else {
                this.messageControl.attr("message", this.resourceMessage.E_SPACE_MANAGER_SPACE_CREATED_FAILED_0);
                this.messageControl.show();
                dojo.attr(this.WID + "btn_save", "disabled", false);
            }
            
        }));
        deferred.start();
        
    },
    
    defaultIcon: function() {
        return builderConfig.builderPath + "/images/spaceicons/icon-01.gif";
    },
    
    _createSpaceFromEnablerTemplate: function(title, description, theme) {
    
        var templateList = this._templateList;
        var templateId = templateList.options[templateList.selectedIndex].value;
        
        this._createSpaceWithTemplateID(title, description, theme, templateId);
        
    },
    
    getMashupsImportSpaceUrl: function() {
        return [location.protocol, "//", location.host, "/mum/mycontenthandler?uri=space:collection&mode=import"].join("");
    },
    
    _createSpaceFromHubTemplate: function(title, description, theme) {
    
        var templateList = this._templateList;
        
        var hubImportServiceUrl = templateList.options[templateList.selectedIndex].value;        
        hubImportServiceUrl = this.iContext.io.rewriteURI(this.unescapeXML(hubImportServiceUrl));
        
        var self = this;
        dojo.xhrPost({
        
            url: hubImportServiceUrl,
            handleAs: "json",
            
            content: {
                "authType": "Form",
                "description": description,
                "import_service_url": this.getMashupsImportSpaceUrl(),
                "title": title,
                "locale": this.cs.getValue("default.locale")
            },
            
            load: function(data) {
                var statusCode = parseInt(data.status, 10);
                
                if (statusCode >= 300 || statusCode < 200) {
                    this.error(data);
                } else {
                    var spaceId = data.spaceId.split(":")[2];
                    
                    var newSpace = com.ibm.mm.builder.utils.spaceUtil.getSpaceNode(spaceId);
					com.ibm.mm.builder.utils.spaceUtil.setSpaceIconURL(newSpace, self.defaultIcon());
                    self._setFavorite(newSpace);
                    var spaceModel = com.ibm.mm.builder.utils.spaceUtil.getSpaceModel();
                    spaceModel.commit().start();
                    
                    self._setTheme(newSpace, theme);
                    
                    if (self._needSetAsFavorite(newSpace)) 
                        dojo.publish(com.ibm.mm.builder.iwidget.spacemanager.SpaceManagerConstants.Topic.Space.addToFavorite, [newSpace]);
                    self.eventService.broadcastEvent("com.ibm.mashups.builder.spacemanager.spaceCreated", spaceId);
                    if (!self.createSpaceFromSpaceManager) {
                        self.eventService.broadcastEvent("com.ibm.mashups.builder.switchSpace", spaceId);
                    }
                    
                    self.messageControl.hide();
                    self.hide();
                }
                
            },
            
            error: dojo.hitch(this, function(data) {
                this.messageControl.attr("message", this.resourceMessage.E_SPACE_MANAGER_SPACE_CREATED_FAILED_0);
                this.messageControl.show();
                dojo.attr(this.WID + "btn_save", "disabled", false);
            })
        });
    },
    
    _setFavorite: function(space) {
    
        if (this._needSetAsFavorite(space)) {
            space.setFavorite(true);
        }
    },
    
    _needSetAsFavorite: function(space) {
        var makeFavCheck = dojo.byId(this.WID + "makeFavorite");
        return space && !makeFavCheck.disabled && makeFavCheck.checked && this.canSetFavorite;
    },
    
    _createSpaceFromSpace: function(title, description, theme) {
    
        var spaceList = dojo.byId(this.WID + "spaceList");
        if (spaceList.options.length == 0) {
            this.messageControl.attr("message", this.resourceMessage.E_SPACE_MANAGER_NO_SPACE_FOR_SPACE_CREATION_0);
            this.messageControl.show();
            return;
        }
        
        dojo.attr(this.WID + "btn_save", "disabled", true);
        
        var spaceUtil = com.ibm.mm.builder.utils.spaceUtil;
        var spaceModel = spaceUtil.getSpaceModel();
        
		var basedSpaceId = spaceList.options[spaceList.selectedIndex].value;
        var space = spaceModel.create({
            "clonedSpace": basedSpaceId
        });
		
        space.setTitle(title, builderConfig.locale);
        space.setDescription(description, builderConfig.locale);
        this._setFavorite(space);
        
        spaceModel.insert(space);
        var deferred = spaceModel.commit();
        
        deferred.setOperationCallback(dojo.hitch(this, function(newSpace) {
        
            if (newSpace && newSpace.getID()) {
            
                var payload = newSpace.getID();
                this._setTheme(newSpace, theme);
                
                if (this._needSetAsFavorite(newSpace)) 
                    dojo.publish(com.ibm.mm.builder.iwidget.spacemanager.SpaceManagerConstants.Topic.Space.addToFavorite, [newSpace]);
                this.eventService.broadcastEvent("com.ibm.mashups.builder.spacemanager.spaceCreated", payload);
                if (!this.createSpaceFromSpaceManager) {
                    this.eventService.broadcastEvent("com.ibm.mashups.builder.switchSpace", payload);
                }
                this.messageControl.hide();
                this.hide();
                
            } else {
                this.messageControl.attr("message", this.resourceMessage.E_SPACE_MANAGER_SPACE_CREATED_FAILED_0);
                this.messageControl.show();
                dojo.attr(this.WID + "btn_save", "disabled", false);
            }
            
        }));
        
        deferred.start();
    },
    
    _verifyTitle: function(title) {
        if (!title) {
            this.messageControl.attr("message", this.resourceMessage.E_SPACE_MANAGER_SPACE_NAME_IS_REQUIRED_0);
            this.messageControl.show();
            return false
        }
        if (title.length == 0) {
            this.messageControl.attr("message", this.resourceMessage.E_SPACE_MANAGER_SPACE_NAME_IS_REQUIRED_0);
            this.messageControl.show();
            return false;
        }
        title = dojo.trim(title)
        if (title.length == 0) {
            this.messageControl.attr("message", this.resourceMessage.E_SPACE_MANAGER_SPACE_NAME_IS_REQUIRED_0);
            this.messageControl.show();
            return false;
        }
        
        if (title.length >= 256) {
            this.messageControl.attr("message", this.resourceMessage.E_SPACE_MANAGER_SPACE_NAME_HAS_MAX_LIMIT_0);
            this.messageControl.show();
            return false;
        }
        
        var match = ibmConfig[com.ibm.mashups.enabler.services.ConfigConstants.BUILDER_TITLE_FILTER_REGEXP];
        if (match) {
            if (title.match(match)) {
                this.messageControl.attr("message", this.resourceMessage.E_SPACE_MANAGER_SPACE_NAME_HAS_INVALID_CHAR_0);
                this.messageControl.show();
                return false;
            }
        }
        return true;
    },
    
    _verifyDescription: function(description) {
    
        if (!dojo.isString(description)) 
            return false;
        
        if (description.length >= 512) {
            this.messageControl.attr("message", this.resourceMessage.E_SPACE_MANAGER_SPACE_DESC_HAS_MAX_LIMIT_0);
            this.messageControl.show();
            return false;
        }
        
        return true;
    },
    
    _verifyInput: function(title, description) {
        return this._verifyTitle(title) && this._verifyDescription(description);
    },
    
    save: function() {
    
        var title = this._getTitle();
        var description = this._getDescription();
        
        if (!this.messageControl) {
            dojo.registerModulePath("com.ibm.lotus.oneui.v100.messages", this.iContext.io.rewriteURI("../dijit-library/oneUI.versionized/messages"));
            dojo.require("com.ibm.lotus.oneui.v100.messages.Message");
            this.messageControl = new (dojo.getObject(this._messageClass).Message)({
                messageType: 'error'
            }, this.WID + "messageBox");
            this.messageControl.hide();
        }
        
        //validation
        if (!this._verifyInput(title, description)) {
            return;
        }
        
        var theme = this._getSelectedTheme();
        var spaceType = this._getSpaceCreateType();
        
        //create space from template
        var templateList = this._templateList;
        
        if (spaceType == this.SPACE_CREATE_TYPE_TEMPLATE) {
            this._createSpaceFromTemplate(title, description, theme);
            
        } else {
            this._createSpaceFromSpace(title, description, theme);
        }
        
        
    }
});
