/* Copyright IBM Corp. 2010  All Rights Reserved.                    */
dojo.require("com.ibm.mm.builder.iwidget.SystemWidget");
dojo.require("com.ibm.mm.builder.iwidget.spacemanager.SpaceManager");
dojo.require("com.ibm.mm.builder.iwidget.spacemanager.widget.SpaceManagerWidget");
dojo.require("com.ibm.mm.builder.iwidget.spacemanager.SpaceManagerActions");
dojo.require("com.ibm.mm.builder.iwidget.spacemanager.SpaceManagerConstants");

dojo.declare("com.ibm.mm.builder.spaceManagerWidget", null, {
    byId : function(id) {
	  return dojo.byId(this.WID + id);
	},

	onLoad : function() {
		this.iWidgetAttributes = this.iContext.getiWidgetAttributes();
		
	   var widgetId = this.iContext.widgetId;
	   this.WID = "_"+ widgetId + "_";
	   
	   dojo.registerModulePath("com.ibm.lotus.oneui.v100.messages", this.iContext.io.rewriteURI("../dijit-library/oneUI.versionized/messages"));
	   dojo.require("com.ibm.lotus.oneui.v100.messages.Message");
	   
	   this.spaceManagerWidget = null;
	   
	   this._constants = com.ibm.mm.builder.iwidget.spacemanager.SpaceManagerConstants;
	   this._constants.showPagesCount = this.iWidgetAttributes.getItemValue("showPagesCount");
	   this._constants.showPageOwner = this.iWidgetAttributes.getItemValue("showPageOwner");
	   this.eventService = com.ibm.mashups.services.ServiceManager.getService("eventService");
	   
	   dojo.subscribe(this._constants.Topic.Space["switch"], this, this._switchSpace);
	   dojo.subscribe(this._constants.Topic.Space["switchPage"], this, this._switchPage);
	   
	   this.resourceBundle = com.ibm.mm.builder.coreWidgetsStrings;	
	   this.dirtyFlag = false;	   
	   
   	   this._dialog_ = { open: false };
	},

	onShow : function() {
		if (!this.spaceManagerWidget) {
			var sm = new com.ibm.mm.builder.iwidget.spacemanager.SpaceManager();
			
			var div = this.byId("spaceManager");
			this.spaceManagerWidget = new com.ibm.mm.builder.iwidget.spacemanager.widget.SpaceManagerWidget({spaceManager : sm}, div);
		}else {
			if(this.dirtyFlag){
				this.spaceManagerWidget.refresh();
				this.dirtyFlag = !this.dirtyFlag;
			}
		}
		
		this._dialog_ = this.iContext.dialogContainer;
		dojo.connect(this._dialog_, "trueHide", this, "hide");

		dojo.byId(this.WID+"btn_done").value = this.resourceBundle.I_SPACE_MANAGER_DONE;
		dojo.attr(dojo.byId(this.WID+"btn_done"),'aria-label',this.resourceBundle.I_SPACE_MANAGER_DONE);
		
		this.deletedSpaces = [];
		this.pageThemeChanged = [];
		this.spaceOwnerChanged = [];
		this.pageDeleted = [];
	},
	
	onSpaceCreated : function(iEvent) {
		
		if (this._dialog_.open) {
			
			this.spaceManagerWidget.onSpaceCreated(iEvent.payload);
			this.eventService.broadcastEvent("com.ibm.mashups.builder.refreshSpaceSelector");
			
		}else{
			this.dirtyFlag = true;
		}
	},
	
	onExportSpace : function(iEvent) {
		if (iEvent && iEvent.payload) {
			com.ibm.mm.builder.iwidget.spacemanager.SpaceManagerActions.space.exportSpace(iEvent.payload);
		}
	},
	
	onDeleteSpace : function(iEvent) {
		this.deletedSpaces.push(iEvent.payload);
	},
	
	onPageThemeChanged : function(iEvent){
		var pageId = iEvent.payload.pageId;
		var pageTitle = iEvent.payload.pageTitle;
		
		if (this._dialog_.open) {
			this.pageThemeChanged.push(pageId);
			
		}else{
			setTimeout(function(){
                window.location.reload();
            }, 0);
		}
	},
	
	onPageCreated : function(iEvent){
		if (!this._dialog_.open) {
			this.dirtyFlag = true;
		}
	},
	
	onPageDeleted : function(iEvent){
		var payload = iEvent.payload; //{currentPageId:currentPageId, parentPageId: parentPageId, pageId: pageId}
		
		if (this._dialog_.open) {
			this.pageDeleted.push(payload);			
		}else{
			this.dirtyFlag = true;
		}
	},
	
	onSpaceOwnerChanged : function(iEvent){
		this.spaceOwnerChanged.push(iEvent.payload);//{spaceId:spaceId, currentSpaceId: currentSpaceId}
	},
	
	onAddSpaceToFavorite : function(iEvent) {
		if (iEvent && iEvent.payload) {
			com.ibm.mm.builder.iwidget.spacemanager.SpaceManagerActions.space.addSpaceToFavorite(iEvent.payload);
		}
	},
	
	onRemoveSpaceFromFavorite : function(iEvent) {
        if (iEvent && iEvent.payload) {
            com.ibm.mm.builder.iwidget.spacemanager.SpaceManagerActions.space.removeSpaceFromFavorite(iEvent.payload);
        }
	},
	
	_switchSpace : function(spaceId) {
		if (spaceId) {
			this.eventService.broadcastEvent("com.ibm.mashups.builder.closeMashupDialog", this.iContext.widgetId);
			
			
			var callbackFun = dojo.hitch(this,function(){
				this.eventService.broadcastEvent("com.ibm.mashups.builder.switchSpace", spaceId);
			});
			com.ibm.mm.builder.utils.pageUtil.savePageWithConfirm(callbackFun);
		}
	},
	
	_switchPage : function(pageId) {
		if (pageId) {
			this.eventService.broadcastEvent("com.ibm.mashups.builder.closeMashupDialog", this.iContext.widgetId);
			this.eventService.broadcastEvent("com.ibm.mashups.builder.switchPage", pageId);
		}
	},
	
	_hideWithKey: function(e) {
		if (e.charCode == dojo.keys.SPACE || e.keyCode == dojo.keys.ENTER) {
			this.hide();
		}
	},
	
	hide: function(){						
		this.eventService.broadcastEvent("com.ibm.mashups.builder.closeMashupDialog", this.iContext.widgetId);		
		
		if(dojo.indexOf(this.pageThemeChanged, com.ibm.mm.builder.utils.pageUtil.getCurrentPageId()) > -1){
			setTimeout(function(){
                window.location.reload();
            }, 0);
		}
		
		if(this.pageDeleted.length > 0){		
			//			
			dojo.forEach(this.pageDeleted, function(pageStatus){
				if(pageStatus.pageId === pageStatus.currentPageId){
				
					var parentPageId = pageStatus.parentPageId;
					
					if(com.ibm.mm.builder.utils.pageUtil.isRoot(parentPageId)) {
						parentPageId = com.ibm.mm.builder.utils.pageUtil.getFirstRootPageId();
					}
					//refresh navigation	
					com.ibm.mashups.builder.model.Factory.getRuntimeModel().getCurrentPage().setDirty(false);					
					com.ibm.mashups.services.ServiceManager.getService("eventService").broadcastEvent("com.ibm.mashups.builder.switchPage", parentPageId);
				}else{
					com.ibm.mashups.services.ServiceManager.getService("eventService").broadcastEvent("com.ibm.mashups.builder.refreshNavigation");
				}
				
			});
			
		}
		
		if(this.deletedSpaces.length > 0){		
			//			
			dojo.forEach(this.deletedSpaces, function(spaceStatus){
				if(spaceStatus.spaceId === spaceStatus.currentSpaceId){
					com.ibm.mashups.builder.model.Factory.getRuntimeModel().getCurrentPage().setDirty(false);
					com.ibm.mashups.services.ServiceManager.getService("eventService").broadcastEvent("com.ibm.mashups.builder.switchSpace", com.ibm.mm.builder.utils.spaceUtil.getHomeSpaceId() || com.ibm.mm.builder.utils.spaceUtil.getWelcomeSpaceId());
				}else{
					com.ibm.mashups.services.ServiceManager.getService("eventService").broadcastEvent("com.ibm.mashups.builder.refreshSpaceSelector");
				}
			});
		}
		
		if(this.spaceOwnerChanged.length > 0){		
			//			
			dojo.forEach(this.spaceOwnerChanged, function(spaceStatus){
				if(spaceStatus.spaceId === spaceStatus.currentSpaceId){
					com.ibm.mashups.services.ServiceManager.getService("eventService").broadcastEvent("com.ibm.mashups.builder.switchSpace", com.ibm.mm.builder.utils.spaceUtil.getHomeSpaceId() || com.ibm.mm.builder.utils.spaceUtil.getWelcomeSpaceId());
				}else{
					com.ibm.mashups.services.ServiceManager.getService("eventService").broadcastEvent("com.ibm.mashups.builder.refreshSpaceSelector");
				}
			});
		}
			
	}
});
