/* Copyright IBM Corp. 2010  All Rights Reserved.                    */
/**
 * @author EriK (bizheng@cn.ibm.com)
 */
dojo.require("com.ibm.mm.builder.widget.CustomDialog");
dojo.require("com.ibm.mm.enabler.logging");
dojo.require("com.ibm.mm.builder.iwidget.SystemWidget");
dojo.require("com.ibm.mm.builder.dialog.DialogFooter");

dojo.declare("com.ibm.mm.builder.systemwidget.SystemMessageWidget", com.ibm.mm.builder.iwidget.SystemTemplatedWidget, {
		
	infoEnabled: null,
	warnEnabled: null,
	errorEnabled: null,	
	
	_hasMessage: false,
	messageDialog: null,
	currentLevel: 0,  
	currentPageMode: "view",
	
	// the ID of this handler
	handlerID: "com.ibm.mm.builder.systemwidget.SystemMessageWidget",
	// the lowest loglevel passed to this should be INFO
	logLevel: com.ibm.mashups.enabler.logging.LogLevel.INFO,
	
	onLoad: function() {
		this.loadWidgetPref()
		this.LOGGER.addHandler(this);
		dojo.subscribe(com.ibm.mm.builder.eventTopics.Open_Catalog,this,"whenGotoCatalog")
	},
	
	onView: function(){
		this.inherited(arguments);
		
		dojo.toggleClass(this.messageBoxConfigButtons, "mmSystemMessageInfoBtnOnClick", this.infoEnabled);
		dojo.toggleClass(this.messageBoxConfigButtons, "mmSystemMessageWarnBtnOnClick", !this.infoEnabled && this.warnEnabled);
		this.errorEnabled = !this.infoEnabled && !this.warnEnabled
		dojo.toggleClass(this.messageBoxConfigButtons, "mmSystemMessageErrorBtnOnClick", this.errorEnabled);
		
		this._setA11YHint();
	},
	
	/**
	 * Load widget parameters, supported value
	 * debugLevel=info|error|warn
	 */
	loadWidgetPref:function(){
		var att = this.iContext.getiWidgetAttributes();
		if (att != null) {
			this.infoEnabled = (att.getItemValue("infoEnabled") == 'true');
			this.warnEnabled = (att.getItemValue("warnEnabled") == 'true');
			this.errorEnabled = (att.getItemValue("errorEnabled") == 'true');
		}		
	},
	
	/**
	 * Handle function of iEvent "onPageModeChanged"
	 * Hide the system message when the mode is switch to "view"
	 */
	onPageModeChanged:function(iEvent){
		var mode = iEvent.payload;
		this.currentPageMode = mode;
		if(mode == "view" && this.messageDialog)
			this.messageDialog.hide();
	},
	
	createMessageDialog : function() {
		var att = this.iContext.getiWidgetAttributes();
		this.messageDialog = new com.ibm.mm.builder.widget.CustomDialog({
            id: "mm_systemMessage_dialog",
			title: this.cws.I_SYSTEM_MESSAGE_NAME,
			nodeWidth: "414px",
			containerBackgroundColor: "white",
			hasRightBottomResizer: false,
			displayCloseButton: true,
			modelDialog: att.getItemValue("isModel") == 'true',
			sharedWidget:true
        }, this.messageBox)
		
		dojo.style(this.messageBox, "display", "");
	},
	
	displayMessage: function() {
		if(this._hasMessage == false) return;
		
		if(!this.messageDialog)
			this.createMessageDialog();
			
		this.messageDialog.show();
	},
	
	whenGotoCatalog : function(){
		if(this.messageDialog) this.messageDialog.hide();
	},
	
	getHandlerID: function() {
		return this.handlerID;
	},
	getLogLevel: function() {
		return this.logLevel;
	},
	
	/**
	* show error messages in view mode
	*/
    log: function(loggerName, logLevel, method, message){
        //if page in view mode,and log.type is not error, skip the message
        if (logLevel < com.ibm.mashups.enabler.logging.LogLevel.INFO) 
            return;
		
		if (this.currentPageMode == "view" && logLevel != com.ibm.mashups.enabler.logging.LogLevel.SEVERE)
            return;
		
        message = (message || method) + "";
        if (!message) return;
        var msgCode = null;
        if (message.indexOf("BMWMB") == 0) {
            msgCode = message.substring(0, message.indexOf(":"));
            message = message.substring(message.indexOf(":") + 1);
        }
        msgCode = msgCode ? dojo.string.substitute(this.cws.I_SYSTEM_MESSAGE_MSG_CODE, [msgCode]) : "";
			
        var className = "", imgClass = "", level = 0, title = "system message image", shouldDisplay = false;
		
		//for a11y high-contrast mode
		var imageSrc = "";
		
        switch (logLevel) {
            case com.ibm.mashups.enabler.logging.LogLevel.INFO:
                shouldDisplay = this.infoEnabled;
                imageSrc = builderConfig.builderPath + "/images/systemmessage/info_icon.png";
                imgClass = "mmSystemMessageInfo_img";
                className = "mmSystemMessageInfo";
                level = 1;
                title = this.cws.MESSAGE_BOX_ICON_INFO;
                break;
            case com.ibm.mashups.enabler.logging.LogLevel.WARNING:
                shouldDisplay = this.warnEnabled || this.infoEnabled;
                imageSrc = builderConfig.builderPath + "/images/systemmessage/warning_icon.png";
                imgClass = "mmSystemMessageWarning_img";
                className = "mmSystemMessageWarning";
                level = 2;
                title = this.cws.MESSAGE_BOX_ICON_WARN;
                break;
            case com.ibm.mashups.enabler.logging.LogLevel.SEVERE:
                shouldDisplay = this.errorEnabled || this.warnEnabled || this.infoEnabled;
                imageSrc = builderConfig.builderPath + "/images/systemmessage/error_icon.png";
                imgClass = "mmSystemMessageError_img";
                className = "mmSystemMessageError";
                level = 3;
                title = this.cws.MESSAGE_BOX_ICON_ERROR;
                break;
		}
        
		this._hasMessage = true;
        dojo.addClass(this.messageIcon, "mmSystemMessageIconClickable");
        this.messageIcon.setAttribute("tabIndex", "0");
		this.messageImage.src = imageSrc;
		dojo.attr(this.messageImage,'alt',title);
		dojo.style(this.messageImage, "display", "");
		
		if (level > this.currentLevel) {
			var removedClassName = (this.currentLevel == 2 ? "mmSystemMessageWarning_img" : "mmSystemMessageInfo_img");
			dojo.removeClass(this.messageIcon,removedClassName);
			dojo.addClass(this.messageIcon,imgClass);
			this.messageIcon.setAttribute("title",title);
			dojo.attr(this.messageIcon,"aria-label",title);
//            this.messageIcon.innerHTML = dojo.string.substitute('<input type="image" alt="${0}" title="${0}" src ="${1}" class="${2}" />', 
//				[title, src, imgClass]);
            this.currentLevel = level;
        }
        if (!shouldDisplay) className += " mmSystemMessageHidden";
        
		this.appendMessage(dojo.string.substitute(
			'<div class="${0}">'+
				'<div tabindex=0 class="mmSystemMessageInfoContent">'+
					'<div class="mmSystemMessageTypeIcon ${2}" title="${1}">'+
//						'<img alt="${1}" title="${1}" src="${2}" class="${3}"/>'+
					'</div>'+
					'<div class="mmSystemMessageMsgContent">'+
						'<span>'+
							'<span>${3}</span>'+
							'<div class="mmSystemMessageMsgCode">${4}</div>'+
						'</span>'+
					'</div>'+
				'</div>'+
				'<div class="mmSystemMessageInfoBreakLine"></div>'+
			"</div>", [className, title, imgClass, message, msgCode]));
	},
	
    appendMessage: function(messageHTML){
		this.messageBoxConsole.innerHTML += messageHTML;
    },
	
	clear:function(){
		this.messageBoxConsole.innerHTML=""
		this.currentLevel = 0;
		dojo.style(this.messageImage,'display','none');
		this._hasMessage = false;
		dojo.removeClass(this.messageIcon,"mmSystemMessageIconClickable");
		this.messageIcon.removeAttribute("tabIndex");
	},
	
    onClickErrorBtn: function(e){
        if (!this.errorEnabled) {
            this.errorEnabled = true;
            this.reFormatMessage("Error", this.errorEnabled);
            if (this.warnEnabled) {
                this.warnEnabled = false;
                this.reFormatMessage("Warning", false);
            }
            if (this.infoEnabled) {
                this.infoEnabled = false;
                this.reFormatMessage("Info", false);
                this.reFormatMessage("Warning", false);
            }
			com.ibm.mm.builder.utils.htmlUtil.setClass(this.messageBoxConfigButtons, "mmSystemMessageErrorBtnOnClick");
			com.ibm.mm.builder.utils.htmlUtil.setClass(this.errorBtn, "mmSystemMessageErrorBorder");
			dojo.removeClass(this.infoBtn, "mmSystemMessageInfoBorder");
			dojo.removeClass(this.warnBtn, "mmSystemMessageWarnBorder");
        }
		this._setA11YHint();
    },
	
    onClickWarnBtn: function(e){
        if (!this.warnEnabled) {
            this.errorEnabled = false;
            this.warnEnabled = true;
            this.reFormatMessage("Warning", true);
            if (this.infoEnabled) {
                this.infoEnabled = false;
                this.reFormatMessage("Info", false);
            }
			com.ibm.mm.builder.utils.htmlUtil.setClass(this.messageBoxConfigButtons, "mmSystemMessageWarnBtnOnClick");
			com.ibm.mm.builder.utils.htmlUtil.setClass(this.errorBtn, "mmSystemMessageErrorBorder");
			com.ibm.mm.builder.utils.htmlUtil.setClass(this.warnBtn, "mmSystemMessageWarnBorder");
			dojo.removeClass(this.infoBtn, "mmSystemMessageInfoBorder");
        }
		this._setA11YHint();
    },
	
    onClickInfoBtn: function(e){
        if (!this.infoEnabled) {
			this.infoEnabled = true;
            
			this.errorEnabled = false;
			
            if (!this.warnEnabled) {
                this.reFormatMessage("Warning", true);
            }
            this.warnEnabled = false;
			this.reFormatMessage("Info", true);
			com.ibm.mm.builder.utils.htmlUtil.setClass(this.messageBoxConfigButtons, "mmSystemMessageInfoBtnOnClick");
			com.ibm.mm.builder.utils.htmlUtil.setClass(this.errorBtn, "mmSystemMessageErrorBorder");
			com.ibm.mm.builder.utils.htmlUtil.setClass(this.warnBtn, "mmSystemMessageWarnBorder");
			com.ibm.mm.builder.utils.htmlUtil.setClass(this.infoBtn, "mmSystemMessageInfoBorder");
			
        }
		
		this._setA11YHint();
    },
	
	reFormatMessage : function(type, status){
		dojo.query(".mmSystemMessage" + type, this.messageBoxConsole).forEach(function(aDiv){
			dojo.toggleClass(aDiv, "mmSystemMessageHidden", !status);
		});
	},
	
	save:function(){
		var att = this.iContext.getiWidgetAttributes();
		att.setItemValue("infoEnabled", this.infoEnabled);
		att.setItemValue("warnEnabled", this.warnEnabled);
		att.setItemValue("errorEnabled", this.errorEnabled);
		att.save()
		
		this.messageDialog.hide();
	},
	
	_setA11YHint: function() {
		var warnEnabled = this.infoEnabled || this.warnEnabled;
		var errorEnabled = warnEnabled || this.errorEnabled;
		
		if (this.infoEnabled) {
			this.infoBtn.alt = "info is selected";
		} else {
			this.infoBtn.alt = "info";
		}
		
		if (warnEnabled) {
			this.warnBtn.alt = "warn is selected";
		} else {
			this.warnBtn.alt = "warn";
		}
		
		if (errorEnabled) {
			this.errorBtn.alt = "error is selected";
		} else {
			this.errorBtn.alt = "error";
		}
		
	},
	
	onMessageIconPressed: function(evt) {
		if (evt.charCode == dojo.keys.SPACE || evt.keyCode == dojo.keys.ENTER) {
			this.displayMessage();
		}
	}
});
