/* Copyright IBM Corp. 2009  All Rights Reserved.                    */
dojo.provide("mm.tests.enabler.enabler_model_url");

dojo.require("mm.tests.base.support");
dojo.require("mm.tests.enabler.base");
dojo.require("com.ibm.mm.enabler.model.url");

tests.register("mm.tests.enabler.enabler_model_url", 
    [
        new mm.tests.enabler.BaseTest("testCreateModelURL", 
            function (doh) {
                var modelUrlFactory = com.ibm.mm.enabler.model.UrlFactory;
                
                doh.debug("Asserting true, modelFactory != null");
                doh.assertTrue(modelUrlFactory != null);
                
                var modelUrl = modelUrlFactory.createModelUrl(com.ibm.mashups.enabler.model.url.ModelUrlFactory.CATALOG_URL, null);
                
                doh.debug("Asserting true, modelUrl != null");
                doh.assertTrue(modelUrl != null);
                
                var testValue = "/mum/contenthandler?uri=catalog";
                
                doh.debug("Asserting nearly equal " + testValue + " - " + modelUrl.getAbsoluteURL());
                doh.assertTrue(modelUrl.getAbsoluteURL().indexOf(testValue)!=-1);
                
                // set the id
                modelUrl.setPrimaryNode("xyz");
                testValue = "/mum/contenthandler?uri=catalog%3aid%3axyz";
                
                doh.debug("Asserting nearly equal " + testValue + " - " + modelUrl.getAbsoluteURL());
                doh.assertTrue(modelUrl.getAbsoluteURL().toLowerCase().indexOf(testValue)!=-1);

                testValue = "catalog:id:xyz";
                
                doh.debug("Asserting equal " + testValue + " - " + modelUrl.getModelURI());
                doh.assertEqual(testValue, modelUrl.getModelURI());

                // set a id with two parts
                modelUrl.setPrimaryNode("collection", false, "member");
                modelUrl.setSecondaryNode("xyz");
                
                //modelUrl.setID("collection", "id:xyz");
                
                // test whether the ssp translation works correctly
                testValue="member:collection@id:xyz";
                doh.debug("Asserting equal " + testValue + " - " + modelUrl.getSchemeSpecificPart());
                doh.assertEqual(testValue, modelUrl.getSchemeSpecificPart());
                
                
                // see if the absolute url is generated correctly
                testValue = "/mum/contenthandler?uri=catalog%3amember%3acollection%40id%3axyz";
                
                doh.debug("Asserting nearly equal " + testValue + " - " + modelUrl.getAbsoluteURL());
                doh.assertTrue(modelUrl.getAbsoluteURL().toLowerCase().indexOf(testValue)!=-1);

                // see if the uri is set correctly
                testValue = "catalog:member:collection@id:xyz";
                
                doh.debug("Asserting equal " + testValue + " - " + modelUrl.getModelURI());
                doh.assertEqual(testValue, modelUrl.getModelURI());
                
                // set the ID Parts through the generic method with subModels:
                var nodes = [ { value: "firstnode",
                                isID: false,
                                subModel: "sub1"},
                              { value: "secondnode",
                                isID: true},
                              { value: "thirdnode"},
                              { value: "fourthnode",
                                isID: false,
                                subModel: "sub4"}
                            ];
                doh.debug("Assigning values to modelUrl");
                modelUrl.setNodes(nodes);
                
                // test whether the setnodes method works correctly
                testValue="sub1:firstnode@id:secondnode@id:thirdnode@sub4:fourthnode";
                doh.debug("Asserting equal " + testValue + " - " + modelUrl.getSchemeSpecificPart());
                doh.assertEqual(testValue, modelUrl.getSchemeSpecificPart());
                
                // see if setting / getting the schemespecific part works correctly
                testValue = "i%20am%20a%20little%20tea%20pot%3fapricot%20flavor";
                
                modelUrl.setSchemeSpecificPart(testValue);
                
                doh.debug("Asserting equal " + testValue + " - " + modelUrl.getSchemeSpecificPart());
                doh.assertEqual(testValue, modelUrl.getSchemeSpecificPart());
            }
        ),
        new mm.tests.enabler.BaseTest("testGetModelURL", 
            function (doh) {
                var modelUrlFactory = com.ibm.mm.enabler.model.UrlFactory;
                
                doh.debug("Asserting true, modelFactory != null");
                doh.assertTrue(modelUrlFactory != null);
                
                // possible URLs
                // /mum/contenthandler?uri=scheme:ssp&p1=v1&p2=v2
                // /mum/mycontenthandler?uri=scheme:ssp&p1=v1&p2=v2
                // /mum/contenthandler/vpname/scheme/ssp?p1=v1&p2=v2
                // /mum/mycontenthandler/vpname/scheme/ssp?p1=v1&p2=v2
                
                var urls = [
                    "/mum/contenthandler?uri=scheme:ssp&p1=v1&p2=v2",
                    "/mum/mycontenthandler?uri=scheme:ssp&p1=v1&p2=v2",
                    "/mum/contenthandler/vp/scheme/ssp?p1=v1&p2=v2",
                    "/mum/mycontenthandler/mm/scheme/ssp?p1=v1&p2=v2"
                    ];
                    
                var testURI = "scheme:ssp";
                    
                for (var i = 0; i<urls.length; i++) {
                    doh.debug("Transforming URL " + urls[i]);
                    var modelUrl = modelUrlFactory.getModelUrl(urls[i]);
                    
                    doh.debug("Asserting equal " + testURI + " - " + modelUrl.getModelURI());
                    doh.assertEqual(testURI, modelUrl.getModelURI());
                }
            }
        )
    ]
);
