/* Copyright IBM Corp. 2010  All Rights Reserved.                    */
dojo.provide("com.ibm.mm.widget.dataViewer._WB_VER_.dataModel");

dojo.require("dojox.xml.parser");
dojo.require("com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil");

/*
 * dataModel takes the responsibility of parsing the data. The data returned from data model support
 * pagination as default. Set pagination fields as empty string or zero if data source does not support it.
 * 
 */

dojo.declare("com.ibm.mm.widget.dataViewer._WB_VER_.dataModel", null, {
	canProcess: function(data, contentType){
		/*For performance reason, we return the second parameter data*/
		return {'support' : false, 'data' : null};
	},

	process: function(data){
		return null;
	}
});

dojo.declare("com.ibm.mm.widget.dataViewer._WB_VER_.XMLDataModel", com.ibm.mm.widget.dataViewer._WB_VER_.dataModel, {
	name: 'XMLDataModel',

	constructor: function(){
		this.dataModel = new com.ibm.mm.widget.dataViewer._WB_VER_.FlattenDataModel();
	},

	canProcess: function(data, contentType){
		if (contentType && data && contentType.toUpperCase().indexOf('XML') !== -1){
		    data = dojox.xml.parser.parse(data);
		}
		
		if (dojo.isObject(data)) {
			var feedNodes = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.getChildNodesByTagName(data, "feed");
			
			if (feedNodes.length > 0) {
				return {'support' : true, 'data' : data};
			}
		}
		return {'support' : false, 'data' : null};
	},

	process: function(data, _xmlDoc){
		var xmlDoc = _xmlDoc ? _xmlDoc : (dojo.isObject(data) ? data : dojox.xml.parser.parse(data) );
		var jsonArray = this.handleFeed(xmlDoc);
		if (!dojo.isObject(data)) xmlDoc = null;
		if (jsonArray.length <= 0){
			//throw("No content from data source");
			throw(new com.ibm.mm.widget.dataViewer._WB_VER_.NoContentException(com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerMessages.E_NO_CONTENT));
		}
		var columnList = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.getColumnList(jsonArray[0]);
		var paginationData = {'totalResult' : jsonArray.length, 'startIndex' : 0, 'itemsPerPage' : jsonArray.length,
			'first' : '', 'last' : '', 'previous' : '', 'next' : '', 
			'result' : jsonArray,  'columnList' : columnList};
		return paginationData;
	},
	
	/*
	 * Use data model to handle the ATOM feed
	 */
	handleFeed: function(data){
		var entryArray = [];
		var entryNodes = dojo.isIE ? data.getElementsByTagName("entry") : dojo.query("entry", data);
		if (entryNodes) {
			for (var i = 0; i < entryNodes.length; i++) {
				var entryNode = entryNodes[i];
				if (!entryNode) {
					continue;
				}
				try{
					this.dataModel.process(entryNode, entryArray);			
				} catch(e){
					//Data model could not handle this entry
					continue;
				}
			}
		}
		return entryArray;
		
	}
});

dojo.declare("com.ibm.mm.widget.dataViewer._WB_VER_.RSSDataModel", com.ibm.mm.widget.dataViewer._WB_VER_.dataModel, {
	name: "RSSDataModel",
	
    constructor: function(){
        this.dataModel = new com.ibm.mm.widget.dataViewer._WB_VER_.FlattenDataModel();
    },
    
	canProcess: function(data, contentType){
        if (contentType && contentType.toUpperCase().indexOf('XML') !== -1 && data){
            data = dojox.xml.parser.parse(data);
        }
        
        if (dojo.isObject(data)){
			var rootNodes = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.getChildNodesByTagName(data, "rss");
			if (rootNodes.length === 0) {
				rootNodes = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.getChildNodesByTagName(data, "rdf");
			}
			if (rootNodes.length > 0) {
                return {'support' : true, 'data' : data};
			}
        }
        return {'support' : false, 'data' : null};
	},
	
	process: function(data, _xmlDoc){
        var xmlDoc = _xmlDoc ? _xmlDoc : (dojo.isObject(data) ? data : dojox.xml.parser.parse(data) );
        var jsonArray = this.handleFeed(xmlDoc);
        if (!dojo.isObject(data)) xmlDoc = null;
        if (jsonArray.length <= 0){
            //throw("No content from data source");
            throw(new com.ibm.mm.widget.dataViewer._WB_VER_.NoContentException(com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerMessages.E_NO_CONTENT));
        }
        var columnList = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.getColumnList(jsonArray[0]);
        
        var paginationData = {'totalResult' : jsonArray.length, 'startIndex' : 0, 'itemsPerPage' : jsonArray.length,
            'first' : '', 'last' : '', 'previous' : '', 'next' : '', 
            'result' : jsonArray,  'columnList' : columnList};
        return paginationData;
	},
	
    /*
     * Use data model to handle the RSS feed
     */
    handleFeed: function(data){
        var entryArray = [];
        var entryNodes = dojo.isIE ? data.getElementsByTagName("item") : dojo.query("item", data);
        if (entryNodes) {
            for (var i = 0; i < entryNodes.length; i++) {
                var entryNode = entryNodes[i];
                if (!entryNode) {
                    continue;
                }
                try{
                    this.dataModel.process(entryNode, entryArray);          
                } catch(e){
                    //Data model could not handle this entry
                    continue;
                }
            }
        }
        return entryArray;
    }
});

dojo.declare("com.ibm.mm.widget.dataViewer._WB_VER_.CSVDataModel", com.ibm.mm.widget.dataViewer._WB_VER_.dataModel, {
	name: 'CSVDataModel',

	canProcess: function(data, contentType){
		if (dojo.isString(contentType) && contentType.toUpperCase().indexOf('XML') >= 0){
			return {'support' : false, 'data' : null};
		}

		if (data && dojo.isString(data)){
			var rows = data.split(/\s*\n\s*/);
			if (!rows || rows.length <= 0){
				return {'support' : false, 'data' : null};
			}
			
			var columnList = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.splitterCSVData(rows[0]);
			if (!columnList || columnList.length <= 0) return {'support' : false, 'data' : null};
			var columnLength = columnList.length;
			for (var i=1; i<rows.length; i++){
				if (rows[i] === "") {
					break;
				}
	
				var rowList = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.splitterCSVData(rows[i]);
				if (!rowList || rowList.length !== columnLength) return {'support' : false, 'data' : null};
			}
	
			return {'support' : true, 'data' : null};			
		}

		return {'support' : false, 'data' : null};
	},

	process: function(data){
		var jsonArray = this.processCSVData(data);
		if (jsonArray.length <= 0){
			//throw("No content from data source");
			throw(new com.ibm.mm.widget.dataViewer._WB_VER_.NoContentException(com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerMessages.E_NO_CONTENT));
		}
		var columnList = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.getColumnList(jsonArray[0]);
		
		var paginationData = {'totalResult' : jsonArray.length, 'startIndex' : 0, 'itemsPerPage' : jsonArray.length,
			'first' : '', 'last' : '', 'previous' : '', 'next' : '', 
			'result' : jsonArray,  'columnList' : columnList};
		return paginationData;

	},

	processCSVData: function(dataString, viewConfig){

		var jsonArray = [];		

		var rows = dataString.split(/\s*\n\s*/);
		if (!rows || rows.length <= 0){
			//throw('Illegal CSV document');
			throw(com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerMessages.E_ILLEGAL_CSV_DOCUMENT);
		}

		var columnList = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.splitterCSVData(rows[0]);
		for (var j=0; j<columnList.length; j++){
			columnList[j] = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.unescapeCSVCell(columnList[j]);
		}
		for (var i=1; i<rows.length; i++){
			if (rows[i] === "") {
				break;
			}

			var rowDataList = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.splitterCSVData(rows[i]);
			if (rowDataList.length < columnList.length){
				//throw('Illegal CSV document');
				throw(com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerMessages.E_ILLEGAL_CSV_DOCUMENT);
			}

			var data = {};
			for (var j=0; j<columnList.length; j++){
				data[columnList[j]] = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.unescapeCSVCell(rowDataList[j]);
			}
			jsonArray.push(data);
		}
		
		return jsonArray;
	}
	
});

dojo.declare("com.ibm.mm.widget.dataViewer._WB_VER_.CSVLikeDataModel", com.ibm.mm.widget.dataViewer._WB_VER_.dataModel, {
	name: 'CSVLikeDataModel',

	/*
	 * If input string comply with below format, return true, otherwise, return false
	 * column 1 name, column 2 name, ... | type, type, ... | cell 1 value, cell 2 value, ... | ...
	 */
	canProcess: function(data, contentType){
		if (dojo.isString(contentType) && contentType.toUpperCase().indexOf('XML') >= 0){
			return {'support' : false, 'data' : null};
		}

		if (data && dojo.isString(data)){
			data = data.replace(/\s*\n\s*/g, "");
			var rows = data.split('|');
			if (!rows || rows.length <= 2){
				return {'support' : false, 'data' : null};
			}
			
			var columnList = rows[0].split(',');
			if (!columnList || columnList.length <= 0) return {'support' : false, 'data' : null};
	
			var columnLength = columnList.length;
			for (var i=1; i<rows.length; i++){
				if (rows[i] === "") {
					break;
				}
	
				var rowList = rows[i].split(',');
				if (!rowList || rowList.length !== columnLength) return {'support' : false, 'data' : null};
			}
	
			return {'support' : true, 'data' : null};			
		}

		return {'support' : false, 'data' : null};
	},

	process: function(data){
		data = data.replace(/\s*\n\s*/g, "");
		var rows = data.split('|');
		
		var columnList = rows[0].split(',');
		
		var jsonArray = [];
		var object;
		for (var i=2; i<rows.length; i++){
			if (rows[i] === "") {
				break;
			}

			object = {};
			var rowList = rows[i].split(',');
			for (var j=0; j<columnList.length; j++){
				object[columnList[j]] = rowList[j];
			}
			jsonArray.push(object);

		}

		if (jsonArray.length <= 0){
			//throw("No content from data source");
			throw(new com.ibm.mm.widget.dataViewer._WB_VER_.NoContentException(com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerMessages.E_NO_CONTENT));
		}
		
		var paginationData = {'totalResult' : jsonArray.length, 'startIndex' : 0, 'itemsPerPage' : jsonArray.length,
			'first' : '', 'last' : '', 'previous' : '', 'next' : '', 
			'result' : jsonArray,  'columnList' : columnList};
		return paginationData;

	}
});

dojo.declare("com.ibm.mm.widget.dataViewer._WB_VER_.JSONArrayDataModel", com.ibm.mm.widget.dataViewer._WB_VER_.dataModel, {
	name: 'JSONArrayDataModel',

	canProcess: function(data, contentType){
		if (contentType && contentType.toUpperCase().indexOf('XML') !== -1){
			return {'support' : false, 'data' : null};
		}
		if (dojo.isString(data)) {
			try {
				data = dojo.fromJson(data);
			} catch(e) {
				return {'support' : false, 'data' : null};
			}
		}
		return {'support' : dojo.isArray(data) && data.length > 0, 'data' : null };
	},

	process: function(jsonArray){
		if (dojo.isString(jsonArray)) {
			jsonArray = dojo.fromJson(jsonArray);
		}
		if (jsonArray.length <= 0){
			//throw("No content from data source");
			throw(new com.ibm.mm.widget.dataViewer._WB_VER_.NoContentException(com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerMessages.E_NO_CONTENT));
		}
		var columnList = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.getColumnList(jsonArray[0]);
		
		var paginationData = {'totalResult' : jsonArray.length, 'startIndex' : 0, 'itemsPerPage' : jsonArray.length,
			'first' : '', 'last' : '', 'previous' : '', 'next' : '', 
			'result' : jsonArray,  'columnList' : columnList};
		return paginationData;

	}
});

dojo.declare("com.ibm.mm.widget.dataViewer._WB_VER_.JSONFeedDataModel", com.ibm.mm.widget.dataViewer._WB_VER_.dataModel, {
	name: 'JSONFeedDataModel',

	canProcess: function(data, contentType){
		if (contentType && contentType.toUpperCase().indexOf('XML') !== -1){
			return {'support' : false, 'data' : null};
		}
		return { 'support' : !!(data && data.totalResult && (data.startIndex !== undefined) && data.itemsPerPage && data.first && data.last && data.result && data.columnList), 'data' : null }; 

	},

	process: function(data){
		return data;
	}
});

dojo.declare("com.ibm.mm.widget.dataViewer._WB_VER_.JSONFeedEventDataModel", com.ibm.mm.widget.dataViewer._WB_VER_.dataModel, {
	name: 'JSONFeedEventDataModel',

	canProcess: function(data, contentType){
		if (contentType && contentType.toUpperCase().indexOf('XML') !== -1){
			return {'support' : false, 'data' : null};
		}
		
		if (!data){
			return {'support' : false, 'data' : null};
		}

		try{
			//simply check the format
			var jsonData = data;
			if (jsonData && jsonData['atom:feed']){
				return {'support' : true, 'data' : null};
			}
		}catch(e){}

		return {'support' : false, 'data' : null};
	},

	process: function(data){

		var result = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.parseJSONFeed(data);
		
		var paginationData = {'totalResult' : result.totalResults, 'startIndex' : result.StartIndex || 0, 'itemsPerPage' : result.itemsPerPage,
			'first' : result.first || '', 'last' : result.last || '', 'previous' : result.previous || '', 'next' : result.next || '', 
			'result' : result.result,  'columnList' : result.columnNames};
			
		//store to cache before return
		var url = result.first || result.last || result.previous || result.next;
		if (url === ''){ 
			throw(com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerMessages.E_ILLEGAL_PIPELINE_DATA);			
		}
		
		//opensearch spec, startIndex starts from 1
		var startIndex = paginationData.startIndex;
		var count = paginationData.itemsPerPage;
		var pipelineID = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.getparamFromURL(url, "id");
		
		var selfURL = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.createPipelineURL(url, "count", count);
		selfURL = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.createPipelineURL(url, "startIndex", startIndex);
		
		var cache = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.dataFetcher._cache;
		
		delete cache.data;         //clear cache
		cache.data = null;
		
		cache.key.startIndex = startIndex;
		cache.key.count = count;
		cache.key.pipelineID = pipelineID;
		cache.key.url = selfURL;
		cache.data = paginationData;
		
		return paginationData;

	}
});

/*
 * FlattenDataModel takes the responsibility of parsing the ATOM data feed entry. Mainly the ATOM
 * feeds come from Mashup Hub.
 * This class support ATOM feed with below characteristic
 * <entry>
 * 	<content type="application/xml">
 * 		data ...
 * 	</content>
 * </entry>
 */
dojo.declare("com.ibm.mm.widget.dataViewer._WB_VER_.FlattenDataModel", null, {
	/*
	 * entryNode : feed entry node, as input
	 * entryArray : store processed result
	 */
	process: function(entryNode, entryArray){
		if (entryNode.nodeName.toLowerCase() === "entry") {
			var contentNodes = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.getChildNodesByTagName(entryNode, "content");
			if (!contentNodes || contentNodes.length === 0) {
				contentNode = entryNode;
			} else {
				var contentNode = contentNodes[0];
			}
		} else {
			// RSS case
			var contentNode = entryNode;
		}
        var startNode = contentNode;
		
		var rowNodes = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.getChildNodesByTagName(contentNode, "row");
		if (rowNodes && rowNodes.length > 0) {
			startNode = rowNodes[0];
		}
        
		var childNodes = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.getDescendantNodes(startNode);
        if (childNodes.length === 0) {
			childNodes.push(startNode);
		}
		
		com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil._setResultForEntryNode(entryNode, childNodes, entryArray);
	}
});

/*Write more data model below*/
