/* Copyright IBM Corp. 2010  All Rights Reserved.                    */
dojo.provide("com.ibm.mm.widget.dataViewer._WB_VER_.dataSource");

dojo.require("dojox.collections.Set");
dojo.require("com.ibm.mm.widget.dataViewer._WB_VER_.DataViewerException");
dojo.require("com.ibm.mm.widget.dataViewer._WB_VER_.dataModel");

/*
 * dataSource takes the responsibility of 1)retrieving data from data source, 2)parsing data
 * via leveraging registered data model's capability
 * 
 * Developer could add new dataModel to support more data
 * 
 * The data from getData is a JSON object with below format.
 * {
 * 		totalResult: 423000,
 * 		startIndex: 21,
 * 		itemsPerPage: 10,
 * 		first: '',
 * 		last: '',
 * 		previous: '',
 * 		next: '',
 * 		result: [],
 * 		columnList: []
 * }
 * 
 * If data source does not support pagination, set fields for pagination as zero or empty string.
 * 
 * getData is a asynchronous interface, the callback is invoked with the data from data source in above
 * format.
 * 
 * Data viewer should be able to render data source supporting this interface.
 */

dojo.declare("com.ibm.mm.widget.dataViewer._WB_VER_.dataSource", null, {
	getData: function(callback){}
});

dojo.declare("com.ibm.mm.widget.dataViewer._WB_VER_.remoteDataSource", com.ibm.mm.widget.dataViewer._WB_VER_.dataSource, {
	name: 'remoteDataSource',
	
	constructor: function(feedURL, errorCallback){
		this.feedURL = feedURL;
		this.errorCallback = errorCallback;
		this.dataModels = [
			new com.ibm.mm.widget.dataViewer._WB_VER_.XMLDataModel(), 
			new com.ibm.mm.widget.dataViewer._WB_VER_.RSSDataModel(),
			new com.ibm.mm.widget.dataViewer._WB_VER_.JSONArrayDataModel(),
			new com.ibm.mm.widget.dataViewer._WB_VER_.CSVLikeDataModel(), 
			new com.ibm.mm.widget.dataViewer._WB_VER_.CSVDataModel(),
			new com.ibm.mm.widget.dataViewer._WB_VER_.JSONFeedDataModel()];
		this.resourceBundle = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerMessages;
	},

	getData: function(callback){
		var self = this;
		var bindArgs = {
			url: this.feedURL ,
			load: function(data, ioArgs){
				try{
					var contentType = ioArgs ? ioArgs.xhr.getResponseHeader('Content-Type') : null;
					var found = false;
					
					for(var i=0; i < self.dataModels.length; i++) {
						var dataModel = self.dataModels[i];
						var status = dataModel.canProcess(data, contentType);
						if (status['support']){
							found = true;
							var paginationData = dataModel.process(data, status['data']);
							callback(paginationData, self.name, dataModel.name);
							break;
						}
					}
					
					if (!found){
						// Data source is not supported
						throw(new com.ibm.mm.widget.dataViewer._WB_VER_.DataSourceNotSupportException(com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerMessages.E_DATA_SOURCE_NOT_SUPPORTED));
					}
				}
				catch(e){
					self.errorCallback(e);
				}
			},
			error: function(error, ioArgs){
				self.errorCallback(new com.ibm.mm.widget.dataViewer._WB_VER_.IOException(self.resourceBundle.E_CHECK_URL));
			}
		}

		var dataFetcher = new com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.dataFetcher();
		dataFetcher.getData(bindArgs);
	}
});

dojo.declare("com.ibm.mm.widget.dataViewer._WB_VER_.localDataSource", com.ibm.mm.widget.dataViewer._WB_VER_.dataSource, {
	name: 'localDataSource',
	
	constructor: function(data, errorCallback){
		this.data = data;
		this.errorCallback = errorCallback;
		this.dataModel = [
			new com.ibm.mm.widget.dataViewer._WB_VER_.XMLDataModel(),
			new com.ibm.mm.widget.dataViewer._WB_VER_.JSONArrayDataModel(),
			new com.ibm.mm.widget.dataViewer._WB_VER_.CSVLikeDataModel(), 
			new com.ibm.mm.widget.dataViewer._WB_VER_.CSVDataModel(),
			new com.ibm.mm.widget.dataViewer._WB_VER_.JSONFeedDataModel(),
			new com.ibm.mm.widget.dataViewer._WB_VER_.JSONFeedEventDataModel()];
	},
	getData: function(callback){
		try{
			var found = false;
			for (var i=0; i<this.dataModel.length; i++){
				var dataModel = this.dataModel[i];
				var status = dataModel.canProcess(this.data, null);
				if (status['support']){
					found = true;
					var paginationData = dataModel.process(this.data, status['data']);
					callback(paginationData, this.name, dataModel.name);
					break;
				}
			}
			
			if (!found){
				throw(new com.ibm.mm.widget.dataViewer._WB_VER_.DataSourceNotSupportException(com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerMessages.E_DATA_SOURCE_NOT_SUPPORTED));
			}
		}
		catch(e){
			this.errorCallback(e);
		}
		
	}
});

dojo.declare("com.ibm.mm.widget.dataViewer._WB_VER_.DojoDataStoreDataSource", com.ibm.mm.widget.dataViewer._WB_VER_.dataSource, {
	name: 'DojoDataStoreDataSource',
	
	constructor: function(data, errorCallback){
		this.data = data;
		this.errorCallback = errorCallback;
	},
	getData: function(callback){

		try{
			if ( !this.data || !dojo.isFunction(this.data.getFeatures) || !this.data.getFeatures()["dojo.data.api.Read"] ){
				throw(new com.ibm.mm.widget.dataViewer._WB_VER_.DataSourceNotSupportException(com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerMessages.E_DATA_SOURCE_NOT_SUPPORTED));
			}

			this.processDojoDataStore(this.data, callback);
		}
		catch(e){
			this.errorCallback(e);
		}
		
	},
	
	processDojoDataStore: function(store, callback) {
		var self = this;
		
		function complete(items) {
			items = items || [];
			var existingAttrs = [];
			var jsonArray = [];
			for (var i = 0, n = items.length; i < n; i++) {
				var item = items[i];
				if (store.hasAttribute(item, "children")) {
					self.errorCallback("Data source is not supported");
					return;
				}
				var attrs = store.getAttributes(item);
				existingAttrs = dojox.collections.Set.union(existingAttrs, attrs);
			}
			// dojo CsvStore treats empty strings as no value. So Column without value will not be displayed
			if (existingAttrs.count === 0){
                throw(new com.ibm.mm.widget.dataViewer._WB_VER_.NoContentException(com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerMessages.E_NO_CONTENT));
            }
			
			for (var i = 0, n = items.length; i < n; i++) {
				var item = items[i];
				var jsonObj = {};
				existingAttrs.forEach(function(attr) {
					jsonObj[attr] = (store.getValue(item, attr, "")).toString();
				});
				jsonArray.push(jsonObj);
			}
			if (jsonArray.length <= 0){
				throw(new com.ibm.mm.widget.dataViewer._WB_VER_.NoContentException(com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerMessages.E_NO_CONTENT));
			}
			
			var columnList = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.getColumnList(jsonArray[0]);
			
			var paginationData = {'totalResult' : jsonArray.length, 'startIndex' : 0, 'itemsPerPage' : jsonArray.length,
				'first' : '', 'last' : '', 'previous' : '', 'next' : '', 
				'result' : jsonArray,  'columnList' : columnList};
			
			callback(paginationData, self.name, ""/*no data model name*/);
		}
		
		function error(error) {
			self.errorCallback(error);
		}
		
		store.fetch({onComplete : complete, onError: error});
	}

});

