/* Copyright IBM Corp. 2010  All Rights Reserved.                    */
dojo.provide("com.ibm.mm.widget.dataViewer._WB_VER_.dataViewer");

dojo.require("dojo.data.ItemFileReadStore");
dojo.require("dojo.string");

dojo.require("com.ibm.mm.widget.dataViewer._WB_VER_.widget.DataViewer");
dojo.require("com.ibm.mm.widget.dataViewer._WB_VER_.widget.ColumnsList");
dojo.require("com.ibm.mm.widget.dataViewer._WB_VER_.widget.ColorPalette");
dojo.require("com.ibm.mm.widget.dataViewer._WB_VER_.dataSource");
dojo.require("com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil");
dojo.require("com.ibm.mm.widget.dataViewer._WB_VER_.DataViewerException");

/*
 * Data Viewer is used to display tabular data. It supports two data sources 1) hub data feed 2) tabular data from other iwidget via wiring
 * For data mismatch, there are two solutions. 1) Leverage hub capability to support CSV, Excel, Access etc. 2) Leverage transformation iWidget
 * to transform non-tabular data to tabular data (JSON array)
 * Data Viewer supports end user to customize the data display setting.
 * 
 * Method onLoad, onview and onedit are iWidget interface.
 * Method handleJSONArray, handleURL, onDataSelected are for iWidget wiring.
 */

/*
 * From design point of view, com.ibm.mm.widget.dataViewer._WB_VER_.dataViewer implement elements required by iWidget SPEC and 
 * glues below classes to work together to accomplish data viewer's functionality.
 * 
 * Data source take the responsibility of retrieving data from remote URL, dojo data store and other wired widgets
 * Data model take the responsibility of interpreting the data from data source. JSON Array, XML document, CSV document
 * Entry data model take the responsibility of interpreting the ATOM entry data.
 * com.ibm.mm.widget.dataViewer._WB_VER_.widget.DataViewer take the responsibility of rendering the data from data source based on 
 * rendering configuration from iWidget itemset.
 * com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil, com.ibm.mm.widget.dataViewer._WB_VER_.widget.ColorPalette and com.ibm.mm.widget.dataViewer._WB_VER_.widget.ColumnsList
 * are utility function or classes.
 * 
 * If the future change is to support new data source. You need to write new data source, data model or entry data model.
 * If the future change is to support new rendering configuration, you need to enhance com.ibm.mm.widget.dataViewer._WB_VER_.widget.DataViewer
 *  
 */
dojo.declare("com.ibm.mm.widget.dataViewer._WB_VER_.dataViewer", null, {
	
	// Constant
	INITIAL_TABLE_HTML: "<div><table class='mumDataViewer-_WB_VER_ default' role='presentation'><thead><tr><th scope='col'><span>${L_COLUMN}1</span></th><th scope='col'><span>${L_COLUMN}2</span></th><th scope='col'><span>${L_COLUMN}3</span></th><th scope='col'><span>${L_COLUMN}4</span></th><th scope='col'><span>${L_COLUMN}5</span></th></tr></thead><tbody><tr><td><span>${L_ROW}1</span></td><td/><td/><td/><td/></tr><tr class='even'><td><span>${L_ROW}2</span></td><td/><td/><td/><td/></tr></tbody></table></div>",
	INITIAL_TABLE_FOOTER: "<div class='pageIndex default'>${L_TABLE_PAGE}&nbsp;1</div><div class='pageBtn default'>${L_TABLE_PREVIOUS} <span class='pageLinkSeparator'>|</span> ${L_TABLE_NEXT}</div>",

	ID_DIJIT_DIV: 'urlDijitDiv',       // dom id for url.dijit
    ID_VURLOBJ: "vURL",
		
	reload: true,
	_urlIsFromWiring: false,
	_urlFromWiring: null,
	_editNodeInnerHTMLCache: null,
    _viewNodeInnerHTMLCache: null,
	_onChangeUrlConnect: null,
	_eventConnects: null,
	_dataSource: null,
    _wires: null,
	_isWiring: 0,
	
	// URL Dijit parameters
	_urlDijitClass: "com.ibm.mashups.widget.dijit.url.v100",
    _urlWidgetHelper: null,
    _urlDijit: null,
    
	constructor: function(){
		this.hasData = false;
		this.dynamicEvents = {};
		this.domID = null;
		this.dataModels = null;
		this.message = "";
		this.resourceBundle = null;
		this._eventConnects = [];
        this._wires = {};
		this.publishEventEnabled = {
			'New_Feed_Address' : true,
			'New_CSV_Address' : true,
			'Send_Table' : false,		// performance optimizing, do not general table data if no wiring exists.
			'Row_Selection' : true,
			'Send_Row_as_Table' : true,
			'Select_Cell_as_Table' : true,
			'Select_Cell_as_Text' : true,
			'Dynamic_Event' : {}
		};
		
		/*For performance reason, set by onLoad and used by onview only once*/
		this._viewConfig = null;
		
		this.LOGGER = com.ibm.mashups.enabler.logging.Logger.getLogger("com.ibm.mm.widget.dataViewer._WB_VER_.dataViewer");
	},
    
	/*
	 * Invoked when data viewer is loaded
	 */
	onLoad: function(){
		var cs = com.ibm.mashups.services.ServiceManager.getService(com.ibm.mashups.enabler.services.ConfigService.SERVICE_NAME);
		
		dojo.registerModulePath("com.ibm.mm.widget.dataViewer._WB_VER_",this.iContext.io.rewriteURI("js/com/ibm/mm/widget/dataViewer"));
		dojo['requireLocalization']("com.ibm.mm.widget.dataViewer._WB_VER_", "dataViewer", cs.getValue("locale"), cs.getValue("availableLocales"));
		com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerMessages = dojo.i18n.getLocalization("com.ibm.mm.widget.dataViewer._WB_VER_", "dataViewer");	
        
		dojo.registerModulePath(this._urlDijitClass, this.iContext.io.rewriteURI("urlDijit"));
		dojo["require"](this._urlDijitClass + "._base");
		
        var att=this.iContext.getiWidgetAttributes();
        var url = att.getItemValue("feedURL");
        
		var hubUrl = com.ibm.mashups.services.ServiceManager.getService(com.ibm.mashups.enabler.services.ConfigService.SERVICE_NAME).getValue(com.ibm.mashups.enabler.services.ConfigConstants.HUB_URL);
		
		// instantiate the Widget Helper
        this._urlWidgetHelper = new (dojo.getObject(this._urlDijitClass).WidgetHelper)({
			migrateUrl: url || "",
            iContext: this.iContext,
            openSearchUrl: hubUrl + '/atom?nologin=true',
            attributeKey: this.ID_VURLOBJ,
            // onLoadUrl: dojo.hitch(this, this.onLoadButtonClick),
			hideLoadButton: true,
			hideBrowseButton: (!hubUrl),
			autoSave: false,
			noForm: true
        });
        
        this.contextRoot = this.iContext.io.rewriteURI("");
        this.resourceBundle = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerMessages;
		this.reload = true;

		this.domID = "_" + this.iContext.widgetId + "_";
		
		this._viewConfig = this._loadItemSet();
		
		this._subscribe = dojo.subscribe("dataViewer/" + this.iContext.widgetId + "/dataSelected", this, "onDataSelected");
	},
	
	onUnload: function(){
		dojo.unsubscribe(this._subscribe);

		var dataViewer = dijit.byId(this.domID + "dataViewerId");
		try {
			if (dataViewer && dataViewer.destroy) {
				dataViewer.destroy();
				dijit.registry.remove(this.domID + "dataViewerId");
			}
		} catch (e) {
			// #11579
		}

		if (this.colorPicker && this.colorPicker.destroy){
			if (this.colorPickerConnect){
				dojo.disconnect(this.colorPickerConnect);
			}
			this.colorPicker.destroy();
		}

		if (this.ColumnTable && this.ColumnTable.destroy){
			this.ColumnTable.destroy();
			dijit.registry.remove(this.domID + "ColumnTable");
		}
		dojo.forEach(this._eventConnects, dojo.disconnect);
	},
	
	/*
	 * Invoked when data viewer to display view mode
	 */
	onview: function(){
		var att = this.iContext.getiWidgetAttributes();
		if (this.reload) {
			var viewRootNode = this.byId("dataViewerViewRoot");
            try {
                // Apply NLS
                this._viewNodeInnerHTMLCache = this._viewNodeInnerHTMLCache || dojo.trim(dojo.string.substitute(viewRootNode.innerHTML, this.resourceBundle));
                dojo.place(this._viewNodeInnerHTMLCache, viewRootNode, "only");
            } catch (e) {}
			
			var viewConfig = this._viewConfig;
			if (!viewConfig) {
				viewConfig = this._loadItemSet();
			}
            this.updateWiringFlag();
			var feedURL = viewConfig.feedURL;
			var isWiring = viewConfig.isWiring;
			if (!feedURL && isWiring !== "true") {
				this.showInitMessage();
			} else {
				if (isWiring === "true" && this._urlIsFromWiring) {
					// If url is from eventing, set the url to eventing payload url
					viewConfig.feedURL = this._urlFromWiring;
				}
			    this.renderDataFromURL(viewConfig);
			}
			
			// Scrollbar is needed for data viewer
			dojo.style(this.iContext.getRootElement(), "overflow", "auto");
			
	        if (this._viewConfig) {
	            delete this._viewConfig;
	            this._viewConfig = null;
	        }
		}
		
        if (this._urlDijit && this._urlDijit.destroyRecursive) {
            this._urlDijit.destroyRecursive();
            delete this._urlDijit;
            this._urlDijit = null;
        }
		dojo.disconnect(this._onChangeUrlConnect);
        this._onChangeUrlConnect = dojo.connect(this._urlWidgetHelper, "onChangeUrl", this, "_onChangeUrl");
		
		dojo.disconnect(this._contentTypeHandler);
	},
	
	/*
	 * Invoked when data viewer to display config view
	 */
	onedit: function(){
		// defect 8484.
		/*
		var editDiv = dojo.byId(this.iContext.widgetId+"_edit");
		if (editDiv){
			editDiv.style.width = "900px";
		}
		*/
		var configRootNode = this.byId("dataViewerConfigRoot");
        try {
            // Apply NLS
            this._editNodeInnerHTMLCache = this._editNodeInnerHTMLCache || dojo.trim(dojo.string.substitute( configRootNode.innerHTML, this.resourceBundle));
            dojo.place(this._editNodeInnerHTMLCache, configRootNode, "only");
        } catch (e) {}
		
		this._fixImagePath(configRootNode);
        
		this.updateWiringFlag();
		
		dojo.fx.wipeIn({
			node: this.byId("datadiv")
		}).play();
        
		var att=this.iContext.getiWidgetAttributes();

		var feedURL = att.getItemValue("feedURL");
		var isWiring = att.getItemValue("isWiring");

		var rowsPerView = att.getItemValue("rowsPerView");
		var showHeader = att.getItemValue("showHeader");
		var columnsStr = att.getItemValue("columns");

		var tableTitle = att.getItemValue("tableTitle");
		var tableTitleAlignment = att.getItemValue("tableTitleAlignment");
		var tableTitleFont = att.getItemValue("tableTitleFont");
		var tableTitleFontSize = att.getItemValue("tableTitleFontSize");
		var tableTitleFontBold = att.getItemValue("tableTitleFontBold");
		var tableTitleFontItalic = att.getItemValue("tableTitleFontItalic");
		var tableTitleColor = att.getItemValue("tableTitleColor");

		var tableHeaderFont = att.getItemValue("tableHeaderFont");
		var tableHeaderFontSize = att.getItemValue("tableHeaderFontSize");
		var tableHeaderFontBold = att.getItemValue("tableHeaderFontBold");
		var tableHeaderFontItalic = att.getItemValue("tableHeaderFontItalic");
		var tableHeaderColor = att.getItemValue("tableHeaderColor");

		var tableContentFont = att.getItemValue("tableContentFont");
		var tableContentFontSize = att.getItemValue("tableContentFontSize");
		var tableContentFontBold = att.getItemValue("tableContentFontBold");
		var tableContentFontItalic = att.getItemValue("tableContentFontItalic");
		var tableContentColor = att.getItemValue("tableContentColor");

		var columnLineSize = att.getItemValue("columnLineSize");
		var rowLineSize = att.getItemValue("rowLineSize");
		var oddRowColor = att.getItemValue("oddRowColor");
		var evenRowColor = att.getItemValue("evenRowColor");
		
		var filterColunm = att.getItemValue("filterColunm");
		var filterColunmOption = att.getItemValue("filterColunmOption");
		var filterColunmType = att.getItemValue("filterColunmType") || "text";
		var filterFunction = att.getItemValue("filterFunction");
		var filterTargetValue = att.getItemValue("filterTargetValue");
		var isHighLightFilter = att.getItemValue("isHighLightFilter");
		var isFilter = att.getItemValue("isFilter");
		var isRemoveFilter = att.getItemValue("isRemoveFilter");
		var highLightFilterColor = att.getItemValue("highLightFilterColor");
		
		var invalidFeedMessage = att.getItemValue("invalidFeedMessage");
		var noContentMessage = att.getItemValue("noContentMessage");
		var allContentFilteredMessage = att.getItemValue("allContentFilteredMessage");
		
		this.byId("rowsPerPage").value = parseInt(rowsPerView, 10);
		var showHeaderCheckBox = this.byId("showHeader");
		if (showHeader === "true") showHeaderCheckBox.checked = true;
		else showHeaderCheckBox.checked = false;

		var columns = {};
		if (columnsStr && columnsStr !== "null") {
			try{
				columns = dojo.fromJson(columnsStr);
				if (this.ColumnTable){
					this.ColumnTable.destroy();
					this.ColumnTable = null;
					dijit.registry.remove(this.domID + "ColumnTable");
				}
				this.ColumnTable = new com.ibm.mm.widget.dataViewer._WB_VER_.widget.ColumnsList({
					wid: this.domID + "field",
					contextRootBuilder: this.contextRoot
				}, this.byId("ColumnTable"));
				this.ColumnTable.setSettings(columns);
				this.ColumnTable.render();
			}catch(e1){
				this.LOGGER.severe("onedit", this.resourceBundle.E_ITEMSET_COLUMNS_BROKEN);
			}
		}
		this.byId("tableTitle").value = tableTitle === "null" ? "" : tableTitle;
		this.byId("titleAlign").value = tableTitleAlignment;
		this.byId("titleFont").value = tableTitleFont;
		this.byId("titleFontSize").value = tableTitleFontSize;
		this.byId("titleFontBold").value = tableTitleFontBold;
		this.byId("titleFontBoldImg").src = (tableTitleFontBold === "true") ? this.contextRoot + "/images/bold_selected.png" : this.contextRoot + "/images/bold.png";
		this.byId("titleFontBoldImg").title = this.byId("titleFontBoldImg").alt = (tableTitleFontBold === "true") ? this.resourceBundle.L_CONF_STYLE_TABLE_TITLE_FONT_DISABLE_BOLD : this.resourceBundle.L_CONF_STYLE_TABLE_TITLE_FONT_ENABLE_BOLD;
		this.byId("titleFontItalic").value = tableTitleFontItalic;
		this.byId("titleFontItalicImg").src = (tableTitleFontItalic === "true") ? this.contextRoot + "/images/italic_selected.png" : this.contextRoot + "/images/italic.png";
		this.byId("titleFontItalicImg").title = this.byId("titleFontItalicImg").alt = (tableTitleFontItalic === "true") ? this.resourceBundle.L_CONF_STYLE_TABLE_TITLE_FONT_DISABLE_ITALIC : this.resourceBundle.L_CONF_STYLE_TABLE_TITLE_FONT_ENABLE_ITALIC;
		
		this.byId("headerFont").value = tableHeaderFont;
		this.byId("headerFontSize").value = tableHeaderFontSize;
		this.byId("headerFontBold").value = tableHeaderFontBold;
		this.byId("headerFontBoldImg").src = (tableHeaderFontBold === "true") ? this.contextRoot + "/images/bold_selected.png" : this.contextRoot + "/images/bold.png";
		this.byId("headerFontBoldImg").title = this.byId("headerFontBoldImg").alt = (tableHeaderFontBold === "true") ? this.resourceBundle.L_CONF_STYLE_TABLE_HEADER_FONT_DISABLE_BOLD : this.resourceBundle.L_CONF_STYLE_TABLE_HEADER_FONT_ENABLE_BOLD ;
		this.byId("headerFontItalic").value = tableHeaderFontItalic;
		this.byId("headerFontItalicImg").src = (tableHeaderFontItalic === "true") ? this.contextRoot + "/images/italic_selected.png" : this.contextRoot + "/images/italic.png";
		this.byId("headerFontItalicImg").title = this.byId("headerFontItalicImg").alt = (tableHeaderFontItalic === "true") ? this.resourceBundle.L_CONF_STYLE_TABLE_HEADER_FONT_DISABLE_ITALIC : this.resourceBundle.L_CONF_STYLE_TABLE_HEADER_FONT_ENABLE_ITALIC;

		this.byId("tableFont").value = tableContentFont;
		this.byId("tableFontSize").value = tableContentFontSize;
		this.byId("tableFontBold").value = tableContentFontBold;
		this.byId("tableFontBoldImg").src = (tableContentFontBold === "true") ? this.contextRoot + "/images/bold_selected.png" : this.contextRoot + "/images/bold.png";
		this.byId("tableFontBoldImg").title = this.byId("tableFontBoldImg").alt = (tableContentFontBold === "true") ? this.resourceBundle.L_CONF_STYLE_TABLE_FONT_DISABLE_BOLD : this.resourceBundle.L_CONF_STYLE_TABLE_FONT_ENABLE_BOLD;
		this.byId("tableFontItalic").value = tableContentFontItalic;
		this.byId("tableFontItalicImg").src = (tableContentFontItalic === "true") ? this.contextRoot + "/images/italic_selected.png" : this.contextRoot + "/images/italic.png";
		this.byId("tableFontItalicImg").title = this.byId("tableFontItalicImg").alt = (tableContentFontItalic === "true") ? this.resourceBundle.L_CONF_STYLE_TABLE_FONT_DISABLE_ITALIC : this.resourceBundle.L_CONF_STYLE_TABLE_FONT_ENABLE_ITALIC;
		
		this.byId(this.domID + "tableTitle").title = this.resourceBundle.L_CONF_TABLE_TITLE;
		this.byId(this.domID + "titleFont").title = this.resourceBundle.L_CONF_TABLE_FONT;
		this.byId(this.domID + "titleFontSize").title = this.resourceBundle.L_CONF_STYLE_TABLE_TITLE_FONT_SIZE;
		this.byId(this.domID + "headerFont").title = this.resourceBundle.L_CONF_STYLE_TABLE_HEADER_FONT;
		this.byId(this.domID + "headerFontSize").title = this.resourceBundle.L_CONF_STYLE_TABLE_HEADER_FONT_SIZE;
		this.byId(this.domID + "tableFont").title = this.resourceBundle.L_CONF_STYLE_TABLE_HEADER_FONT;
		this.byId(this.domID + "tableFontSize").title = this.resourceBundle.L_CONF_STYLE_TABLE_FONT_SIZE;
		this.byId(this.domID + "columnLines").title = this.resourceBundle.L_CONF_STYLE_TABLE_CELL_COLUMN_LINE;
		this.byId(this.domID + "rowLines").title = this.resourceBundle.L_CONF_STYLE_TABLE_CELL_ROW_LINE;

		var colorDOM = this.byId("titleFontColor");
		if (tableTitleColor.indexOf('#') !== 0) tableTitleColor = "#000000";
		colorDOM.style.color = tableTitleColor;
		colorDOM.style.backgroundColor = tableTitleColor;
		colorDOM.setAttribute('color', tableTitleColor);
		colorDOM.title = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.hexColor2String(tableTitleColor);
		
		colorDOM = this.byId("headerFontColor");
		if (tableHeaderColor.indexOf('#') !== 0) tableHeaderColor = "#000000";
		colorDOM.style.color = tableHeaderColor;
		colorDOM.style.backgroundColor = tableHeaderColor;
		colorDOM.setAttribute('color', tableHeaderColor);
		colorDOM.title = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.hexColor2String(tableHeaderColor);
		
		colorDOM = this.byId("tableFontColor");
		if (tableContentColor.indexOf('#') !== 0) tableContentColor = "#000000";
		colorDOM.style.color = tableContentColor;
		colorDOM.style.backgroundColor = tableContentColor;
		colorDOM.setAttribute('color', tableContentColor);
		colorDOM.title = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.hexColor2String(tableContentColor);
		
		colorDOM = this.byId("oddRowColor");
		if (oddRowColor.indexOf('#') !== 0) oddRowColor = "#ffffff";
		colorDOM.style.color = oddRowColor;
		colorDOM.style.backgroundColor = oddRowColor;
		colorDOM.setAttribute('color', oddRowColor);
		colorDOM.title = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.hexColor2String(oddRowColor);

		colorDOM = this.byId("evenRowColor");
		if (evenRowColor.indexOf('#') !== 0) evenRowColor = "#eeffff";
		colorDOM.style.color = evenRowColor;
		colorDOM.style.backgroundColor = evenRowColor;
		colorDOM.setAttribute('color', evenRowColor);
		colorDOM.title = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.hexColor2String(evenRowColor);

		var btn, img, align, str = "";
		dojo.forEach(["left", "center", "right"], function(align){
			img = this.byId('align_title_' + align + '_img');
			btn = this.byId('align_title_' + align + "_btn");
			img.src = this.contextRoot + "/images/align_" + align + ((tableTitleAlignment === align) ? "_selected" : "") + ".png";
			if (tableTitleAlignment === align) {
				str = dojo.string.substitute(this.resourceBundle.L_CONF_ALIGN_IS_SELECTED_1, [this.resourceBundle["L_" + align.toUpperCase()]]);
			} else {
				str = dojo.string.substitute(this.resourceBundle.L_CONF_ALIGN_1, [this.resourceBundle["L_" + align.toUpperCase()]]);
			}
			img.alt = btn.title = str;
			dojo.attr(img, "aria-label", str);

		}, this);
		this.byId("titleAlign").value = tableTitleAlignment;
		
		this.byId("columnLines").value = columnLineSize;
		this.byId("rowLines").value = rowLineSize;

		var columnAdSelect = this.byId("columnAd");
		dojo.empty(columnAdSelect);
		var optionValues = [];
		try{
			optionValues = dojo.fromJson(filterColunmOption);
		} catch(e2){
			this.LOGGER.severe("onedit", this.resourceBundle.E_ITEMSET_FILTERCOLUMNOPTION_BROKEN);
		}
		for (var i=0; i<optionValues.length; i++){
			var option = dojo.create("option");
			option.innerHTML = option.value = optionValues[i];
			if (option.value === filterColunm) {
				dojo.attr(option, "selected", "selected");
			}
			columnAdSelect.appendChild(option);
		}
		columnAdSelect.value = filterColunm;
		var contentTypeSelect = this.byId("contentType");
		
		var options = dojo.query("option[value='" + filterColunmType + "']", contentTypeSelect);
		if (options.length > 0) {
			dojo.attr(options[0], "selected", "selected");
		}
		contentTypeSelect.value = filterColunmType;
        
        var contentCompareSelect = this.byId("contentCompare");
		this.changeCompare(contentTypeSelect.value, contentCompareSelect, filterFunction);
		
		this._contentTypeHandler = dojo.connect(contentTypeSelect, "onchange", this, function(){
			this.changeCompare(contentTypeSelect.value, contentCompareSelect);
		});
		
		this.byId("comparVar").value = filterTargetValue === "null" ? "" : filterTargetValue;
		
		if (isFilter === "true") {
			dojo.attr(this.byId("actionType_filter"),"checked","checked");
		} else if (isHighLightFilter === "true") {
			dojo.attr(this.byId("actionType_highlight"),"checked","checked");
		} else if (isRemoveFilter === "true") {
			dojo.attr(this.byId("actionType_remove"),"checked","checked");
		}
		
		if (highLightFilterColor.indexOf('#') !== 0) highLightFilterColor = "#ebec78";
		var highlightWithColorInput = this.byId("highlightWithColor");
		dojo.style(highlightWithColorInput, {
			color: highLightFilterColor,
			backgroundColor: highLightFilterColor
		});
		dojo.attr(highlightWithColorInput, 'color', highLightFilterColor);
		highlightWithColorInput.title = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.hexColor2String(highLightFilterColor);
		
		this.byId("invalid_feed").value = invalidFeedMessage || this.resourceBundle.E_CHECK_URL;
		this.byId("no_content").value = noContentMessage || this.resourceBundle.E_NO_CONTENT;
		this.byId("all_content_filtered").value = allContentFilteredMessage || this.resourceBundle.I_ALL_CONTENT_FILTERED;
		
		this._urlDijit = this._urlDijit || this._urlWidgetHelper.initializeDijit(this._getUrlDijitDiv());
        dojo.disconnect(this._onChangeUrlConnect);
		this._onChangeUrlConnect = dojo.connect(this._urlWidgetHelper, "onChangeUrl", this, "onLoadButtonClick");
        
		
        if (isWiring === "true"){
            this.showMessage(this.resourceBundle.L_CONF_WIRING, "warning", "wiring");
			this._disableUrlDijit(true);
        } else{
            this._urlWidgetHelper.setUrl(feedURL);
            this.showMessage(false, null, "wiring");
			this._disableUrlDijit(false);
        }
	},

    /**
     * Change the path of image node in rootNode to canonical path
     * @param {domNode} root dom node
     */
    _fixImagePath: function(rootNode) {
        rootNode = this.byId(rootNode);
        if (rootNode) {
            var baseURL = this.iContext.io.rewriteURI(".");
            dojo.query("img[src],input[src]", rootNode).forEach(function(imgNode){
                var src = dojo.attr(imgNode, "src");
                var canonicalSrc = src.replace(/\S*_ROOT_/, baseURL);
                dojo.attr(imgNode, "src", canonicalSrc);
            }, this);
        }
    },

    /**
     * Get dom node by id in iWidget
     * @param {String|DomNode} id
     */
    byId: function(id) {
		return dojo.byId(this.domID + id) || dojo.byId(id);
		//return dojo.isString(id) ? (this.iContext.getElementById(this.domID + id) || this.iContext.getElementById(id)) : id;
    },
    
	_getUrlDijitDiv: function() {
		return this.byId(this.ID_DIJIT_DIV);
	},
	
	_disableUrlDijit: function(disabled) {
        //dojo.style(this._getUrlDijitDiv(), "display", disabled ? "none" : "block");
	    this._urlWidgetHelper.disableUrlInput(disabled);
        this._urlWidgetHelper.disableLoadButton(disabled);
	},
	
	_getValueFromJson: function(json, attribute, defaultValue){
		try {
			var obj = dojo.fromJson(json);
			return obj[attribute];
		}catch(e){
			return defaultValue;
		}		
	},
	
	_handleReceivedData: function(iEvent){
        var sourceId = iEvent.source;
		var self = this;
        if (!this._wires[sourceId]) {
            this._wires[sourceId] = true;
            ++this._isWiring;        // enable wired mode, can not change url
        }
		this._urlIsFromWiring = false;
		this._dataSource = new com.ibm.mm.widget.dataViewer._WB_VER_.localDataSource(iEvent.payload, function(e){
			self.showErrorMessage(e);
		});
		this._dataSource.getData(function(data){
			var viewConfig = self._loadItemSet();
			self.processData(data, viewConfig);
			self.setWiringFlag(true);

			self.publishTable(data);
		});
	},

	/*
	 * This method supports display data from other iWidget, payload type is JSON array
	 */
	handleJSONArray: function(iEvent){
		if (iEvent && dojo.isString(iEvent.payload)) {
			iEvent.payload = dojo.fromJson(iEvent.payload);
		}
		this._handleReceivedData(iEvent);
	},

	/*
	 * This method supports display data from other iWidget, payload type is string, in the format of 
	 * column name 1, column name 2, ... | type, type, ... | cell value, cell value, ... | cell value, cell value, ... 
	 */
	handleCsvLikeData: function(iEvent){
		this._handleReceivedData(iEvent);
	},

	/*
	 * This method supports display data from other iWidget, payload type is ATOM feed XML document 
	 */
	handleXMLData: function(iEvent){
		this._handleReceivedData(iEvent);
	},

    _onChangeUrl: function(dataSourceURL) {
        var viewConfig = this._loadItemSet();
        viewConfig.feedURL = dataSourceURL;
        this.renderDataFromURL(viewConfig);
    },
    
	/*
	 * This method supports display data from other iWidget, payload is resource url
	 */
	handleURL: function(iEvent){
		var url = iEvent.payload,
            sourceId = iEvent.source;
		
		url = dojo.trim(url);
		if (!url) return;
		
		if (!this._wires[sourceId]) {
            this._wires[sourceId] = true;
            ++this._isWiring;        // enable wired mode, can not change url
        }
		this._urlIsFromWiring = true;
		this._urlFromWiring = url;
        this._urlWidgetHelper.setUrl(url);
	},
	
	/*
	 * This method supports display data from other iWidget, payload is Dojo data store
	 */
	handleDataStore: function(iEvent){
		var self = this;
		var store = iEvent.payload;
        var sourceId = iEvent.source;
		if(dojo.isString(store)){
			//csv data, for Symphony integration
			store = new com.ibm.mm.data.table({'url': '', 'data': iEvent.payload});
		}
        this._urlWidgetHelper.setUrl("");
		if (!this._wires[sourceId]) {
            this._wires[sourceId] = true;
            ++this._isWiring;        // enable wired mode, can not change url
        }
		this._dataSource = new com.ibm.mm.widget.dataViewer._WB_VER_.DojoDataStoreDataSource(store, function(e){
			self.showErrorMessage(e);
		});
		this._urlIsFromWiring = false;
		this._dataSource.getData(function(data){
			var viewConfig = self._loadItemSet();
			self.processData(data, viewConfig);
			self.setWiringFlag(true);

			self.publishTable(data);
		});

	},
	
	handleRemoveWire: function(iEvent) {
		var sourceId = iEvent.payload.sourceWidget;
        if (this._wires[sourceId]) {
            this._wires[sourceId] = false;
            delete this._wires[sourceId];
            --this._isWiring;
            this._isWiring = this._isWiring < 0 ? 0 : this._isWiring;
        }
	},
	
	setWiringFlag: function(isWired){
		var att=this.iContext.getiWidgetAttributes();
		att.setItemValue("isWiring", "" + isWired, false);
		att.save();
		if (this._viewConfig) {
			this._viewConfig.isWiring = "" + isWired;
		}
	},
	
	updateWiringFlag: function(){
		// var widgetWires = iWidgetContainer.getWidgetById(this.iContext.widgetId).getWires();
		//if (dojo.isArray(widgetWires)){
		if (!this._isWiring /*widgetWires.length === 0*/){
			this.setWiringFlag(false);
            this._urlIsFromWiring = false;
		} else{
			this.setWiringFlag(true);
		}
		//}
	},

	/*
	 * This method supports to publish events when table row is selected.
	 */
	onDataSelected: function(message){
		if (this.publishEventEnabled['Row_Selection']){
	        this.iContext.iEvents.publishEvent("Row Selection", message.dataInfo.rowData);			
		}
        if (this.publishEventEnabled['Send_Row_as_Table']){
            this.iContext.iEvents.publishEvent("Send Row as Table", new com.ibm.mm.data.table({'data': com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.JSONObject2CSV(message.dataInfo.rowJSonData)}));        	
        }
        if (this.publishEventEnabled['Select_Cell_as_Table']){
            this.iContext.iEvents.publishEvent("Select Cell as Table", new com.ibm.mm.data.table({'data': com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.JSONObject2CSV(message.dataInfo.cellJSonData)}));        	
        }
        if (this.publishEventEnabled['Select_Cell_as_Text']){
        	this.iContext.iEvents.publishEvent("Select Cell as Text", message.dataInfo.cellValue);
        }
        
		for (var key in message.dataInfo.rowJSonData){
            if (this.dynamicEvents[key] /*&& this.publishEventEnabled['Dynamic_Event'][key]*/) {
                this.iContext.iEvents.publishEvent(key, message.dataInfo.rowJSonData[key], "string");
            }
		}
	},
	
	publishNewAddressOnNewWire: function(){
		var att=this.iContext.getiWidgetAttributes();
		var feedURL = this._urlWidgetHelper.getUrl();
		var urlType = att.getItemValue("type");
		if (!feedURL) return;
		
		// TODO: will merge two events into one: data source url
		// bug 11373: WAS-FF 3.5/XP-DataViewer-Data Viewer can't receive data by Table as URL(TABLE)
		//if (urlType === 'feed'){
			this.publishEventEnabled['New_Feed_Address'] = true;
			this.iContext.iEvents.publishEvent("New Feed Address", feedURL);
		//} else if (urlType === "csv") {
			this.publishEventEnabled['New_CSV_Address'] = true;
			this.iContext.iEvents.publishEvent("New CSV Address", feedURL);
		//}
	},
	
	publishSendTableOnNewWire: function(){
		this.publishEventEnabled['Send_Table'] = true;	
		//publish table
		if(this.message){
			this.publishTable(this.message);
		}
	},
	
    publishTable: function(data){
		if (this.publishEventEnabled['Send_Table']){
            var csv = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.DataObject2CSV(data);
            var table = new com.ibm.mm.data.table({'url': "", 'data': csv});
            this.iContext.iEvents.publishEvent("Send Table", table);
        }
    },
    
	publishRowSelectionOnNewWire: function(){
		this.publishEventEnabled['Row_Selection'] = true;		
	},
	
	publishSendRowAsTableOnNewWire: function(){
		this.publishEventEnabled['Send_Row_as_Table'] = true;		
	},
	
	publishSelectCellAsTableOnNewWire: function(){
		this.publishEventEnabled['Select_Cell_as_Table'] = true;		
	},
	
	publishSelectCellAsTextOnNewWire: function(){
		this.publishEventEnabled['Select_Cell_as_Text'] = true;		
	},
	
	publishDynamicEventOnNewWire: function(iEvent){
        var payload = iEvent.payload;
        var eventName = payload.sourceEvent;
		this.publishEventEnabled['Dynamic_Event'][eventName] = true;
	},
	
	/*
	 * Below methods are used internally as utility.
	 */
	
	/**
	 * Show messages
	 * @param {String} message
	 * @param {String} type (optional) type can be "info", "error", "warning". if type is null, "error" is default.
	 */
	showMessage: function(message, type, messageBox) {
        messageBox = this.byId(messageBox) || this.byId("messageBox");
		dojo.empty(messageBox);
		
		if (!message) {
			/*	Performance consideration, disable message fadeout animation
			dojo.fadeOut({ node: messageBox }).play();
			*/
            messageBox.style.display = "none";
            return;
        }
        
        var img = dojo.create("img");
        var span = dojo.create("span");
        span.appendChild(dojo.doc.createTextNode(message));
        
        switch(type) {
            case "info":
                img.alt = this.resourceBundle.L_INFORMATION;
                img.src = this.iContext.io.rewriteURI("images/info_icon.png");
                dojo.toggleClass(messageBox, "lotusWarning", false);
                dojo.toggleClass(messageBox, "lotusInfo", true);
                break;
            case "warning":
                img.alt = this.resourceBundle.L_WARNING;
                img.src = this.iContext.io.rewriteURI("images/warning_icon.png");
                dojo.toggleClass(messageBox, "lotusWarning", true);
                dojo.toggleClass(messageBox, "lotusInfo", false);
                break;
            default:       // "error" as default
                img.alt = this.resourceBundle.L_ERROR;
                img.src = this.iContext.io.rewriteURI("images/error_icon.png");
                dojo.toggleClass(messageBox, "lotusWarning", false);
                dojo.toggleClass(messageBox, "lotusInfo", false);
        }
        messageBox.appendChild(img);
        messageBox.appendChild(span);
        messageBox.style.display = "block";
        dojo.fadeIn({node: messageBox}).play();
	},
	
    showInitMessage: function(){
        this.byId("loadingMessage").style.display = "none";
        this.byId("iTableEdit").style.display = "";
        
		var dataViewer = dijit.byId(this.domID + "dataViewerId");
        if (dataViewer) dataViewer.destroy(false);
        
        this.byId("dataViewerId_outerTD").innerHTML = dojo.string.substitute(this.INITIAL_TABLE_HTML, this.resourceBundle);
		this.byId("pageLink").innerHTML = dojo.string.substitute(this.INITIAL_TABLE_FOOTER, this.resourceBundle);
        
		// use "innerHTML" here, because initial text has structure
        this.showMessage(" ", "info");
		dojo.query("span", this.byId("messageBox"))[0].innerHTML = this.resourceBundle.I_INIT_TEXT;
    },
    
	showErrorMessage: function(error, messageBox){
		messageBox = this.byId(messageBox) || this.byId("messageBox");
		if (messageBox === this.byId("messageBox")) {
			this.byId("loadingMessage").style.display = "none";
			this.byId("iTableEdit").style.display = "";
			
			var dataViewer = dijit.byId(this.domID + "dataViewerId");
			if (dataViewer) dataViewer.destroy(false);
			
	        this.byId("dataViewerId_outerTD").innerHTML = dojo.string.substitute(this.INITIAL_TABLE_HTML, this.resourceBundle);
	        this.byId("pageLink").innerHTML = dojo.string.substitute(this.INITIAL_TABLE_FOOTER, this.resourceBundle);
        }
		
		var errorMsg = "", 
		    type = "error";
		if (!this._viewConfig) {
			this._viewConfig = this._loadItemSet();
		}
		if (error instanceof com.ibm.mm.widget.dataViewer._WB_VER_.IOException) {
			errorMsg = this._viewConfig.invalidFeedMessage || error.message;
		} else if (error instanceof com.ibm.mm.widget.dataViewer._WB_VER_.NoContentException) {
			errorMsg = this._viewConfig.noContentMessage || error.message;
			type = "info";
		} else if (error instanceof com.ibm.mm.widget.dataViewer._WB_VER_.DataViewerException){
			errorMsg = error.message;
		} else if (error.constructor.name === TypeError){
			errorMsg = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerMessages.E_JS_TYPEERROR;
		} else {
			errorMsg = error;
		}
		errorMsg =  errorMsg || com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerMessages.E_UNKNOWN_ERROR;
		this.showMessage(errorMsg, type, messageBox);
	},
	
	showErrorMessageTableExist: function(error){
		this.byId("loadingMessage").style.display = "none";
		this.byId("iTableEdit").style.display = "block";
		this.showMessage(error);
	},
	
	showLoadingMessage: function(){
		this.byId("loadingMessage").style.display = "block";
		this.showMessage(false);
		this.byId("iTableEdit").style.display = "none";
	},
	
	generateDojoDataStore : function(targetData) {
		var json = {"items" : []};
        for (var i = 0; i < targetData.length; i++) {
            var item = {};
            for (var key in targetData[i]) {
            	item[key] = targetData[i][key].toString();
            }
            json.items.push(item);
        }
		var store = new dojo.data.ItemFileReadStore({data : json});
		delete store._features["dojo.data.api.Identity"];
		return store;
	},
	
	/*
	 * Render tabular data to table according to viewConfig settings, set filter rule if necessary
	 */
	renderTable: function(data, viewConfig){
		var dataViewer = dijit.byId(this.domID + "dataViewerId");
		if (dataViewer) {
			dataViewer.destroy();
			dijit.registry.remove(this.domID + "dataViewerId");
			dataViewer = null;
		}

		var outerTd = this.byId("dataViewerId_outerTD");
		dojo.empty(outerTd);
		var containerDiv = dojo.create('div');
		outerTd.appendChild(containerDiv);

		dataViewer = new com.ibm.mm.widget.dataViewer._WB_VER_.widget.DataViewer({
			id: this.domID + "dataViewerId",
			mmWidgetId: this.iContext.widgetId,
			imageBase: this.iContext.io.rewriteURI("images/"),
			dataViewerStyle: {
				titleValue : viewConfig['tableTitle'],
				titleFont : viewConfig['tableTitleFont'],
				titleAlign : viewConfig['tableTitleAlignment'],
				titleFontBold : viewConfig['tableTitleFontBold'],
				titleFontItalic : viewConfig['tableTitleFontItalic'],
				titleFontColor : viewConfig['tableTitleColor'],
				titleFontSize : viewConfig['tableTitleFontSize'],
				
				showHeader : viewConfig['showHeader'],
				headerFont: viewConfig['tableHeaderFont'],
				headerFontSize: viewConfig['tableHeaderFontSize'],
				headerFontBold: viewConfig['tableHeaderFontBold'],
				headerFontItalic: viewConfig['tableHeaderFontItalic'],
				headerFontColor: viewConfig['tableHeaderColor'],
				
				tableFont: viewConfig['tableContentFont'],
				tableFontSize: viewConfig['tableContentFontSize'],
				tableFontBold: viewConfig['tableContentFontBold'],
				tableFontItalic: viewConfig['tableContentFontItalic'],
				tableFontColor: viewConfig['tableContentColor'],
				
				columnLines: viewConfig['columnLineSize'],
				rowLines: viewConfig['rowLineSize'],
				oddRowColor: viewConfig['oddRowColor'],
				evenRowColor: viewConfig['evenRowColor'],
				
				highlightWithColor: viewConfig['highLightFilterColor'],
				columnsAlign: viewConfig['columns']['columnsAlign']
			},
			columnsOrder: viewConfig['columns']['columnsOrder']
		}, containerDiv);
		
		var rowsPP = viewConfig['rowsPerView'];
		var columnFilter = viewConfig['columns']['columnFilter'];
		
		dataViewer.setRowsPerPage(parseInt(rowsPP, 10));
		
		var columnLabel = viewConfig['columns']['columnLabel'];
		var columnSorttype = (!viewConfig['columns']['columnSorttype']?"String":viewConfig['columns']['columnSorttype']);
		
		var eventName = {};
		for (var i = 0, length = data.columnList.length; i < length; i++) {
			eventName[data.columnList[i]] = columnLabel[i];
		}
		
		this.updateDynamicEvents(eventName);
		//add columnLabel as input parameter
		dataViewer.fetchAllInfo(data, columnFilter,columnLabel,columnSorttype);
		var ownId = this.domID;
		dataViewer.setID(ownId);
		
        var filterColumn = viewConfig['filterColunm'];
        var comFunction = viewConfig['filterFunction'];
        var comVar = viewConfig['filterTargetValue'];
		
	    dataViewer.addDataFilter(filterColumn, comFunction, comVar);
		if (comVar) {
			if (viewConfig['isFilter'] === "true") {
				dataViewer.applyDataFilter(false);
			} else if (viewConfig['isHighLightFilter'] === "true") {
	    		dataViewer.applyHighlightFilter();
			} else if (viewConfig['isRemoveFilter'] === "true") {
				dataViewer.applyDataFilter(true);
			}
		} else {
			dataViewer.renderFirstPage();
		}
		
		if (viewConfig["noSort"] === "true") {
		    dataViewer.onSort = function() {};
		}
		
		if (dataViewer.getRowsCount() === 0) {
			var emptyMessage = viewConfig['allContentFilteredMessage'] || this.resourceBundle.I_ALL_CONTENT_FILTERED;
			this.showMessage(emptyMessage, "info");
		} else {
			dojo.query("table.mumDataViewer-_WB_VER_ tr td a[href]", this.byId("outerTD")).forEach(function(td){
				// Prevent from redirecting page when clicking link in data table
				dojo.attr(td, "target", "_blank");
			});
		}
	},
	
	processData: function(data, viewConfig){
		this.byId("loadingMessage").style.display = "none";

		this.showMessage(false);

		this.message = data;
		
		this.resetColumnsSetting(data, viewConfig);
		
		this.hasData = true;
		this.showTable(data, viewConfig);
	},
	
	isColumnsSettingEmptyOrStale: function(columnList, viewConfig){
		if (!dojo.isArray(viewConfig['columns']['columnList']) || !viewConfig['columns']['columnsAlign'] ||
			!dojo.isArray(viewConfig['columns']['columnFilter']) || !dojo.isArray(viewConfig['columns']['columnsOrder']) ){
				return true;
		}
		
		if (dojo.isArray(viewConfig['columns']['columnList'])){
			var oldColumnList = viewConfig['columns']['columnList'];
			if (oldColumnList.length !== columnList.length) return true;

			for (var i=0; i<columnList.length; i++){
				if (columnList[i] !== oldColumnList[i]) return true;
			}
		}
		return false;
	},
	
	resetColumnsSetting: function(data, viewConfig){
		var columnsSettings = {
			columnList: [],
			columnsAlign: {},
			columnFilter: [],
			columnsOrder: [],
			columnLabel: [],
			columnSorttype: []
		};
		var filterColunmOption = "[]";
		
		if (!data){
			viewConfig['columns'] = columnsSettings;
			
			var att = this.iContext.getiWidgetAttributes();
			att.setItemValue("columns", "", false);
			att.setItemValue("filterColunmOption", filterColunmOption, false);
			att.save();
			return;
		}

		var columnList = data.columnList;

		if (this.isColumnsSettingEmptyOrStale(columnList, viewConfig)){
			for (var i = 0; i < columnList.length; i++) {
				columnsSettings.columnList.push(columnList[i]);
				columnsSettings.columnsAlign[columnList[i]] = "left";
				columnsSettings.columnFilter.push(true);
				columnsSettings.columnsOrder.push(i);
				columnsSettings.columnLabel.push(columnList[i]);
				columnsSettings.columnSorttype.push("String");
			}

			viewConfig['columns'] = columnsSettings;
			
			var att = this.iContext.getiWidgetAttributes();
			att.setItemValue("columns", dojo.toJson(columnsSettings), false);
			att.save();
		}
		
		if (columnList && dojo.isArray(columnList)){
			filterColunmOption = dojo.toJson(columnList);
			var att = this.iContext.getiWidgetAttributes();
			att.setItemValue("filterColunmOption", filterColunmOption, false);
			att.save();
		}
	},
	
	/*
	 * This method supports table column display order/filter/alignment
	 */
	prepareDataForColumnListWidget: function(columnList){
		if (columnList.length <= 0){
			throw(new com.ibm.mm.widget.dataViewer._WB_VER_.NoContentException(this.resourceBundle.E_NO_CONTENT));
		}

		var columns = [];
		for (var i = 0; i < columnList.length; i++) {
			var name = columnList[i];
			//add label and sorttype to column datatype
			var column = {
				'name': name,
				'align': 'left',	// default
				'checked': true,	// default
				'index': i,
				'label': name,
				'sorttype':'String'				
			};
			columns.push(column);
		}
		return columns;
	},
	
	showTable: function(data, viewConfig){
		if (this.hasData) {
			var tableEdit = this.byId("iTableEdit");
			this.renderTable(data, viewConfig);
			this.updatePageLink();
			tableEdit.style.display = "";
		}
	},
	
	_loadItemSet : function(){
		var att=this.iContext.getiWidgetAttributes();
		
		var	columns = {};
		var columnsStr = att.getItemValue("columns");
		if (columnsStr && columnsStr !== "null") {
			try{
				columns = dojo.fromJson(columnsStr);
				if (columns.columnList) {
					if (!columns.columnLabel) {
						columns.columnLabel = dojo.map(columns.columnList, function(item){
							return item;
						});
					}
					if (!columns.columnSorttype) {
						columns.columnSorttype = dojo.map(columns.columnList, function(item) {
							return "String";
						});
					}
				}
			} catch(e) {
				att.setItemValue("columns", "", false);
				this.LOGGER.severe("_loadItemSet", this.resourceBundle.E_ITEMSET_COLUMNS_BROKEN);
			}
		}
		
		var tableTitle = att.getItemValue("tableTitle");
		var filterTargetValue = att.getItemValue("filterTargetValue");
        
		var viewConfig = {
			'feedURL' : att.getItemValue("feedURL"),
			'type': att.getItemValue("type"),
			'isWiring' : att.getItemValue("isWiring"),
			'rowsPerView' : att.getItemValue("rowsPerView"),
			'showHeader' : att.getItemValue("showHeader"),
			'columns' : columns,
			'tableTitle' : tableTitle === "null" ? "" : tableTitle,
			'tableTitleFont' : att.getItemValue("tableTitleFont"),
			'tableTitleAlignment': att.getItemValue("tableTitleAlignment"),
			'tableTitleFontSize' : att.getItemValue("tableTitleFontSize"),
			'tableTitleFontBold' : att.getItemValue("tableTitleFontBold"),
			'tableTitleFontItalic' : att.getItemValue("tableTitleFontItalic"),
			'tableTitleColor' : att.getItemValue("tableTitleColor"),
			'tableHeaderFont' : att.getItemValue("tableHeaderFont"),
			'tableHeaderFontSize' : att.getItemValue("tableHeaderFontSize"),
			'tableHeaderFontBold' : att.getItemValue("tableHeaderFontBold"),
			'tableHeaderFontItalic' : att.getItemValue("tableHeaderFontItalic"),
			'tableHeaderColor' : att.getItemValue("tableHeaderColor"),
			'tableContentFont' : att.getItemValue("tableContentFont"),
			'tableContentFontSize' : att.getItemValue("tableContentFontSize"),
			'tableContentFontBold' : att.getItemValue("tableContentFontBold"),
			'tableContentFontItalic' : att.getItemValue("tableContentFontItalic"),
			'tableContentColor' : att.getItemValue("tableContentColor"),
			'columnLineSize' : att.getItemValue("columnLineSize"),
			'rowLineSize' : att.getItemValue("rowLineSize"),
			'oddRowColor' : att.getItemValue("oddRowColor"),
			'evenRowColor' : att.getItemValue("evenRowColor"),
			'filterColunm' : att.getItemValue("filterColunm"),
			'filterColunmOption' : att.getItemValue("filterColunmOption"),
			'filterColunmType' : att.getItemValue("filterColunmType"),
			'filterFunction' : att.getItemValue("filterFunction"),
			'filterTargetValue' : filterTargetValue === "null" ? "" : filterTargetValue,
			'isHighLightFilter' : att.getItemValue("isHighLightFilter"),
			'isFilter' : att.getItemValue("isFilter"),
			'isRemoveFilter' : att.getItemValue("isRemoveFilter"),
			'highLightFilterColor' : att.getItemValue("highLightFilterColor"),
			'noSort' : att.getItemValue("noSort"),
			'invalidFeedMessage' : att.getItemValue("invalidFeedMessage"),
			'noContentMessage' : att.getItemValue("noContentMessage"),
			'allContentFilteredMessage' : att.getItemValue("allContentFilteredMessage")
		};
		return viewConfig;
	},
	
	/*
	 * This method supports load hub data feed and invoke callback for data process, hub feed is tabular data
	 */
	renderDataFromURL: function(viewConfig){
        this.showLoadingMessage();
        var self = this;
        var feedURL = viewConfig.feedURL;
		if (viewConfig.isWiring !== "true" || this._urlIsFromWiring) {
			/*
			 * Conditions for widget refreshing data store from url
			 * - Widget is not wired
			 * - Widget is wired, with accepting URL
			 */
	        if (!feedURL) {
	            this.showInitMessage();
	            return;
	        }
	        feedURL = this.iContext.io.rewriteURI(dojo.trim(feedURL));
	        this._dataSource = new com.ibm.mm.widget.dataViewer._WB_VER_.remoteDataSource(feedURL, function(e){
	            self.resetColumnsSetting(null, viewConfig);
	            self.showErrorMessage(e);
	        });
		}
		
		if (this._dataSource) {
			this._dataSource.getData(function(data, dataSource, dataModel){
				self.processData(data, viewConfig);
				
				var urlType = '';
				if (dataModel === 'XMLDataModel') {
					urlType = 'feed';
					if (self.publishEventEnabled['New_Feed_Address']) {
						self.iContext.iEvents.publishEvent("New Feed Address", viewConfig.feedURL);
					}
				}
				else if (dataModel === 'CSVDataModel' || dataModel === 'CSVLikeDataModel') {
					urlType = 'csv';
					if (self.publishEventEnabled['New_CSV_Address']) {
						self.iContext.iEvents.publishEvent("New CSV Address", viewConfig.feedURL);
					}
				}
				if (urlType !== viewConfig['type']) {
					var att = self.iContext.getiWidgetAttributes();
					att.setItemValue("type", urlType);
					att.save();
				}
				//publish table
				self.publishTable(data);
			});
		} else {
			this.showInitMessage();
		}
	},
	
	/*
	 * Support column dynamic event
	 */
	updateDynamicEvents: function(nameList){
		var oldDynamicEvents = this.dynamicEvents;
		var newDynamicEvents = {};
		this.dynamicEvents = {};
		
		for (var key in nameList) {
			newDynamicEvents[key] = true;
			this.dynamicEvents[key] = true;
		}
		
		for (var eventName in oldDynamicEvents) {
			if (!newDynamicEvents[eventName]) {
				this.iContext.iEvents.removeEvent(eventName);
			}
		}
		
		for (var eventName in newDynamicEvents) {
			this._createEvent({
				name: eventName,
				isHandled: false,
				isPublished: true,
				localizedAttributes: {
					"en":{"title":nameList[eventName], "description":""},
					"de":{"title":nameList[eventName], "description":""},
					"zh":{"title":nameList[eventName], "description":""}
				},
				attributes: {
	                "private": false,
					"setOnNewWire": 'publishDynamicEventOnNewWire'
	            }
			});
		}
	},

    /**
     * Dynamic create iEvent
     * @param {Object} kwArgs
     *     name: name of iEvent
     *     type: (optional) type of iEvent, "text" by default
     *     isHandled: (optional) publish or handled, "false" by default
     *     lang: (optional) language, "en" by default
     *     handlingFn: (optional) function name of event handler
     *     localizedAttributes: (optional) 
     *     attributes: (optional) private by default
     */
    _createEvent: function(kwArgs) {
        if (!kwArgs.name || (kwArgs.isHandled && !kwArgs.handlingFn)) {
            return;
        }
        if (!kwArgs.localizedAttributes) {
            var eventShortName = kwArgs.name;
            kwArgs.localizedAttributes = {
                "en": {
                    "title": eventShortName,
                    "description": "desc_" + eventShortName
                }
            }
        }
        var obj = {
            name: null,
            type: "text",
            isHandled: false,
            lang: "en",
            handlingFn: null,
            localizedAttributes: {
                "en":{"title":"", "description":""}
            },
            attributes: {
                "private": true
            }
        };
        var args = dojo.mixin(obj, kwArgs);
        var event = this.iContext.iEvents.createEventDescription(args);
        this.iContext.iEvents.setEvent(event);
    },
    
	/*
	 * Below methods are event handlers for data viewer's UI events in view mode and config mode
	 */
	
	cancel : function(){
		this.reload = false;
		this.iContext.iEvents.fireEvent("onModeChanged",null,{newMode:'view'});
	},
	
	/*
	 * Invoked by 'Save' button in config view, save data viewer's display setting to ItemSet
	 */
	save : function(){
		var feedURL = this._urlWidgetHelper.getUrl(); // var feedURL = this.byId("feedURL").value;
		var attr=this.iContext.getiWidgetAttributes();
		var isWiring = attr.getItemValue("isWiring");
		
		var rowsPerView = this.byId("rowsPerPage").value;
		var showHeader = "true";
       	if (this.byId("showHeader").checked) showHeader = "true";
		else showHeader = "false";
		
		var columns = "";
		if (this.ColumnTable) {
			columns = this.ColumnTable.getSettings();
		}
		
        var dataViewerForm = this.byId("dataViewerForm");
        
		var tableTitle = this.byId("tableTitle").value;
		var tableTitleAlignment = this.byId("titleAlign").value;
		var tableTitleFont = this.byId("titleFont").value;
		var tableTitleFontSize = this.byId("titleFontSize").value;
		var tableTitleFontBold = this.byId("titleFontBold").value;
		var tableTitleFontItalic = this.byId("titleFontItalic").value;
		var tableTitleColor = this.byId("titleFontColor").getAttribute('color');
		
		var tableHeaderFont = this.byId("headerFont").value;
		var tableHeaderFontSize = this.byId("headerFontSize").value;
		var tableHeaderFontBold = this.byId("headerFontBold").value;
		var tableHeaderFontItalic = this.byId("headerFontItalic").value;
		var tableHeaderColor = this.byId("headerFontColor").getAttribute('color');

		var tableContentFont = this.byId("tableFont").value;
		var tableContentFontSize = this.byId("tableFontSize").value;
		var tableContentFontBold = this.byId("tableFontBold").value;
		var tableContentFontItalic = this.byId("tableFontItalic").value;
		var tableContentColor = this.byId("tableFontColor").getAttribute('color');

		var columnLineSize = this.byId("columnLines").value;
		var rowLineSize = this.byId("rowLines").value;
		var oddRowColor = this.byId("oddRowColor").getAttribute('color');
		var evenRowColor = this.byId("evenRowColor").getAttribute('color');

		var filterColunm = this.byId("columnAd").value;
		var filterColunmOption = "[]";
		var options = this.byId("columnAd").getElementsByTagName("OPTION");
		if (dojo.isArray(options) && options.length > 0){
			var array = [];
			for (var i=0; i<options.length; i++) array.push(options[i].value);
			filterColunmOption = dojo.toJson(array);
		}
		var filterColunmType = this.byId("contentType").value;
		var filterFunction = this.byId("contentCompare").value;
		var comparVar = this.byId("comparVar");
		var filterTargetValue = comparVar.value || "";
		
		var filterType = "";
		var filterInputs = dataViewerForm['actionType'];
		dojo.forEach(filterInputs, function(radio) {
			if (radio.checked) filterType = radio.value;
		}, this);
		
		var isHighLightFilter = "" + (filterType === 'highlight');
		var isFilter = "" + (filterType === 'filter');
		var isRemoveFilter = "" + (filterType === 'remove');
		var highLightFilterColor = dojo.attr(this.byId("highlightWithColor"), 'color');
		var invalidFeedMessage = dojo.trim(dataViewerForm['invalidFeed'].value) || com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerMessages.E_INVALID_ATOM_FEED;
		var noContentMessage = dojo.trim(dataViewerForm['noContent'].value) || com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerMessages.E_NO_CONTENT;
		var allContentFilteredMessage = dojo.trim(dataViewerForm['allContentFiltered'].value) || com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerMessages.I_ALL_CONTENT_FILTERED;

		var att = this.iContext.getiWidgetAttributes();
		
		att.setItemValue("feedURL", feedURL);
		att.setItemValue("isWiring", isWiring, false);
        
		att.setItemValue("rowsPerView", rowsPerView, false);
		att.setItemValue("showHeader", showHeader, false);
		att.setItemValue("columns", columns, false);

		att.setItemValue("tableTitle", tableTitle, false)
		att.setItemValue("tableTitleAlignment", tableTitleAlignment, false);
		att.setItemValue("tableTitleFont", tableTitleFont, false);
		att.setItemValue("tableTitleFontSize",tableTitleFontSize,false);
		att.setItemValue("tableTitleFontBold",tableTitleFontBold);
		att.setItemValue("tableTitleFontItalic",tableTitleFontItalic,false);
		att.setItemValue("tableTitleColor", tableTitleColor, false);

		att.setItemValue("tableHeaderFont", tableHeaderFont, false);
		att.setItemValue("tableHeaderFontSize", tableHeaderFontSize, false);
		att.setItemValue("tableHeaderFontBold", tableHeaderFontBold, false);
		att.setItemValue("tableHeaderFontItalic", tableHeaderFontItalic, false);
		att.setItemValue("tableHeaderColor", tableHeaderColor, false);

		att.setItemValue("tableContentFont", tableContentFont, false);
		att.setItemValue("tableContentFontSize", tableContentFontSize, false);
		att.setItemValue("tableContentFontBold", tableContentFontBold, false);
		att.setItemValue("tableContentFontItalic", tableContentFontItalic, false);
		att.setItemValue("tableContentColor", tableContentColor, false);

		att.setItemValue("columnLineSize", columnLineSize, false);
		att.setItemValue("rowLineSize", rowLineSize, false);
		att.setItemValue("oddRowColor", oddRowColor, false);
		att.setItemValue("evenRowColor", evenRowColor, false);

		att.setItemValue("filterColunm", filterColunm, false);
		att.setItemValue("filterColunmOption", filterColunmOption, false);
		att.setItemValue("filterColunmType", filterColunmType, false);
		att.setItemValue("filterFunction", filterFunction, false);
		att.setItemValue("filterTargetValue", filterTargetValue, false);
		att.setItemValue("isHighLightFilter", isHighLightFilter, false);
		att.setItemValue("isFilter", isFilter, false);
		att.setItemValue("isRemoveFilter", isRemoveFilter, false);
		att.setItemValue("highLightFilterColor", highLightFilterColor, false);
		att.setItemValue("invalidFeedMessage", invalidFeedMessage, false);
		att.setItemValue("noContentMessage", noContentMessage, false);
		att.setItemValue("allContentFilteredMessage", allContentFilteredMessage, false);
		
        this._urlWidgetHelper.save();
		
        this.reload = true;
		att.save();
		
		this._viewConfig = this._loadItemSet();
		this.iContext.iEvents.fireEvent("onModeChanged",null,{newMode:'view'});			
	},
	
	removeColumnTable: function(){
		var ColumnTableContainer = this.byId("ColumnTableContainer");		
		
		if (this.ColumnTable){
			this.ColumnTable.destroy();
			this.ColumnTable = null;
			dijit.registry.remove(this.domID + "ColumnTable");

			dojo.empty(ColumnTableContainer);
			var columnTable = dojo.create("div");
			columnTable.id = this.domID+"ColumnTable";
			ColumnTableContainer.appendChild(columnTable);
		}
	},
	
	/*Restore configuration view UI to default state*/
	restoreConfigView: function(){
		var selcontainer = this.byId("columnAd");
    	dojo.empty(selcontainer);
    	this.removeColumnTable();
        
		this.showMessage(false, null, "editMessageBox");
	},
	
	/*
	 * When end users click Load button on config view, data viewer will display UI for user to customize 
	 * 1) which columns to display
     * 2) the order for columns to display
     * 3) use which column for filter
	 */
	onLoadButtonClick : function(feedURL){
		if (!feedURL) {
			this.restoreConfigView();
			return;
		}
		feedURL = this.iContext.io.rewriteURI(feedURL);
		
		var self = this;
		this._dataSource = new com.ibm.mm.widget.dataViewer._WB_VER_.remoteDataSource(feedURL, function(e){
			var selcontainer = self.byId("columnAd");
        	dojo.empty(selcontainer);

			self.removeColumnTable();
			self.showErrorMessage(e, "editMessageBox");
		});
		this._dataSource.getData(function(data){
			self.restoreConfigView();
			var columnList = data.columnList;
			var selcontainer = self.byId("columnAd");
			for (var i = 0; i < columnList.length; i++) {
                var option = dojo.create('option');
                option.innerHTML = option.value = columnList[i];
                selcontainer.appendChild(option);
			}
			
			var columns = self.prepareDataForColumnListWidget(columnList);
			try{
				self.ColumnTable = new com.ibm.mm.widget.dataViewer._WB_VER_.widget.ColumnsList({
					wid: self.domID + "field",
					contextRootBuilder: self.contextRoot
				}, self.byId("ColumnTable"));
				self.ColumnTable.initialize(columns);
				self.ColumnTable.render();
			}catch(e){
				self.LOGGER.severe("onLoadButtonClick", self.resourceBundle.E_CREATE_COLUMN_TABLE);
			}
		});

	},
	
	onTitleAlignClick: function(targetValue){
		var titleAlign = this.byId("titleAlign");
		var formerValue = titleAlign.value;
		if (formerValue !== targetValue) {
			var formerImg = this.byId('align_title_' + formerValue + '_img'),
			    targetImg = this.byId('align_title_' + targetValue + '_img'),
                formerBtn = this.byId('align_title_' + formerValue + "_btn"),
				targetBtn = this.byId('align_title_' + targetValue + '_btn');
            
			formerImg.src = this.contextRoot + "/images/align_" + formerValue + ".png";
			targetImg.src = this.contextRoot + "/images/align_" + targetValue + "_selected.png";

            var formerStr = dojo.string.substitute(this.resourceBundle.L_CONF_ALIGN_1, [this.resourceBundle["L_" + formerValue.toUpperCase()]]),
			    targetStr = dojo.string.substitute(this.resourceBundle.L_CONF_ALIGN_IS_SELECTED_1, [this.resourceBundle["L_" + targetValue.toUpperCase()]]);

            formerImg.alt = formerBtn.title = formerStr;
			targetImg.alt = targetBtn.title = targetStr;
			
			dojo.attr(formerImg, "aria-label", formerStr);
			dojo.attr(targetImg, "aria-label", targetStr);
			
			titleAlign.value = targetValue;
		}
	},
	
	restoreMessage: function(message) {
		var dataViewerForm = this.byId("dataViewerForm");
		var oriMessage = ""
		if (message === "invalidFeed")
		    oriMessage = this.resourceBundle.E_CHECK_URL;
		else if (message === "noContent")
		    oriMessage = this.resourceBundle.E_NO_CONTENT;
		else if (message === "allContentFiltered")
		    oriMessage = this.resourceBundle.I_ALL_CONTENT_FILTERED;
		dataViewerForm[message].value = oriMessage;
	},
	
	next: function(){
		var dataViewer = dijit.byId(this.domID + "dataViewerId");
		if (dataViewer) {
			dataViewer.fetchNextPage();
		}
		this.updatePageLink();
	},
	
	pre: function(){
		var dataViewer = dijit.byId(this.domID + "dataViewerId");
		if (dataViewer) {
			dataViewer.fetchPrePage();
		}
		this.updatePageLink();
	},
	
	getPage: function(index){
		var dataViewer = dijit.byId(this.domID + "dataViewerId");
		if (dataViewer) {
			dataViewer.fetchPage(index);
		}
		this.updatePageLink();
	},
	
	getServerDataPage: function(index){
		var url = this.message.first || this.message.last || this.message.previous || this.message.next;
		if (!url){ 
			//uncatched exception, indicates pipeline data is incorrect
			this.showErrorMessageTableExist(this.resourceBundle.E_ILLEGAL_PIPELINE_DATA);
			return;
		}
		
		var viewConfig = this._loadItemSet();
		var startIndex = index * parseInt(viewConfig['rowsPerView'], 10) + 1/*opensearch spec starts with 1*/;
		var count = viewConfig['rowsPerView'];
		
		var newURL = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.createPipelineURL(url, "startIndex", startIndex);
		newURL = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.createPipelineURL(newURL, "count", count);
		
		this.handleURL({'payload' : newURL});
	},
	
	getPrePageRegion: function(){
		var dataViewer = dijit.byId(this.domID + "dataViewerId");
		if (dataViewer) {
			dataViewer.fetchPrePageRegion();
		}
		this.updatePageLink();
	},
	
	getNextPageRegion: function(){
		var dataViewer = dijit.byId(this.domID + "dataViewerId");
		if (dataViewer) {
			dataViewer.fetchNextPageRegion();
		}
		this.updatePageLink();
	},
	
	updatePageLink: function(){
		var dataViewer = dijit.byId(this.domID + "dataViewerId");
		if (!dataViewer)
			return;
		var link = dataViewer.createPageLink();
		var linktd = this.byId("pageLink");
		linktd.innerHTML = link;
	},
	
	onSectionTitleClick: function(node) {
		if (node) {
            var section = dojo.attr(node, "href");
			section = section.substring(section.indexOf("#") + 1);
			
			var contentNode = this.byId(section + "div");
			var imgNode = dojo.query("img", node)[0];
			
			var isMax = (contentNode.style.display !== "none");
			
			imgNode.src = this.contextRoot + "/images/section_" + (isMax ? "closed" : "open") + ".png";
			imgNode.alt = "Click to " + (isMax ? "open " : "close ") + section + " section";
		    
			dojo.fx[isMax ? "wipeOut" : "wipeIn"]({
				node: contentNode,
				duration: 400
			}).play();
		}
	},
	
	/**
	 * Change compare filter select options
	 * @param {String} compareType "numeric" or "text"
	 */
	changeCompare: function(compareType, selectNode, defaultValue){
		var compareNode = selectNode || this.byId("contentCompare");
        dojo.empty(compareNode);
		
		var optionArray = null;
		if (compareType === 'numeric') {
			optionArray = [
				{'label' : this.resourceBundle.L_CONF_OPTION_GREATER_THAN, 'value' : "gt"},
				{'label' : this.resourceBundle.L_CONF_OPTION_GREATER_THAN_OR_EQUAL_TO, 'value' : "notlt"},
				{'label' : this.resourceBundle.L_CONF_OPTION_EQUAL_TO, 'value' : "eq"},
				{'label' : this.resourceBundle.L_CONF_OPTION_LESS_THAN_OR_EQUAL_TO, 'value' : "notgt"},
				{'label' : this.resourceBundle.L_CONF_OPTION_LESS_THAN, 'value' : "lt"}];
		} else {              // 'text' by default
			optionArray = [
				{'label' : this.resourceBundle.L_CONF_OPTION_BEGINS_WITH, 'value' : "bw"},
				{'label' : this.resourceBundle.L_CONF_OPTION_CONTAINS, 'value' : "ct"},
				{'label' : this.resourceBundle.L_CONF_OPTION_ENDS_WITH, 'value' : "ew"}];
		}
		
		if (!defaultValue) {
			defaultValue = optionArray[0].value;
		}
		for (var i=0; i<optionArray.length; i++){
            var option = dojo.create('option');
            option.innerHTML = optionArray[i].label;
			dojo.attr(option, "value", optionArray[i].value);
			if (option.value === defaultValue) {
				dojo.attr(option, "selected", "selected");
			}
            compareNode.appendChild(option);
		}
		compareNode.value = defaultValue;
	},
	
	popColorPicker: function(colorDOM){
		var indicatorX = dojo.coords(colorDOM, true).x;
		var indicatorY = dojo.coords(colorDOM, true).y;
//fix bug 6947
//		var relativeX = indicatorX - dojo.coords(dojo.byId(this.iContext.widgetId+"_edit"), true).x;
//		var relativeY = indicatorY - dojo.coords(dojo.byId(this.iContext.widgetId+"_edit"), true).y + 24;
		var relativeX = 0;
		var relativeY = 0;
		
		var editDiv = dojo.byId(this.iContext.widgetId+"_edit");
		
		if(editDiv){
			//position according to edit div
			relativeX = indicatorX - dojo.coords(editDiv, true).x;
			relativeY = indicatorY - dojo.coords(editDiv, true).y + 24;
			
		}else{
			//position according to color picker input
			relativeX = indicatorX;
			relativeY = indicatorY + 24;		
		}
		
		var parent = this.byId("ColorPickerContainer");		
		
		if (this.colorPicker){
			if (this.colorPickerConnect){
				dojo.disconnect(this.colorPickerConnect);
			}
			this.colorPicker.destroy();
			var colorPalette = dojo.create("div");
			colorPalette.id = this.domID+"ColorPalette";
			parent.appendChild(colorPalette);
		}
		this.colorPicker = new com.ibm.mm.widget.dataViewer._WB_VER_.widget.ColorPalette({
			id: this.domID + "ColorPalette"
		}, this.byId(this.domID+"ColorPalette"));
		this.colorPicker._setTriggerInput(colorDOM);
		
		this.colorPickerConnect = dojo.connect(this.colorPicker, 'onChange', function(colorValue){
			if(colorValue){
				if (colorValue.indexOf('#') !== 0) colorValue = "#000000";
				dojo.style(colorDOM, {
					"color": colorValue,
					"backgroundColor": colorValue
				});
				dojo.attr(colorDOM, "color", colorValue);
				colorDOM.title = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.hexColor2String(colorValue);
			}
			this.domNode.parentNode.style.display = "none";
			return false;
		});
		
		dojo.style(parent, {
			left: relativeX + "px",
			top: relativeY + "px",
			zIndex: 888,
			display: ""
		});
		
		dijit.focus(this.byId(this.domID+"ColorPalette"));
	},
	
	onColorPicker: function(colorDOM){
		this.popColorPicker(colorDOM);
	},
	
	onHighlightColorPicker: function(colorDOM) {
		if (this.byId("actionType_highlight").checked)
			this.onColorPicker(colorDOM);
	},
	
	onBoldClick: function(link) {
		var imgs = dojo.query('img', link);
		if (!imgs || !imgs.length || imgs.length <= 0) return;

		var img = imgs[0];
		
		img.src = img.src.search("bold_selected.png") === -1 ? this.contextRoot + "/images/bold_selected.png" : this.contextRoot + "/images/bold.png";
		switch(img.name){
			case "titleFontBoldImg":
				var titleFontBold = this.byId("titleFontBold");
				titleFontBold.value = (titleFontBold.value === "true") ? "false" : "true";
				link.title = img.title = img.alt = (titleFontBold.value === "true") ? this.resourceBundle.L_CONF_STYLE_TABLE_TITLE_FONT_DISABLE_BOLD : this.resourceBundle.L_CONF_STYLE_TABLE_TITLE_FONT_ENABLE_BOLD;
				break;
			case "tableFontBoldImg":
				var tableFontBold = this.byId("tableFontBold");
				tableFontBold.value = (tableFontBold.value === "true") ? "false" : "true";
				link.title = img.title = img.alt = (tableFontBold.value === "true") ? this.resourceBundle.L_CONF_STYLE_TABLE_FONT_DISABLE_BOLD : this.resourceBundle.L_CONF_STYLE_TABLE_FONT_ENABLE_BOLD;
				break;
			case "headerFontBoldImg":
				var headerFontBold = this.byId("headerFontBold");
				headerFontBold.value = (headerFontBold.value === "true") ? "false" : "true";
				link.title = img.title = img.alt = (headerFontBold.value === "true") ? this.resourceBundle.L_CONF_STYLE_TABLE_HEADER_FONT_DISABLE_BOLD : this.resourceBundle.L_CONF_STYLE_TABLE_HEADER_FONT_ENABLE_BOLD;
				break;
		}
	},
	
	onItalicClick: function(link) {
		var imgs = dojo.query('img', link);
		if (!imgs || !imgs.length || imgs.length <= 0) return;

		var img = imgs[0];

		img.src = img.src.search("italic_selected.png") === -1 ? this.contextRoot + "/images/italic_selected.png" : this.contextRoot + "/images/italic.png";
		switch(img.name){
			case "titleFontItalicImg":
				var titleFontItalic = this.byId("titleFontItalic");
				titleFontItalic.value = (titleFontItalic.value === "true") ? "false" : "true";
				link.title = img.title = img.alt = (titleFontItalic.value === "true") ? this.resourceBundle.L_CONF_STYLE_TABLE_TITLE_FONT_DISABLE_ITALIC : this.resourceBundle.L_CONF_STYLE_TABLE_TITLE_FONT_ENABLE_ITALIC;
				break;
			case "tableFontItalicImg":
				var tableFontItalic = this.byId("tableFontItalic");
				tableFontItalic.value = (tableFontItalic.value === "true") ? "false" : "true";
				link.title = img.title = img.alt = (tableFontItalic.value === "true") ? this.resourceBundle.L_CONF_STYLE_TABLE_FONT_DISABLE_ITALIC : this.resourceBundle.L_CONF_STYLE_TABLE_FONT_ENABLE_ITALIC;
				break;
			case "headerFontItalicImg":
				var headerFontItalic = this.byId("headerFontItalic");
				headerFontItalic.value = (headerFontItalic.value === "true") ? "false" : "true";
				link.title = img.title = img.alt = (headerFontItalic.value === "true") ? this.resourceBundle.L_CONF_STYLE_TABLE_HEADER_FONT_DISABLE_ITALIC : this.resourceBundle.L_CONF_STYLE_TABLE_HEADER_FONT_ENABLE_ITALIC;
				break;
		}
	},
	
	onSizeChanged: function(iEvent){
		if(this.iContext.getiDescriptor().getItemValue("mode") == this.iContext.constants.mode.EDIT){
			var rootNode = this.byId("root");
			var contentNode = this.byId("contentNode");
			
			var rootMarginBox = dojo.marginBox(rootNode);
			var contentMarginBox = dojo.marginBox(contentNode);
			var dialogContentBox = dojo.contentBox(rootNode.parentNode);
			var footerMarginBox = dojo.marginBox(this.byId("footer"));
			
			rootMarginBox.h = dialogContentBox.h;
			rootMarginBox.w = dialogContentBox.w;
			dojo.marginBox(rootNode, rootMarginBox);
			
			contentMarginBox.h = dialogContentBox.h - footerMarginBox.h;
			contentMarginBox.w = dialogContentBox.w;
			dojo.marginBox(contentNode, contentMarginBox);
		}
	}
});
