/* Copyright IBM Corp. 2010  All Rights Reserved.                    */
dojo.provide("com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil");

/*
 * This file contains utilities function and class for data viewer.
 */

com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.hexColor2String = function(hexColor){
    var red = parseInt("0x" + hexColor.substr(1, 2), 16);
    var green = parseInt("0x" + hexColor.substr(3, 2), 16);
    var blue = parseInt("0x" + hexColor.substr(5, 2), 16);
	return dojo.string.substitute(com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerMessages.L_COLOR_PICKER_COLOR_TITLE, [red, green, blue]);	
}

// convert an Array of like objects to a string. we encode comma (,) and pipe (|) since
// those are the delimeters required by the Data Viewer.
com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.createDataViewString = function(/*Array*/entryObjects){
	var rtnVal = "";
	if (!entryObjects) {
		return rtnVal;
	}
	if (entryObjects.length == 0)
		return rtnVal;
	// we have something
	var row = entryObjects[0];
	var i = 0;
	var names = [];
	var encodedNames = [];
	var types = [];
	var encodedRowNames = [];
	
	// save the object names
	for (var prop in row) {
		names[i] = prop;
		encodedNames[i] = this.encodeString(prop);
		types[i] = "String";
		encodedRowNames[i] = this.encodeString(row[names[i]]);
		i++;
	}
	// add headers
	rtnVal += encodedNames.join(",");
	
	// add types (don't have right now, say String)
	rtnVal += "|";
	rtnVal += types.join(",");
	
	// add first row
	rtnVal += "|";
	rtnVal += encodedRowNames.join(",");
	
	// add remaining objects
	for (var j = 1; j < entryObjects.length; j++) {
		rtnVal += "|";
		row = entryObjects[j];
		for (i = 0; i < names.length; i++) {
			if (i > 0) {
				rtnVal += ",";
			}
			rtnVal += this.encodeString(row[names[i]]);
		}
	}
	return rtnVal;
}

com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.encodeString = function(/*String*/aString){
	// change comma and veritcal bar to unicode
	// , -> &#44    | -> &#124
	// not clear if other encodings are required
	if (!aString || !dojo.isString(aString)) {
		return "";
	}
    return aString.replace(/,/g, "&#44").replace(/\|/g, "&#124");
}

com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.encodeCSVCell = function(cell){
	cell = "" + cell;
	var result = cell.replace(/"/g, '""');
	if (result.indexOf(',') >= 0){
		result = '"' + result + '"';
	}
	result = result.replace(/\n/g, "");
	return result;
}

com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.JSONObject2CSV = function(json){
    var rowColumnName = '', rowData = '';
    for (var key in json) {
		if (key) {
            if (rowColumnName) {
				rowColumnName += " ,";
				rowData += " ,";
			}
			rowColumnName += this.encodeCSVCell(key);
			rowData += this.encodeCSVCell(json[key]);
        }
    }
    rowColumnName += '\n';
    rowData += '\n';
    
    return rowColumnName + rowData;
}

com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.DataObject2CSV = function(data){
	if (!data) return "";
	var columns = data.columnList || [];
	var rows = data.result || [];
	var csv = [];
	for(var i = 0; i < columns.length; i++){
		csv.push(this.encodeCSVCell(columns[i]));
		if (i < columns.length -1) csv.push(",");
	}
	csv.push("\n");
	for(var i = 0; i < rows.length; i++){
		var row = rows[i];
		for(var j = 0; j < columns.length; j++){
			var col = columns[j];
			csv.push(this.encodeCSVCell(row && (row[col] || "")));
			if (j < columns.length -1) csv.push(",");
		}
		csv.push("\n");
	}
	return csv.join("");
}

com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.getDescendantNodes = function(node){
	var childNodesArray = [],
	    childNodes = node.getElementsByTagName('*');   // Only ELEMENT NODE are selected
	
    dojo.forEach(childNodes, function(node){
		if (node.childNodes.length === 1 &&
	          (node.firstChild.nodeType === 2 || // ELEMENT_NODE
	           node.firstChild.nodeType === 3 || // TEXT_NODE
	           node.firstChild.nodeType === 4)) {// CDATA_SECTION_NODE

			// ELEMENT NODE
			childNodesArray.push(node);
        }
    });
	return childNodesArray;
}

com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.getChildNodesByTagName = function(node, name) {
	var result = [];
	//name = name.toLowerCase();
	if (node && node.childNodes) {
		result = node.getElementsByTagName(name);
	}
	return result;
}

com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil._setResultForEntryNode = function(entryNode, childNodes, entryArray/*, dataArray*/){
	var aChild = null;
	var anObject = {};
	for (var i = 0; i < childNodes.length; i++) {
		aChild = childNodes[i];
		if (aChild.nodeType == 1) {
			var name = aChild.localName;
			if (aChild.localName == null) {
				name = aChild.nodeName;
			}
			var value = "";
			if (aChild.firstChild && aChild.firstChild.nodeValue) {
				value = aChild.firstChild.nodeValue;
			}
			if (name) {
				var findAttributeName = function(object, name){
					if (!object[name]) 
						return name;
					var parts = name.split('_');
					if (parts.length <= 0) 
						return name;
					var temp = parseInt(parts[parts.length - 1], 10);
					if (parts.length == 1 || isNaN(temp)){
						for(var j = 1; j < Number.MAX_VALUE; j++){
							var candidate = name + "_" + j;
							if (!object[candidate]) 
								return candidate;
						}
					}
					else {
						var start = temp + 1;
						var prefix = parts.slice(0, parts.length - 1).join('_');
						for(var j = start; j < Number.MAX_VALUE; j++){
							var candidate = prefix + "_" + j;
							if (!object[candidate]) 
								return candidate;
						}
					}
					throw(new com.ibm.mm.widget.dataViewer._WB_VER_.DataViewerException(com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerMessages.E_TOO_MANY_ELEMENTS_WITH_SAME_TAGNAME));
				}
				if (anObject[name]) 
					name = findAttributeName(anObject, name);
				anObject[name] = value; // null value is ok...
				if (entryArray.length > 0 && !entryArray[0][name]) {
					entryArray[0][name] = "";
				}
			}
		}
	}
	entryArray.push(anObject);
}

com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil._feedEntry2Object = function(node, entryArray){
	
	var object = {};
	com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil._traverseEntry(node, object, entryArray);
	entryArray.push(object);
}

com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil._traverseEntry = function(node, object, entryArray){

	var childNodes = node.childNodes;
	if (childNodes) {
		for (var i = 0; i < childNodes.length; i++) {
			var childNode = childNodes[i];
			if (childNode.nodeType == 1) {
				//operation on childNode
				

				var name = childNode.localName;
				if (childNode.localName == null) {
					name = childNode.nodeName;
				}
				var value = "";
				if (typeof childNode.firstChild != "undefined" && childNode.firstChild != null && typeof childNode.firstChild.nodeValue != "undefined" && childNode.firstChild.nodeValue != null && childNode.firstChild.nodeType != 4) {
					value = childNode.firstChild.nodeValue;
				}
				if (name) {
					var findAttributeName = function(object, name){
						if (!object[name]) 
							return name;
						var parts = name.split('_');
						if (parts.length <= 0) 
							return name;
						var temp = parseInt(parts[parts.length - 1]);
						if (parts.length == 1 || isNaN(temp)){
							for(var j = 1; j < Number.MAX_VALUE; j++){
								var candidate = name + "_" + j;
								if (!object[candidate]) 
									return candidate;
							}
						}
						else {
							var start = temp + 1;
							var prefix = parts.slice(0, parts.length - 1).join('_');
							for(var j = start; j < Number.MAX_VALUE; j++){
								var candidate = prefix + "_" + j;
								if (!object[candidate]) 
									return candidate;
							}
						}
						throw(new com.ibm.mm.widget.dataViewer._WB_VER_.DataViewerException(com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerMessages.E_TOO_MANY_ELEMENTS_WITH_SAME_TAGNAME));
					}
					if (object[name]) 
						name = findAttributeName(object, name);
					object[name] = value; // null value is ok...
					if (entryArray.length > 0 && !entryArray[0][name]) {
						entryArray[0][name] = "";
					}
				}
				
				this._traverseEntry(childNode, object);
			}
		}
	}	
}

com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.splitterCSVData = function(dataString){
	var cells = dataString.split(",");

	//handle case where cell contains ,
	var len = cells.length;
	var i, j;
	for (var m=0; m<len; m++){
		i = j = -1;
		for (var k=0; k<cells.length; k++){
			if (i == -1 && cells[k].charAt(0) == '"' && cells[k].charAt(cells[k].length - 1) != '"' ){
				i = k;
				continue;
			}
			if (i>0 && cells[k].charAt(cells[k].length - 1) == '"' && cells[k].charAt(0) != '"' ){
				j = k;
				break;
			}
		}
		
		if (i >0 && j >0){
			var str = cells[i];
			for (var k=i+1; k<j+1; k++){
				str = str + "," + cells[k];
			}

			var temp = [];
			for (var k=0; k<i; k++){
				temp.push(cells[k]);
			}
			temp.push(str);
			for (var k=j+1; k<cells.length; k++){
				temp.push(cells[k]);
			}
			cells = temp;
		}else {
			break;
		}
	}

	return cells;
}
	
com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.unescapeCSVCell = function(cellString){
	if (cellString.length >= 2 && cellString.indexOf('"') == 0 && cellString.lastIndexOf('"') == (cellString.length -1) ){
		cellString = cellString.substring(1, cellString.length - 2);
	}
	return cellString;
}

com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.getColumnList = function(object){
	var columnList = [];
	for (var key in object){
		columnList.push(key);
	}
	return columnList;
}

com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.parseJSONFeed = function(data){

    var posFields = ["totalResults", "itemsPerPage", "StartIndex"];
    
    function getLocalName(qualifiedName){
        var separatorIndex = qualifiedName.indexOf(":");
        return qualifiedName.substring(separatorIndex + 1);
    }
    
    function getNameSpace(qualifiedName){
        return qualifiedName.substring(0, qualifiedName.indexOf(":"));
    }
    
    function getLinks(obj){
        var links = obj["atom:feed"]["atom:link"] || [];
        var linkRes = {};
        for (var i = 0, len = links.length; i < len; i++) {
            var key = dojo.getObject("@rel.value", false, links[i]);
            if (key) 
                linkRes[key] = dojo.getObject("@href.value", false, links[i]);
        }
        return linkRes;
    }
    
    function getPosInfo(obj){
        var posInfo = {};
        var feed = obj["atom:feed"];
        for (var key in feed) {
            if (dojo.indexOf(posFields, getLocalName(key)) !== -1) {
                posInfo[getLocalName(key)] = parseInt(dojo.getObject("#text.value", false, feed[key]));
            }
        }
        return posInfo;
    }
    
    function isLeafElement(obj){
        var count = 0;
        for (name in obj) {
            count++;
        }
        var isLeaf = (count == 0 || typeof obj["#text"] != "undefined");
        return isLeaf;
    }
	
    function findName(key, columnNames) {
		if (dojo.indexOf(columnNames, key) === -1) return key;
		var index = 1;
		while (dojo.indexOf(columnNames, key + "_" + index) >= 0) {
			index++;
		}
		return key + "_" + index;
	}
	
	function _decodeSpace(inputNode) {
	    var value = dojo.trim(dojo.isString(inputNode) ? inputNode : inputNode.value || "");
	
	    var keyword = /_5F/g;
	    var escapeStr = "_";
	
	    var pattern = /_20/g;
	    var toReplace = " ";
	    return value.replace(pattern, toReplace).replace(keyword, escapeStr);
    }
	
	function setField(key, value, entryFields, columnNames) {
		var attrName = findName(_decodeSpace(getLocalName(key)), columnNames);
        entryFields[attrName] = dojo.getObject("#text.value", false, value);
		columnNames.push(attrName);
	}
	
    function traverseObj(entry, key, entryFields, columnNames){
		if (isLeafElement(entry)) {
			setField(key, entry, entryFields, columnNames);	
			return;			
		}
        for (var key in entry) {
            if (dojo.isObject(entry[key])) { // have to be an javascript object
                if (key.substring("@") > -1) { // if is attribute, ignore it.
                    continue;
                }
                else {
                    if (isLeafElement(entry[key])) {
						setField(key, entry[key], entryFields, columnNames);	
                    }
                    //if the content is an array, use its first element
                    else 
                        if (dojo.isArray(entry[key]) && entry[key].length > 0) {
                            for (var i = 0; i < entry[key].length; i++) {
								setField(key, entry[key][i], entryFields, columnNames);	                                }
                        }
                        else {
                            traverseObj(entry[key], key, entryFields, columnNames);
                        }
                }
            }
        }
    }
    
	function getFeedType(namespaces) {
		for (key in namespaces) {
			if (key !== "atom" && key !== "os") return 0;				
		}
		return 1;
	}
	
    function getEntriesInfo(obj){
        var res = {};
        res.columnNames = [];
        res.result = [];
        
		var entries= dojo.getObject("atom:feed.atom:entry", false, obj);
		if (!dojo.isArray(entries)) entries = [entries];
		var feedType = getFeedType(obj["__namespaces__"]);	//simply check the type of the feed.
		
        if (entries.length) {
            for (var i = 0, len = entries.length; i < len; i++) {
                var entry = entries[i];
                var entryFields = {};
				var columnNames = [];
				
                for (var key in entry) {
                    if (feedType || getNameSpace(key) !== "atom" || key === "atom:content") {
                        traverseObj(entry[key], key, entryFields, columnNames);
                    }
                }
				for (var j=0; j<columnNames.length;j++) {
					if (dojo.indexOf(res.columnNames, columnNames[j]) == -1)
						res.columnNames.push(columnNames[j]);
				}
                res.result.push(entryFields);
            }
        }
        return res;
    }
	
    function validatePagedResult(res) {
		if (!res.totalResults || !res.itemsPerPage || !res.StartIndex) return {result: false, error: "Required attribues are missing."};
		if (!res.self || !res.last || !res.first) return {result: false, error: "Required attribues are missing."};
		return {result: true};
	}
	
    function parseResult(obj){
        return dojo.mixin({}, getLinks(obj), getPosInfo(obj), getEntriesInfo(obj));
    }
	
	if (dojo.isString(data)) data = dojo.fromJson(data);
	var result = parseResult(data);

	if (!result){
		//throw("Illegal pipeline data");
		throw(new com.ibm.mm.widget.dataViewer._WB_VER_.DataViewerException(com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerMessages.E_ILLEGAL_PIPELINE_DATA));
	}
	return result;
}

/*
 * This module is used by data editor to suport large data set. The cache implementation is specific
 * to pipeline, its url template.
 * 
 */
dojo.declare("com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.dataFetcher", null, {
	constructor: function(){
		this.cache = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.dataFetcher._cache;
	},
	
	getData: function(args){
		var supportCache = this.checkCacheSupport(args.url);
		
		if (supportCache && this.isInCache(args.url)){
			args.load(this.getDataFromCache(args.url));
			return;
		}
		
		var self = this;
		var url = supportCache ? this.preloadDataURL(args.url) : args.url;
		var bindArgs = {
			url: url,
			load: function(data, ioArgs){
				if (supportCache){
					self.storeToCache(data, url);
					args.load(self.getDataFromCache(args.url));					
				} else {
					args.load(data, ioArgs);
				}
			},
			error: function(error, ioArgs){
				args.error(error, ioArgs);
			}
		}
		dojo.xhrGet(bindArgs);
	},
	
	storeToCache: function(data, url){

		var result = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.parseJSONFeed(data);
		
		var paginationData = {'totalResult' : result.totalResults, 'startIndex' : result.StartIndex || 0, 'itemsPerPage' : result.itemsPerPage,
			'first' : result.first || '', 'last' : result.last || '', 'previous' : result.previous || '', 'next' : result.next || '', 
			'result' : result.result,  'columnList' : result.columnNames};

		//opensearch spec, startIndex starts from 1
		var num = parseInt(com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.getparamFromURL(url, "startIndex"), 10);
		var startIndex = (num > 1) ? (num - 1) : 0;
		var count = parseInt(com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.getparamFromURL(url, "count"), 10);
		var pipelineID = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.getparamFromURL(url, "id");
		
		//clear cache
		delete this.cache.data;
		this.cache.data = null;
		
		this.cache.key.startIndex = startIndex;
		this.cache.key.count = count;
		this.cache.key.pipelineID = pipelineID;
		this.cache.key.url = url;
		this.cache.data = paginationData;

	},
	
	isInCache: function(url){
		
		//opensearch spec, startIndex starts from 1
		var num = parseInt(com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.getparamFromURL(url, "startIndex"), 10);
		var startIndex = num > 1 ? (num - 1) : 0;
		var count = parseInt(com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.getparamFromURL(url, "count"));
		var pipelineID = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.getparamFromURL(url, "id");
		
		if (this.cache.key.startIndex <= startIndex && 
			(this.cache.key.startIndex + this.cache.key.count) >= (startIndex + count) && 
			/*compare url template*/ this.cache.key.pipelineID == pipelineID){
			return true;
		}
		return false;
	},
	
	getDataFromCache: function(url){
		function getDataInRange(jsonArray, start, count){
			return jsonArray.slice(start, start + count);
		}
		
		//opensearch spec, startIndex starts from 1
		var num = parseInt(com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.getparamFromURL(url, "startIndex"), 10);
		var startIndex = num > 1 ? (num - 1) : 0 ;
		var count = parseInt(com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.getparamFromURL(url, "count"));

		var paginationData = {
			'totalResult' : this.cache.data.totalResult, 
			'startIndex' : startIndex, 'itemsPerPage' : count,
			'first' : this.cache.data.first || '', 
			'last' : this.cache.data.last || '', 
			'previous' : '', 
			'next' : '', 
			'result' : getDataInRange(this.cache.data.result, startIndex - this.cache.key.startIndex, count),  
			'columnList' : this.cache.data.columnList.slice()
		};

		return paginationData;
	},
	
	preloadDataURL: function(url){
		var PRELOAD_ENTRY_NUMBER = 100;
		
		var count = PRELOAD_ENTRY_NUMBER;	
		var newURL = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.createPipelineURL(url, "count", count);
		
		return newURL;
	},
	
	checkCacheSupport: function(url){
		//specific checking rule for pipeline url template
		var regexs = [/startIndex/, /count/, /pipeline/, /id/, /status/, /format/];
		
		return dojo.every(regexs, function(regex){return regex.test(url)});
	}
});

com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.dataFetcher._cache = { 
	'key' : {
		'startIndex': 0,
		'count': 0,
		'pipelineID' : 0,
		'url': ''
	}, 
	'data' : null
};

com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.getparamFromURL = function(url, key){
	if (url.indexOf(key + "=") < 0 ){
		//throw("Illegal URL");
		throw(new com.ibm.mm.widget.dataViewer._WB_VER_.DataViewerException(com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerMessages.E_ILLEGAL_PIPELINE_DATA));
	}
	
	var str = url.substring(url.indexOf(key + "=") + key.length + 1);
	var end = str.indexOf("&");
	
	var result = "";

	if (end >= 0){
		result = str.substring(0, end);
	} else{
		result = str;
	}
	
	if (!result){
		//throw("Illegal URL");
		throw(new com.ibm.mm.widget.dataViewer._WB_VER_.DataViewerException(com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerMessages.E_ILLEGAL_PIPELINE_DATA));
	}
	
	return result;
	
}

com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.createPipelineURL = function(url, key, value){
	if (url.indexOf(key + "=") < 0 ){
		//throw("Illegal URL");
		throw(new com.ibm.mm.widget.dataViewer._WB_VER_.DataViewerException(com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerMessages.E_ILLEGAL_PIPELINE_DATA));
	}
    
	var part1 = url.substring(0, url.indexOf(key + "=")  + key.length + 1) + value;
	
	var str = url.substring(url.indexOf(key + "=") + key.length + 1);
	var end = str.indexOf("&");
	
	var part2 = "";

	if (end >= 0){
		part2 = str.substring(end);
	}
	return part1 + part2;		
}

/*
 * Below functions are copied from /mm.widget.dataViewer/Web Content/js/com/ibm/mm/widget.dataViewer/utils/htmlUtil.js,
 * They are used by data viewer. The reason is to support embedding page capability, product widgets
 * should NOT depend on widget.dataViewer component.
 */
com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.setClass = function(/* HTMLElement */node, /* string */classStr){
	//	summary
	//	Clobbers the existing list of classes for the node, replacing it with
	//	the list given in the 2nd argument. Returns true or false
	//	indicating success or failure.
	node = dojo.byId(node);
	var cs = new String(classStr);
	try{
		if(dojo.isString(node.className)){
			node.className = cs;
		}else if(node.setAttribute){
			node.setAttribute("class", classStr);
			node.className = cs;
		}else{
			return false;
		}
	}catch(e){
		com.ibm.mm.enabler.debug.error(dojo.string.substitute(com.ibm.mm.widget.dataViewer._WB_VER_.coreWidgetsMessages.E_HTML_UTIL_SET_CLASS_1,[e.message]));
	}
	return true;
}

com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.getParentByType = function(/* HTMLElement */node, /* string */type) {
	//	summary
	//	Returns the first ancestor of node with tagName type.

	var _document = dojo.doc;
	var parent = dojo.byId(node);
	type = type.toLowerCase();
	while((parent)&&(parent.nodeName.toLowerCase()!=type)){
		if(parent==(_document["body"]||_document["documentElement"])){
			return null;
		}
		parent = parent.parentNode;
	}
	return parent;	//	HTMLElement
}
