/* Copyright IBM Corp. 2010  All Rights Reserved.                    */
dojo.provide("com.ibm.mm.widget.dataViewer._WB_VER_.widget.ColumnsList");

dojo.require("dijit._Widget");
dojo.require("dijit._Templated");
dojo.require("dojo.string");

dojo.declare("com.ibm.mm.widget.dataViewer._WB_VER_.widget.ColumnsList", [dijit._Widget, dijit._Templated], {
	
	wid: '',
	
	tableBody: null,
	
	templateString: "<div id='${wid}' class='columnList'><table role='presentation'><tbody dojoAttachPoint='tableBody'></tbody></table></div>",
	
	columns: [],		// columns should be put in oirginal order with index property
	
	_columnsMap: {},	// hashmap for random accessing columns
	
	resourceBundle: null,
	
	tdEventsList: null,
	
	contextRootBuilder: "/dataViewer",		// Will be rewritten with current context root
	
	postCreate: function() {
		this.widgetId = this.wid;
	},
	
	destroy: function(){
		if (this.tdEventsList && dojo.isArray(this.tdEventsList)){
			for (var i = 0; i < this.tdEventsList.length; i++){
				if (this.tdEventsList[i] && dojo.isArray(this.tdEventsList[i])) dojo.forEach(this.tdEventsList[i], dojo.disconnect);				
			}
		}
		this.inherited(arguments);
	},
	
	initialize: function(/*array*/columns) {
		this.resourceBundle = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerMessages;
		if (dojo.isArray(columns)) {
			this.columns = columns;
		}
		for (var i = 0; i < this.columns.length; i++) {
			this._columnsMap[this.columns[i].name] = i;
		}
	},
	
	render: function() {
		dojo.empty(this.tableBody);
		if (!this.columns || this.columns.length == 0)
			return;
		
		var orderedColumns = new Array(this.columns.length);
		for (var i = 0; i < orderedColumns.length; i++) {
			orderedColumns[this.columns[i].index] = this.columns[i];
		}
		
		this.tdEventsList = [];
		var sortTypeValues = ["String", "Number"],
		    sortTypeList= [this.resourceBundle.L_CONF_COLUMN_SORTTYPE_STRING,this.resourceBundle.L_CONF_COLUMN_SORTTYPE_NUMBER],
            sortTypeTitle = dojo.string.substitute(this.resourceBundle.L_CONF_COLUMN_SORTTYPE_1, [this.resourceBundle.L_CONF_COLUMN_SORTTYPE_STRING]);
		
		for (var i = 0, length = orderedColumns.length; i < length; i++) {
			var tdEvents =  [];
			var column = orderedColumns[i];
            var ctr = dojo.create('tr');
            
			var td1 = dojo.create("td", {}, ctr);
            var td2 = dojo.create('td', {
                "class": "columnName"
            }, ctr);
			var td3 = dojo.create('td', {           // text align buttons
				"class": "alignButtons"
			}, ctr);
			var td4 = dojo.create('td', {}, ctr);	// hidden input
			var td5 = dojo.create('td', {           // column order buttons
				"class": "orderButtons"
			}, ctr);
			var td6 = dojo.create("td", {           // sort type(String or Number)
				"class": "sortType"
			}, ctr);
			var td7 = dojo.create("td", {           // restore button
				"class": "restoreButtons"
			}, ctr);
			
			// TD1: checkbox for filtering columns
			var td1Html = "<input type='checkbox' class='autoWidth' id='" +this.widgetId + "COLUMN_" + i + "HEADER_CHECK' name='" + column.name + "' title='" + dojo.string.substitute(this.resourceBundle.L_CONF_SHOWCOLUMN_LABEL_1, [column.name]) + "'";
			td1Html += ((column.checked === true || column.checked === 'checked')?"checked='true'":"");
			td1Html += " >";
			td1Html += "<label for='" +this.widgetId + "COLUMN_" + i + "HEADER_CHECK' style='display:none'>" + dojo.string.substitute(this.resourceBundle.L_CONF_SHOWCOLUMN_LABEL_1, [column.name]) + "</label>";
            td1.innerHTML = td1Html;
			// events[0]
            tdEvents.push(dojo.connect(td1, "onclick", this, "onColumnCheckBoxClick"));
			
            // TD2: display label in td2
            var labelText = column.label || column.name;
            var td2Html = "<input type=\"text\" name=\"" + column.name + "_label\" title=\"" + this.resourceBundle.L_CONF_COLUMN_TITLE_RENAME_LABEL + " " + column.name + "\" value=\""+labelText+"\"/>";
            td2.innerHTML = td2Html;
			// events[1]
            tdEvents.push(dojo.connect(td2.firstChild, "onchange", this, "onColumnLabelChange"));
            
			// TD3: text align buttons
			var div_left = dojo.create('span', {}, td3);
			var div_center = dojo.create('span', {}, td3);
			var div_right = dojo.create('span', {}, td3);
			
			// TD4: hidden input, store text align value
			column.align = (column.align) ? column.align : "left"
			td4.innerHTML = "<input type='hidden' id='" + this.wid + "align_col_" + escape(column.name) + "' value='" + column.align + "'/>";
			
			var leftHtml = "";
			if (column.align === "left") {
				leftHtml = "<input type='image' alt='" + dojo.string.substitute(this.resourceBundle.L_CONF_ALIGN_IS_SELECTED_1, [this.resourceBundle.L_LEFT]) + "' title='" + dojo.string.substitute(this.resourceBundle.L_CONF_ALIGN_IS_SELECTED_1, [this.resourceBundle.L_LEFT]) + "' aria-label='" +  dojo.string.substitute(this.resourceBundle.L_CONF_ALIGN_IS_SELECTED_1, [this.resourceBundle.L_LEFT])  + "' id='" + this.wid + "align_col_left_img_" + escape(column.name) + "' name='" + column.name + "' value='left' src='" + this.contextRootBuilder + "/images/align_left_selected.png' style='cursor:pointer;'/>";
			} else {
				leftHtml = "<input type='image' alt='" + dojo.string.substitute(this.resourceBundle.L_CONF_ALIGN_1, [this.resourceBundle.L_LEFT]) + "' title='" + dojo.string.substitute(this.resourceBundle.L_CONF_ALIGN_1, [this.resourceBundle.L_LEFT]) + "' aria-label='" +  dojo.string.substitute(this.resourceBundle.L_CONF_ALIGN_1, [this.resourceBundle.L_LEFT])  + "' id='" + this.wid + "align_col_left_img_" + escape(column.name) + "' name='" + column.name + "' value='left' src='" + this.contextRootBuilder + "/images/align_left.png' style='cursor:pointer;'/>";
			}
			div_left.innerHTML = leftHtml;
			
			var centerHtml = "";
			if (column.align === "center") {
				centerHtml = "<input type='image' alt='" + dojo.string.substitute(this.resourceBundle.L_CONF_ALIGN_IS_SELECTED_1, [this.resourceBundle.L_CENTER]) + "' title='" + dojo.string.substitute(this.resourceBundle.L_CONF_ALIGN_IS_SELECTED_1, [this.resourceBundle.L_CENTER]) + "' aria-label='" +  dojo.string.substitute(this.resourceBundle.L_CONF_ALIGN_IS_SELECTED_1, [this.resourceBundle.L_CENTER]) + "' id='" + this.wid + "align_col_center_img_" + escape(column.name) + "' name='" + column.name + "' value='center' src='" + this.contextRootBuilder + "/images/align_center_selected.png' style='cursor:pointer;'/>";
			} else {
				centerHtml = "<input type='image' alt='" + dojo.string.substitute(this.resourceBundle.L_CONF_ALIGN_1, [this.resourceBundle.L_CENTER]) + "' title='" + dojo.string.substitute(this.resourceBundle.L_CONF_ALIGN_1, [this.resourceBundle.L_CENTER]) + "' aria-label='" +  dojo.string.substitute(this.resourceBundle.L_CONF_ALIGN_1, [this.resourceBundle.L_CENTER])  + "' id='" + this.wid + "align_col_center_img_" + escape(column.name) + "' name='" + column.name + "' value='center' src='" + this.contextRootBuilder + "/images/align_center.png' style='cursor:pointer;'/>";
			}
			div_center.innerHTML = centerHtml;
			if (column.align === "right") {
				div_right.innerHTML = "<input type='image' alt='" + dojo.string.substitute(this.resourceBundle.L_CONF_ALIGN_IS_SELECTED_1, [this.resourceBundle.L_RIGHT]) + "' title='" + dojo.string.substitute(this.resourceBundle.L_CONF_ALIGN_IS_SELECTED_1, [this.resourceBundle.L_RIGHT]) + "' aria-label='" +  dojo.string.substitute(this.resourceBundle.L_CONF_ALIGN_IS_SELECTED_1, [this.resourceBundle.L_RIGHT])  + "' id='" + this.wid + "align_col_right_img_" + escape(column.name) + "' name='" + column.name + "' value='right' src='" + this.contextRootBuilder + "/images/align_right_selected.png' style='cursor:pointer;'/>";
			} else {
				div_right.innerHTML = "<input type='image' alt='" + dojo.string.substitute(this.resourceBundle.L_CONF_ALIGN_1, [this.resourceBundle.L_RIGHT]) + "' title='" + dojo.string.substitute(this.resourceBundle.L_CONF_ALIGN_1, [this.resourceBundle.L_RIGHT]) + "' aria-label='" +  dojo.string.substitute(this.resourceBundle.L_CONF_ALIGN_1, [this.resourceBundle.L_RIGHT]) + "' id='" + this.wid + "align_col_right_img_" + escape(column.name) + "' name='" + column.name + "' value='right' src='" + this.contextRootBuilder + "/images/align_right.png' style='cursor:pointer;'/>";
			}
			
			// events[2] - events[4]
			tdEvents.push(dojo.connect(div_left, "onclick", this, "onAlignButtonClick"));
			tdEvents.push(dojo.connect(div_center, "onclick", this, "onAlignButtonClick"));
			tdEvents.push(dojo.connect(div_right, "onclick", this, "onAlignButtonClick"));
			
			// TD5: column order buttons
			var div_up = dojo.create('span', {}, td5);
			var div_down = dojo.create('span', {}, td5);
			
			if (i <= 0) {
				div_up.innerHTML = "<input type='image' alt='" + this.resourceBundle.L_CONF_COLUMN_ORDER_MOVEUP + "' title='" + this.resourceBundle.L_CONF_COLUMN_ORDER_MOVEUP + "' src='" + this.contextRootBuilder + "/images/up_disabled.png' style='cursor:not-allowed;'/>";
			} else {
				div_up.innerHTML = "<input type='image' alt='" + this.resourceBundle.L_CONF_COLUMN_ORDER_MOVEUP + "' title='" + this.resourceBundle.L_CONF_COLUMN_ORDER_MOVEUP + "' value='" + i + "' src='" + this.contextRootBuilder + "/images/up.png' style='cursor:pointer;'/>";
				// events[5]
				tdEvents.push(dojo.connect(div_up, "onclick", this, "onColumnUpClick"));
			}
			
			if (i >= this.columns.length-1) {
				div_down.innerHTML = "<input type='image' alt='" + this.resourceBundle.L_CONF_COLUMN_ORDER_MOVEDOWN + "' title='" + this.resourceBundle.L_CONF_COLUMN_ORDER_MOVEDOWN + "' src='" + this.contextRootBuilder + "/images/down_disabled.png' style='cursor:not-allowed;'/>";
			} else {
				div_down.innerHTML = "<input type='image' alt='" + this.resourceBundle.L_CONF_COLUMN_ORDER_MOVEDOWN + "' title='" + this.resourceBundle.L_CONF_COLUMN_ORDER_MOVEDOWN + "' value='" + i + "' src='" + this.contextRootBuilder + "/images/down.png' style='cursor:pointer;'/>";
				// events[6]
				tdEvents.push(dojo.connect(div_down, "onclick", this, "onColumnDownClick"));
			}	
					
			// TD6: display sortBy drop down menu
			var sortTypeText = column.sorttype;
			var selectHtml = "<select name=\"" + column.name + "_sorttype\" title=\"" + sortTypeTitle + "\">";
			for(var j=0; j<sortTypeList.length; j++){
				selectHtml += "<option value=\"" + sortTypeValues[j] + "\"" + ((!!sortTypeText&&sortTypeText==sortTypeValues[j])?" selected":"") + " title=\"Sort as "+sortTypeList[j]+"\">" + sortTypeList[j] + "</option>";
			}
			selectHtml += "</select>";
			td6.innerHTML = selectHtml;
			var sortTypeSelect = dojo.query("select", td6)[0];
			// events[7]
			tdEvents.push(dojo.connect(sortTypeSelect, "onchange", this, "onColumnSorttypeChange"));
			
			// TD7: Restore column name button
			var restoreTitle = dojo.string.substitute(this.resourceBundle.L_CONF_COLUMNS_RESTORE_TITLE_1, [column.name]);
			td7.innerHTML = "<button type='button' title=' " + restoreTitle+ " '>" + this.resourceBundle.L_CONF_COLUMNS_RESTORE_TITLE + "</button>"
			var restoreNameBtn = dojo.query("button", td7)[0];
			// events[8]
			tdEvents.push(dojo.connect(restoreNameBtn, "onclick", this, "onRestoreNameBtnClick"));
			
			this.tdEventsList[i] = tdEvents;
            this.tableBody.appendChild(ctr);
			ctr.initialColumnName = column.name;
		}
	},
	
	onColumnCheckBoxClick: function(event) {
		var columnName = event.target.name;
		if (columnName && this._columnsMap) {
			this.columns[this._columnsMap[columnName]].checked = event.target.checked ? event.target.checked : false;
		}
	},
	
	swapRowContent: function(oriRowIndex, tarRowIndex, tr1, tr2) {
		//disconnect the dynamic event bind before swap
		for(var j = 0; j < this.tdEventsList.length; j++){
			if(j == oriRowIndex || j == tarRowIndex){
				for(var k = 0; k < this.tdEventsList[j].length; k++){
					if(k == 5 || k == 6) continue;//events[5] and [6] are for swap button which need no swap
					dojo.disconnect(this.tdEventsList[j][k]);
				}
			}
		}
		
		for (var i = 0, length = tr1.cells.length; i < length; i++) {
			if(i == 4) continue; //tds[4] is the swap button which needs no swap
			
			var tr1Sorttype,tr2Sorttype;
			if(i == 5){
				//save the sorttype before content swap
				tr1Sorttype = dojo.query("select", tr1.cells[i])[0].value;
				tr2Sorttype = dojo.query("select", tr2.cells[i])[0].value;
			}
			this.swapCellContent(tr1.cells[i], tr2.cells[i]);
			
			if (i == 2){/* add onclick handler for column alignment images*/
				var imgControls = dojo.query("input", tr1.cells[2]);
				for (var j=0; j<imgControls.length; j++) this.tdEventsList[oriRowIndex][i] = dojo.connect(imgControls[j].parentNode, "onclick", this, "onAlignButtonClick");

				imgControls = dojo.query("input", tr2.cells[2]);
				for (j=0; j<imgControls.length; j++) this.tdEventsList[tarRowIndex][i] = dojo.connect(imgControls[j].parentNode, "onclick", this, "onAlignButtonClick");
			}
            
			if(i == 5){
				//restore sorttype after content swap
				var newTr1Sorttype = dojo.query("select", tr1.cells[i])[0];
				var newTr2Sorttype = dojo.query("select", tr2.cells[i])[0];
				newTr1Sorttype.value = tr2Sorttype;
				newTr2Sorttype.value = tr1Sorttype;
				this.tdEventsList[oriRowIndex][7] = dojo.connect(newTr1Sorttype, "onchange", this, "onColumnSorttypeChange");
				this.tdEventsList[tarRowIndex][7] = dojo.connect(newTr2Sorttype, "onchange", this, "onColumnSorttypeChange");
			}
			
			if (i==6) {
				var restoreNameBtn1 = dojo.query("button", tr1.cells[i])[0];
				var restoreNameBtn2 = dojo.query("button", tr2.cells[i])[0];
				this.tdEventsList[oriRowIndex][8] = dojo.connect(restoreNameBtn1, "onclick", this, "onRestoreNameBtnClick");
				this.tdEventsList[tarRowIndex][8] = dojo.connect(restoreNameBtn2, "onclick", this, "onRestoreNameBtnClick");
			}
		}
		var initialColumnName1 = tr1.initialColumnName;
		tr1.initialColumnName = tr2.initialColumnName;
		tr2.initialColumnName = initialColumnName1;
	},
	
	swapCellContent: function(td1, td2)	 {
		td1.parentNode.replaceChild(td2.cloneNode(true), td1);
		td2.parentNode.replaceChild(td1.cloneNode(true), td2);
	},
	
	getColumnIndexFromRow: function(tr) {
		var inputNode = dojo.query("input", tr.cells[1])[0];
		var columnName = inputNode.value;
		for (var i = 0, length = this.columns.length; i < length; i++) {
			if (this.columns[i].label === columnName) {
                columnName = this.columns[i].name;
				break;
            }
		}
		return this._columnsMap[columnName];
	},
	
	onColumnUpClick: function(event) {
		var index = event.target.getAttribute('value');
		index = parseInt(index, 10);
		if (index <= 0) return;
		
		var oriRow = this.tableBody.rows[index];
		var tarRow = this.tableBody.rows[index - 1];
		this.swapRowContent(index, (index - 1), oriRow, tarRow);
		
		this.columns[this.getColumnIndexFromRow(oriRow)].index ++;
		this.columns[this.getColumnIndexFromRow(tarRow)].index --;
	},
	
	onColumnDownClick: function(event) {
		var index = event.target.getAttribute('value');
		index = parseInt(index, 10);
		if (index >= this.tableBody.rows.length - 1) return;
		
		var oriRow = this.tableBody.rows[index];
		var tarRow = this.tableBody.rows[index + 1];
		this.swapRowContent(index,(index + 1),oriRow, tarRow);
		
		this.columns[this.getColumnIndexFromRow(oriRow)].index --;
		this.columns[this.getColumnIndexFromRow(tarRow)].index ++;
	},
	
	onAlignButtonClick: function(event) {
		var target = event.target;
		var formerValue = dojo.byId(this.wid + 'align_col_' + escape(target.name)).value;
		var targetValue = target.getAttribute('value');
		if (targetValue != formerValue) {
			var formerImg = dojo.byId(this.wid + 'align_col_' + formerValue + '_img_' + target.name);
			if (formerImg) {
				formerImg.src = this.contextRootBuilder + "/images/align_" + formerValue + ".png";
				formerImg.alt = dojo.string.substitute(this.resourceBundle.L_CONF_ALIGN_1, [this.resourceBundle["L_" + formerValue.toUpperCase()]]);
				dojo.attr(formerImg, "aria-label", formerImg.alt);
			}
			var newImg = dojo.byId(this.wid + 'align_col_' + targetValue + '_img_' + target.name);
			if (newImg) {
				newImg.src = this.contextRootBuilder + "/images/align_" + targetValue + "_selected.png";
				newImg.alt = dojo.string.substitute(this.resourceBundle.L_CONF_ALIGN_IS_SELECTED_1, [this.resourceBundle["L_" + targetValue.toUpperCase()]]);
				dojo.attr(newImg, "aria-label", newImg.alt);
			}
			
			dojo.byId(this.wid + 'align_col_' + escape(target.name)).value = target.getAttribute('value');
			for (var i = 0; i < this.columns.length; i++) {
				if (this.columns[i].name == target.name) {
					this.columns[i].align = target.getAttribute('value');
				}
			}
		}
	},
	
	//set column label
	onColumnLabelChange: function(event) {
		var columnName = event.target.name;
		columnName = columnName.substr(0,columnName.length-6);    //delete "_label"
		if (columnName && this._columnsMap) {
			this.columns[this._columnsMap[columnName]].label = event.target.value;
		}
	},
	
	//set column sort type
	onColumnSorttypeChange: function(event) {
		var columnName = event.target.name;
		columnName = columnName.substr(0,columnName.length-9);    //delete "_sorttype"
		if (columnName && this._columnsMap) {
			this.columns[this._columnsMap[columnName]].sorttype = event.target.value;
		}
		
		var sortTypeTitle = dojo.string.substitute(this.resourceBundle.L_CONF_COLUMN_SORTTYPE_1, [event.target.value]);

		event.target.setAttribute("title", sortTypeTitle);
	},
	
	onRestoreNameBtnClick: function(event) {
		var target = event.target;
		var tr = com.ibm.mm.widget.dataViewer._WB_VER_.dataViewerUtil.getParentByType(target, "tr");
		var columnName = tr.initialColumnName;
		var inputBox = dojo.query("td.columnName input", tr)[0];
		inputBox.value = columnName;
		if (columnName && this._columnsMap) {
			this.columns[this._columnsMap[columnName]].label = columnName;
		}
	},
	
	setSettings: function(columnsSettings){
		var newColumns = [],
			list = columnsSettings.columnList,
			aligns = columnsSettings.columnsAlign,
			filters = columnsSettings.columnFilter,
			orders = columnsSettings.columnsOrder,
			labels = columnsSettings.columnLabel,
			sortTypes = columnsSettings.columnSorttype;
		
		if (!labels || labels.length === 0) labels = list;
		
		for (var i = 0, len = list.length; i < len; i++) {
			var columnsItem = {
				name: list[i],
				align: aligns[list[i]],
				checked: filters[i],
				index: orders[i],
				label: labels[i],
				sorttype: (!sortTypes || !sortTypes[i]) ? "String" : sortTypes[i]
			}
			newColumns.push(columnsItem);
		}
		this.initialize(newColumns);
	},
	
	getSettings: function() {
		var columnsSettings = {
			columnList: [],
			columnsAlign: {},
			columnFilter: [],
			columnsOrder: [],
			columnLabel: [],
			columnSorttype: []
		}
		for (var i = 0, len = this.columns.length; i < len; i++) {
			columnsSettings.columnList.push(this.columns[i].name);
			columnsSettings.columnsAlign[this.columns[i].name] = this.columns[i].align;
			columnsSettings.columnFilter.push(this.columns[i].checked);
			columnsSettings.columnsOrder.push(this.columns[i].index);
			columnsSettings.columnLabel.push(!this.columns[i].label?this.columns[i].name:this.columns[i].label);
			columnsSettings.columnSorttype.push(!this.columns[i].sorttype?"String":this.columns[i].sorttype);
		}
		return dojo.toJson(columnsSettings);
	}
});
