dojo.require("dojox.uuid.generateTimeBasedUuid");

dojo.declare("com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.ChangeWatchingPage", [com.ibm.mashups.builder.iwidget.widgetbuilder.wizard.Page], {
	constructor : function() {
		this._valueCache = {};
		this._updateInterval = 3000;
		this._updateTimer = null;
	},
	
	_createItem : function(name,value){
		var item = new com.ibm.mashups.builder.iwidget.widgetbuilder.wizard.ItemSetObject();
		item.id = name;
		item.value = value;
		return item;
	},

	getWatchedControls : function() {
		return [];
	},
	
	getQueryScopeNode : function() {
		return dojo.body();
	},
	
	_doNotifyChange : function() {
		this.updateDefinition();
		this.notifyUpdatePreview();
	},
	
	_notifyChange : function() {
		if (this._updateTimer) {
			window.clearTimeout(this._updateTimer);
		}
		this._updateTimer = window.setTimeout(dojo.hitch(this, this._doNotifyChange), this._updateInterval);
		
	},
	
	_setupListeners : function() {
		var controls = this.getWatchedControls();
		var scopeNode = this.getQueryScopeNode();
		for (var i = 0, n = controls.length; i < n; i++) {
			(dojo.hitch(this, function() {
			var control = controls[i];
			if (control.queryString) {
				dojo.query(control.queryString, scopeNode).forEach(function(node) {
					var id = dojo.attr(node, "id");
					if (!id) {
						id = dojox.uuid.generateTimeBasedUuid();
						dojo.attr(node, "id", id);
					}
					dojo.connect(node, "onblur", this, function() {
						var currValue, oldValue;
						if (dojo.isFunction(control.getValue)) {
							currValue = control.getValue.apply(node);
						}
						else {
							currValue = node.value;
						}
						oldValue = this._valueCache[id];
						if (currValue != oldValue) {
							this._notifyChange();
							this._valueCache[id] = currValue;
						}
					});
				}, this);
			}
			}))();
		}
	}
});

dojo.provide("com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.DataViewerException");
dojo.declare("com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.DataViewerException", Error ,{
    message : "",
    name : "DataViewerException",
    constructor: function(inMessage){
        this.message = inMessage;
    }
});

dojo.provide("com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.IOException");
dojo.declare("com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.IOException", com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.DataViewerException, {
	name : "IOException",
    constructor: function(inMessage){
        this.message = inMessage;
    }
});

dojo.provide("com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.DataSourceNotSupportException");
dojo.declare("com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.DataSourceNotSupportException", com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.DataViewerException, {
    name : "DataSourceNotSupportException",
    constructor: function(inMessage){
        this.message = inMessage;
    }
});

dojo.provide("com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.NoContentException");
dojo.declare("com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.NoContentException", com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.DataViewerException, {
    name : "NoContentException",
    constructor: function(inMessage){
        this.message = inMessage;
    }
});

dojo.provide("com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil");

/*
 * This file contains utilities function and class for data viewer.
 */

com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil.hexColor2String = function(hexColor){
    var red = parseInt("0x" + hexColor.substr(1, 2), 16);
    var green = parseInt("0x" + hexColor.substr(3, 2), 16);
    var blue = parseInt("0x" + hexColor.substr(5, 2), 16);
	return dojo.string.substitute(com.ibm.mm.builder.iwidget.widgetbuilder.widgetBuilderMessages.L_COLOR_PICKER_COLOR_TITLE, [red, green, blue]);	
}

// convert an Array of like objects to a string. we encode comma (,) and pipe (|) since
// those are the delimeters required by the Data Viewer.
com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil.createDataViewString = function(/*Array*/entryObjects){
	var rtnVal = "";
	if (!entryObjects) {
		return rtnVal;
	}
	if (entryObjects.length == 0)
		return rtnVal;
	// we have something
	var row = entryObjects[0];
	var i = 0;
	var names = [];
	var encodedNames = [];
	var types = [];
	var encodedRowNames = [];
	
	// save the object names
	for (var prop in row) {
		names[i] = prop;
		encodedNames[i] = this.encodeString(prop);
		types[i] = "String";
		encodedRowNames[i] = this.encodeString(row[names[i]]);
		i++;
	}
	// add headers
	rtnVal += encodedNames.join(",");
	
	// add types (don't have right now, say String)
	rtnVal += "|";
	rtnVal += types.join(",");
	
	// add first row
	rtnVal += "|";
	rtnVal += encodedRowNames.join(",");
	
	// add remaining objects
	for (var j = 1; j < entryObjects.length; j++) {
		rtnVal += "|";
		row = entryObjects[j];
		for (i = 0; i < names.length; i++) {
			if (i > 0) {
				rtnVal += ",";
			}
			rtnVal += this.encodeString(row[names[i]]);
		}
	}
	return rtnVal;
}

com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil.encodeString = function(/*String*/aString){
	// change comma and veritcal bar to unicode
	// , -> &#44    | -> &#124
	// not clear if other encodings are required
	if (!aString || !dojo.isString(aString)) {
		return "";
	}
    return aString.replace(/,/g, "&#44").replace(/\|/g, "&#124");
}

com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil.encodeCSVCell = function(cell){
	cell = "" + cell;
	var result = cell.replace(/"/g, '""');
	if (result.indexOf(',') >= 0){
		result = '"' + result + '"';
	}
	result = result.replace(/\n/g, "");
	return result;
}

com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil.JSONObject2CSV = function(json){
    var rowColumnName = '', rowData = '';
    for (var key in json) {
		if (key) {
            if (rowColumnName) {
				rowColumnName += " ,";
				rowData += " ,";
			}
			rowColumnName += this.encodeCSVCell(key);
			rowData += this.encodeCSVCell(json[key]);
        }
    }
    rowColumnName += '\n';
    rowData += '\n';
    
    return rowColumnName + rowData;
}

com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil.DataObject2CSV = function(data){
	if (!data) return "";
	var columns = data.columnList || [];
	var rows = data.result || [];
	var csv = [];
	for(var i = 0; i < columns.length; i++){
		csv.push(this.encodeCSVCell(columns[i]));
		if (i < columns.length -1) csv.push(",");
	}
	csv.push("\n");
	for(var i = 0; i < rows.length; i++){
		var row = rows[i];
		for(var j = 0; j < columns.length; j++){
			var col = columns[j];
			csv.push(this.encodeCSVCell(row && (row[col] || "")));
			if (j < columns.length -1) csv.push(",");
		}
		csv.push("\n");
	}
	return csv.join("");
}

com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil.getDescendantNodes = function(node){
	var childNodesArray = [],
	    childNodes = node.getElementsByTagName('*');   // Only ELEMENT NODE are selected
	
    dojo.forEach(childNodes, function(node){
		if (node.childNodes.length === 1 &&
	          (node.firstChild.nodeType === 2 || // ELEMENT_NODE
	           node.firstChild.nodeType === 3 || // TEXT_NODE
	           node.firstChild.nodeType === 4)) {// CDATA_SECTION_NODE

			// ELEMENT NODE
			childNodesArray.push(node);
        }
    });
	return childNodesArray;
}

com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil.getChildNodesByTagName = function(node, name) {
	var result = [];
	//name = name.toLowerCase();
	if (node && node.childNodes) {
		result = node.getElementsByTagName(name);
	}
	return result;
}

com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil._setResultForEntryNode = function(entryNode, childNodes, entryArray/*, dataArray*/){
	var aChild = null;
	var anObject = {};
	for (var i = 0; i < childNodes.length; i++) {
		aChild = childNodes[i];
		if (aChild.nodeType == 1) {
			var name = aChild.localName;
			if (aChild.localName == null) {
				name = aChild.nodeName;
			}
			var value = "";
			if (aChild.firstChild && aChild.firstChild.nodeValue) {
				value = aChild.firstChild.nodeValue;
			}
			if (name) {
				var findAttributeName = function(object, name){
					if (!object[name]) 
						return name;
					var parts = name.split('_');
					if (parts.length <= 0) 
						return name;
					var temp = parseInt(parts[parts.length - 1]);
					if (parts.length == 1 || isNaN(temp)){
						for(var j = 1; j < Number.MAX_VALUE; j++){
							var candidate = name + "_" + j;
							if (!object[candidate]) 
								return candidate;
						}
					}
					else {
						var start = temp + 1;
						var prefix = parts.slice(0, parts.length - 1).join('_');
						for(var j = start; j < Number.MAX_VALUE; j++){
							var candidate = prefix + "_" + j;
							if (!object[candidate]) 
								return candidate;
						}
					}
					throw(new com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.DataViewerException(com.ibm.mm.builder.iwidget.widgetbuilder.widgetBuilderMessages.E_TOO_MANY_ELEMENTS_WITH_SAME_TAGNAME));
				}
				if (anObject[name]) 
					name = findAttributeName(anObject, name);
				anObject[name] = value; // null value is ok...
				if (entryArray.length > 0 && !entryArray[0][name]) {
					entryArray[0][name] = "";
				}
			}
		}
	}
	entryArray.push(anObject);
}

com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil._feedEntry2Object = function(node, entryArray){
	
	var object = {};
	com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil._traverseEntry(node, object, entryArray);
	entryArray.push(object);
}

com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil._traverseEntry = function(node, object, entryArray){

	var childNodes = node.childNodes;
	if (childNodes) {
		for (var i = 0; i < childNodes.length; i++) {
			var childNode = childNodes[i];
			if (childNode.nodeType == 1) {
				//operation on childNode
				

				var name = childNode.localName;
				if (childNode.localName == null) {
					name = childNode.nodeName;
				}
				var value = "";
				if (typeof childNode.firstChild != "undefined" && childNode.firstChild != null && typeof childNode.firstChild.nodeValue != "undefined" && childNode.firstChild.nodeValue != null && childNode.firstChild.nodeType != 4) {
					value = childNode.firstChild.nodeValue;
				}
				if (name) {
					var findAttributeName = function(object, name){
						if (!object[name]) 
							return name;
						var parts = name.split('_');
						if (parts.length <= 0) 
							return name;
						var temp = parseInt(parts[parts.length - 1]);
						if (parts.length == 1 || isNaN(temp)){
							for(var j = 1; j < Number.MAX_VALUE; j++){
								var candidate = name + "_" + j;
								if (!object[candidate]) 
									return candidate;
							}
						}
						else {
							var start = temp + 1;
							var prefix = parts.slice(0, parts.length - 1).join('_');
							for(var j = start; j < Number.MAX_VALUE; j++){
								var candidate = prefix + "_" + j;
								if (!object[candidate]) 
									return candidate;
							}
						}
						throw(new com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.DataViewerException(com.ibm.mm.builder.iwidget.widgetbuilder.widgetBuilderMessages.E_TOO_MANY_ELEMENTS_WITH_SAME_TAGNAME));
					}
					if (object[name]) 
						name = findAttributeName(object, name);
					object[name] = value; // null value is ok...
					if (entryArray.length > 0 && !entryArray[0][name]) {
						entryArray[0][name] = "";
					}
				}
				
				this._traverseEntry(childNode, object);
			}
		}
	}	
}

com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil.splitterCSVData = function(dataString){
	var cells = dataString.split(",");

	//handle case where cell contains ,
	var len = cells.length;
	var i, j;
	for (var m=0; m<len; m++){
		i = j = -1;
		for (var k=0; k<cells.length; k++){
			if (i == -1 && cells[k].charAt(0) == '"' && cells[k].charAt(cells[k].length - 1) != '"' ){
				i = k;
				continue;
			}
			if (i>0 && cells[k].charAt(cells[k].length - 1) == '"' && cells[k].charAt(0) != '"' ){
				j = k;
				break;
			}
		}
		
		if (i >0 && j >0){
			var str = cells[i];
			for (var k=i+1; k<j+1; k++){
				str = str + "," + cells[k];
			}

			var temp = [];
			for (var k=0; k<i; k++){
				temp.push(cells[k]);
			}
			temp.push(str);
			for (var k=j+1; k<cells.length; k++){
				temp.push(cells[k]);
			}
			cells = temp;
		}else {
			break;
		}
	}

	return cells;
}
	
com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil.unescapeCSVCell = function(cellString){
	if (cellString.length >= 2 && cellString.indexOf('"') == 0 && cellString.lastIndexOf('"') == (cellString.length -1) ){
		cellString = cellString.substring(1, cellString.length - 2);
	}
	return cellString;
}

com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil.getColumnList = function(object){
	var columnList = [];
	for (var key in object){
		columnList.push(key);
	}
	return columnList;
}

com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil.parseJSONFeed = function(data){

    var posFields = ["totalResults", "itemsPerPage", "StartIndex"];
    
    function getLocalName(qualifiedName){
        var separatorIndex = qualifiedName.indexOf(":");
        return qualifiedName.substring(separatorIndex + 1);
    }
    
    function getNameSpace(qualifiedName){
        return qualifiedName.substring(0, qualifiedName.indexOf(":"));
    }
    
    function getLinks(obj){
        var links = obj["atom:feed"]["atom:link"] || [];
        var linkRes = {};
        for (var i = 0, len = links.length; i < len; i++) {
            var key = dojo.getObject("@rel.value", false, links[i]);
            if (key) 
                linkRes[key] = dojo.getObject("@href.value", false, links[i]);
        }
        return linkRes;
    }
    
    function getPosInfo(obj){
        var posInfo = {};
        var feed = obj["atom:feed"];
        for (var key in feed) {
            if (dojo.indexOf(posFields, getLocalName(key)) !== -1) {
                posInfo[getLocalName(key)] = parseInt(dojo.getObject("#text.value", false, feed[key]));
            }
        }
        return posInfo;
    }
    
    function isLeafElement(obj){
        var count = 0;
        for (name in obj) {
            count++;
        }
        var isLeaf = (count == 0 || typeof obj["#text"] != "undefined");
        return isLeaf;
    }
	
    function findName(key, columnNames) {
		if (dojo.indexOf(columnNames, key) === -1) return key;
		var index = 1;
		while (dojo.indexOf(columnNames, key + "_" + index) >= 0) {
			index++;
		}
		return key + "_" + index;
	}
	
	function _decodeSpace(inputNode) {
	    var value = dojo.trim(dojo.isString(inputNode) ? inputNode : inputNode.value || "");
	
	    var keyword = /_5F/g;
	    var escapeStr = "_";
	
	    var pattern = /_20/g;
	    var toReplace = " ";
	    return value.replace(pattern, toReplace).replace(keyword, escapeStr);
    }
	
	function setField(key, value, entryFields, columnNames) {
		var attrName = findName(_decodeSpace(getLocalName(key)), columnNames);
        entryFields[attrName] = dojo.getObject("#text.value", false, value);
		columnNames.push(attrName);
	}
	
    function traverseObj(entry, key, entryFields, columnNames){
		if (isLeafElement(entry)) {
			setField(key, entry, entryFields, columnNames);	
			return;			
		}
        for (var key in entry) {
            if (dojo.isObject(entry[key])) { // have to be an javascript object
                if (key.substring("@") > -1) { // if is attribute, ignore it.
                    continue;
                }
                else {
                    if (isLeafElement(entry[key])) {
						setField(key, entry[key], entryFields, columnNames);	
                    }
                    //if the content is an array, use its first element
                    else 
                        if (dojo.isArray(entry[key]) && entry[key].length > 0) {
                            for (var i = 0; i < entry[key].length; i++) {
								setField(key, entry[key][i], entryFields, columnNames);	                                }
                        }
                        else {
                            traverseObj(entry[key], key, entryFields, columnNames);
                        }
                }
            }
        }
    }
    
	function getFeedType(namespaces) {
		for (key in namespaces) {
			if (key !== "atom" && key !== "os") return 0;				
		}
		return 1;
	}
	
    function getEntriesInfo(obj){
        var res = {};
        res.columnNames = [];
        res.result = [];
        
		var entries= dojo.getObject("atom:feed.atom:entry", false, obj);
		if (!dojo.isArray(entries)) entries = [entries];
		var feedType = getFeedType(obj["__namespaces__"]);	//simply check the type of the feed.
		
        if (entries.length) {
            for (var i = 0, len = entries.length; i < len; i++) {
                var entry = entries[i];
                var entryFields = {};
				var columnNames = [];
				
                for (var key in entry) {
                    if (feedType || getNameSpace(key) !== "atom" || key === "atom:content") {
                        traverseObj(entry[key], key, entryFields, columnNames);
                    }
                }
				for (var j=0; j<columnNames.length;j++) {
					if (dojo.indexOf(res.columnNames, columnNames[j]) == -1)
						res.columnNames.push(columnNames[j]);
				}
                res.result.push(entryFields);
            }
        }
        return res;
    }
	
    function validatePagedResult(res) {
		if (!res.totalResults || !res.itemsPerPage || !res.StartIndex) return {result: false, error: "Required attribues are missing."};
		if (!res.self || !res.last || !res.first) return {result: false, error: "Required attribues are missing."};
		return {result: true};
	}
	
    function parseResult(obj){
        return dojo.mixin({}, getLinks(obj), getPosInfo(obj), getEntriesInfo(obj));
    }
	
	if (dojo.isString(data)) data = dojo.fromJson(data);
	var result = parseResult(data);

	if (!result){
		//throw("Illegal pipeline data");
		throw(new com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.DataViewerException(com.ibm.mm.builder.iwidget.widgetbuilder.widgetBuilderMessages.E_ILLEGAL_PIPELINE_DATA));
	}
	return result;
}

/*
 * This module is used by data editor to suport large data set. The cache implementation is specific
 * to pipeline, its url template.
 * 
 */
dojo.declare("com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil.dataFetcher", null, {
	constructor: function(){
		this.cache = com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil.dataFetcher._cache;
	},
	
	getData: function(args){
		var supportCache = this.checkCacheSupport(args.url);
		
		if (supportCache && this.isInCache(args.url)){
			args.load(this.getDataFromCache(args.url));
			return;
		}
		
		var self = this;
		var url = supportCache ? this.preloadDataURL(args.url) : args.url;
		var bindArgs = {
			url: url,
			load: function(data, ioArgs){
				if (supportCache){
					self.storeToCache(data, url);
					args.load(self.getDataFromCache(args.url));					
				} else {
					args.load(data, ioArgs);
				}
			},
			error: function(error, ioArgs){
				args.error(error, ioArgs);
			}
		}
		dojo.xhrGet(bindArgs);
	},
	
	storeToCache: function(data, url){

		var result = com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil.parseJSONFeed(data);
		
		var paginationData = {'totalResult' : result.totalResults, 'startIndex' : result.StartIndex || 0, 'itemsPerPage' : result.itemsPerPage,
			'first' : result.first || '', 'last' : result.last || '', 'previous' : result.previous || '', 'next' : result.next || '', 
			'result' : result.result,  'columnList' : result.columnNames};

		//opensearch spec, startIndex starts from 1
		var num = parseInt(com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil.getparamFromURL(url, "startIndex"), 10);
		var startIndex = (num > 1) ? (num - 1) : 0;
		var count = parseInt(com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil.getparamFromURL(url, "count"), 10);
		var pipelineID = com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil.getparamFromURL(url, "id");
		
		//clear cache
		delete this.cache.data;
		this.cache.data = null;
		
		this.cache.key.startIndex = startIndex;
		this.cache.key.count = count;
		this.cache.key.pipelineID = pipelineID;
		this.cache.key.url = url;
		this.cache.data = paginationData;

	},
	
	isInCache: function(url){
		
		//opensearch spec, startIndex starts from 1
		var num = parseInt(com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil.getparamFromURL(url, "startIndex"), 10);
		var startIndex = num > 1 ? (num - 1) : 0;
		var count = parseInt(com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil.getparamFromURL(url, "count"));
		var pipelineID = com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil.getparamFromURL(url, "id");
		
		if (this.cache.key.startIndex <= startIndex && 
			(this.cache.key.startIndex + this.cache.key.count) >= (startIndex + count) && 
			/*compare url template*/ this.cache.key.pipelineID == pipelineID){
			return true;
		}
		return false;
	},
	
	getDataFromCache: function(url){
		function getDataInRange(jsonArray, start, count){
			return jsonArray.slice(start, start + count);
		}
		
		//opensearch spec, startIndex starts from 1
		var num = parseInt(com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil.getparamFromURL(url, "startIndex"), 10);
		var startIndex = num > 1 ? (num - 1) : 0 ;
		var count = parseInt(com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil.getparamFromURL(url, "count"));

		var paginationData = {
			'totalResult' : this.cache.data.totalResult, 
			'startIndex' : startIndex, 'itemsPerPage' : count,
			'first' : this.cache.data.first || '', 
			'last' : this.cache.data.last || '', 
			'previous' : '', 
			'next' : '', 
			'result' : getDataInRange(this.cache.data.result, startIndex - this.cache.key.startIndex, count),  
			'columnList' : this.cache.data.columnList.slice()
		};

		return paginationData;
	},
	
	preloadDataURL: function(url){
		var PRELOAD_ENTRY_NUMBER = 100;
		
		var count = PRELOAD_ENTRY_NUMBER;	
		var newURL = com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil.createPipelineURL(url, "count", count);
		
		return newURL;
	},
	
	checkCacheSupport: function(url){
		//specific checking rule for pipeline url template
		var regexs = [/startIndex/, /count/, /pipeline/, /id/, /status/, /format/];
		
		return dojo.every(regexs, function(regex){return regex.test(url)});
	}
});

com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil.dataFetcher._cache = { 
	'key' : {
		'startIndex': 0,
		'count': 0,
		'pipelineID' : 0,
		'url': ''
	}, 
	'data' : null
};

com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil.getparamFromURL = function(url, key){
	if (url.indexOf(key + "=") < 0 ){
		//throw("Illegal URL");
		throw(new com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.DataViewerException(com.ibm.mm.builder.iwidget.widgetbuilder.widgetBuilderMessages.E_ILLEGAL_PIPELINE_DATA));
	}
	
	var str = url.substring(url.indexOf(key + "=") + key.length + 1);
	var end = str.indexOf("&");
	
	var result = "";

	if (end >= 0){
		result = str.substring(0, end);
	} else{
		result = str;
	}
	
	if (!result){
		//throw("Illegal URL");
		throw(new com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.DataViewerException(com.ibm.mm.builder.iwidget.widgetbuilder.widgetBuilderMessages.E_ILLEGAL_PIPELINE_DATA));
	}
	
	return result;
	
}

com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil.createPipelineURL = function(url, key, value){
	if (url.indexOf(key + "=") < 0 ){
		//throw("Illegal URL");
		throw(new com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.DataViewerException(com.ibm.mm.builder.iwidget.widgetbuilder.widgetBuilderMessages.E_ILLEGAL_PIPELINE_DATA));
	}
    
	var part1 = url.substring(0, url.indexOf(key + "=")  + key.length + 1) + value;
	
	var str = url.substring(url.indexOf(key + "=") + key.length + 1);
	var end = str.indexOf("&");
	
	var part2 = "";

	if (end >= 0){
		part2 = str.substring(end);
	}
	return part1 + part2;		
}

/*
 * Below functions are copied from /mm.widget.dataViewer/Web Content/js/com/ibm/mm/widget.dataViewer/utils/htmlUtil.js,
 * They are used by data viewer. The reason is to support embedding page capability, product widgets
 * should NOT depend on widget.dataViewer component.
 */
com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil.setClass = function(/* HTMLElement */node, /* string */classStr){
	//	summary
	//	Clobbers the existing list of classes for the node, replacing it with
	//	the list given in the 2nd argument. Returns true or false
	//	indicating success or failure.
	node = dojo.byId(node);
	var cs = new String(classStr);
	try{
		if(dojo.isString(node.className)){
			node.className = cs;
		}else if(node.setAttribute){
			node.setAttribute("class", classStr);
			node.className = cs;
		}else{
			return false;
		}
	}catch(e){
		com.ibm.mm.enabler.debug.error(dojo.string.substitute(com.ibm.mm.builder.iwidget.widgetbuilder.widgetBuilderMessages.E_HTML_UTIL_SET_CLASS_1,[e.message]));
	}
	return true;
}

com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.dataViewerUtil.getParentByType = function(/* HTMLElement */node, /* string */type) {
	//	summary
	//	Returns the first ancestor of node with tagName type.

	var _document = dojo.doc;
	var parent = dojo.byId(node);
	type = type.toLowerCase();
	while((parent)&&(parent.nodeName.toLowerCase()!=type)){
		if(parent==(_document["body"]||_document["documentElement"])){
			return null;
		}
		parent = parent.parentNode;
	}
	return parent;	//	HTMLElement
}

dojo.require('dijit.ColorPalette');	

dojo.declare("com.ibm.mm.builder.iwidget.widgetbuilder.outOfBoxWizards.dataViewer.ColorPalette", dijit.ColorPalette, {
	// palette: String
	//		Size of grid, either "7x10" or "3x4".
	palette: "8x16",

	// _palettes: Map
	// 		This represents the value of the colors.
	//		The first level is a hashmap of the different arrays available
	//		The next two dimensions represent the columns and rows of colors.
	_palettes: {
		"8x16": [
			["#FFFFFF", "#DDDDDD", "#BBBBBB", "#999999", "#666666", "#444444", "#222222", "#000000"],
			["#FFEEEE", "#FFFFDD", "#FFFFEE", "#EEFFEE", "#EEFFFF", "#EEEEFF", "#FFEEFF", "#FFEEFF"],
			["#FFCCCC", "#FFFFBB", "#FFFFCC", "#CCFFCC", "#CCFFFF", "#CCCCFF", "#FFCCFF", "#FFCCFF"],
			["#FFAAAA", "#FFEE99", "#FFFFAA", "#AAFFAA", "#AAFFFF", "#AAAAFF", "#EEAAFF", "#FFAAFF"],
			["#FF8888", "#FFDD88", "#FFFF88", "#88FF88", "#88FFFF", "#8888FF", "#DD88FF", "#FF88FF"],
			["#FF6666", "#FFCC66", "#FFFF66", "#66FF66", "#66FFFF", "#6666FF", "#CC66FF", "#FF66FF"],
			["#FF4444", "#FFBB44", "#FFFF44", "#44FF44", "#44FFFF", "#4444FF", "#BB44FF", "#FF44FF"],
			["#FF2222", "#FFAA22", "#FFFF22", "#22FF22", "#22FFFF", "#2222FF", "#AA22FF", "#FF22FF"],
			["#FF0000", "#FF9900", "#FFFF00", "#00FF00", "#00FFFF", "#0000FF", "#9900FF", "#FF00FF"],
			["#DD0000", "#DD8800", "#DDDD00", "#00DD00", "#00DDDD", "#0000DD", "#8800DD", "#DD00DD"],
			["#BB0000", "#BB7700", "#BBBB00", "#00BB00", "#00BBBB", "#0000BB", "#7700BB", "#BB00BB"],
			["#990000", "#996600", "#999900", "#009900", "#009999", "#000099", "#660099", "#990099"],
			["#770000", "#774400", "#777700", "#007700", "#007777", "#000077", "#550077", "#770077"],
			["#550000", "#553300", "#555500", "#005500", "#005555", "#000055", "#440055", "#550055"],
			["#330000", "#332200", "#333300", "#003300", "#003333", "#000033", "#330033", "#330033"],
			["#110000", "#111100", "#111100", "#001100", "#001111", "#000011", "#220011", "#110011"]
		]
	},

	_name: {
		"8x16": [
			["White", "Fog", "Silver", "Dark Gray", "Dim Gray", "Charcoal", "Soot", "Black"],
			["Lavender Blush", "Light Yellow", "Ivory", "Pale Jade", "Azure", "Mist", "Pale Lavender", "Pale Lavender"],
			["Pink", "Cornsilk", "Lemon Chiffon", "Mint", "Overcast Blue", "Slate Blue", "Light Violet", "Light Violet"],
			["Light Pink", "Moccasin", "Cream", "Pale Green", "Pale Turquoise", "Light Cornflower", "Violet", "Bubblegum"],
			["Light Coral", "Apricot", "Butter", "Light Green", "Light Sky Blue", "Sky Blue", "Plum", "Cherry Blossom"],
			["Salmon", "Peach", "Banana", "Spearmint", "Swimming Pool Blue", "Blue Flower", "Lilac", "Light Magenta"],
			["Tomato", "Orange", "Yellow Corn", "Florescent Green", "Blue Taffy", "Royal Blue", "Wisteria", "Pink Lemonade"],
			["Scarlet", "Dark Orange", "Canary", "Lawn Green", "Electric Blue", "Lapis Lazuli", "Heliotrope", "Cezanne Rose"],
			["Red", "Tangerine", "Yellow", "Lime", "Cyan", "Blue", "Plasma", "Magenta"],
			["Venetian Red", "Cappuccino", "Pistachio", "Emerald", "Turquoise", "Medium Blue", "Amethyst", "Mulberry"],
			["Fire Brick", "Dark Goldenrod", "Khaki Green", "Grass green", "Dark Turquoise", "Sapphire", "Iris", "Dark Fuchsia"],
			["Dark Red", "Sienna", "Scuppernong", "Apple", "Dark Cyan", "Dark Blue", "Delphinium", "Hyacinth"],
			["Maroon", "Saddle Brown", "Olive", "Green", "Teal", "Navy", "Grape", "Purple"],
			["Burgundy", "Raw Umber", "Hazel", "Dark Green", "Deep Sea Green", "Midnight Blue", "Morning Glory", "Cranberry-Grape Juice"],
			["Mahogany", "Bistre", "Avocado Peel", "Forest Green", "Dark Teal", "Ultramarine", "Acai", "Acai"],
			["Ruby Black", "Dark Brown", "Onyx", "Black Forest", "Deep Sea", "Blackberry", "Blackberry Cobbler", "Blackcurrant"]
		]
	},
	// _imagePaths: Map
	//		Path to the palette images
	_imagePaths: {
		"8x16": com.ibm.mashups.builder.iwidget.widgetbuilder.wizard.framework.getTemplateRootPath() + "public/templates/dataViewer/wizard/images/color_palette.png"
	},

	// templatePath: String
	//		Path to the template of this widget.
	templateString: "<div class=\"dijitInline dijitColorPalette\">\n\t<div class=\"dijitColorPaletteInner\" dojoAttachPoint=\"divNode\" waiRole=\"grid\" tabIndex=\"-1\">\n\t\t<img alt=\"\" class=\"dijitColorPaletteUnder\" dojoAttachPoint=\"imageNode\" waiRole=\"presentation\" />\n\t</div>\t\n</div>\n",

	// _paletteDims: Object
	//		Size of the supported palettes for alignment purposes.
	_paletteDims: {
		"8x16": {"width": "166px", "height": "326px"}
	},
	
	triggerInput: null,
	
	_focusFirstImg:function(){
		this._cellNodes[0].childNodes[0].focus();//focus on the first image input after color picker popup
	},
	
	postCreate: function(){
		// A name has to be given to the colorMap, this needs to be unique per Palette.
		dojo.mixin(this.divNode.style, this._paletteDims[this.palette]);
		this.imageNode.setAttribute("src", this._imagePaths[this.palette]);
		var choices = this._palettes[this.palette];	
		var colorNames = this._name[this.palette];
		this.domNode.style.position = "relative";
		this._cellNodes = [];
		var url= dojo.moduleUrl("dojo", "resources/blank.gif");
	    var colorObject = new dojo.Color();
	    var coords = this._paletteCoords;
		
		for(var row=0; row < choices.length; row++){
			for(var col=0; col < choices[row].length; col++) {
                var imgNode;
                imgNode = dojo.doc.createElement("input");
                imgNode.type = "image";
				
                dojo.addClass(imgNode, "dijitPaletteImg");
                var color = choices[row][col],
                        colorValue = color; //colorObject.setColor(dojo.Color.named[color]);
                imgNode.color = colorValue;//.toHex();
                imgNode.src = url;
                var red = parseInt("0x" + color.substr(1, 2), 16);
                var green = parseInt("0x" + color.substr(3, 2), 16);
                var blue = parseInt("0x" + color.substr(5, 2), 16);
				imgNode.title = imgNode.alt = dojo.string.substitute(com.ibm.mm.builder.iwidget.widgetbuilder.widgetBuilderMessages.L_COLOR_PICKER_COLOR_TITLE, [red, green, blue]);
                
                dojo.style(imgNode,"border-color",colorValue);
                dojo.style(imgNode,"border-width",0);
                dojo.attr(imgNode,"value",colorValue);
                
                var imgStyle = imgNode.style;
                imgStyle.color = imgStyle.backgroundColor = imgNode.color;
				var cellNode = dojo.doc.createElement("span");
				cellNode.appendChild(imgNode);
				
                dojo.forEach(["Dijitclick", "MouseEnter", "Blur", "Focus", "KeyDown"], function(handler) {
                    this.connect(cellNode.childNodes[0], "on" + handler.toLowerCase(), "_onCell" + handler);
                }, this);
                
                this.divNode.appendChild(cellNode);
				var cellStyle = cellNode.style;
                cellStyle.top = coords.topOffset + (row * coords.cHeight) + "px";
                cellStyle.left = coords.leftOffset + (col * coords.cWidth) + "px";
				dojo.attr(cellNode.childNodes[0], "tabIndex", "-1");
				
				dojo.addClass(cellNode, "dijitPaletteCell");
				dijit.setWaiRole(cellNode, "gridcell");
                cellNode.index = this._cellNodes.length;
                cellNode.childNodes[0].index = this._cellNodes.length;
                this._cellNodes.push(cellNode);
            }
		}
		this._cellNodes[this._currentFocus].tabIndex = 0;
		this._xDim = choices[0].length;
		this._yDim = choices.length;
		
		this.connect(this.divNode, "onUnload", "_setTriggerInputFocus");
        this.connect(this.divNode, "onfocus", "_onDivNodeFocus");
        this.connect(this.divNode, "onblur", "onBlur");
        
		// Now set all events
		// The palette itself is navigated to with the tab key on the keyboard
		// Keyboard navigation within the Palette is with the arrow keys
		// Spacebar selects the color.
		// For the up key the index is changed by negative the x dimension.
		
		var keyIncrementMap = {
			UP_ARROW: -this._xDim,
			// The down key the index is increase by the x dimension.
			DOWN_ARROW: this._xDim,
			// Right and left move the index by 1.
			RIGHT_ARROW: 1,
			LEFT_ARROW: -1
		};
		for(var key in keyIncrementMap){
			this._connects.push(dijit.typematic.addKeyListener(this.domNode,
				{keyCode:dojo.keys[key], ctrlKey:false, altKey:false, shiftKey:false},
				this,
				function(){
					var increment = keyIncrementMap[key];
					return function(count){ this._navigateByKey(increment, count); };
				}(),
				this.timeoutChangeRate, this.defaultTimeout));
		}
		
		this.focus();
	},
	
	/**
	 * @Override
	 * Called when the widget stops being "active" because focus moved to something outside of it, or the user clicked somewhere outside of it, or the widget was hidden.
	 * @param {Object} event
	 */
	onBlur: function(event) {
		event = dojo.fixEvent(event);
		this.onChange();
		dojo.stopEvent(event);
	},
	_onBlur: function() {		
		this.inherited(arguments);
		this.onChange();
	},
	
	_onCellKeyDown: function(event) {
        event = dojo.fixEvent(event);
        if (event.keyCode === dojo.keys.ESCAPE){
            dojo.stopEvent(event);
            this.onChange();
			return false;
        }
	},
	
	_navigateByKey: function(increment, typeCount){
		// summary:
		// 	  	This is the callback for typematic.
		// 		It changes the focus and the highlighed color.
		// increment:
		// 		How much the key is navigated.
		// typeCount:
		//		How many times typematic has fired.

		// typecount == -1 means the key is released.
		if(typeCount == -1){ return; }
		
		var newFocusIndex = this._currentFocus + increment;
		if(newFocusIndex < this._cellNodes.length && newFocusIndex > -1)
		{
			var focusNode = this._cellNodes[newFocusIndex];
			focusNode.childNodes[0].focus();
			this._currentFocus = newFocusIndex;
		}
	},
	
	_selectColor:function(selectNode){
		var img=selectNode;
		var imgValue = img.value;
		this.value = imgValue;
		this.onChange(imgValue);
	},
	
	_setTriggerInput: function(inObj){
		this.triggerInput = inObj;
	},
	
	_setTriggerInputFocus: function(){
		this.triggerInput && this.triggerInput.focus();
	},
	
	_onCellDijitclick: function(/*Event*/ evt){
		// summary:
		//		Handler for click, enter key & space key. Selects the color.
		// evt:
		//		The event.
		evt = dojo.fixEvent(evt);
		var target = evt.currentTarget;
		if (this._currentFocus != target.index){
			this._currentFocus = target.index;
			window.setTimeout(function(){dijit.focus(target)}, 0);
		}
		this._selectColor(target);
		dojo.stopEvent(evt);
		this.triggerInput.focus();//focus the input which popup the color picker
	},
	
	_removeCellHighlight: function(index){
		dojo.removeClass(this._cellNodes[index].childNodes[0], "dijitPaletteCellHighlight");
	}
});
