-- *****************************************************************
--
-- Licensed Materials - Property of IBM
--                                      
-- 5724-U69                             
--                                      
-- Copyright IBM Corp. 2001, 2006  All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
--
-- *****************************************************************

-- Mashup DB2v8 Script for creating tables, keys, indexes

-- *****************************************************************
--
-- SCHEMA VERSION (100)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.VERSION_INFO(
    OID VARCHAR(64)    NOT NULL,
    VERSION_MAJOR   INTEGER,
    VERSION_MINOR   INTEGER,
    VERSION_RELEASE INTEGER,
    VERSION_DEV     INTEGER,
    VERSION_TIME    BIGINT,
    DESCRIPTION     VARCHAR(254),
    CONSTRAINT PK100 PRIMARY KEY (OID)
)
IN @TSPRE@REGTP
;

-- *****************************************************************
--
-- ACCOUNT (200)
--
-- *****************************************************************
-- 04/04 Accounts were ordered dropped.
--  The expectation is a userId is provided to persistence code
--  which is a vmm char(64) unique id. Susbsystems will create
--  required objects on the fly. Maybe want more centralized
--  provisioning to faciliate admin?
--CREATE TABLE @SCHEMA@.ACCOUNT (
--    OID         CHAR(64)           NOT NULL,
--    EXTERNAL_ID VARCHAR(255)       NOT NULL,
--    NAME        VARCHAR(255)       NOT NULL,
--    CREATED     BIGINT             NOT NULL,
--    MODIFIED    BIGINT             NOT NULL,
--    STATE       INTEGER DEFAULT 1  NOT NULL,
--    CONSTRAINT PK200 PRIMARY KEY (OID)
--);

-- *****************************************************************
--
-- CATALOG (300)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.CATALOG (
    OID         VARCHAR(64)       NOT NULL,
    ACCOUNT_OID VARCHAR(1000)     NOT NULL,
    UNIQUE_NAME VARCHAR(255)      NOT NULL,
    CREATED     BIGINT            NOT NULL,
    MODIFIED    BIGINT            NOT NULL,
    STATE       INTEGER DEFAULT 1 NOT NULL,
    CONSTRAINT PK300 PRIMARY KEY (OID)
)
IN @TSPRE@REGTP
;

CREATE TABLE @SCHEMA@.CATALOG_LOD (
    RESOURCE_OID VARCHAR(64)       NOT NULL,
    LOCALE       VARCHAR(64)    NOT NULL,
    TITLE        VARCHAR(255)   NOT NULL,
    DESCRIPTION  VARCHAR(1024)  ,
    CONSTRAINT PK301 PRIMARY KEY (RESOURCE_OID, LOCALE),
    CONSTRAINT FK302 FOREIGN KEY (RESOURCE_OID) REFERENCES @SCHEMA@.CATALOG (OID) ON DELETE CASCADE
)
IN @TSPRE@REGTP
;

-- *****************************************************************
--
-- CATALOG ENTRY (310)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.CATALOG_ENTRY (
    OID            			VARCHAR(64)        NOT NULL,
    CATALOG_OID    			VARCHAR(64)        NOT NULL,
    CATEGORY_OID   			VARCHAR(64)        NOT NULL,
    DEFINITION_URL 			VARCHAR(2500)      NOT NULL,
    CONTENT_URL    			VARCHAR(2500)      ,
    PREVIEW_URL    			VARCHAR(2500)      ,
    PREVIEW_THUMBNAIL_URL	VARCHAR(2500)      ,
    HELP_URL       			VARCHAR(2500)      ,
    ICON_URL       			VARCHAR(2500)      ,
    HUB_ENTRY_URL  			VARCHAR(2500)      ,
    DEF_URL_TYPE   			INTEGER            ,
    ICON_URL_TYPE  			INTEGER            ,
    CREATED        			BIGINT             NOT NULL,
    MODIFIED       			BIGINT             NOT NULL,
    STATE          			INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT PK310 PRIMARY KEY (OID)
)
IN @TSPRE@REGTP
;

CREATE TABLE @SCHEMA@.CATALOG_ENTRY_LOD (
    RESOURCE_OID  		VARCHAR(64)    NOT NULL,
    LOCALE        		VARCHAR(64)    NOT NULL,
    TITLE         		VARCHAR(255)   NOT NULL,
    DESCRIPTION   		VARCHAR(1024)  ,
    SHORT_DESCRIPTION   VARCHAR(255)   ,
    CONSTRAINT PK311 PRIMARY KEY (RESOURCE_OID, LOCALE),
    CONSTRAINT FK311 FOREIGN KEY (RESOURCE_OID) REFERENCES @SCHEMA@.CATALOG_ENTRY (OID) ON DELETE CASCADE
)
IN @TSPRE@REGTP
;

CREATE TABLE @SCHEMA@.CATALOG_ENTRY_DD (
    RESOURCE_OID  VARCHAR(64)    NOT NULL,
    NAME          VARCHAR(255)   NOT NULL,
    VALUE         VARCHAR(3000)  NOT NULL,
    CONSTRAINT PK312 PRIMARY KEY (RESOURCE_OID, NAME),
    CONSTRAINT FK312 FOREIGN KEY (RESOURCE_OID) REFERENCES @SCHEMA@.CATALOG_ENTRY (OID) ON DELETE CASCADE
)
IN @TSPRE@REGTP
;


-- *****************************************************************
--
-- CATALOG CATEGORY (320)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.CATALOG_CATEGORY (
    OID         VARCHAR(64)         NOT NULL,
    CATALOG_OID VARCHAR(64)         NOT NULL,
    NAME        VARCHAR(255)        ,
    CREATED     BIGINT              NOT NULL,
    MODIFIED    BIGINT              NOT NULL,
    STATE       INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT PK320 PRIMARY KEY (OID),
    CONSTRAINT FK320 FOREIGN KEY (CATALOG_OID) REFERENCES @SCHEMA@.CATALOG (OID) ON DELETE CASCADE
)
IN @TSPRE@REGTP
;

CREATE TABLE @SCHEMA@.CATALOG_CATEGORY_LOD (
    RESOURCE_OID VARCHAR(64)    NOT NULL,
    LOCALE       VARCHAR(64)    NOT NULL,
    TITLE        VARCHAR(255)   NOT NULL,
    DESCRIPTION  VARCHAR(1024)  ,
    CONSTRAINT PK321 PRIMARY KEY (RESOURCE_OID, LOCALE),
    CONSTRAINT FK321 FOREIGN KEY (RESOURCE_OID) REFERENCES @SCHEMA@.CATALOG_CATEGORY (OID) ON DELETE CASCADE
)
IN @TSPRE@REGTP
;


-- *****************************************************************
--
-- CATALOG CATEGORY INCLUDES (330)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.CATALOG_CATEGORY_INC (
    OID          		VARCHAR(64)       NOT NULL,
    CATALOG_OID  		VARCHAR(64)       NOT NULL,
    CATEGORY_OID 		VARCHAR(64)       NOT NULL,
    INCLUDE_CAT  		VARCHAR(255)  	  NOT NULL,
    INCLUDE_CATEGORY	VARCHAR(255)      NOT NULL,
    CONSTRAINT PK330 PRIMARY KEY (OID)
)
IN @TSPRE@REGTP
;

-- *****************************************************************
--
-- CATALOG INCLUDES (340)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.CATALOG_INC (
    OID          		VARCHAR(64)       NOT NULL,
    CATALOG_OID  		VARCHAR(64)       NOT NULL,
    INCLUDE_CAT  		VARCHAR(255)  	  NOT NULL,
    CONSTRAINT PK340 PRIMARY KEY (OID)
)
IN @TSPRE@REGTP
;

-- *****************************************************************
--
-- PREFERENCE (400)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.PREFERENCE (
    OID          VARCHAR(64)        NOT NULL,
    UNIQUE_NAME  VARCHAR(255)       NOT NULL,
    PARENT_OID   VARCHAR(64)        NOT NULL,
    TYPE         INTEGER            NOT NULL,
    WDGT_INST_ID VARCHAR(255)       NOT NULL,
    ACCOUNT_ID   VARCHAR(900)       NOT NULL,
    PAGE_ID      VARCHAR(255)       NOT NULL,
    CREATED      BIGINT             NOT NULL,
    MODIFIED     BIGINT             NOT NULL,
    STATE        INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT PK401 PRIMARY KEY (OID)
)
IN @TSPRE@REGTP
;

-- *****************************************************************
--
-- PREFERENCE NODE (WAS USED TO DEAL WITH COMPOSITE(NESTED)
--                  PREFERENCES, UNTIL DROPPED - HERE FOR REFERENCE)
--
-- *****************************************************************
--CREATE TABLE @SCHEMA@.PREFERENCE_NODE (
--    OID         CHAR(64)           NOT NULL,
--    UNIQUE_NAME VARCHAR(255)       NOT NULL,
--    PREF_OID    CHAR(64)           NOT NULL,
--    PARENT_OID  CHAR(64)           NOT NULL,
--    TYPE        INTEGER            NOT NULL,
--    CREATED     BIGINT             NOT NULL,
--    MODIFIED    BIGINT             NOT NULL,
--    STATE       INTEGER DEFAULT 1  NOT NULL,
--    CONSTRAINT PK111 PRIMARY KEY (OID),
--    CONSTRAINT FK111 FOREIGN KEY (PREF_OID) REFERENCES @SCHEMA@.PREFERENCE (OID) ON DELETE CASCADE
--);

-- *****************************************************************
--
-- PREFERENCE NODE VALUE (410)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.PREFERENCE_VALUE (
    OID           VARCHAR(64)        NOT NULL,
    PREF_OID      VARCHAR(64)        NOT NULL,
    NAME          VARCHAR(255)       NOT NULL,
    READ_ONLY     INTEGER DEFAULT 0  NOT NULL,
    IS_LARGE      INTEGER DEFAULT 0  NOT NULL,
    HAS_LIST      INTEGER DEFAULT 0  NOT NULL,
    VALUE         VARCHAR(1024)      ,
    LARGE_VALUE   CLOB(1M)           ,
    STATE         INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT PK410 PRIMARY KEY (OID),
    CONSTRAINT FK410 FOREIGN KEY (PREF_OID) REFERENCES @SCHEMA@.PREFERENCE (OID) ON DELETE CASCADE
)
IN @TSPRE@REGTP
;

-- *****************************************************************
--
-- NAVIGATION NODE (500)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.NAVNODE (
    OID            VARCHAR(64)        NOT NULL,
    OWNER_OID      VARCHAR(650)       NOT NULL,
    THEME_ID       VARCHAR(255)       NOT NULL,
    THEME_NAME     VARCHAR(255)       NOT NULL,
    CONTENT        BLOB(1M)           ,
    BYTE_COUNT     INTEGER            ,
    IS_ZIPPED      INTEGER DEFAULT 0  NOT NULL,
    COMMUNITY_OID  VARCHAR(64)        ,
    SPACE_OID      VARCHAR(64)        ,
    CREATED        BIGINT             NOT NULL,
    MODIFIED       BIGINT             NOT NULL,
    STATE          INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT PK500 PRIMARY KEY (OID, OWNER_OID)
)
IN @TSPRE@REGTP
;

CREATE TABLE @SCHEMA@.NAVNODE_LOD (
    RESOURCE_OID  VARCHAR(64)    NOT NULL,
    OWNER_OID     VARCHAR(650)   NOT NULL,
    LOCALE        VARCHAR(64)    NOT NULL,
    TITLE         VARCHAR(255)   NOT NULL,
    DESCRIPTION   VARCHAR(1024)          ,
    CONSTRAINT FK500 FOREIGN KEY (RESOURCE_OID,OWNER_OID) REFERENCES @SCHEMA@.NAVNODE (OID,OWNER_OID) ON DELETE CASCADE
)
IN @TSPRE@REGTP
;

CREATE TABLE @SCHEMA@.NAVNODE_DD (
    RESOURCE_OID  VARCHAR(64)    NOT NULL,
    OWNER_OID     VARCHAR(650)   NOT NULL,
    NAME          VARCHAR(255)   NOT NULL,
    VALUE         VARCHAR(3000)  NOT NULL,
    CONSTRAINT PK502 PRIMARY KEY (RESOURCE_OID,OWNER_OID,NAME),
    CONSTRAINT FK502 FOREIGN KEY (RESOURCE_OID,OWNER_OID) REFERENCES @SCHEMA@.NAVNODE (OID,OWNER_OID) ON DELETE CASCADE
)
IN @TSPRE@REGTP
;

-- *****************************************************************
--
-- NAVIGATION TREE (510)
--
-- *****************************************************************

CREATE TABLE @SCHEMA@.NAV_TREE (
    OWNER_OID    VARCHAR(650)        NOT NULL,
    PAGE_OID     VARCHAR(64)         NOT NULL,
    PARENT_OID   VARCHAR(64)         NOT NULL,
    ORDINAL      INTEGER  DEFAULT 1  ,
    IS_VIRTUAL   INTEGER  DEFAULT 0  ,
    CONSTRAINT PK510 PRIMARY KEY (OWNER_OID, PAGE_OID)
)
IN @TSPRE@REGTP
;

-- *****************************************************************
--
-- ACCESS CONTROL (600)
--
-- *****************************************************************

CREATE TABLE @SCHEMA@.COMMUNITY_DEF (
    OID            VARCHAR(64)        NOT NULL,
    OWNER_UID      VARCHAR(650)       NOT NULL,
    RESOURCE_OID   VARCHAR(64)        NOT NULL,
    RESOURCE_TYPE  VARCHAR(32)        NOT NULL,
    CREATED        BIGINT             NOT NULL,
    MODIFIED       BIGINT             NOT NULL,
    STATE          INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT PK600 PRIMARY KEY( OID )
)
IN @TSPRE@REGTP
;

-- UNIQUE CONSTRAINT
ALTER TABLE @SCHEMA@.COMMUNITY_DEF ADD CONSTRAINT UQ600 UNIQUE (OID,RESOURCE_OID);

CREATE TABLE @SCHEMA@.ACL (
    COMMUNITY_OID     VARCHAR(64)        NOT NULL,
    PARTICIPANT_UID   VARCHAR(650)       NOT NULL,
    PARTICIPANT_TYPE  INTEGER            NOT NULL,
    PERMISSIONS       VARCHAR(255)       NOT NULL,
    CREATED           BIGINT             NOT NULL,
    MODIFIED          BIGINT             NOT NULL,
    STATE             INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT PK610 PRIMARY KEY (COMMUNITY_OID,PARTICIPANT_UID),
    CONSTRAINT FK611 FOREIGN KEY (COMMUNITY_OID) REFERENCES @SCHEMA@.COMMUNITY_DEF (OID) ON DELETE CASCADE
)
IN @TSPRE@REGTP
;

-- *****************************************************************
--
-- SPACES (700)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.SPACENODE (
    OID            VARCHAR(64)        NOT NULL,
    OWNER_OID      VARCHAR(650)       NOT NULL,
    ROOTNAV_OID    VARCHAR(64)        ,
    TEMPLATE_OID  VARCHAR(64)        ,
    CREATED        BIGINT             NOT NULL,
    MODIFIED       BIGINT             NOT NULL,
    STATE          INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT PK700 PRIMARY KEY (OID, OWNER_OID)
)
IN @TSPRE@REGTP
;

CREATE TABLE @SCHEMA@.SPACENODE_LOD (
    RESOURCE_OID  VARCHAR(64)    NOT NULL,
    OWNER_OID     VARCHAR(650)   NOT NULL,
    LOCALE        VARCHAR(64)    NOT NULL,
    TITLE         VARCHAR(255)   NOT NULL,
    DESCRIPTION   VARCHAR(1024)          ,
    CONSTRAINT PK701 PRIMARY KEY (RESOURCE_OID,OWNER_OID,LOCALE),
    CONSTRAINT FK701 FOREIGN KEY (RESOURCE_OID,OWNER_OID) REFERENCES @SCHEMA@.SPACENODE (OID,OWNER_OID) ON DELETE CASCADE
)
IN @TSPRE@REGTP
;

CREATE TABLE @SCHEMA@.SPACENODE_DD (
    RESOURCE_OID  VARCHAR(64)    NOT NULL,
    OWNER_OID     VARCHAR(650)   NOT NULL,
    NAME          VARCHAR(255)   NOT NULL,
    VALUE         VARCHAR(3000)  NOT NULL,
    CONSTRAINT PK702 PRIMARY KEY (RESOURCE_OID,OWNER_OID,NAME),
    CONSTRAINT FK702 FOREIGN KEY (RESOURCE_OID,OWNER_OID) REFERENCES @SCHEMA@.SPACENODE (OID,OWNER_OID) ON DELETE CASCADE
)
IN @TSPRE@REGTP
;

-- *****************************************************************
--
-- TEMPLATES (800)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.TEMPLATENODE (
    OID            VARCHAR(64)        NOT NULL,
    OWNER_OID      VARCHAR(650)       ,
    CONTENT        BLOB(1M)           ,
    BYTE_COUNT     INTEGER            ,
    TEMPLATE_TYPE  VARCHAR(64)        ,
    CREATED        BIGINT             NOT NULL,
    MODIFIED       BIGINT             NOT NULL,
    STATE          INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT PK800 PRIMARY KEY (OID)
)
IN @TSPRE@REGTP
;

CREATE TABLE @SCHEMA@.TEMPLATENODE_LOD (
    RESOURCE_OID  VARCHAR(64)    NOT NULL,
    LOCALE        VARCHAR(64)    NOT NULL,
    TITLE         VARCHAR(255)   NOT NULL,
    DESCRIPTION   VARCHAR(1024)          ,
    CONSTRAINT PK801 PRIMARY KEY (RESOURCE_OID,LOCALE),
    CONSTRAINT FK801 FOREIGN KEY (RESOURCE_OID) REFERENCES @SCHEMA@.TEMPLATENODE (OID) ON DELETE CASCADE
)
IN @TSPRE@REGTP
;

-- *****************************************************************
--
-- ACCESS CONTROL RESOURCES (900)
--
-- *****************************************************************

CREATE TABLE @SCHEMA@.AC_RESOURCE (
    OID            VARCHAR(64)        NOT NULL,
    OWNER_UID      VARCHAR(650)       NOT NULL,
    RESOURCE_OID   VARCHAR(64)        NOT NULL,
    RESOURCE_TYPE  VARCHAR(32)        NOT NULL,
    ROLE_BLOCKS    VARCHAR(1024)              ,
    CREATED        BIGINT             NOT NULL,
    MODIFIED       BIGINT             NOT NULL,
    STATE          INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT PK900 PRIMARY KEY( RESOURCE_OID )
)
IN @TSPRE@REGTP
;

CREATE TABLE @SCHEMA@.AC_ROLE (
    AC_RESOURCE_OID   VARCHAR(64)        NOT NULL,
    ROLE_OID          VARCHAR(64)        NOT NULL,
    ROLE_NAME         VARCHAR(1024)      NOT NULL,
    ROLE_TYPE         VARCHAR(1024)              ,
    CREATED           BIGINT             NOT NULL,
    MODIFIED          BIGINT             NOT NULL,
    STATE             INTEGER DEFAULT 1  NOT NULL,
    CONSTRAINT PK910 PRIMARY KEY( ROLE_OID ),
    CONSTRAINT FK911 FOREIGN KEY (AC_RESOURCE_OID) REFERENCES @SCHEMA@.AC_RESOURCE (RESOURCE_OID) ON DELETE CASCADE
)
IN @TSPRE@REGTP
;

CREATE TABLE @SCHEMA@.AC_MEMBER (
    ROLE_OID          VARCHAR(64)        NOT NULL,
    MEMBER_UID        VARCHAR(650)       NOT NULL,
    MEMBER_TYPE       INTEGER            NOT NULL,
    CONSTRAINT PK920 PRIMARY KEY (ROLE_OID,MEMBER_UID),
    CONSTRAINT FK921 FOREIGN KEY (ROLE_OID) REFERENCES @SCHEMA@.AC_ROLE (ROLE_OID) ON DELETE CASCADE
)
IN @TSPRE@REGTP
;

-- *****************************************************************
--
-- FILESTORE (1000)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.FILESTORE_PATH (
    OID         VARCHAR(64)           NOT NULL,
    PARENT_OID  VARCHAR(64)           NOT NULL,
    NAME        VARCHAR(255)          NOT NULL,
    PATH        VARCHAR(255)          NOT NULL,
    LOCKED      VARCHAR(64)           , 
    OWNER       VARCHAR(64)           ,             
    CREATED     BIGINT                NOT NULL,
    MODIFIED    BIGINT                NOT NULL,
    COLL_TYPE   INTEGER DEFAULT 1     NOT NULL,
    CONSTRAINT PK1010 PRIMARY KEY (OID)
)
IN @TSPRE@REGTP
;

CREATE TABLE @SCHEMA@.FILESTORE_FILE (
    OID         VARCHAR(64)           NOT NULL,           
    F_SIZE      INTEGER               NOT NULL,
    CONTENT        BLOB(1G)           ,
    CONSTRAINT PK1000 PRIMARY KEY (OID),
    CONSTRAINT FK1001 FOREIGN KEY (OID) REFERENCES @SCHEMA@.FILESTORE_PATH (OID) ON DELETE CASCADE
)
IN @TSPRE@REGTP
;

--*****************************************************************
--
-- Indexing
--
--*****************************************************************
-- Catalog
CREATE INDEX @SCHEMA@.CATACCT      ON @SCHEMA@.CATALOG(ACCOUNT_OID);
CREATE INDEX @SCHEMA@.ENTRYCATGOID ON @SCHEMA@.CATALOG_ENTRY(CATALOG_OID, CATEGORY_OID);
CREATE INDEX @SCHEMA@.CATGCATOID   ON @SCHEMA@.CATALOG_CATEGORY(CATALOG_OID);
CREATE INDEX @SCHEMA@.CATINTCATOID ON @SCHEMA@.CATALOG_INC(CATALOG_OID);

-- Preferences
CREATE INDEX @SCHEMA@.PREFPARENT ON @SCHEMA@.PREFERENCE(PARENT_OID,ACCOUNT_ID);
CREATE INDEX @SCHEMA@.PREFTYPE   ON @SCHEMA@.PREFERENCE(TYPE);

-- Navigation
CREATE INDEX @SCHEMA@.PAGECOMM     ON @SCHEMA@.NAVNODE(COMMUNITY_OID);
CREATE INDEX @SCHEMA@.PAGELODOWNRS ON @SCHEMA@.NAVNODE_LOD(OWNER_OID,RESOURCE_OID);
CREATE INDEX @SCHEMA@.TREEOWPAR    ON @SCHEMA@.NAV_TREE(OWNER_OID,PARENT_OID);

-- Acl
CREATE INDEX @SCHEMA@.COMMOWNPAR ON @SCHEMA@.COMMUNITY_DEF(OWNER_UID);
CREATE INDEX @SCHEMA@.PRTTYUID   ON @SCHEMA@.ACL(PARTICIPANT_TYPE,PARTICIPANT_UID);
CREATE INDEX @SCHEMA@.PRTUID     ON @SCHEMA@.ACL(PARTICIPANT_UID);

-- AC
CREATE INDEX @SCHEMA@.AC_ROLE_RESOURCE ON @SCHEMA@.AC_ROLE(AC_RESOURCE_OID);
CREATE INDEX @SCHEMA@.AC_MEMBER_UID ON @SCHEMA@.AC_MEMBER(MEMBER_UID);
CREATE INDEX @SCHEMA@.AC_RESOURCE_OWNER ON @SCHEMA@.AC_RESOURCE(OWNER_UID,RESOURCE_OID);

--*****************************************************************
--
-- Initialization
--
--*****************************************************************
-- Schema version (leave this here to faciliate version checking)

INSERT INTO @SCHEMA@.VERSION_INFO (OID,VERSION_MAJOR,VERSION_MINOR,VERSION_RELEASE,VERSION_DEV,VERSION_TIME,DESCRIPTION)
VALUES ('458202233263219661970198300000000000',1,0,0,13,0,'Initialization from install script');


  
