-- *****************************************************************
--
-- Licensed Materials - Property of IBM
--                                      
-- 5724-U69                             
--                                      
-- Copyright IBM Corp. 2001, 2006  All Rights Reserved.
--
-- US Government Users Restricted Rights - Use, duplication or
-- disclosure restricted by GSA ADP Schedule Contract with
-- IBM Corp.
--
-- *****************************************************************

-- Mashup Informix Script for creating tables, keys, indexes

-- *****************************************************************
--
-- SCHEMA VERSION (100)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.VERSION_INFO(
    OID VARCHAR(64)    NOT NULL,
    VERSION_MAJOR   INTEGER,
    VERSION_MINOR   INTEGER,
    VERSION_RELEASE INTEGER,
    VERSION_DEV     INTEGER,
    VERSION_TIME    INT8,
    DESCRIPTION     VARCHAR(254),
    PRIMARY KEY (OID) CONSTRAINT PK100
)
-- IN MASHUPSREGTABSPACE
;

-- *****************************************************************
--
-- ACCOUNT (200)
--
-- *****************************************************************
-- 04/04 Accounts were ordered dropped.
--  The expectation is a userId is provided to persistence code
--  which is a vmm char(64) unique id. Susbsystems will create
--  required objects on the fly. Maybe want more centralized
--  provisioning to faciliate admin?
--CREATE TABLE @SCHEMA@.ACCOUNT (
--    OID         CHAR(64)           NOT NULL,
--    EXTERNAL_ID VARCHAR(254)       NOT NULL,
--    NAME        VARCHAR(254)       NOT NULL,
--    CREATED     INT8             NOT NULL,
--    MODIFIED    INT8             NOT NULL,
--    STATE       INTEGER DEFAULT 1  NOT NULL,
--    CONSTRAINT PK200 PRIMARY KEY (OID)
--);

-- *****************************************************************
--
-- CATALOG (300)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.CATALOG (
    OID         VARCHAR(64)       NOT NULL,
    ACCOUNT_OID LVARCHAR(1024)    NOT NULL,
    UNIQUE_NAME VARCHAR(254)      NOT NULL,
    CREATED     INT8              NOT NULL,
    MODIFIED    INT8              NOT NULL,
    STATE       INTEGER DEFAULT 1 NOT NULL,
    PRIMARY KEY (OID) CONSTRAINT PK300
)
-- IN MASHUPSREGTABSPACE
;

CREATE TABLE @SCHEMA@.CATALOG_LOD (
    RESOURCE_OID VARCHAR(64)       NOT NULL,
    LOCALE       VARCHAR(64)       NOT NULL,
    TITLE        VARCHAR(254)      NOT NULL,
    DESCRIPTION  LVARCHAR(1024)    ,
    PRIMARY KEY (RESOURCE_OID, LOCALE) CONSTRAINT PK301,
    FOREIGN KEY (RESOURCE_OID) REFERENCES @SCHEMA@.CATALOG (OID) ON DELETE CASCADE CONSTRAINT FK302
);

-- *****************************************************************
--
-- CATALOG ENTRY (310)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.CATALOG_ENTRY (
    OID            			VARCHAR(64)        NOT NULL,
    CATALOG_OID    			VARCHAR(64)        NOT NULL,
    CATEGORY_OID   			VARCHAR(64)        NOT NULL,
    DEFINITION_URL 			LVARCHAR(2500)     NOT NULL,
    CONTENT_URL    			LVARCHAR(2500)     ,
    PREVIEW_URL    			LVARCHAR(2500)     ,
    PREVIEW_THUMBNAIL_URL	LVARCHAR(2500)     ,
    HELP_URL       			LVARCHAR(2500)     ,    
    ICON_URL       			LVARCHAR(2500)     ,
    HUB_ENTRY_URL  			LVARCHAR(2500)     ,
    DEF_URL_TYPE   			INTEGER            ,
    ICON_URL_TYPE  			INTEGER            ,
    CREATED        			INT8               NOT NULL,
    MODIFIED       			INT8               NOT NULL,
    STATE          			INTEGER DEFAULT 1  NOT NULL,
    PRIMARY KEY (OID) CONSTRAINT PK310
)
-- IN MASHUPSREGTABSPACE
;

CREATE TABLE @SCHEMA@.CATALOG_ENTRY_LOD (
    RESOURCE_OID  		VARCHAR(64)    NOT NULL,
    LOCALE        		VARCHAR(64)    NOT NULL,
    TITLE         		VARCHAR(254)   NOT NULL,
    DESCRIPTION   		LVARCHAR(1024) ,
    SHORT_DESCRIPTION   VARCHAR(254)   ,    
    PRIMARY KEY (RESOURCE_OID, LOCALE) CONSTRAINT PK311,
    FOREIGN KEY (RESOURCE_OID) REFERENCES @SCHEMA@.CATALOG_ENTRY (OID) ON DELETE CASCADE CONSTRAINT FK311
)
-- IN MASHUPSREGTABSPACE
;

CREATE TABLE @SCHEMA@.CATALOG_ENTRY_DD (
    RESOURCE_OID  VARCHAR(64)    NOT NULL,
    NAME          VARCHAR(254)   NOT NULL,
    VALUE         LVARCHAR(3000) NOT NULL,
    PRIMARY KEY (RESOURCE_OID, NAME) CONSTRAINT PK312,
    FOREIGN KEY (RESOURCE_OID) REFERENCES @SCHEMA@.CATALOG_ENTRY (OID) ON DELETE CASCADE CONSTRAINT FK312
)
-- IN MASHUPSREGTABSPACE
;


-- *****************************************************************
--
-- CATALOG CATEGORY (320)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.CATALOG_CATEGORY (
    OID         VARCHAR(64)         NOT NULL,
    CATALOG_OID VARCHAR(64)         NOT NULL,
    NAME        VARCHAR(254)        ,
    CREATED     INT8                NOT NULL,
    MODIFIED    INT8                NOT NULL,
    STATE       INTEGER DEFAULT 1   NOT NULL,
    PRIMARY KEY (OID) CONSTRAINT PK320,
    FOREIGN KEY (CATALOG_OID) REFERENCES @SCHEMA@.CATALOG (OID) ON DELETE CASCADE CONSTRAINT FK320
)
-- IN MASHUPSREGTABSPACE
;

CREATE TABLE @SCHEMA@.CATALOG_CATEGORY_LOD (
    RESOURCE_OID VARCHAR(64)    NOT NULL,
    LOCALE       VARCHAR(64)    NOT NULL,
    TITLE        VARCHAR(254)   NOT NULL,
    DESCRIPTION  LVARCHAR(1024) ,
    PRIMARY KEY (RESOURCE_OID, LOCALE) CONSTRAINT PK321,
    FOREIGN KEY (RESOURCE_OID) REFERENCES @SCHEMA@.CATALOG_CATEGORY (OID) ON DELETE CASCADE CONSTRAINT FK321
)
-- IN MASHUPSREGTABSPACE
;


-- *****************************************************************
--
-- CATALOG CATEGORY INCLUDES (330)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.CATALOG_CATEGORY_INC (
    OID          		VARCHAR(64)       NOT NULL,
    CATALOG_OID  		VARCHAR(64)       NOT NULL,
    CATEGORY_OID 		VARCHAR(64)       NOT NULL,
    INCLUDE_CAT  		VARCHAR(254)  	  NOT NULL,
    INCLUDE_CATEGORY	VARCHAR(254)      NOT NULL,
    PRIMARY KEY (OID) CONSTRAINT PK330
)
-- IN MASHUPSREGTABSPACE
;

-- *****************************************************************
--
-- CATALOG INCLUDES (340)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.CATALOG_INC (
    OID          		VARCHAR(64)       NOT NULL,
    CATALOG_OID  		VARCHAR(64)       NOT NULL,
    INCLUDE_CAT  		VARCHAR(254)  	  NOT NULL,
    PRIMARY KEY (OID) CONSTRAINT PK340
)
-- IN MASHUPSREGTABSPACE
;
-- *****************************************************************
--
-- PREFERENCE (400)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.PREFERENCE (
    OID          VARCHAR(64)        NOT NULL,
    UNIQUE_NAME  VARCHAR(254)       NOT NULL,
    PARENT_OID   VARCHAR(64)        NOT NULL,
    TYPE         INTEGER            NOT NULL,
    WDGT_INST_ID VARCHAR(254)       NOT NULL,
    ACCOUNT_ID   LVARCHAR(1024)     NOT NULL,
    PAGE_ID      VARCHAR(254)       NOT NULL,
    CREATED      INT8               NOT NULL,
    MODIFIED     INT8               NOT NULL,
    STATE        INTEGER DEFAULT 1  NOT NULL,
    PRIMARY KEY (OID) CONSTRAINT PK401
)
-- IN MASHUPSREGTABSPACE
;

-- *****************************************************************
--
-- PREFERENCE NODE (WAS USED TO DEAL WITH COMPOSITE(NESTED)
--                  PREFERENCES, UNTIL DROPPED - HERE FOR REFERENCE)
--
-- *****************************************************************
--CREATE TABLE @SCHEMA@.PREFERENCE_NODE (
--    OID         CHAR(64)           NOT NULL,
--    UNIQUE_NAME VARCHAR(254)       NOT NULL,
--    PREF_OID    CHAR(64)           NOT NULL,
--    PARENT_OID  CHAR(64)           NOT NULL,
--    TYPE        INTEGER            NOT NULL,
--    CREATED     INT8             NOT NULL,
--    MODIFIED    INT8             NOT NULL,
--    STATE       INTEGER DEFAULT 1  NOT NULL,
--    CONSTRAINT PK111 PRIMARY KEY (OID),
--    CONSTRAINT FK111 FOREIGN KEY (PREF_OID) REFERENCES @SCHEMA@.PREFERENCE (OID) ON DELETE CASCADE
--);

-- *****************************************************************
--
-- PREFERENCE NODE VALUE (410)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.PREFERENCE_VALUE (
    OID           VARCHAR(64)        NOT NULL,
    PREF_OID      VARCHAR(64)        NOT NULL,
    NAME          VARCHAR(254)       NOT NULL,
    READ_ONLY     INTEGER DEFAULT 0  NOT NULL,
    IS_LARGE      INTEGER DEFAULT 0  NOT NULL,
    HAS_LIST      INTEGER DEFAULT 0  NOT NULL,
    VALUE         LVARCHAR(1024)     ,
    LARGE_VALUE   CLOB               ,
    STATE         INTEGER DEFAULT 1  NOT NULL,
    PRIMARY KEY (OID) CONSTRAINT PK410,
    FOREIGN KEY (PREF_OID) REFERENCES @SCHEMA@.PREFERENCE (OID) ON DELETE CASCADE CONSTRAINT FK410
)
-- IN MASHUPSREGTABSPACE
;

-- *****************************************************************
--
-- NAVIGATION NODE (500)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.NAVNODE (
    OID            VARCHAR(64)        NOT NULL,
    OWNER_OID      LVARCHAR(1024)     NOT NULL,
    THEME_ID       VARCHAR(254)       NOT NULL,
    THEME_NAME     VARCHAR(254)       NOT NULL,
    CONTENT        BLOB               ,
    BYTE_COUNT     INTEGER            ,
    IS_ZIPPED      INTEGER DEFAULT 0  NOT NULL,
    COMMUNITY_OID  VARCHAR(64)        ,
    SPACE_OID      VARCHAR(64)        ,
    CREATED        INT8               NOT NULL,
    MODIFIED       INT8               NOT NULL,
    STATE          INTEGER DEFAULT 1  NOT NULL,
    PRIMARY KEY (OID, OWNER_OID) CONSTRAINT PK500
)
-- IN MASHUPSREGTABSPACE
;

CREATE TABLE @SCHEMA@.NAVNODE_LOD (
    RESOURCE_OID  VARCHAR(64)    NOT NULL,
    OWNER_OID     LVARCHAR(1024) NOT NULL,
    LOCALE        VARCHAR(64)    NOT NULL,
    TITLE         VARCHAR(254)   NOT NULL,
    DESCRIPTION   LVARCHAR(1024)          ,
    FOREIGN KEY (RESOURCE_OID,OWNER_OID) REFERENCES @SCHEMA@.NAVNODE (OID,OWNER_OID) ON DELETE CASCADE CONSTRAINT FK500
)
-- IN MASHUPSREGTABSPACE
;

CREATE TABLE @SCHEMA@.NAVNODE_DD (
    RESOURCE_OID  VARCHAR(64)    NOT NULL,
    OWNER_OID     LVARCHAR(1024) NOT NULL,
    NAME          VARCHAR(254)   NOT NULL,
    VALUE         LVARCHAR(3000) NOT NULL,
    PRIMARY KEY (RESOURCE_OID,OWNER_OID,NAME) CONSTRAINT PK502,
    FOREIGN KEY (RESOURCE_OID,OWNER_OID) REFERENCES @SCHEMA@.NAVNODE (OID,OWNER_OID) ON DELETE CASCADE CONSTRAINT FK502
-- IN MASHUPSREGTABSPACE
);

-- *****************************************************************
--
-- NAVIGATION TREE (510)
--
-- *****************************************************************

CREATE TABLE @SCHEMA@.NAV_TREE (
    OWNER_OID    LVARCHAR(1024)      NOT NULL,
    PAGE_OID     VARCHAR(64)         NOT NULL,
    PARENT_OID   VARCHAR(64)         NOT NULL,
    ORDINAL      INTEGER  DEFAULT 1  ,
    IS_VIRTUAL   INTEGER  DEFAULT 0  ,
    PRIMARY KEY (OWNER_OID, PAGE_OID) CONSTRAINT PK510
)
-- IN MASHUPSREGTABSPACE
;

-- *****************************************************************
--
-- ACCESS CONTROL (600)
--
-- *****************************************************************

CREATE TABLE @SCHEMA@.COMMUNITY_DEF (
    OID            VARCHAR(64)        NOT NULL,
    OWNER_UID      LVARCHAR(1024)     NOT NULL,
    RESOURCE_OID   VARCHAR(64)        NOT NULL,
    RESOURCE_TYPE  VARCHAR(32)        NOT NULL,
    CREATED        INT8               NOT NULL,
    MODIFIED       INT8               NOT NULL,
    STATE          INTEGER DEFAULT 1  NOT NULL,
    PRIMARY KEY( OID ) CONSTRAINT PK600
)
-- IN MASHUPSREGTABSPACE
;

-- UNIQUE CONSTRAINT
ALTER TABLE @SCHEMA@.COMMUNITY_DEF ADD CONSTRAINT UNIQUE (OID,RESOURCE_OID);

CREATE TABLE @SCHEMA@.ACL (
    COMMUNITY_OID     VARCHAR(64)        NOT NULL,
    PARTICIPANT_UID   LVARCHAR(1024)     NOT NULL,
    PARTICIPANT_TYPE  INTEGER            NOT NULL,
    PERMISSIONS       VARCHAR(254)       NOT NULL,
    CREATED           INT8               NOT NULL,
    MODIFIED          INT8               NOT NULL,
    STATE             INTEGER DEFAULT 1  NOT NULL,
    PRIMARY KEY (COMMUNITY_OID,PARTICIPANT_UID) CONSTRAINT PK610,
    FOREIGN KEY (COMMUNITY_OID) REFERENCES @SCHEMA@.COMMUNITY_DEF (OID) ON DELETE CASCADE CONSTRAINT FK611
)
-- IN MASHUPSREGTABSPACE
;

-- *****************************************************************
--
-- SPACES (700)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.SPACENODE (
    OID            VARCHAR(64)        NOT NULL,
    OWNER_OID      LVARCHAR(1024)     NOT NULL,
    ROOTNAV_OID    VARCHAR(64)        ,
    TEMPLATE_OID   VARCHAR(64)        ,
    CREATED        INT8               NOT NULL,
    MODIFIED       INT8               NOT NULL,
    STATE          INTEGER DEFAULT 1  NOT NULL,
    PRIMARY KEY (OID, OWNER_OID) CONSTRAINT PK700
);

CREATE TABLE @SCHEMA@.SPACENODE_LOD (
    RESOURCE_OID  VARCHAR(64)    NOT NULL,
    OWNER_OID     LVARCHAR(1024) NOT NULL,
    LOCALE        VARCHAR(64)    NOT NULL,
    TITLE         VARCHAR(255)   NOT NULL,
    DESCRIPTION   LVARCHAR(1024)          ,
    PRIMARY KEY (RESOURCE_OID,OWNER_OID,LOCALE) CONSTRAINT PK701,
    FOREIGN KEY (RESOURCE_OID,OWNER_OID) REFERENCES @SCHEMA@.SPACENODE (OID,OWNER_OID) ON DELETE CASCADE CONSTRAINT FK701
);

CREATE TABLE @SCHEMA@.SPACENODE_DD (
    RESOURCE_OID  VARCHAR(64)    NOT NULL,
    OWNER_OID     LVARCHAR(1024) NOT NULL,
    NAME          VARCHAR(255)   NOT NULL,
    VALUE         LVARCHAR(3000) NOT NULL,
    PRIMARY KEY (RESOURCE_OID,OWNER_OID,NAME) CONSTRAINT PK702,
    FOREIGN KEY (RESOURCE_OID,OWNER_OID) REFERENCES @SCHEMA@.SPACENODE (OID,OWNER_OID) ON DELETE CASCADE CONSTRAINT FK702
);

-- *****************************************************************
--
-- TEMPLATES (800)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.TEMPLATENODE (
    OID            VARCHAR(64)        NOT NULL,
    OWNER_OID      LVARCHAR(1024)     ,
    CONTENT        BLOB               ,
    BYTE_COUNT     INTEGER            ,
    TEMPLATE_TYPE  VARCHAR(64)        ,
    CREATED        INT8               NOT NULL,
    MODIFIED       INT8               NOT NULL,
    STATE          INTEGER DEFAULT 1  NOT NULL,
    PRIMARY KEY (OID) CONSTRAINT PK800
);

CREATE TABLE @SCHEMA@.TEMPLATENODE_LOD (
    RESOURCE_OID  VARCHAR(64)    NOT NULL,
    LOCALE        VARCHAR(64)    NOT NULL,
    TITLE         VARCHAR(255)   NOT NULL,
    DESCRIPTION   LVARCHAR(1024)          ,
    PRIMARY KEY (RESOURCE_OID,LOCALE) CONSTRAINT PK801,
    FOREIGN KEY (RESOURCE_OID) REFERENCES @SCHEMA@.TEMPLATENODE (OID) ON DELETE CASCADE CONSTRAINT FK801
);

-- *****************************************************************
--
-- ACCESS CONTROL RESOURCES (900)
--
-- *****************************************************************

CREATE TABLE @SCHEMA@.AC_RESOURCE (
    OID            VARCHAR(64)        NOT NULL,
    OWNER_UID      LVARCHAR(1024)     NOT NULL,
    RESOURCE_OID   VARCHAR(64)        NOT NULL,
    RESOURCE_TYPE  VARCHAR(32)        NOT NULL,
    ROLE_BLOCKS    LVARCHAR(1024)             ,
    CREATED        INT8               NOT NULL,
    MODIFIED       INT8               NOT NULL,
    STATE          INTEGER DEFAULT 1  NOT NULL,
    PRIMARY KEY( RESOURCE_OID ) CONSTRAINT PK900
);

CREATE TABLE @SCHEMA@.AC_ROLE (
    AC_RESOURCE_OID   VARCHAR(64)        NOT NULL,
    ROLE_OID          VARCHAR(64)        NOT NULL,
    ROLE_NAME         LVARCHAR(1024)     NOT NULL,
    ROLE_TYPE         LVARCHAR(1024)             ,
    CREATED           INT8               NOT NULL,
    MODIFIED          INT8               NOT NULL,
    STATE             INTEGER DEFAULT 1  NOT NULL,
    PRIMARY KEY( ROLE_OID ) CONSTRAINT PK910,
    FOREIGN KEY (AC_RESOURCE_OID) REFERENCES @SCHEMA@.AC_RESOURCE (RESOURCE_OID) ON DELETE CASCADE CONSTRAINT FK911
);

CREATE TABLE @SCHEMA@.AC_MEMBER (
    ROLE_OID          VARCHAR(64)        NOT NULL,
    MEMBER_UID        LVARCHAR(1024)     NOT NULL,
    MEMBER_TYPE       INT8               NOT NULL,
    PRIMARY KEY (ROLE_OID,MEMBER_UID) CONSTRAINT PK920,
    FOREIGN KEY (ROLE_OID) REFERENCES @SCHEMA@.AC_ROLE (ROLE_OID) ON DELETE CASCADE CONSTRAINT FK921
);

-- *****************************************************************
--
-- FILESTORE (1000)
--
-- *****************************************************************
CREATE TABLE @SCHEMA@.FILESTORE_PATH (
    OID         VARCHAR(64)           NOT NULL,
    PARENT_OID  VARCHAR(64)           NOT NULL,
    NAME        VARCHAR(255)          NOT NULL,
    PATH        VARCHAR(255)          NOT NULL,
    LOCKED      VARCHAR(64)           , 
    OWNER       VARCHAR(64)           ,             
    CREATED     INT8                NOT NULL,
    MODIFIED    INT8                NOT NULL,
    COLL_TYPE   INT8 DEFAULT 1     NOT NULL,
    PRIMARY KEY (OID) CONSTRAINT PK1010
);

CREATE TABLE @SCHEMA@.FILESTORE_FILE (
    OID         VARCHAR(64)           NOT NULL,           
    F_SIZE        INT8               NOT NULL,
    CONTENT        BLOB           ,
    PRIMARY KEY (OID) CONSTRAINT PK1000,
    FOREIGN KEY (OID) REFERENCES @SCHEMA@.FILESTORE_PATH (OID) ON DELETE CASCADE CONSTRAINT FK1001
);


--*****************************************************************
--
-- Indexing
--
--*****************************************************************
-- Catalog
CREATE INDEX @SCHEMA@.CATACCT      ON @SCHEMA@.CATALOG(ACCOUNT_OID);
CREATE INDEX @SCHEMA@.ENTRYCATGOID ON @SCHEMA@.CATALOG_ENTRY(CATALOG_OID, CATEGORY_OID);
CREATE INDEX @SCHEMA@.CATGCATOID   ON @SCHEMA@.CATALOG_CATEGORY(CATALOG_OID);
CREATE INDEX @SCHEMA@.CATINTCATOID ON @SCHEMA@.CATALOG_INC(CATALOG_OID);

-- Preferences
CREATE INDEX @SCHEMA@.PREFPARENT ON @SCHEMA@.PREFERENCE(PARENT_OID,ACCOUNT_ID);
CREATE INDEX @SCHEMA@.PREFTYPE   ON @SCHEMA@.PREFERENCE(TYPE);

-- Navigation
CREATE INDEX @SCHEMA@.PAGECOMM     ON @SCHEMA@.NAVNODE(COMMUNITY_OID);
CREATE INDEX @SCHEMA@.PAGELODOWNRS ON @SCHEMA@.NAVNODE_LOD(OWNER_OID,RESOURCE_OID);
CREATE INDEX @SCHEMA@.TREEOWPAR    ON @SCHEMA@.NAV_TREE(OWNER_OID,PARENT_OID);

-- Acl
CREATE INDEX @SCHEMA@.COMMOWNPAR ON @SCHEMA@.COMMUNITY_DEF(OWNER_UID);
CREATE INDEX @SCHEMA@.PRTTYUID   ON @SCHEMA@.ACL(PARTICIPANT_TYPE,PARTICIPANT_UID);
CREATE INDEX @SCHEMA@.PRTUID     ON @SCHEMA@.ACL(PARTICIPANT_UID);

-- AC
CREATE INDEX @SCHEMA@.AC_ROLE_RESOURCE ON @SCHEMA@.AC_ROLE(AC_RESOURCE_OID);
CREATE INDEX @SCHEMA@.AC_MEMBER_UID ON @SCHEMA@.AC_MEMBER(MEMBER_UID);
CREATE INDEX @SCHEMA@.AC_RESOURCE_OWNER ON @SCHEMA@.AC_RESOURCE(OWNER_UID,RESOURCE_OID);

--*****************************************************************
--
-- Initialization
--
--*****************************************************************
-- Schema version (leave this here to faciliate version checking)

INSERT INTO @SCHEMA@.VERSION_INFO (OID,VERSION_MAJOR,VERSION_MINOR,VERSION_RELEASE,VERSION_DEV,VERSION_TIME,DESCRIPTION)
VALUES ('458202233263219661970198300000000000',1,0,0,13,0,'Initialization from install script');


  
