/** Licensed Materials - Property of IBM, 5724-U69, (C) Copyright IBM Corp. 2009 - All Rights reserved.  **/
dojo.provide("com.ibm.sharedWidgets");
if(!dojo._hasResource["com.ibm.data.SelectionModel"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.data.SelectionModel"] = true;
dojo.provide("com.ibm.data.SelectionModel");

dojo.declare("com.ibm.data.SelectionModel",
	null,
	{
		// treeModel: An instance of a DataTreeModel which backs this SelectionModel
		treeModel: null,
		
		// selectionPath: Array of items in the DataTreeModel which represent the current selection path.
		//		Starts at the currently selected node and goes up the tree to the root.
		selectionPath: [],
		
		constructor: function(args) {
			dojo.mixin(this, args);
			this.modelConnection = dojo.connect(this.treeModel, "onTreeChange", this, "onModelTreeChange");
		},
		
		atLevel: function(level, fromRoot) {
			return this.selectionPath[fromRoot ? this.selectionPath.length - 1 - level : level];
		},
		getPath: function() {
			return this.selectionPath.slice();
		},
		
		onModelTreeChange: function(/*Item*/ childItem, /*Item*/ oldParentItem, /*Item*/ newParentItem, /*Item*/ nextSiblingItem) {
			if(oldParentItem != newParentItem 
					&& dojo.some(this.selectionPath, function(item){
						return item == childItem;
					}, this)) {
				this._calculateNewPath(this.selectionPath[0]);
				this.onSelectionPathChange(false);
			}
		},
		
		_calculateNewPath: function(lastSelected) {
			// the model is built from the top-down, so the model should already have
			// loaded all the ancestors of the lastSelected item so that model.getParent()
			// returns loaded items
			var cur = lastSelected;
			this.selectionPath.splice(0, this.selectionPath.length);
			while(cur) {
				this.selectionPath.push(cur);
				cur = this.treeModel.getParent(cur);
			}
		},
		
		onSelectionPathChange: function(/*Boolean*/ selectionChanged) {
			// summary: Event called when the selection path is updated.  This can occur when the
			//		selection model changes because the tree was restructured, changing the path
			//		from the currently selected node to the root by reparenting some nodes, or
			//		by actually changing the currently selected node in the tree.
			// selectionChanged: Boolean true if the currently selected node changed, false if the
			//		path changed but the currently selected node is the same.
		},
		
		changeSelection: function(/*item*/ newSelection) {
			// This line is commented out to allow Mashups to 
			// process the selected node after moving it using
			// the more actions menu
			//if(this.selectionPath[0] == newSelection) return;
			this._calculateNewPath(newSelection);
			this.onSelectionPathChange(true);
		}
	}
);

}

if(!dojo._hasResource["dojo.data.util.filter"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.data.util.filter"] = true;
dojo.provide("dojo.data.util.filter");

dojo.data.util.filter.patternToRegExp = function(/*String*/pattern, /*boolean?*/ ignoreCase){
	//	summary:  
	//		Helper function to convert a simple pattern to a regular expression for matching.
	//	description:
	//		Returns a regular expression object that conforms to the defined conversion rules.
	//		For example:  
	//			ca*   -> /^ca.*$/
	//			*ca*  -> /^.*ca.*$/
	//			*c\*a*  -> /^.*c\*a.*$/
	//			*c\*a?*  -> /^.*c\*a..*$/
	//			and so on.
	//
	//	pattern: string
	//		A simple matching pattern to convert that follows basic rules:
	//			* Means match anything, so ca* means match anything starting with ca
	//			? Means match single character.  So, b?b will match to bob and bab, and so on.
	//      	\ is an escape character.  So for example, \* means do not treat * as a match, but literal character *.
	//				To use a \ as a character in the string, it must be escaped.  So in the pattern it should be 
	//				represented by \\ to be treated as an ordinary \ character instead of an escape.
	//
	//	ignoreCase:
	//		An optional flag to indicate if the pattern matching should be treated as case-sensitive or not when comparing
	//		By default, it is assumed case sensitive.

	var rxp = "^";
	var c = null;
	for(var i = 0; i < pattern.length; i++){
		c = pattern.charAt(i);
		switch (c) {
			case '\\':
				rxp += c;
				i++;
				rxp += pattern.charAt(i);
				break;
			case '*':
				rxp += ".*"; break;
			case '?':
				rxp += "."; break;
			case '$':
			case '^':
			case '/':
			case '+':
			case '.':
			case '|':
			case '(':
			case ')':
			case '{':
			case '}':
			case '[':
			case ']':
				rxp += "\\"; //fallthrough
			default:
				rxp += c;
		}
	}
	rxp += "$";
	if(ignoreCase){
		return new RegExp(rxp,"mi"); //RegExp
	}else{
		return new RegExp(rxp,"m"); //RegExp
	}
	
};

}

if(!dojo._hasResource["dojo.data.util.sorter"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.data.util.sorter"] = true;
dojo.provide("dojo.data.util.sorter");

dojo.data.util.sorter.basicComparator = function(	/*anything*/ a, 
													/*anything*/ b){
	//	summary:  
	//		Basic comparision function that compares if an item is greater or less than another item
	//	description:  
	//		returns 1 if a > b, -1 if a < b, 0 if equal.
	//		'null' values (null, undefined) are treated as larger values so that they're pushed to the end of the list.
	//		And compared to each other, null is equivalent to undefined.
	
	//null is a problematic compare, so if null, we set to undefined.
	//Makes the check logic simple, compact, and consistent
	//And (null == undefined) === true, so the check later against null
	//works for undefined and is less bytes.
	var r = -1;
	if(a === null){
		a = undefined;
	}
	if(b === null){
		b = undefined;
	}
	if(a == b){
		r = 0; 
	}else if(a > b || a == null){
		r = 1; 
	}
	return r; //int {-1,0,1}
};

dojo.data.util.sorter.createSortFunction = function(	/* attributes array */sortSpec,
														/*dojo.data.core.Read*/ store){
	//	summary:  
	//		Helper function to generate the sorting function based off the list of sort attributes.
	//	description:  
	//		The sort function creation will look for a property on the store called 'comparatorMap'.  If it exists
	//		it will look in the mapping for comparisons function for the attributes.  If one is found, it will
	//		use it instead of the basic comparator, which is typically used for strings, ints, booleans, and dates.
	//		Returns the sorting function for this particular list of attributes and sorting directions.
	//
	//	sortSpec: array
	//		A JS object that array that defines out what attribute names to sort on and whether it should be descenting or asending.
	//		The objects should be formatted as follows:
	//		{
	//			attribute: "attributeName-string" || attribute,
	//			descending: true|false;   // Default is false.
	//		}
	//	store: object
	//		The datastore object to look up item values from.
	//
	var sortFunctions=[];   

	function createSortFunction(attr, dir){
		return function(itemA, itemB){
			var a = store.getValue(itemA, attr);
			var b = store.getValue(itemB, attr);
			//See if we have a override for an attribute comparison.
			var comparator = null;
			if(store.comparatorMap){
				if(typeof attr !== "string"){
					 attr = store.getIdentity(attr);
				}
				comparator = store.comparatorMap[attr]||dojo.data.util.sorter.basicComparator;
			}
			comparator = comparator||dojo.data.util.sorter.basicComparator; 
			return dir * comparator(a,b); //int
		};
	}
	var sortAttribute;
	for(var i = 0; i < sortSpec.length; i++){
		sortAttribute = sortSpec[i];
		if(sortAttribute.attribute){
			var direction = (sortAttribute.descending) ? -1 : 1;
			sortFunctions.push(createSortFunction(sortAttribute.attribute, direction));
		}
	}

	return function(rowA, rowB){
		var i=0;
		while(i < sortFunctions.length){
			var ret = sortFunctions[i++](rowA, rowB);
			if(ret !== 0){
				return ret;//int
			}
		}
		return 0; //int  
	};  //  Function
};

}

if(!dojo._hasResource["dojo.data.util.simpleFetch"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.data.util.simpleFetch"] = true;
dojo.provide("dojo.data.util.simpleFetch");


dojo.data.util.simpleFetch.fetch = function(/* Object? */ request){
	//	summary:
	//		The simpleFetch mixin is designed to serve as a set of function(s) that can
	//		be mixed into other datastore implementations to accelerate their development.  
	//		The simpleFetch mixin should work well for any datastore that can respond to a _fetchItems() 
	//		call by returning an array of all the found items that matched the query.  The simpleFetch mixin
	//		is not designed to work for datastores that respond to a fetch() call by incrementally
	//		loading items, or sequentially loading partial batches of the result
	//		set.  For datastores that mixin simpleFetch, simpleFetch 
	//		implements a fetch method that automatically handles eight of the fetch()
	//		arguments -- onBegin, onItem, onComplete, onError, start, count, sort and scope
	//		The class mixing in simpleFetch should not implement fetch(),
	//		but should instead implement a _fetchItems() method.  The _fetchItems() 
	//		method takes three arguments, the keywordArgs object that was passed 
	//		to fetch(), a callback function to be called when the result array is
	//		available, and an error callback to be called if something goes wrong.
	//		The _fetchItems() method should ignore any keywordArgs parameters for
	//		start, count, onBegin, onItem, onComplete, onError, sort, and scope.  
	//		The _fetchItems() method needs to correctly handle any other keywordArgs
	//		parameters, including the query parameter and any optional parameters 
	//		(such as includeChildren).  The _fetchItems() method should create an array of 
	//		result items and pass it to the fetchHandler along with the original request object 
	//		-- or, the _fetchItems() method may, if it wants to, create an new request object 
	//		with other specifics about the request that are specific to the datastore and pass 
	//		that as the request object to the handler.
	//
	//		For more information on this specific function, see dojo.data.api.Read.fetch()
	request = request || {};
	if(!request.store){
		request.store = this;
	}
	var self = this;

	var _errorHandler = function(errorData, requestObject){
		if(requestObject.onError){
			var scope = requestObject.scope || dojo.global;
			requestObject.onError.call(scope, errorData, requestObject);
		}
	};

	var _fetchHandler = function(items, requestObject){
		var oldAbortFunction = requestObject.abort || null;
		var aborted = false;

		var startIndex = requestObject.start?requestObject.start:0;
		var endIndex   = (requestObject.count && (requestObject.count !== Infinity))?(startIndex + requestObject.count):items.length;

		requestObject.abort = function(){
			aborted = true;
			if(oldAbortFunction){
				oldAbortFunction.call(requestObject);
			}
		};

		var scope = requestObject.scope || dojo.global;
		if(!requestObject.store){
			requestObject.store = self;
		}
		if(requestObject.onBegin){
			requestObject.onBegin.call(scope, items.length, requestObject);
		}
		if(requestObject.sort){
			items.sort(dojo.data.util.sorter.createSortFunction(requestObject.sort, self));
		}
		if(requestObject.onItem){
			for(var i = startIndex; (i < items.length) && (i < endIndex); ++i){
				var item = items[i];
				if(!aborted){
					requestObject.onItem.call(scope, item, requestObject);
				}
			}
		}
		if(requestObject.onComplete && !aborted){
			var subset = null;
			if (!requestObject.onItem) {
				subset = items.slice(startIndex, endIndex);
			}
			requestObject.onComplete.call(scope, subset, requestObject);   
		}
	};
	this._fetchItems(request, _fetchHandler, _errorHandler);
	return request;	// Object
};

}

if(!dojo._hasResource["dojo.date.stamp"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.date.stamp"] = true;
dojo.provide("dojo.date.stamp");

// Methods to convert dates to or from a wire (string) format using well-known conventions

dojo.date.stamp.fromISOString = function(/*String*/formattedString, /*Number?*/defaultTime){
	//	summary:
	//		Returns a Date object given a string formatted according to a subset of the ISO-8601 standard.
	//
	//	description:
	//		Accepts a string formatted according to a profile of ISO8601 as defined by
	//		[RFC3339](http://www.ietf.org/rfc/rfc3339.txt), except that partial input is allowed.
	//		Can also process dates as specified [by the W3C](http://www.w3.org/TR/NOTE-datetime)
	//		The following combinations are valid:
	//
	//			* dates only
	//			|	* yyyy
	//			|	* yyyy-MM
	//			|	* yyyy-MM-dd
	// 			* times only, with an optional time zone appended
	//			|	* THH:mm
	//			|	* THH:mm:ss
	//			|	* THH:mm:ss.SSS
	// 			* and "datetimes" which could be any combination of the above
	//
	//		timezones may be specified as Z (for UTC) or +/- followed by a time expression HH:mm
	//		Assumes the local time zone if not specified.  Does not validate.  Improperly formatted
	//		input may return null.  Arguments which are out of bounds will be handled
	// 		by the Date constructor (e.g. January 32nd typically gets resolved to February 1st)
	//		Only years between 100 and 9999 are supported.
	//
  	//	formattedString:
	//		A string such as 2005-06-30T08:05:00-07:00 or 2005-06-30 or T08:05:00
	//
	//	defaultTime:
	//		Used for defaults for fields omitted in the formattedString.
	//		Uses 1970-01-01T00:00:00.0Z by default.

	if(!dojo.date.stamp._isoRegExp){
		dojo.date.stamp._isoRegExp =
//TODO: could be more restrictive and check for 00-59, etc.
			/^(?:(\d{4})(?:-(\d{2})(?:-(\d{2}))?)?)?(?:T(\d{2}):(\d{2})(?::(\d{2})(.\d+)?)?((?:[+-](\d{2}):(\d{2}))|Z)?)?$/;
	}

	var match = dojo.date.stamp._isoRegExp.exec(formattedString);
	var result = null;

	if(match){
		match.shift();
		if(match[1]){match[1]--;} // Javascript Date months are 0-based
		if(match[6]){match[6] *= 1000;} // Javascript Date expects fractional seconds as milliseconds

		if(defaultTime){
			// mix in defaultTime.  Relatively expensive, so use || operators for the fast path of defaultTime === 0
			defaultTime = new Date(defaultTime);
			dojo.map(["FullYear", "Month", "Date", "Hours", "Minutes", "Seconds", "Milliseconds"], function(prop){
				return defaultTime["get" + prop]();
			}).forEach(function(value, index){
				if(match[index] === undefined){
					match[index] = value;
				}
			});
		}
		result = new Date(match[0]||1970, match[1]||0, match[2]||1, match[3]||0, match[4]||0, match[5]||0, match[6]||0);
//		result.setFullYear(match[0]||1970); // for year < 100

		var offset = 0;
		var zoneSign = match[7] && match[7].charAt(0);
		if(zoneSign != 'Z'){
			offset = ((match[8] || 0) * 60) + (Number(match[9]) || 0);
			if(zoneSign != '-'){ offset *= -1; }
		}
		if(zoneSign){
			offset -= result.getTimezoneOffset();
		}
		if(offset){
			result.setTime(result.getTime() + offset * 60000);
		}
	}

	return result; // Date or null
}

/*=====
	dojo.date.stamp.__Options = function(){
		//	selector: String
		//		"date" or "time" for partial formatting of the Date object.
		//		Both date and time will be formatted by default.
		//	zulu: Boolean
		//		if true, UTC/GMT is used for a timezone
		//	milliseconds: Boolean
		//		if true, output milliseconds
		this.selector = selector;
		this.zulu = zulu;
		this.milliseconds = milliseconds;
	}
=====*/

dojo.date.stamp.toISOString = function(/*Date*/dateObject, /*dojo.date.stamp.__Options?*/options){
	//	summary:
	//		Format a Date object as a string according a subset of the ISO-8601 standard
	//
	//	description:
	//		When options.selector is omitted, output follows [RFC3339](http://www.ietf.org/rfc/rfc3339.txt)
	//		The local time zone is included as an offset from GMT, except when selector=='time' (time without a date)
	//		Does not check bounds.  Only years between 100 and 9999 are supported.
	//
	//	dateObject:
	//		A Date object

	var _ = function(n){ return (n < 10) ? "0" + n : n; };
	options = options || {};
	var formattedDate = [];
	var getter = options.zulu ? "getUTC" : "get";
	var date = "";
	if(options.selector != "time"){
		var year = dateObject[getter+"FullYear"]();
		date = ["0000".substr((year+"").length)+year, _(dateObject[getter+"Month"]()+1), _(dateObject[getter+"Date"]())].join('-');
	}
	formattedDate.push(date);
	if(options.selector != "date"){
		var time = [_(dateObject[getter+"Hours"]()), _(dateObject[getter+"Minutes"]()), _(dateObject[getter+"Seconds"]())].join(':');
		var millis = dateObject[getter+"Milliseconds"]();
		if(options.milliseconds){
			time += "."+ (millis < 100 ? "0" : "") + _(millis);
		}
		if(options.zulu){
			time += "Z";
		}else if(options.selector != "time"){
			var timezoneOffset = dateObject.getTimezoneOffset();
			var absOffset = Math.abs(timezoneOffset);
			time += (timezoneOffset > 0 ? "-" : "+") + 
				_(Math.floor(absOffset/60)) + ":" + _(absOffset%60);
		}
		formattedDate.push(time);
	}
	return formattedDate.join('T'); // String
}

}

if(!dojo._hasResource["dojo.data.ItemFileReadStore"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.data.ItemFileReadStore"] = true;
dojo.provide("dojo.data.ItemFileReadStore");





dojo.declare("dojo.data.ItemFileReadStore", null,{
	//	summary:
	//		The ItemFileReadStore implements the dojo.data.api.Read API and reads
	//		data from JSON files that have contents in this format --
	//		{ items: [
	//			{ name:'Kermit', color:'green', age:12, friends:['Gonzo', {_reference:{name:'Fozzie Bear'}}]},
	//			{ name:'Fozzie Bear', wears:['hat', 'tie']},
	//			{ name:'Miss Piggy', pets:'Foo-Foo'}
	//		]}
	//		Note that it can also contain an 'identifer' property that specified which attribute on the items 
	//		in the array of items that acts as the unique identifier for that item.
	//
	constructor: function(/* Object */ keywordParameters){
		//	summary: constructor
		//	keywordParameters: {url: String}
		//	keywordParameters: {data: jsonObject}
		//	keywordParameters: {typeMap: object)
		//		The structure of the typeMap object is as follows:
		//		{
		//			type0: function || object,
		//			type1: function || object,
		//			...
		//			typeN: function || object
		//		}
		//		Where if it is a function, it is assumed to be an object constructor that takes the 
		//		value of _value as the initialization parameters.  If it is an object, then it is assumed
		//		to be an object of general form:
		//		{
		//			type: function, //constructor.
		//			deserialize:	function(value) //The function that parses the value and constructs the object defined by type appropriately.
		//		}
	
		this._arrayOfAllItems = [];
		this._arrayOfTopLevelItems = [];
		this._loadFinished = false;
		this._jsonFileUrl = keywordParameters.url;
		this._jsonData = keywordParameters.data;
		this._datatypeMap = keywordParameters.typeMap || {};
		if(!this._datatypeMap['Date']){
			//If no default mapping for dates, then set this as default.
			//We use the dojo.date.stamp here because the ISO format is the 'dojo way'
			//of generically representing dates.
			this._datatypeMap['Date'] = {
											type: Date,
											deserialize: function(value){
												return dojo.date.stamp.fromISOString(value);
											}
										};
		}
		this._features = {'dojo.data.api.Read':true, 'dojo.data.api.Identity':true};
		this._itemsByIdentity = null;
		this._storeRefPropName = "_S";  // Default name for the store reference to attach to every item.
		this._itemNumPropName = "_0"; // Default Item Id for isItem to attach to every item.
		this._rootItemPropName = "_RI"; // Default Item Id for isItem to attach to every item.
		this._reverseRefMap = "_RRM"; // Default attribute for constructing a reverse reference map for use with reference integrity
		this._loadInProgress = false;	//Got to track the initial load to prevent duelling loads of the dataset.
		this._queuedFetches = [];
		if(keywordParameters.urlPreventCache !== undefined){
			this.urlPreventCache = keywordParameters.urlPreventCache?true:false;
		}
		if(keywordParameters.clearOnClose){
			this.clearOnClose = true;
		}
	},
	
	url: "",	// use "" rather than undefined for the benefit of the parser (#3539)

	data: null,	// define this so that the parser can populate it

	typeMap: null, //Define so parser can populate.
	
	//Parameter to allow users to specify if a close call should force a reload or not.
	//By default, it retains the old behavior of not clearing if close is called.  But
	//if set true, the store will be reset to default state.  Note that by doing this,
	//all item handles will become invalid and a new fetch must be issued.
	clearOnClose: false,

	//Parameter to allow specifying if preventCache should be passed to the xhrGet call or not when loading data from a url.  
	//Note this does not mean the store calls the server on each fetch, only that the data load has preventCache set as an option.
	//Added for tracker: #6072
	urlPreventCache: false,  

	_assertIsItem: function(/* item */ item){
		//	summary:
		//		This function tests whether the item passed in is indeed an item in the store.
		//	item: 
		//		The item to test for being contained by the store.
		if(!this.isItem(item)){ 
			throw new Error("dojo.data.ItemFileReadStore: Invalid item argument.");
		}
	},

	_assertIsAttribute: function(/* attribute-name-string */ attribute){
		//	summary:
		//		This function tests whether the item passed in is indeed a valid 'attribute' like type for the store.
		//	attribute: 
		//		The attribute to test for being contained by the store.
		if(typeof attribute !== "string"){ 
			throw new Error("dojo.data.ItemFileReadStore: Invalid attribute argument.");
		}
	},

	getValue: function(	/* item */ item, 
						/* attribute-name-string */ attribute, 
						/* value? */ defaultValue){
		//	summary: 
		//		See dojo.data.api.Read.getValue()
		var values = this.getValues(item, attribute);
		return (values.length > 0)?values[0]:defaultValue; // mixed
	},

	getValues: function(/* item */ item, 
						/* attribute-name-string */ attribute){
		//	summary: 
		//		See dojo.data.api.Read.getValues()

		this._assertIsItem(item);
		this._assertIsAttribute(attribute);
		return item[attribute] || []; // Array
	},

	getAttributes: function(/* item */ item){
		//	summary: 
		//		See dojo.data.api.Read.getAttributes()
		this._assertIsItem(item);
		var attributes = [];
		for(var key in item){
			// Save off only the real item attributes, not the special id marks for O(1) isItem.
			if((key !== this._storeRefPropName) && (key !== this._itemNumPropName) && (key !== this._rootItemPropName) && (key !== this._reverseRefMap)){
				attributes.push(key);
			}
		}
		return attributes; // Array
	},

	hasAttribute: function(	/* item */ item,
							/* attribute-name-string */ attribute) {
		//	summary: 
		//		See dojo.data.api.Read.hasAttribute()
		return this.getValues(item, attribute).length > 0;
	},

	containsValue: function(/* item */ item, 
							/* attribute-name-string */ attribute, 
							/* anything */ value){
		//	summary: 
		//		See dojo.data.api.Read.containsValue()
		var regexp = undefined;
		if(typeof value === "string"){
			regexp = dojo.data.util.filter.patternToRegExp(value, false);
		}
		return this._containsValue(item, attribute, value, regexp); //boolean.
	},

	_containsValue: function(	/* item */ item, 
								/* attribute-name-string */ attribute, 
								/* anything */ value,
								/* RegExp?*/ regexp){
		//	summary: 
		//		Internal function for looking at the values contained by the item.
		//	description: 
		//		Internal function for looking at the values contained by the item.  This 
		//		function allows for denoting if the comparison should be case sensitive for
		//		strings or not (for handling filtering cases where string case should not matter)
		//	
		//	item:
		//		The data item to examine for attribute values.
		//	attribute:
		//		The attribute to inspect.
		//	value:	
		//		The value to match.
		//	regexp:
		//		Optional regular expression generated off value if value was of string type to handle wildcarding.
		//		If present and attribute values are string, then it can be used for comparison instead of 'value'
		return dojo.some(this.getValues(item, attribute), function(possibleValue){
			if(possibleValue !== null && !dojo.isObject(possibleValue) && regexp){
				if(possibleValue.toString().match(regexp)){
					return true; // Boolean
				}
			}else if(value === possibleValue){
				return true; // Boolean
			}
		});
	},

	isItem: function(/* anything */ something){
		//	summary: 
		//		See dojo.data.api.Read.isItem()
		if(something && something[this._storeRefPropName] === this){
			if(this._arrayOfAllItems[something[this._itemNumPropName]] === something){
				return true;
			}
		}
		return false; // Boolean
	},

	isItemLoaded: function(/* anything */ something){
		//	summary: 
		//		See dojo.data.api.Read.isItemLoaded()
		return this.isItem(something); //boolean
	},

	loadItem: function(/* object */ keywordArgs){
		//	summary: 
		//		See dojo.data.api.Read.loadItem()
		this._assertIsItem(keywordArgs.item);
	},

	getFeatures: function(){
		//	summary: 
		//		See dojo.data.api.Read.getFeatures()
		return this._features; //Object
	},

	getLabel: function(/* item */ item){
		//	summary: 
		//		See dojo.data.api.Read.getLabel()
		if(this._labelAttr && this.isItem(item)){
			return this.getValue(item,this._labelAttr); //String
		}
		return undefined; //undefined
	},

	getLabelAttributes: function(/* item */ item){
		//	summary: 
		//		See dojo.data.api.Read.getLabelAttributes()
		if(this._labelAttr){
			return [this._labelAttr]; //array
		}
		return null; //null
	},

	_fetchItems: function(	/* Object */ keywordArgs, 
							/* Function */ findCallback, 
							/* Function */ errorCallback){
		//	summary: 
		//		See dojo.data.util.simpleFetch.fetch()
		var self = this;
		var filter = function(requestArgs, arrayOfItems){
			var items = [];
			var i, key;
			if(requestArgs.query){
				var value;
				var ignoreCase = requestArgs.queryOptions ? requestArgs.queryOptions.ignoreCase : false; 

				//See if there are any string values that can be regexp parsed first to avoid multiple regexp gens on the
				//same value for each item examined.  Much more efficient.
				var regexpList = {};
				for(key in requestArgs.query){
					value = requestArgs.query[key];
					if(typeof value === "string"){
						regexpList[key] = dojo.data.util.filter.patternToRegExp(value, ignoreCase);
					}
				}

				for(i = 0; i < arrayOfItems.length; ++i){
					var match = true;
					var candidateItem = arrayOfItems[i];
					if(candidateItem === null){
						match = false;
					}else{
						for(key in requestArgs.query) {
							value = requestArgs.query[key];
							if (!self._containsValue(candidateItem, key, value, regexpList[key])){
								match = false;
							}
						}
					}
					if(match){
						items.push(candidateItem);
					}
				}
				findCallback(items, requestArgs);
			}else{
				// We want a copy to pass back in case the parent wishes to sort the array. 
				// We shouldn't allow resort of the internal list, so that multiple callers 
				// can get lists and sort without affecting each other.  We also need to
				// filter out any null values that have been left as a result of deleteItem()
				// calls in ItemFileWriteStore.
				for(i = 0; i < arrayOfItems.length; ++i){
					var item = arrayOfItems[i];
					if(item !== null){
						items.push(item);
					}
				}
				findCallback(items, requestArgs);
			}
		};

		if(this._loadFinished){
			filter(keywordArgs, this._getItemsArray(keywordArgs.queryOptions));
		}else{

			if(this._jsonFileUrl){
				//If fetches come in before the loading has finished, but while
				//a load is in progress, we have to defer the fetching to be 
				//invoked in the callback.
				if(this._loadInProgress){
					this._queuedFetches.push({args: keywordArgs, filter: filter});
				}else{
					this._loadInProgress = true;
					var getArgs = {
							url: self._jsonFileUrl, 
							handleAs: "json-comment-optional",
							preventCache: this.urlPreventCache
						};
					var getHandler = dojo.xhrGet(getArgs);
					getHandler.addCallback(function(data){
						try{
							self._getItemsFromLoadedData(data);
							self._loadFinished = true;
							self._loadInProgress = false;
							
							filter(keywordArgs, self._getItemsArray(keywordArgs.queryOptions));
							self._handleQueuedFetches();
						}catch(e){
							self._loadFinished = true;
							self._loadInProgress = false;
							errorCallback(e, keywordArgs);
						}
					});
					getHandler.addErrback(function(error){
						self._loadInProgress = false;
						errorCallback(error, keywordArgs);
					});

					//Wire up the cancel to abort of the request
					//This call cancel on the deferred if it hasn't been called
					//yet and then will chain to the simple abort of the
					//simpleFetch keywordArgs
					var oldAbort = null;
					if(keywordArgs.abort){
						oldAbort = keywordArgs.abort;
					}
					keywordArgs.abort = function(){
						var df = getHandler;
						if (df && df.fired === -1){
							df.cancel();
							df = null;
						}
						if(oldAbort){
							oldAbort.call(keywordArgs);
						}
					};
				}
			}else if(this._jsonData){
				try{
					this._loadFinished = true;
					this._getItemsFromLoadedData(this._jsonData);
					this._jsonData = null;
					filter(keywordArgs, this._getItemsArray(keywordArgs.queryOptions));
				}catch(e){
					errorCallback(e, keywordArgs);
				}
			}else{
				errorCallback(new Error("dojo.data.ItemFileReadStore: No JSON source data was provided as either URL or a nested Javascript object."), keywordArgs);
			}
		}
	},

	_handleQueuedFetches: function(){
		//	summary: 
		//		Internal function to execute delayed request in the store.
		//Execute any deferred fetches now.
		if (this._queuedFetches.length > 0) {
			for(var i = 0; i < this._queuedFetches.length; i++){
				var fData = this._queuedFetches[i];
				var delayedQuery = fData.args;
				var delayedFilter = fData.filter;
				if(delayedFilter){
					delayedFilter(delayedQuery, this._getItemsArray(delayedQuery.queryOptions)); 
				}else{
					this.fetchItemByIdentity(delayedQuery);
				}
			}
			this._queuedFetches = [];
		}
	},

	_getItemsArray: function(/*object?*/queryOptions){
		//	summary: 
		//		Internal function to determine which list of items to search over.
		//	queryOptions: The query options parameter, if any.
		if(queryOptions && queryOptions.deep) {
			return this._arrayOfAllItems; 
		}
		return this._arrayOfTopLevelItems;
	},

	close: function(/*dojo.data.api.Request || keywordArgs || null */ request){
		 //	summary: 
		 //		See dojo.data.api.Read.close()
		 if(this.clearOnClose && (this._jsonFileUrl !== "")){
			 //Reset all internalsback to default state.  This will force a reload
			 //on next fetch, but only if the data came from a url.  Passed in data
			 //means it should not clear the data.
			 this._arrayOfAllItems = [];
			 this._arrayOfTopLevelItems = [];
			 this._loadFinished = false;
			 this._itemsByIdentity = null;
			 this._loadInProgress = false;
			 this._queuedFetches = [];
		 }
	},

	_getItemsFromLoadedData: function(/* Object */ dataObject){
		//	summary:
		//		Function to parse the loaded data into item format and build the internal items array.
		//	description:
		//		Function to parse the loaded data into item format and build the internal items array.
		//
		//	dataObject:
		//		The JS data object containing the raw data to convery into item format.
		//
		// 	returns: array
		//		Array of items in store item format.
		
		// First, we define a couple little utility functions...
		var addingArrays = false;
		
		function valueIsAnItem(/* anything */ aValue){
			// summary:
			//		Given any sort of value that could be in the raw json data,
			//		return true if we should interpret the value as being an
			//		item itself, rather than a literal value or a reference.
			// example:
			// 	|	false == valueIsAnItem("Kermit");
			// 	|	false == valueIsAnItem(42);
			// 	|	false == valueIsAnItem(new Date());
			// 	|	false == valueIsAnItem({_type:'Date', _value:'May 14, 1802'});
			// 	|	false == valueIsAnItem({_reference:'Kermit'});
			// 	|	true == valueIsAnItem({name:'Kermit', color:'green'});
			// 	|	true == valueIsAnItem({iggy:'pop'});
			// 	|	true == valueIsAnItem({foo:42});
			var isItem = (
				(aValue !== null) &&
				(typeof aValue === "object") &&
				(!dojo.isArray(aValue) || addingArrays) &&
				(!dojo.isFunction(aValue)) &&
				(aValue.constructor == Object || dojo.isArray(aValue)) &&
				(typeof aValue._reference === "undefined") && 
				(typeof aValue._type === "undefined") && 
				(typeof aValue._value === "undefined")
			);
			return isItem;
		}
		
		var self = this;
		function addItemAndSubItemsToArrayOfAllItems(/* Item */ anItem){
			self._arrayOfAllItems.push(anItem);
			for(var attribute in anItem){
				var valueForAttribute = anItem[attribute];
				if(valueForAttribute){
					if(dojo.isArray(valueForAttribute)){
						var valueArray = valueForAttribute;
						for(var k = 0; k < valueArray.length; ++k){
							var singleValue = valueArray[k];
							if(valueIsAnItem(singleValue)){
								addItemAndSubItemsToArrayOfAllItems(singleValue);
							}
						}
					}else{
						if(valueIsAnItem(valueForAttribute)){
							addItemAndSubItemsToArrayOfAllItems(valueForAttribute);
						}
					}
				}
			}
		}

		this._labelAttr = dataObject.label;

		// We need to do some transformations to convert the data structure
		// that we read from the file into a format that will be convenient
		// to work with in memory.

		// Step 1: Walk through the object hierarchy and build a list of all items
		var i;
		var item;
		this._arrayOfAllItems = [];
		this._arrayOfTopLevelItems = dataObject.items;

		for(i = 0; i < this._arrayOfTopLevelItems.length; ++i){
			item = this._arrayOfTopLevelItems[i];
			if(dojo.isArray(item)){
				addingArrays = true;
			}
			addItemAndSubItemsToArrayOfAllItems(item);
			item[this._rootItemPropName]=true;
		}

		// Step 2: Walk through all the attribute values of all the items, 
		// and replace single values with arrays.  For example, we change this:
		//		{ name:'Miss Piggy', pets:'Foo-Foo'}
		// into this:
		//		{ name:['Miss Piggy'], pets:['Foo-Foo']}
		// 
		// We also store the attribute names so we can validate our store  
		// reference and item id special properties for the O(1) isItem
		var allAttributeNames = {};
		var key;

		for(i = 0; i < this._arrayOfAllItems.length; ++i){
			item = this._arrayOfAllItems[i];
			for(key in item){
				if (key !== this._rootItemPropName)
				{
					var value = item[key];
					if(value !== null){
						if(!dojo.isArray(value)){
							item[key] = [value];
						}
					}else{
						item[key] = [null];
					}
				}
				allAttributeNames[key]=key;
			}
		}

		// Step 3: Build unique property names to use for the _storeRefPropName and _itemNumPropName
		// This should go really fast, it will generally never even run the loop.
		while(allAttributeNames[this._storeRefPropName]){
			this._storeRefPropName += "_";
		}
		while(allAttributeNames[this._itemNumPropName]){
			this._itemNumPropName += "_";
		}
		while(allAttributeNames[this._reverseRefMap]){
			this._reverseRefMap += "_";
		}

		// Step 4: Some data files specify an optional 'identifier', which is 
		// the name of an attribute that holds the identity of each item. 
		// If this data file specified an identifier attribute, then build a 
		// hash table of items keyed by the identity of the items.
		var arrayOfValues;

		var identifier = dataObject.identifier;
		if(identifier){
			this._itemsByIdentity = {};
			this._features['dojo.data.api.Identity'] = identifier;
			for(i = 0; i < this._arrayOfAllItems.length; ++i){
				item = this._arrayOfAllItems[i];
				arrayOfValues = item[identifier];
				var identity = arrayOfValues[0];
				if(!this._itemsByIdentity[identity]){
					this._itemsByIdentity[identity] = item;
				}else{
					if(this._jsonFileUrl){
						throw new Error("dojo.data.ItemFileReadStore:  The json data as specified by: [" + this._jsonFileUrl + "] is malformed.  Items within the list have identifier: [" + identifier + "].  Value collided: [" + identity + "]");
					}else if(this._jsonData){
						throw new Error("dojo.data.ItemFileReadStore:  The json data provided by the creation arguments is malformed.  Items within the list have identifier: [" + identifier + "].  Value collided: [" + identity + "]");
					}
				}
			}
		}else{
			this._features['dojo.data.api.Identity'] = Number;
		}

		// Step 5: Walk through all the items, and set each item's properties 
		// for _storeRefPropName and _itemNumPropName, so that store.isItem() will return true.
		for(i = 0; i < this._arrayOfAllItems.length; ++i){
			item = this._arrayOfAllItems[i];
			item[this._storeRefPropName] = this;
			item[this._itemNumPropName] = i;
		}

		// Step 6: We walk through all the attribute values of all the items,
		// looking for type/value literals and item-references.
		//
		// We replace item-references with pointers to items.  For example, we change:
		//		{ name:['Kermit'], friends:[{_reference:{name:'Miss Piggy'}}] }
		// into this:
		//		{ name:['Kermit'], friends:[miss_piggy] } 
		// (where miss_piggy is the object representing the 'Miss Piggy' item).
		//
		// We replace type/value pairs with typed-literals.  For example, we change:
		//		{ name:['Nelson Mandela'], born:[{_type:'Date', _value:'July 18, 1918'}] }
		// into this:
		//		{ name:['Kermit'], born:(new Date('July 18, 1918')) } 
		//
		// We also generate the associate map for all items for the O(1) isItem function.
		for(i = 0; i < this._arrayOfAllItems.length; ++i){
			item = this._arrayOfAllItems[i]; // example: { name:['Kermit'], friends:[{_reference:{name:'Miss Piggy'}}] }
			for(key in item){
				arrayOfValues = item[key]; // example: [{_reference:{name:'Miss Piggy'}}]
				for(var j = 0; j < arrayOfValues.length; ++j) {
					value = arrayOfValues[j]; // example: {_reference:{name:'Miss Piggy'}}
					if(value !== null && typeof value == "object"){
						if(value._type && value._value){
							var type = value._type; // examples: 'Date', 'Color', or 'ComplexNumber'
							var mappingObj = this._datatypeMap[type]; // examples: Date, dojo.Color, foo.math.ComplexNumber, {type: dojo.Color, deserialize(value){ return new dojo.Color(value)}}
							if(!mappingObj){ 
								throw new Error("dojo.data.ItemFileReadStore: in the typeMap constructor arg, no object class was specified for the datatype '" + type + "'");
							}else if(dojo.isFunction(mappingObj)){
								arrayOfValues[j] = new mappingObj(value._value);
							}else if(dojo.isFunction(mappingObj.deserialize)){
								arrayOfValues[j] = mappingObj.deserialize(value._value);
							}else{
								throw new Error("dojo.data.ItemFileReadStore: Value provided in typeMap was neither a constructor, nor a an object with a deserialize function");
							}
						}
						if(value._reference){
							var referenceDescription = value._reference; // example: {name:'Miss Piggy'}
							if(!dojo.isObject(referenceDescription)){
								// example: 'Miss Piggy'
								// from an item like: { name:['Kermit'], friends:[{_reference:'Miss Piggy'}]}
								arrayOfValues[j] = this._itemsByIdentity[referenceDescription];
							}else{
								// example: {name:'Miss Piggy'}
								// from an item like: { name:['Kermit'], friends:[{_reference:{name:'Miss Piggy'}}] }
								for(var k = 0; k < this._arrayOfAllItems.length; ++k){
									var candidateItem = this._arrayOfAllItems[k];
									var found = true;
									for(var refKey in referenceDescription){
										if(candidateItem[refKey] != referenceDescription[refKey]){ 
											found = false; 
										}
									}
									if(found){ 
										arrayOfValues[j] = candidateItem; 
									}
								}
							}
							if(this.referenceIntegrity){
								var refItem = arrayOfValues[j];
								if(this.isItem(refItem)){
									this._addReferenceToMap(refItem, item, key);
								}
							}
						}else if(this.isItem(value)){
							//It's a child item (not one referenced through _reference).  
							//We need to treat this as a referenced item, so it can be cleaned up
							//in a write store easily.
							if(this.referenceIntegrity){
								this._addReferenceToMap(value, item, key);
							}
						}
					}
				}
			}
		}
	},

	_addReferenceToMap: function(/*item*/ refItem, /*item*/ parentItem, /*string*/ attribute){
		 //	summary:
		 //		Method to add an reference map entry for an item and attribute.
		 //	description:
		 //		Method to add an reference map entry for an item and attribute. 		 //
		 //	refItem:
		 //		The item that is referenced.
		 //	parentItem:
		 //		The item that holds the new reference to refItem.
		 //	attribute:
		 //		The attribute on parentItem that contains the new reference.
		 
		 //Stub function, does nothing.  Real processing is in ItemFileWriteStore.
	},

	getIdentity: function(/* item */ item){
		//	summary: 
		//		See dojo.data.api.Identity.getIdentity()
		var identifier = this._features['dojo.data.api.Identity'];
		if(identifier === Number){
			return item[this._itemNumPropName]; // Number
		}else{
			var arrayOfValues = item[identifier];
			if(arrayOfValues){
				return arrayOfValues[0]; // Object || String
			}
		}
		return null; // null
	},

	fetchItemByIdentity: function(/* Object */ keywordArgs){
		//	summary: 
		//		See dojo.data.api.Identity.fetchItemByIdentity()

		// Hasn't loaded yet, we have to trigger the load.
		var item;
		var scope;
		if(!this._loadFinished){
			var self = this;
			if(this._jsonFileUrl){

				if(this._loadInProgress){
					this._queuedFetches.push({args: keywordArgs});
				}else{
					this._loadInProgress = true;
					var getArgs = {
							url: self._jsonFileUrl, 
							handleAs: "json-comment-optional",
							preventCache: this.urlPreventCache
					};
					var getHandler = dojo.xhrGet(getArgs);
					getHandler.addCallback(function(data){
						var scope =  keywordArgs.scope?keywordArgs.scope:dojo.global;
						try{
							self._getItemsFromLoadedData(data);
							self._loadFinished = true;
							self._loadInProgress = false;
							item = self._getItemByIdentity(keywordArgs.identity);
							if(keywordArgs.onItem){
								keywordArgs.onItem.call(scope, item);
							}
							self._handleQueuedFetches();
						}catch(error){
							self._loadInProgress = false;
							if(keywordArgs.onError){
								keywordArgs.onError.call(scope, error);
							}
						}
					});
					getHandler.addErrback(function(error){
						self._loadInProgress = false;
						if(keywordArgs.onError){
							var scope =  keywordArgs.scope?keywordArgs.scope:dojo.global;
							keywordArgs.onError.call(scope, error);
						}
					});
				}

			}else if(this._jsonData){
				// Passed in data, no need to xhr.
				self._getItemsFromLoadedData(self._jsonData);
				self._jsonData = null;
				self._loadFinished = true;
				item = self._getItemByIdentity(keywordArgs.identity);
				if(keywordArgs.onItem){
					scope =  keywordArgs.scope?keywordArgs.scope:dojo.global;
					keywordArgs.onItem.call(scope, item);
				}
			} 
		}else{
			// Already loaded.  We can just look it up and call back.
			item = this._getItemByIdentity(keywordArgs.identity);
			if(keywordArgs.onItem){
				scope =  keywordArgs.scope?keywordArgs.scope:dojo.global;
				keywordArgs.onItem.call(scope, item);
			}
		}
	},

	_getItemByIdentity: function(/* Object */ identity){
		//	summary:
		//		Internal function to look an item up by its identity map.
		var item = null;
		if(this._itemsByIdentity){
			item = this._itemsByIdentity[identity];
		}else{
			item = this._arrayOfAllItems[identity];
		}
		if(item === undefined){
			item = null;
		}
		return item; // Object
	},

	getIdentityAttributes: function(/* item */ item){
		//	summary: 
		//		See dojo.data.api.Identity.getIdentifierAttributes()
		 
		var identifier = this._features['dojo.data.api.Identity'];
		if(identifier === Number){
			// If (identifier === Number) it means getIdentity() just returns
			// an integer item-number for each item.  The dojo.data.api.Identity
			// spec says we need to return null if the identity is not composed 
			// of attributes 
			return null; // null
		}else{
			return [identifier]; // Array
		}
	},
	
	_forceLoad: function(){
		//	summary: 
		//		Internal function to force a load of the store if it hasn't occurred yet.  This is required
		//		for specific functions to work properly.  
		var self = this;
		if(this._jsonFileUrl){
				var getArgs = {
					url: self._jsonFileUrl, 
					handleAs: "json-comment-optional",
					preventCache: this.urlPreventCache,
					sync: true
				};
			var getHandler = dojo.xhrGet(getArgs);
			getHandler.addCallback(function(data){
				try{
					//Check to be sure there wasn't another load going on concurrently 
					//So we don't clobber data that comes in on it.  If there is a load going on
					//then do not save this data.  It will potentially clobber current data.
					//We mainly wanted to sync/wait here.
					//TODO:  Revisit the loading scheme of this store to improve multi-initial
					//request handling.
					if(self._loadInProgress !== true && !self._loadFinished){
						self._getItemsFromLoadedData(data);
						self._loadFinished = true;
					}else if(self._loadInProgress){
						//Okay, we hit an error state we can't recover from.  A forced load occurred
						//while an async load was occurring.  Since we cannot block at this point, the best
						//that can be managed is to throw an error.
						throw new Error("dojo.data.ItemFileReadStore:  Unable to perform a synchronous load, an async load is in progress."); 
					}
				}catch(e){
					
					throw e;
				}
			});
			getHandler.addErrback(function(error){
				throw error;
			});
		}else if(this._jsonData){
			self._getItemsFromLoadedData(self._jsonData);
			self._jsonData = null;
			self._loadFinished = true;
		} 
	}
});
//Mix in the simple fetch implementation to this class.
dojo.extend(dojo.data.ItemFileReadStore,dojo.data.util.simpleFetch);

}

if(!dojo._hasResource["dojo.string"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.string"] = true;
dojo.provide("dojo.string");

/*=====
dojo.string = { 
	// summary: String utilities for Dojo
};
=====*/

dojo.string.rep = function(/*String*/str, /*Integer*/num){
	//	summary:
	//		Efficiently replicate a string `n` times.
	//	str:
	//		the string to replicate
	//	num:
	//		number of times to replicate the string
	
	if(num <= 0 || !str){ return ""; }
	
	var buf = [];
	for(;;){
		if(num & 1){
			buf.push(str);
		}
		if(!(num >>= 1)){ break; }
		str += str;
	}
	return buf.join("");	// String
};

dojo.string.pad = function(/*String*/text, /*Integer*/size, /*String?*/ch, /*Boolean?*/end){
	//	summary:
	//		Pad a string to guarantee that it is at least `size` length by
	//		filling with the character `ch` at either the start or end of the
	//		string. Pads at the start, by default.
	//	text:
	//		the string to pad
	//	size:
	//		length to provide padding
	//	ch:
	//		character to pad, defaults to '0'
	//	end:
	//		adds padding at the end if true, otherwise pads at start
	//	example:
	//	|	// Fill the string to length 10 with "+" characters on the right.  Yields "Dojo++++++".
	//	|	dojo.string.pad("Dojo", 10, "+", true);

	if(!ch){
		ch = '0';
	}
	var out = String(text),
		pad = dojo.string.rep(ch, Math.ceil((size - out.length) / ch.length));
	return end ? out + pad : pad + out;	// String
};

dojo.string.substitute = function(	/*String*/		template, 
									/*Object|Array*/map, 
									/*Function?*/	transform, 
									/*Object?*/		thisObject){
	//	summary:
	//		Performs parameterized substitutions on a string. Throws an
	//		exception if any parameter is unmatched.
	//	template: 
	//		a string with expressions in the form `${key}` to be replaced or
	//		`${key:format}` which specifies a format function. keys are case-sensitive. 
	//	map:
	//		hash to search for substitutions
	//	transform: 
	//		a function to process all parameters before substitution takes
	//		place, e.g. dojo.string.encodeXML
	//	thisObject: 
	//		where to look for optional format function; default to the global
	//		namespace
	//	example:
	//	|	// returns "File 'foo.html' is not found in directory '/temp'."
	//	|	dojo.string.substitute(
	//	|		"File '${0}' is not found in directory '${1}'.",
	//	|		["foo.html","/temp"]
	//	|	);
	//	|
	//	|	// also returns "File 'foo.html' is not found in directory '/temp'."
	//	|	dojo.string.substitute(
	//	|		"File '${name}' is not found in directory '${info.dir}'.",
	//	|		{ name: "foo.html", info: { dir: "/temp" } }
	//	|	);
	//	example:
	//		use a transform function to modify the values:
	//	|	// returns "file 'foo.html' is not found in directory '/temp'."
	//	|	dojo.string.substitute(
	//	|		"${0} is not found in ${1}.",
	//	|		["foo.html","/temp"],
	//	|		function(str){
	//	|			// try to figure out the type
	//	|			var prefix = (str.charAt(0) == "/") ? "directory": "file";
	//	|			return prefix + " '" + str + "'";
	//	|		}
	//	|	);
	//	example:
	//		use a formatter
	//	|	// returns "thinger -- howdy"
	//	|	dojo.string.substitute(
	//	|		"${0:postfix}", ["thinger"], null, {
	//	|			postfix: function(value, key){
	//	|				return value + " -- howdy";
	//	|			}
	//	|		}
	//	|	);

	thisObject = thisObject||dojo.global;
	transform = (!transform) ? 
					function(v){ return v; } : 
					dojo.hitch(thisObject, transform);

	return template.replace(/\$\{([^\s\:\}]+)(?:\:([^\s\:\}]+))?\}/g, function(match, key, format){
		var value = dojo.getObject(key, false, map);
		if(format){
			value = dojo.getObject(format, false, thisObject).call(thisObject, value, key);
		}
		return transform(value, key).toString();
	}); // string
};

/*=====
dojo.string.trim = function(str){
	//	summary:
	//		Trims whitespace from both sides of the string
	//	str: String
	//		String to be trimmed
	//	returns: String
	//		Returns the trimmed string
	//	description:
	//		This version of trim() was taken from [Steven Levithan's blog](http://blog.stevenlevithan.com/archives/faster-trim-javascript).
	//		The short yet performant version of this function is dojo.trim(),
	//		which is part of Dojo base.  Uses String.prototype.trim instead, if available.
	return "";	// String
}
=====*/

dojo.string.trim = String.prototype.trim ?
	dojo.trim : // aliasing to the native function
	function(str){
		str = str.replace(/^\s+/, '');
		for(var i = str.length - 1; i >= 0; i--){
			if(/\S/.test(str.charAt(i))){
				str = str.substring(0, i + 1);
				break;
			}
		}
		return str;
	};

}

if(!dojo._hasResource["dojox.xml.parser"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojox.xml.parser"] = true;
dojo.provide("dojox.xml.parser");

//DOM type to int value for reference.
//Ints make for more compact code than full constant names.
//ELEMENT_NODE                  = 1;
//ATTRIBUTE_NODE                = 2;
//TEXT_NODE                     = 3;
//CDATA_SECTION_NODE            = 4;
//ENTITY_REFERENCE_NODE         = 5;
//ENTITY_NODE                   = 6;
//PROCESSING_INSTRUCTION_NODE   = 7;
//COMMENT_NODE                  = 8;
//DOCUMENT_NODE                 = 9;
//DOCUMENT_TYPE_NODE            = 10;
//DOCUMENT_FRAGMENT_NODE        = 11;
//NOTATION_NODE                 = 12;

dojox.xml.parser.parse = function(/*String?*/ str, /*String?*/ mimetype){
	//	summary:
	//		cross-browser implementation of creating an XML document object from null, empty string, and XML text..
	//
	//	str:
	//		Optional text to create the document from.  If not provided, an empty XML document will be created.  
	//		If str is empty string "", then a new empty document will be created.
	//	mimetype:
	//		Optional mimetype of the text.  Typically, this is text/xml.  Will be defaulted to text/xml if not provided.
	var _document = dojo.doc;
	var doc;

	mimetype = mimetype || "text/xml";
	if(str && dojo.trim(str) && "DOMParser" in dojo.global){
		//Handle parsing the text on Mozilla based browsers etc..
		var parser = new DOMParser();
		doc = parser.parseFromString(str, mimetype);
		var de = doc.documentElement;
		var errorNS = "http://www.mozilla.org/newlayout/xml/parsererror.xml";
		if(de.nodeName == "parsererror" && de.namespaceURI == errorNS){
			var sourceText = de.getElementsByTagNameNS(errorNS, 'sourcetext')[0];
			if(!sourceText){
				sourceText = sourceText.firstChild.data;
			}
        	throw new Error("Error parsing text " + nativeDoc.documentElement.firstChild.data + " \n" + sourceText);
		}
		return doc;

	}else if("ActiveXObject" in dojo.global){
		//Handle IE.
		var ms = function(n){ return "MSXML" + n + ".DOMDocument"; };
		var dp = ["Microsoft.XMLDOM", ms(6), ms(4), ms(3), ms(2)];
		dojo.some(dp, function(p){
			try{
				doc = new ActiveXObject(p);
			}catch(e){ return false; }
			return true;
		});
		if(str && doc){
			doc.async = false;
			doc.loadXML(str);
			var pe = doc.parseError;
			if(pe.errorCode !== 0){
				throw new Error("Line: " + pe.line + "\n" +
					"Col: " + pe.linepos + "\n" +
					"Reason: " + pe.reason + "\n" + 
					"Error Code: " + pe.errorCode + "\n" +
					"Source: " + pe.srcText);
			}
		}
		if(doc){
			return doc; //DOMDocument
		}
	}else if(_document.implementation && _document.implementation.createDocument){
		if(str && dojo.trim(str) && _document.createElement){
			//Everyone else that we couldn't get to work.  Fallback case.
			// FIXME: this may change all tags to uppercase!
			var tmp = _document.createElement("xml");
			tmp.innerHTML = str;
			var xmlDoc = _document.implementation.createDocument("foo", "", null);
			dojo.forEach(tmp.childNodes, function(child){
				xmlDoc.importNode(child, true);
			});
			return xmlDoc;	//	DOMDocument
		}else{
			return _document.implementation.createDocument("", "", null); // DOMDocument
		}
	}
	return null;	//	null
}

dojox.xml.parser.textContent = function(/*Node*/node, /*String?*/text){
	//	summary:
	//		Implementation of the DOM Level 3 attribute; scan node for text
	//	description:
	//		Implementation of the DOM Level 3 attribute; scan node for text
	//		This function can also update the text of a node by replacing all child 
	//		content of the node.
	//	node:
	//		The node to get the text off of or set the text on.
	//	text:
	//		Optional argument of the text to apply to the node.
	if(arguments.length>1){
		var _document = node.ownerDocument || dojo.doc;  //Preference is to get the node owning doc first or it may fail
		dojox.xml.parser.replaceChildren(node, _document.createTextNode(text));
		return text;	//	String
	}else{
		if(node.textContent !== undefined){ //FF 1.5 -- remove?
			return node.textContent;	//	String
		}
		var _result = "";
		if(node){
			dojo.forEach(node.childNodes, function(child){
				switch(child.nodeType){
					case 1: // ELEMENT_NODE
					case 5: // ENTITY_REFERENCE_NODE
						_result += dojox.xml.parser.textContent(child);
						break;
					case 3: // TEXT_NODE
					case 2: // ATTRIBUTE_NODE
					case 4: // CDATA_SECTION_NODE
						_result += child.nodeValue;
				}
			});
		}
		return _result;	//	String
	}
}

dojox.xml.parser.replaceChildren = function(/*Element*/node, /*Node || Array*/ newChildren){
	//	summary:
	//		Removes all children of node and appends newChild. All the existing
	//		children will be destroyed.
	//	description:
	//		Removes all children of node and appends newChild. All the existing
	//		children will be destroyed.
	// 	node:
	//		The node to modify the children on
	//	newChildren:
	//		The children to add to the node.  It can either be a single Node or an
	//		array of Nodes.
	var nodes = [];

	if(dojo.isIE){
		dojo.forEach(node.childNodes, function(child){
			nodes.push(child);
		});
	}

	dojox.xml.parser.removeChildren(node);
	dojo.forEach(nodes, dojo.destroy);

	if(!dojo.isArray(newChildren)){
		node.appendChild(newChildren);
	}else{
		dojo.forEach(newChildren, function(child){
			node.appendChild(child);
		});
	}
}

dojox.xml.parser.removeChildren = function(/*Element*/node){
	//	summary:
	//		removes all children from node and returns the count of children removed.
	//		The children nodes are not destroyed. Be sure to call dojo.destroy on them
	//		after they are not used anymore.
	//	node:
	//		The node to remove all the children from.
	var count = node.childNodes.length;
	while(node.hasChildNodes()){
		node.removeChild(node.firstChild);
	}
	return count; // int
}


dojox.xml.parser.innerXML = function(/*Node*/node){
	//	summary:
	//		Implementation of MS's innerXML function.
	//	node:
	//		The node from which to generate the XML text representation.
	if(node.innerXML){
		return node.innerXML;	//	String
	}else if(node.xml){
		return node.xml;		//	String
	}else if(typeof XMLSerializer != "undefined"){
		return (new XMLSerializer()).serializeToString(node);	//	String
	}
	return null;
}

}

if(!dojo._hasResource["dojox.data.dom"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojox.data.dom"] = true;
dojo.provide("dojox.data.dom");


//DOM type to int value for reference.
//Ints make for more compact code than full constant names.
//ELEMENT_NODE                  = 1;
//ATTRIBUTE_NODE                = 2;
//TEXT_NODE                     = 3;
//CDATA_SECTION_NODE            = 4;
//ENTITY_REFERENCE_NODE         = 5;
//ENTITY_NODE                   = 6;
//PROCESSING_INSTRUCTION_NODE   = 7;
//COMMENT_NODE                  = 8;
//DOCUMENT_NODE                 = 9;
//DOCUMENT_TYPE_NODE            = 10;
//DOCUMENT_FRAGMENT_NODE        = 11;
//NOTATION_NODE                 = 12;

//This file contains internal/helper APIs as holders for people who used them.  They have been migrated to
//a better project, dojox.xml and experimental has been removed there.  Please update usage to the new package.
dojo.deprecated("dojox.data.dom", "Use dojox.xml.parser instead.", "2.0");

dojox.data.dom.createDocument = function(/*string?*/ str, /*string?*/ mimetype){
	//	summary:
	//		cross-browser implementation of creating an XML document object.
	//
	//	str:
	//		Optional text to create the document from.  If not provided, an empty XML document will be created.  
	//		If str is empty string "", then a new empty document will be created.
	//	mimetype:
	//		Optional mimetype of the text.  Typically, this is text/xml.  Will be defaulted to text/xml if not provided.
	dojo.deprecated("dojox.data.dom.createDocument()", "Use dojox.xml.parser.parse() instead.", "2.0");
	try{
		return dojox.xml.parser.parse(str,mimetype); //DOMDocument.
	}catch(e){
		/*Squeltch errors like the old parser did.*/
		return null;
	}
};

dojox.data.dom.textContent = function(/*Node*/node, /*string?*/text){
	//	summary:
	//		Implementation of the DOM Level 3 attribute; scan node for text
	//	description:
	//		Implementation of the DOM Level 3 attribute; scan node for text
	//		This function can also update the text of a node by replacing all child 
	//		content of the node.
	//	node:
	//		The node to get the text off of or set the text on.
	//	text:
	//		Optional argument of the text to apply to the node.
	dojo.deprecated("dojox.data.dom.textContent()", "Use dojox.xml.parser.textContent() instead.", "2.0");
	if(arguments.length> 1){
		return dojox.xml.parser.textContent(node, text); //string
	}else{
		return dojox.xml.parser.textContent(node); //string
	}
};

dojox.data.dom.replaceChildren = function(/*Element*/node, /*Node || array*/ newChildren){
	//	summary:
	//		Removes all children of node and appends newChild. All the existing
	//		children will be destroyed.
	//	description:
	//		Removes all children of node and appends newChild. All the existing
	//		children will be destroyed.
	// 	node:
	//		The node to modify the children on
	//	newChildren:
	//		The children to add to the node.  It can either be a single Node or an
	//		array of Nodes.
	dojo.deprecated("dojox.data.dom.replaceChildren()", "Use dojox.xml.parser.replaceChildren() instead.", "2.0");
	dojox.xml.parser.replaceChildren(node, newChildren);
};

dojox.data.dom.removeChildren = function(/*Element*/node){
	//	summary:
	//		removes all children from node and returns the count of children removed.
	//		The children nodes are not destroyed. Be sure to call dojo._destroyElement on them
	//		after they are not used anymore.
	//	node:
	//		The node to remove all the children from.
	dojo.deprecated("dojox.data.dom.removeChildren()", "Use dojox.xml.parser.removeChildren() instead.", "2.0");
	return dojox.xml.parser.removeChildren(node); //int
};

dojox.data.dom.innerXML = function(/*Node*/node){
	//	summary:
	//		Implementation of MS's innerXML function.
	//	node:
	//		The node from which to generate the XML text representation.
	dojo.deprecated("dojox.data.dom.innerXML()", "Use dojox.xml.parser.innerXML() instead.", "2.0");
	return dojox.xml.parser.innerXML(node); //string||null
};


}

if(!dojo._hasResource["com.ibm.portal.xslt"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.portal.xslt"] = true;
dojo.provide( "com.ibm.portal.xslt" );

dojo.require( "dojox.data.dom" );

dojo.declare( "com.ibm.portal.xslt.TransformerFactory",
    null,
    {
        constructor: function() {
            // create our internal XSL cache
            this._xsltMap = new Array();
        },
        /**
         * summary:
         *		Creates a new com.ibm.portal.xslt.Transformer object.
         */
        newTransformer: function(/*String*/ xsltUrl) {
             ibm.portal.debug.entry( "newTransformer", [ xsltUrl ] );
             var trf = this._getCached(xsltUrl);
             if(trf == null) {
             	trf = new com.ibm.portal.xslt.Transformer(xsltUrl);
             	this._xsltMap.push({url: xsltUrl, transformer: trf});
             }
             return trf;
        },
        _getCached: function(xsltUrl) {
        	var xslt = null;
             // try to get the XSL object from our internal cache
             for (i=0; i<this._xsltMap.length; i++) {
                 var entry = this._xsltMap[i];
                 if (xsltUrl == entry.url) {
                     // alert("cache hit");
                     xslt = entry.transformer;
                     break;
                 }
             }
             return xslt;
        }
    }
);

dojo.declare( "com.ibm.portal.xslt.Transformer",
    null,
    {
        /**
         * summary:
         *		Creates a new transformer for cross-browser XSLT operations
         */
        constructor: function(/* String */ xsltUrl) {
            this._xslt = com.ibm.portal.xslt.loadXsl(xsltUrl);
        },
        /**
         * summary:
         *		Transforms the given xmlDoc and puts the result into the passed
         *		DOM node
         *
         * xmlDoc:
         * 		XML Document to transform
         * xsltParams:
         *		Set of configuration parameters to pass to the transformation
         *		engine.  Object map in this format: {param1Name: "param1Value", param2Name: "param2Value"}
         * node:
         * 		DOM node to put the transform results in
         * doc:
         * 		HTML document to update
         */ 
        transformToRegion: function(xmlDoc, xsltParams, node, doc) {
			if (dojo.isIE) {
				var resultStr = com.ibm.portal.xslt.transform(xmlDoc, this._xslt, null, xsltParams, true);
				node.innerHTML = dojo.string.trim(resultStr);
			} else {
				/*
				var resultsDoc = this.transformToDocument( xmlDoc, xsltParams);
				dojox.data.dom.replaceChildren(node, resultsDoc.documentElement);
				*/
				var frag = com.ibm.portal.xslt.gecko._transformToFragment(xmlDoc, this._xslt, null, xsltParams, doc);
				node.innerHTML = "";
				node.appendChild(frag);
			}
        },
        /** 
         * summary:
         *		Transforms the given xmlDoc and returns a new XML document or String containing
         *		the result
         * xmlDoc:
         * 		XML Document to transform
         * xsltParams:
         *		Set of configuration parameters to pass to the transformation
         *		engine.  Object map in this format: {param1Name: "param1Value", param2Name: "param2Value"}
         * bReturnAsString:
         * 		Boolean indicating whether a XML document or String should be returned.
         */
        transformToDocument: function(xmlDoc, xsltParams, bReturnAsString) {
             var results = com.ibm.portal.xslt.transform(xmlDoc, this._xslt, null, xsltParams, bReturnAsString);
             return results;
        }
    }
);

// global transformer factory
com.ibm.portal.xslt.TRANSFORMER_FACTORY = new com.ibm.portal.xslt.TransformerFactory();



//---------------------------------------------------------------------- xml related utility methods
/*
 * loadXml(sUrl) - returns oDomDoc. parses xml from the url into DOM document object.
 * loadXmlString() - returns oDomDoc. parses xml from the contents of the string into DOM document object.
 * loadXsl()
 * transform()
 */
com.ibm.portal.xslt.ie = {};
com.ibm.portal.xslt.gecko = {};

com.ibm.portal.xslt.getXmlHttpRequest = function() {
	var oXml = null;
	if (typeof ActiveXObject != "undefined") {
		oXml = new ActiveXObject("Microsoft.XMLHTTP");
	} else {
		oXml = new XMLHttpRequest();
	}
  return oXml;
}

com.ibm.portal.xslt.loadXml = function(sUrl) {
	if (typeof ActiveXObject != "undefined") 
		return com.ibm.portal.xslt.ie.loadXml(sUrl);
	else 
		return com.ibm.portal.xslt.gecko.loadXml(sUrl);
}

com.ibm.portal.xslt.loadXmlString = function(sXml) {
	if (typeof ActiveXObject != "undefined") 
		return com.ibm.portal.xslt.ie.loadXmlString(sXml);
	else 
		return com.ibm.portal.xslt.gecko.loadXmlString(sXml);
}

com.ibm.portal.xslt.loadXsl = function(sUrl) {
	if (typeof ActiveXObject != "undefined") 
		return com.ibm.portal.xslt.ie.loadXsl(sUrl);
	else 
		return com.ibm.portal.xslt.gecko.loadXsl(sUrl);
}

com.ibm.portal.xslt.transform = function (xml, xsl, sXslMode, aXslParams, bReturnString)
{
   ibm.portal.debug.entry( "transform", [xml,xsl,sXslMode,aXslParams,bReturnString] );  
   if (typeof ActiveXObject != "undefined") {
    return com.ibm.portal.xslt.ie.transform(xml, xsl, sXslMode, aXslParams,bReturnString);
  }
  else 
    return com.ibm.portal.xslt.gecko.transform(xml, xsl, sXslMode, aXslParams,bReturnString);
}

com.ibm.portal.xslt.transformAndUpdate = function (/*HTMLElement*/nodeToUpdate, /*XMLDocument*/xml, /*XMLDocument*/xsl, /*String?*/sXslMode, /*Map*/aXslParams) {
	ibm.portal.debug.entry( "transformAndUpdate", [ nodeToUpdate, xml, xsl, sXslMode, aXslParams ]);
	
	if ( typeof ActiveXObject != "undefined" ) {
		var resultStr = com.ibm.portal.xslt.transform(xml, xsl, sXslMode, aXslParams, true);
		nodeToUpdate.innerHTML = dojo.string.trim(resultStr);
	} else {
		var doc = nodeToUpdate.ownerDocument ? nodeToUpdate.ownerDocument : document;
		var frag = com.ibm.portal.xslt.gecko._transformToFragment(xml, xsl, sXslMode, aXslParams, doc);
		nodeToUpdate.innerHTML = "";
		nodeToUpdate.appendChild(frag);
	}
	
	ibm.portal.debug.exit( "transformAndUpdate" );
}

//---------------------------------------------------------------------- IE xml related utility methods

com.ibm.portal.xslt.ie.XSLT_PROG_IDS = [
		"Msxml2.XSLTemplate.6.0",
		"Msxml2.XSLTemplate.5.0",
		"Msxml2.XSLTemplate.4.0",
		"MSXML2.XSLTemplate.3.0",
		"MSXML2.XSLTemplate"
	];
	
com.ibm.portal.xslt.ie.DOM_PROG_IDS = [
		"Msxml2.DOMDocument.6.0",
		"Msxml2.DOMDocument.5.0",
		"Msxml2.DOMDocument.4.0",
		"MSXML2.DOMDocument",
		"MSXML.DOMDocument",
		"Microsoft.XMLDOM"
	];
	
com.ibm.portal.xslt.ie.FTDOM_PROG_IDS = [
		"Msxml2.FreeThreadedDOMDocument.6.0",
		"Msxml2.FreeThreadedDOMDocument.5.0",
		"Msxml2.FreeThreadedDOMDocument.4.0",
		"MSXML2.FreeThreadedDOMDocument",
		"MSXML.FreeThreadedDOMDocument",
		"Microsoft.FreeThreadedXMLDOM"
	];
	
com.ibm.portal.xslt.ie._getMSXMLImpl = function(array) {
	// This iterates through the passed in array of Strings which represent ProgIDs for
	// MSXML objects, and attempts to find the first available one and returns an instance
	// to the caller
	for(var i = 0; i < array.length; i++) {
		try {
			var impl = new ActiveXObject(array[i]);
			if(impl) return impl;
		}
		catch(err){}
	}
	throw new Error("No MSXML implementation exists");
}

com.ibm.portal.xslt.ie.loadXml = function(sUrl) {
	//var oXmlDoc = new ActiveXObject("MSXML2.DOMDocument");
	var oXmlDoc = this._getMSXMLImpl(this.DOM_PROG_IDS);
	oXmlDoc.async=0;
	oXmlDoc.resolveExternals = 0;
  	if(!oXmlDoc.load(sUrl))
  	{
  		//Callers should catch this and can substitute their own error message
  		throw new Error("Error loading xml file " + sUrl);
  	}
	return oXmlDoc;

}

com.ibm.portal.xslt.ie.loadXmlString = function(sXml) {
	var oXmlDoc = this._getMSXMLImpl(this.DOM_PROG_IDS);
	oXmlDoc.async=0;
	oXmlDoc.resolveExternals = 0;
  	if(!oXmlDoc.loadXML(sXml))
  	{
  	    //Callers should catch this and can substitute their own error message
  		throw new Error("Error loading xml string " + sXml); 
  	}
	return oXmlDoc;
}

com.ibm.portal.xslt.ie.loadXsl = function(sUrl) {
	//we need to use MSXML2.FreeThreadedDOMDocument interface in order to support 
	//mode and parameters in XSL transformation.
	var oXslDoc = this._getMSXMLImpl(this.FTDOM_PROG_IDS);
	oXslDoc.async=0;
	oXslDoc.resolveExternals = 0;
  	if(!oXslDoc.load(sUrl))
  	{
  		//Callers should catch this and can substitute their own error message
  		throw new Error("Error loading xsl file " + sUrl);
  	}	
	return oXslDoc;
}

com.ibm.portal.xslt.ie.transform = function(xmlDoc, xsl, sXslMode, aXslParams,bReturnString) {
	var oXml = xmlDoc;
	var oXsl = xsl;

     try {		
		if(!oXsl.documentElement) oXsl = this.loadXsl(xsl);
	 }
	 catch(e) {
		var sMsg = e.message;
		throw new Error(""+sMsg, ""+sMsg);
	 }
	//create the xsl processor and apply the transformation
	var oXslt = this._getMSXMLImpl(this.XSLT_PROG_IDS);
	oXslt.stylesheet = oXsl;
	var oXslProc = oXslt.createProcessor();
	oXslProc.input = oXml;
	
	//set paramaters if any
	if(aXslParams) {
		for(var p in aXslParams) {
			oXslProc.addParameter(p, aXslParams[p]);
		}
	}
	if (sXslMode) oXslProc.addParameter("mode", sXslMode);
	
	if (bReturnString) {
		if(!oXslProc.transform()) {
			//Callers should catch this and can substitute their own error message
  			throw new Error("Error transforming xml doc " + oXml); 
  		}
  		return oXslProc.output;
	} else {
		var oHtmlDoc = this._getMSXMLImpl(this.DOM_PROG_IDS);
		oHtmlDoc.async = false;
		oHtmlDoc.validateOnParse = false;
		oXml.transformNodeToObject(oXsl,oHtmlDoc);
		return oHtmlDoc;	
	}
}

//---------------------------------------------------------------------- GECKO xml related utility methods

com.ibm.portal.xslt.gecko.loadXml = function(sUrl) {
    //var oXmlResponse = NG.ServerRequest.postRequest(sUrl);
//    if (oXmlResponse) return xmlLoadString(oXmlResponse.responseText);
//    else return null;
	var oDomDoc = null;
	if(dojo.isSafari) {
		var xhr = new XMLHttpRequest();
		xhr.open( "GET", sUrl, false );
		xhr.send( null );
		  
		if ( xhr.status == 200 ) {
			oDomDoc = xhr.responseXML;
		}
	}
	else {
		oDomDoc = document.implementation.createDocument('','',null);
		oDomDoc.async = 0; // this is the important part
		oDomDoc.load(sUrl);
	} 
	return oDomDoc;
}

com.ibm.portal.xslt.gecko.loadXmlString = function(sXml) {
    var parser = new DOMParser();
    try { oXmlDoc = parser.parseFromString(sXml, "text/xml"); }
    catch (exc) {
	    //Callers should catch this and can substitute their own error message
  		throw new Error("Error loading xml string " + sXml); 
    }
	return oXmlDoc;
}

com.ibm.portal.xslt.gecko.loadXsl = function(sUrl) {
	//This is done through createDocument because of anchor(#) we have in portal url. 
	//Do not change the code without testing the case.
	var oDomDoc = null;
	if(dojo.isSafari) {
		var xhr = new XMLHttpRequest();
		xhr.open( "GET", sUrl, false );
		xhr.send( null );
		  
		if ( xhr.status == 200 ) {
			oDomDoc = xhr.responseXML;
		}
	}
	else {
		oDomDoc = document.implementation.createDocument('','',null); 
		oDomDoc.async = 0; // this is the important part
		oDomDoc.load(sUrl);
	}
	
	return oDomDoc;
}

com.ibm.portal.xslt.gecko._getXSLTProc = function(xmlDoc, xsl, sXslMode, aXslParams) {
	var xslDoc = xsl;
	if(!xslDoc.documentElement) 
	{
		xslDoc = this.loadXsl(xsl);
	}        
    var proc = new XSLTProcessor();
    proc.importStylesheet(xslDoc); 

	
	//set parameters if any
	if(aXslParams) {
		for(var p in aXslParams)  {
			proc.setParameter(null, p, aXslParams[p]);
		}
	}
	
	if (sXslMode) proc.setParameter(null, "mode", sXslMode);
	
	return proc;
}

com.ibm.portal.xslt.gecko._transformToFragment = function(xmlDoc, xsl, sXslMode, aXslParams, doc) {
	var proc = com.ibm.portal.xslt.gecko._getXSLTProc(xmlDoc, xsl, sXslMode, aXslParams);
	
	var resultDoc = null;
	resultDoc = proc.transformToFragment(xmlDoc, doc);
	proc.clearParameters();
	return resultDoc;
}

com.ibm.portal.xslt.gecko.transform = function(xmlDoc, xsl, sXslMode, aXslParams,bReturnString) {
	try {
		var resultDoc = null;
		if (!bReturnString) {
			var proc = com.ibm.portal.xslt.gecko._getXSLTProc(xmlDoc, xsl, sXslMode, aXslParams);
			resultDoc = proc.transformToDocument(xmlDoc);
			return resultDoc;
		}
		else {
			resultDoc = com.ibm.portal.xslt.gecko._transformToFragment(xmlDoc, xsl, sXslMode, aXslParams, document);
		}

		var serializer = new XMLSerializer();
		// need to trim newlines and spaces from beginning and end so that the root node always has the same
		// number of child nodes regardless of the browser implementation
		// this should be lossless of real expected content
		var resultStr = dojo.string.trim(serializer.serializeToString(resultDoc));
		if(dojo.isOpera && resultDoc.firstChild && resultDoc.firstChild.nodeName == 'result') {
			var start = resultStr.indexOf("<result>") + 8;
			var end = resultStr.lastIndexOf("</result>");
			resultStr = dojo.string.trim(resultStr.substring(start, end));
		}
		return resultStr;    
    }
    catch (exc)
    {
        //alert("error transforming document: "+exc)
		//Callers should catch this and can substitute their own error message
  		throw new Error("Error transforming xml doc " + exc);
	}
}

/* This method sets the content of a layer within the HTML page
 * to the result of transforming the xml parameter by the xsl
 * parameter. The xml and xsl parameters may be of any form
 * supported by the transformXml() method. The layer parameter
 * may be either a DOM object or the name of a DOM object that
 * can be found using the findObject() method.
 */

com.ibm.portal.xslt.setLayerContentByXml = function (layer, xml, xsl, xslparam,bReturnString) {
    var result = com.ibm.portal.xslt.transform(xml,xsl,null,xslparam,bReturnString);
    if (layer.innerHTML) layer.innerHTML = result;
    else {
        var obj = document.getElementById(layer);
        obj.innerHTML=result;
    }
}

}

if(!dojo._hasResource["com.ibm.domUtilities"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.domUtilities"] = true;
/*
 * @author Ben
 */
dojo.provide( "com.ibm.domUtilities" );
/*
 * This module provides cross-browser functions for interacting with a DOM object to
 * create nodes and get and set attributes that may or may not be namespaced.  Since
 * browsers use various functions for interacting with namespaced DOM nodes and attributes,
 * this module abstracts those away and provides a single layer for using those operations.
 */

dojo.require( "dojox.data.dom" );
dojo.require( "com.ibm.portal.xslt" );

com.ibm.domUtilities = {
	
	constants: {
		// MSXML_NodeTypes: Constants for defining integer values for node type strings
		MSXML_NodeTypes: {
			element: 1,
			attribute: 2,
			text: 3,
			cdata: 4,
			entity_reference: 5,
			entity: 6,
			processing_instruction: 7,
			comment: 8,
			document: 9,
			document_type: 10,
			document_fragment: 11,
			notation: 12
		}
	},
	
	nsInfo: function(/*String*/ str, /*Object*/ namespaces) {
		// summary: Extracts the namespace URI, prefix, and local name of a QName according to this
		//		object's namespaces map that includes known prefixes and their namespace URIs.  If
		//		the string is not namespaced, then the namespaceURI and prefix are set to null, and
		//		the localName is set to the str as-is.
		// str: QName to extract namespace from
		// namespaces: Map of namespaces where keys are namespace prefixes and values are the namespace URIs.
		// returns: Map - {namespaceURI: namespaceURI, prefix: prefix, localName: localName}
		var parts = str.split(":");
		var prefix, localName;
		if(parts.length > 1) {
			prefix = parts[0];
			localName = parts[1];
			return { namespaceURI: namespaces[prefix], prefix: prefix, localName: localName};
		}
		else {
			return { namespaceURI: null, prefix: null, localName: str};
		}
	},
	getAttribute: function(/*DOMNode*/ node, /*String*/ attrName, /*Object*/ namespaces) {
		// summary: Gets an attribute of the given node, supporting namespaced and 
		// 		non-namespaced attributes.
		// node: Node to retrieve the attribute value from
		// attrName: The name of the attribute to get from the node.
		//		If the attribute is namespaced, it will be split into its parts using the : delimiter
		//		and the namespace used during lookup will be the one keyed in the namespace map.
		// namespaces: Map of prefixes to namespaceURIs
		// returns: Object value of attribute
		var ret = null;
		var parts = com.ibm.domUtilities.nsInfo(attrName, namespaces);
		if(parts.namespaceURI) {
			if(node.getAttributeNS) {
				ret = node.getAttributeNS( parts.namespaceURI, parts.localName );
			}
			else if(dojo.isIE) {
				ret = node.attributes.getQualifiedItem( parts.localName, parts.namespaceURI );
				if(ret) ret = ret.value;
			}
			else ret = node.getAttribute( attrName );
		}
		else {
			ret = node.getAttribute( attrName );
		}
		return ret;
	},
	setAttribute: function(/*DOMNode*/ node, /*String*/ attrName, /*String*/ value, /*Object*/ namespaces) {
		// summary: Sets an attribute of the given node, supporting namespaced and 
		// 		non-namespaced attributes.
		// node: Node to set the attribute value on
		// attrName: The name of the attribute to set on the node.
		//		If the attribute is namespaced, it will be split into its parts using the : delimiter
		//		and the namespace used during lookup will be the one keyed in the namespace map.
		// value: The actual value to store in the node at the key attribute specified by attrName.
		// namespaces: Map of prefixes to namespaceURIs
		if(value === true) value = "true";
		else if(value === false) value = "false";
		var parts = com.ibm.domUtilities.nsInfo(attrName, namespaces);
		if(parts.namespaceURI) {
			if(node.setAttributeNS) {
				node.setAttributeNS( parts.namespaceURI, attrName, value );
			}
			else if(dojo.isIE && node.ownerDocument) {
				var attrNode = node.ownerDocument.createNode(com.ibm.domUtilities.constants.MSXML_NodeTypes.attribute, attrName, parts.namespaceURI);
				attrNode.value = value;
				node.setAttributeNode(attrNode);
			}
			else node.setAttribute( attrName, value );
		}
        else node.setAttribute( attrName, value );
	},
	removeAttribute: function(/*DOMNode*/ node, /*String*/ attrName, /*Object*/ namespaces) {
		// summary: Removes an attribute of the given node, supporting namespaced and 
		// 		non-namespaced attributes.
		// node: Node to remove the attribute from
		// attrName: The name of the attribute to remove from the node.
		//		If the attribute is namespaced, it will be split into its parts using the : delimiter
		//		and the namespace used during lookup will be the one keyed in the namespaces map.
		// namespaces: Map of prefixes to namespaceURIs
		var parts = com.ibm.domUtilities.nsInfo(attrName, namespaces);
		if(parts.namespaceURI) {
			if(node.removeAttributeNS) {
				// for some reason we have to use the localName when getting the attribute even
				// though we have to use the full name when setting it
				node.removeAttributeNS( parts.namespaceURI, attrName );
			}
			else if(dojo.isIE) {
				node.attributes.removeQualifiedItem( parts.localName, parts.namespaceURI );
			}
			else node.removeAttribute( attrName );
		}
        else node.removeAttribute( attrName );
	},
	hasAttribute: function(/*DOMNode*/ node, /*String*/ attrName, /*Object*/ namespaces) {
		// summary: Checks if an attribute of the given node exists, supporting namespaced and 
		// 		non-namespaced attributes.
		// node: Node to check for the existence of the attribute from
		// attrName: The name of the attribute to check from the node.
		//		If the attribute is namespaced, it will be split into its parts using the : delimiter
		//		and the namespace used during lookup will be the one keyed in this item or store's 
		// 		namespace map.
		// namespaces: Map of prefixes to namespaceURIs
		// returns: Boolean true if attribute exists, false otherwise
		var ret = null;
		var parts = com.ibm.domUtilities.nsInfo(attrName, namespaces);
		if(parts.namespaceURI) {
			if(node.hasAttributeNS) {
				ret = node.hasAttributeNS( parts.namespaceURI, parts.localName );
			}
			else if(dojo.isIE) {
				ret = node.attributes.getQualifiedItem( parts.localName, parts.namespaceURI ) != null;
			}
			else ret = node.hasAttribute( attrName );
		}
		else if(!dojo.isIE) ret = node.hasAttribute( attrName );
		else ret = node.getAttributeNode( attrName ) != null;
		
		return ret;	
	},
	createElement: function(/*DOMDoc*/ doc, /*String*/ tagName, /*Object*/ namespaces, /*Object?*/ attrMap) {
		// summary: Cross-browser implementation for creating a namespaced node using the namespace
		//		map in this object to resolve prefixes to namespace URIs.
		//		If the tagName is not namespaced or a namespace URI cannot be resolved
		// 		using this object's namespaces map, a non-namespaced element will be created instead.
		// doc: DOMDoc document object to use to create the DOM node.
		// tagName: String name for the tag name of the element to create.  
		// 		Can be namespaced like prefix:localName or not like localName.
		// namespaces: Map of namespaces where keys are namespace prefixes and values are the namespace URIs.
		// attrMap: Optional argument specifying a key-value map of attributes to be
		// 		set on the node before returning it. 
		// returns: DOMNode A new DOM node that was created by doc
		var node = null;
		var parts = com.ibm.domUtilities.nsInfo(tagName, namespaces);
		if(parts.namespaceURI) {
			if(doc.createElementNS) {
				// W3C standard way of creating namespaced elements
				node = doc.createElementNS(parts.namespaceURI, tagName);
			}
			else if(dojo.isIE) {
				// we have to check dojo.isIE because IE throws an error when trying to check for
				// the existence of particular methods on the document object
				
				// this is IE's way of creating a namespaced node
				// use the tagName since it already includes the prefix as well
				node = doc.createNode("element", tagName, parts.namespaceURI);
			}
		}
		// if we don't have a node at this point, just create it without a namespace
		if(!node) node = doc.createElement(tagName);
		
		for(var name in attrMap) {
			com.ibm.domUtilities.setAttribute(node, name, attrMap[name], namespaces);
		}
		
		return node;
	},
	createFromJson: function(/*DOMDoc*/ doc, /*Object*/ def, /*Object*/ namespaces, /*DOMNode?*/ parentNode) {
		var obj = null;
		if(dojo.isString(def)){
			obj =  doc.createTextNode(def);
		}
		else {
			obj = com.ibm.domUtilities.createElement(doc, def.name, namespaces, def.attributes);
			dojo.forEach(def.children, function(childDef) {
				com.ibm.domUtilities.createFromJson(doc, childDef, namespaces, obj);
			});
		}
		
		if(parentNode) parentNode.appendChild(obj);
		return obj;
	},
	removeChildren: function(node) {
		while(node.hasChildNodes()) {
			var f = node.removeChild(node.firstChild);
			delete f;
		}
	},
	textContent: function(/*DOMNode*/ node, /*String?*/ text) {
		return dojox.data.dom.textContent.apply(null, arguments);
	},
	innerXML: function(/*DOMNode*/ node) {
		return dojox.data.dom.innerXML(node);
	},
	stringFromDoc: function(/*DOMNode*/ node) {
		return com.ibm.domUtilities.innerXML(node);
	},
	docFromString: function(/*String*/ str) {
		return com.ibm.portal.xslt.loadXmlString(str);
	},
	encodeXML: function(/*String*/ xmlStr, /*Boolean?*/ encodeQuotes) {
		// summary: Encodes a string for inclusion into an XML document so that any XML delimiters will
		//		be encoded as CDATA.
		if(dojo.isString(xmlStr)) {
			xmlStr = xmlStr.replace(/&/gm, "&amp;").replace(/</gm, "&lt;").replace(/>/gm, "&gt;");
			if(encodeQuotes) xmlStr = xmlStr.replace(/'/gm, "&#039;").replace(/"/gm, "&#034;");
			return xmlStr;
		}
		else if(xmlStr != null) return xmlStr;
		else return "";
	},
	decodeXML: function(/*String*/ xmlStr, /*Boolean?*/ decodeQuotes) {
		if(dojo.isString(xmlStr)) {
			xmlStr = xmlStr.replace(/&lt;/gm, "<").replace(/&gt;/gm, ">").replace(/&amp;/gm, "&");
			if(decodeQuotes) xmlStr = xmlStr.replace(/&#039;/gm, "\'").replace(/&#034;/gm, "\"");
			return xmlStr;
		}
		else if(xmlStr != null) return xmlStr;
		else return "";
	}
}

}

if(!dojo._hasResource["com.ibm.utilities"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.utilities"] = true;
/*
 * @author Ben
 */ 
dojo.provide("com.ibm.utilities");




com.ibm.utilities = {
	urlToProxyUrl: function ( /*String*/ url, /*String?*/ proxyURI ) {
		var ret = proxyURI ? proxyURI : "/proxy";
		var protocol = "http";
		var colon = url.indexOf('://');
		if(colon > -1) {
			protocol = url.substring(0, colon);
			url = url.substring(colon + 3);
		}
		url = url.replace(/:/g, '%3A');
		
		return ret + '/' + protocol + '/' + url;
	},
	withBaseUrl: function(/*String*/ relativeUrl) {
		// summary: Rewrites a relative url to include the base url that's present in
		//		the href attribute of the first base tag found in the document if one exists.
		//		If one does not exist, this returns the relative url argument unchanged.
		//		This is useful for fixing relative URLs in a document that includes a base
		//		url while using IE as it does not include base url calculations when dynamically
		//		changing href or src attributes on elements, or when modifying window.location
		//		properties.
		// relativeUrl: String url relative to the current host to rewrite
		if(relativeUrl.charAt(0) == '/') return relativeUrl;
		return com.ibm.utilities.baseUrl() + relativeUrl;
	},
	baseUrl: function() {
		// summary: Returns the base url used in the document for any relative url
		//		resolution.  This is retrieved by looking up the base tag in the document
		//		and returning its href attribute if it exists.  Otherwise, it simply
		//		returns the empty string.
		if(!this._baseUrl) {
			var base = dojo.doc.getElementsByTagName("base")[0];
			if(base) this._baseUrl = base.getAttribute("href");
			if(!this._baseUrl) this._baseUrl = "";
		}
		return this._baseUrl;
	},
	stripUrlFragment: function(/*String*/url) {
		// summary: Strips the fragment identifier from a url if one exists, returning
		//		the new url without any fragment identifiers.
		// url: String url to strip fragment identifiers
		var h = url.indexOf("#");
		if(h > -1) url = url.substr(0, h);
		return url;
	},
	actionIO: function(/*String*/ url, /*String*/ method) {
		if(url) {
			var form = dojo.doc.createElement("form");
			form.setAttribute("action", url);
			if(method) method = method.toLowerCase();
			switch(method) {
				case "get":
					form.setAttribute("method", "GET");
				case "post":
				case "delete":
				case "put":
					form.setAttribute("method", "POST");
					break;
				default:
			}
			dojo.body().appendChild(form);
			form.submit();
		}
	},
	refreshPage: function(){
		var url, hash = -1, bases = document.getElementsByTagName('base');
		if(bases.length > 0) url = bases[0].href;  // use url from base tag
		else {  // use current location with any hash removed
			url = top.location.href;
			hash = url.indexOf('#');
			if(dojo.isSafari < 4 && hash > -1)  // nothing but location.reload works in 
				window.location.reload();   // Safari when there is a hash in the url
			if(hash > -1)
				url = url.substring(0, hash);
		}
		window.location.assign(url);  // refresh without reloading static content
	}
};

(function(){
	// unique (arbitrary) boundary
	var boundary = new String("{EB2F8DA2-5B2C-F66A-CDD0-A2D42143F5AC}");
	var newL = new String("\r\n");
	var sep = new String("--");
	var startB = newL + sep + boundary + newL;			
	var endB = sep + boundary + sep + newL;
	
	// used to capture the header
	var headerBodySplitterRegx = new RegExp(newL + newL);
	var headerRegx= new RegExp(newL + "\s*([^\r]*)\s*", "mg");
	var headerPartsRegx = /\s*([^:]*):\s*(.+)/;
	
	// used to find the boundary
	var boundaryRegx = /boundary\s*=\s*\"?([^\"]*)\"?/;
	
	var partHandler = function(partArgs, responsePart, ioArgs) {
		// use a try-catch so any errors in callback execution don't
		// kill the processing of other parts... this behaves as
		// if each part were a separate request with its own async
		// callback
		try {
			if(responsePart instanceof Error) {
				if(partArgs.error) partArgs.error(responsePart, ioArgs);
			}
			else {
				try {
					if(partArgs.load) partArgs.load(responsePart, ioArgs);
				}
				catch(err) {
					if(partArgs.error) partArgs.error(err, ioArgs);
				}
			}
			// always call the handle function if it exists
			if(partArgs.handle) partArgs.handle(responsePart, ioArgs);
		} catch(err) {}
	};
	
	function xhrMime() {
		this.respHeaders = [];
		this.responseText = "";
		this.responseXML = null;
		this.status = 0;
		this.statusText = "";
		this.readyState = 0;
		this.onreadystatechange = function(){};
	}
	
	dojo.extend(xhrMime, {
		getResponseHeader: function(key) {
			key = key.toLowerCase();
			for(var i = 0, header; header = this.respHeaders[i], i < this.respHeaders.length; i++) {
				if(header[0].toLowerCase() == key) return header[1];
			}
			return null;
		},
		getAllResponseHeaders: function() {
			var str = "";
			for(var i = 0, header; header = this.respHeaders[i], i < this.respHeaders.length; i++) {
				str += header[0] + ": " + header[1];
				if(i < this.respHeaders.length - 1) {
					str += "\n";
				}
			}
			return str;
		},
		send: function(){},
		open: function(){},
		abort: function(){},
		setRequestHeader: function(){}
	});
	
	var unfoldHeaders = function(headerSection) {
		return headerSection.replace(/\r\n\s/mg, " ");
	}
	
	var defaultContentHandler = function(partArgs, partXhr) {
		var xmlPart = null;
		if(partArgs.handleAs == "xml") {
			// create document object from text string
			try {
				xmlPart = com.ibm.domUtilities.docFromString(partXhr.responseText);
			} catch(err) {}
		}
		partXhr.responseXML = xmlPart;
		// call the appropriate content handler for this part
		return dojo._contentHandlers[partArgs.handleAs](partXhr);
	}

	dojo.mixin(com.ibm.utilities, {
		handleMultiPartResponse: function(parts, response, ioArgs) {
			// Getting the Content-Type header from the response, and extract
			// the boundary string
			var boundMatch = ioArgs.xhr.getResponseHeader("Content-Type").match(boundaryRegx);
			if(!boundMatch) throw new Error("No boundary specified in Content-Type response header");
			var bound = boundMatch[1];
			// build a regx from the response boundary string used to split the parts
			var splitterRegx = new RegExp(newL + sep + bound, "mg");
			
			var respParts = response.split(splitterRegx);
			
			// if handleAs is xml, it comes as text so build it using the domUtilities
			
			// iterate through the response parts, handling the callbacks for each
			for(var i = 1, j = i - 1; i < respParts.length - 1; i++, j++) {
				var partXhr = new xhrMime(),
					part = respParts[i],
					header = null;
				headerRegx.lastIndex = 0;
				
				var partSections = part.split(headerBodySplitterRegx);
				var headerSection = unfoldHeaders(partSections[0]),
					bodySection = partSections[1];
				
				if(!bodySection) bodySection = "";
				
				// extract the headers for this part, stopping at the blank line
				while((header= headerRegx.exec(headerSection)) != null && (header[1].length > 0)) {
					var headerParts = header[1].match(headerPartsRegx);
					if(headerParts)	{
						partXhr.respHeaders.push([headerParts[1],headerParts[2]]);
					}
				}
				
				part = dojo.string.trim(bodySection);
				partXhr.responseText = part;
				
				if(ioArgs.args.partContentHandler) {
					part = ioArgs.args.partContentHandler(parts[j], partXhr, defaultContentHandler);
				}
				else {
					part = defaultContentHandler(parts[j], partXhr);
				}
				
				partHandler(parts[j], part, dojo.mixin({}, ioArgs, {xhr: partXhr}));
			}
		},
		
		multiPartXhr: function( /*String*/ method, /*dojo.__XhrArgs*/ args, /*Array*/ parts) {
			// summary: Sends a request with a multi-part body (and content type) to
			//		the server.  Uses dojo.xhr functions under the covers, so the args
			//		object has the same structure as what those functions expect.
			//		The main difference is that this function builds the raw post or put
			//		data automatically from the parts array.  Each item in the parts array
			//		is an object which is a subset of the dojo.__XhrArgs type.  The callbacks
			//		should be specified per part as this function will provide a general
			//		callback that parses the multi-part response and calls the callback
			//		associated with that response part provided in the parts array.
			// method: String specifying the HTTP method used.  Must be either POST or PUT.
			//		Default is POST.
			// args: dojo.__XhrArgs specifying how this XHR should be handled.  The following
			//		properties are not used since they do not make sense in this context -
			//			[form, handle, load, content, handleAs]
			//		The following are new args that are available for sending multiPart requests.
			//		{
			//			partContentHandler: function(partArgs, partXhr, defaultContentHandler){} optional 
			// 				function to handle response parts after they've been split and parsed enabling a 
			// 				caller to modify the part response body or the XHR mime associated with the part, 
			// 				returns the response associated with this part in some format, potentially modified
			//				by this handler function
			//			preHandle: function(response, ioArgs){} callback called before the parts
			//				callbacks are called
			//			postHandle: function(response, ioArgs){} callback called after the parts
			//				callbacks have been called
			//
			//		}
			// parts: Array the multiple parts to use to build the multi-part request body.
			//		Each item in the array should be an object with these properties -
			//			{
			//				headers: Object key-value map which is used to write out a
			//					section at the top of this part in the form key: value.
			//					Example could be Content-Type of this part of the multi-part
			//					request.
			//				data: String text to write out the body of this part
			//				load: function(response, ioArgs){} callback called where
			// 					the response body is the body of the part associated this
			//					request part
			//				error: function(response, ioArgs){} callback called when
			//					a failure occurs either in the transmission or from the
			//					server
			//				handle: function(response, ioArgs){} callback called at the
			//					end of this request with either the response or an error
			//					if one occured
			//				handleAs: String value indicating how the response body of this
			//					part should be handled
			//			}
			// returns: Deferred object which can be used to attach additional callbacks to
			
			var body = "",
				headersStr = null;
			dojo.forEach(parts, function(part){
				part.handleAs = part.handleAs ? part.handleAs.toLowerCase() : "text";
				headersStr = "";
				for(var x in part.headers) {
					headersStr += x + ": " + part.headers[x] + newL;
				}
				body += startB + headersStr + newL;
				if(part.data && part.data.length > 0) body += part.data + newL;
			});
			
			body += endB;
			
			// if method is PUT, leave it be; otherwise set it to POST
			if(method.toUpperCase() != "PUT") method = "POST";
			
			args.headers = dojo.mixin({}, args.headers, {
				"Content-type": 'multipart/mixed; boundary="' + boundary + '"'
			});
			
			var xhrArgs = dojo.mixin({}, args, {
				load: function(response, ioArgs) {
					if(args.preHandle) args.preHandle(response, ioArgs);
					com.ibm.utilities.handleMultiPartResponse(parts, response, ioArgs);
					if(args.postHandle) args.postHandle(response, ioArgs);
				}, 
				error: function(response, ioArgs) {
					if(args.preHandle) args.preHandle(response, ioArgs);
					dojo.forEach(parts, function(part){
						partHandler(part, response, ioArgs, null);
					});
					if(args.error) args.error(response, ioArgs);
					if(args.postHandle) args.postHandle(response, ioArgs);
				},
				handleAs: "text",
				form: null,
				content: null,
				postData: null,
				putData: null
			});
			
			xhrArgs[method.toLowerCase() + "Data"] = body;
			
			return dojo.xhr(method, xhrArgs, true);
		}
	});
})();

}

if(!dojo._hasResource["com.ibm.data.ProxyHelper"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.data.ProxyHelper"] = true;
dojo.provide( "com.ibm.data.ProxyHelper" );

dojo.require( "com.ibm.utilities" );

dojo.declare( "com.ibm.data.ProxyHelper",
			null,
			{
				// proxyURI: String
				//		URI to the proxy servlet.
				proxyURI: "",
				
				urlThroughProxy: function(/*String*/ url) {
					return com.ibm.utilities.urlToProxyUrl(url ? url : "", this.proxyURI);
				}
			}
);

}

if(!dojo._hasResource["com.ibm.data.CatalogMixin"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.data.CatalogMixin"] = true;
// Datastores written for use in the content search widget must inherit from this class to make the mapItem and prepareQuery function available to the widget
// These functions are used to unify access to datastores, so the widget can  query and access items the same way for every source

dojo.provide("com.ibm.data.CatalogMixin");
dojo.declare("com.ibm.data.CatalogMixin", 
		null,
		{	
			searchable: true,
			
			mapItem: function(/*DatstoreItem*/item){
				// summary: Returns a map containing parameters for the given datastore item
				//		The keys must be: label, description, tags, rating, url, id, thumbnail
				//			- label, description, url, id and thumbnail are strings
				//			- tags is an array of strings
				//			- rating is a string that contains a number, note that decimal values are allowed
				//		Having all content search datastores create item maps with the same keys allows the widget to access information uniformly
				// 		If a datastore item does not have the same attributes for getValue as seen below, this function must be overridden
				//		If a datastore item does not have an appropriate parameter to  map to a key, that map entry can be omitted
				//		An example for a datastore item with a title, summary, rating and identifier:
				//			mapItem: function(/*DatastoreItem*/item){
				//				// does not include the "tags" and "url" keys
				//				var map = {};
				//				map["label"] = this.getValue(item, "title", "untitled");
				//				map["description"] = this.getValue(item, "summary", null);
				//				map["rating"] = this.getValue(item, "rating", "0.0");
				//				map["id"] = this.getValue(item, "identifier", null);
				//				map["thumbnail"] = this.getValue(item, "thumbnail", null);
				//				return map;
				//			}
				var map = {};
				map["label"] = this.getValue(item, "label", "untitled");
				map["description"] = this.getValue(item, "description", null);
				map["tags"] = this.getValues(item, "tags", null);
				map["rating"] = this.getValue(item, "rating", "0.0");
				map["url"] = this.getValue(item, "url", null);
				map["id"] = this.getValue(item, "id", null);
				map["thumbnail"] = this.getValue(item, "thumbnail", null);
				return map;
			},

			prepareQuery: function(/*Object*/keywordArgs) {
				// summary: User overridable function to modify the keywordArgs object used to fetch results from the back end
				//		Called after the keywordArgs.query property has been normalized to an object map but before any other processing has taken place to build the URL
				//		After this function is called, anything in the keywordArgs.query map is appended to the fetch URL in the form (?|&)<key1>=<value1> &<key2>=<value2> &<key3>=<value3> ...
				//		Can be used to extract other parts of the keywordArgs map to add properties to the query object that are dependent on back end implementation
				//		Properties of the query object that are not part of the fetch URL should be deleted
				//		The keywordArgs object is defined in dojo.data.api.Read.fetch and query will be an object containing the key "keywords" with an array of strings as a value
				//		An example for a feed URL containing "searchTerms", "startIndex" and "count" parameters:
				//			prepareQuery: function(/*Object*/keywordArgs) {
				//				if(keywordArgs.query.keywords) {
				//					// searchTerms is a comma separated list of search parameters
				//					keywordArgs.query.searchTerms = keywordArgs.query.keywords.join(",");
				//					delete keywordArgs.query.keywords;
				//				}
				//				if(keywordArgs.count) {
				//					keywordArgs.query.count = keywordArgs.count;
				//					if(keywordArgs.start == null) {
				//						keywordArgs.start = 0;
				//					}
				//					keywordArgs.query.startIndex = keywordArgs.start;
				//				}
				//			}
				return keywordArgs;
			},
			
			validateSelf: function(){
				// summary: validates this datastore, if it does not validate the source will not be used
				// returns true for validation and false otherwise
				return true;
			},
			
			getSourceLabel: function(){
				return false;
			}
});

}

if(!dojo._hasResource["dojo.i18n"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.i18n"] = true;
dojo.provide("dojo.i18n");

/*=====
dojo.i18n = {
	// summary: Utility classes to enable loading of resources for internationalization (i18n)
};
=====*/

dojo.i18n.getLocalization = function(/*String*/packageName, /*String*/bundleName, /*String?*/locale){
	//	summary:
	//		Returns an Object containing the localization for a given resource
	//		bundle in a package, matching the specified locale.
	//	description:
	//		Returns a hash containing name/value pairs in its prototypesuch
	//		that values can be easily overridden.  Throws an exception if the
	//		bundle is not found.  Bundle must have already been loaded by
	//		`dojo.requireLocalization()` or by a build optimization step.  NOTE:
	//		try not to call this method as part of an object property
	//		definition (`var foo = { bar: dojo.i18n.getLocalization() }`).  In
	//		some loading situations, the bundle may not be available in time
	//		for the object definition.  Instead, call this method inside a
	//		function that is run after all modules load or the page loads (like
	//		in `dojo.addOnLoad()`), or in a widget lifecycle method.
	//	packageName:
	//		package which is associated with this resource
	//	bundleName:
	//		the base filename of the resource bundle (without the ".js" suffix)
	//	locale:
	//		the variant to load (optional).  By default, the locale defined by
	//		the host environment: dojo.locale

	locale = dojo.i18n.normalizeLocale(locale);

	// look for nearest locale match
	var elements = locale.split('-');
	var module = [packageName,"nls",bundleName].join('.');
	var bundle = dojo._loadedModules[module];
	if(bundle){
		var localization;
		for(var i = elements.length; i > 0; i--){
			var loc = elements.slice(0, i).join('_');
			if(bundle[loc]){
				localization = bundle[loc];
				break;
			}
		}
		if(!localization){
			localization = bundle.ROOT;
		}

		// make a singleton prototype so that the caller won't accidentally change the values globally
		if(localization){
			var clazz = function(){};
			clazz.prototype = localization;
			return new clazz(); // Object
		}
	}

	throw new Error("Bundle not found: " + bundleName + " in " + packageName+" , locale=" + locale);
};

dojo.i18n.normalizeLocale = function(/*String?*/locale){
	//	summary:
	//		Returns canonical form of locale, as used by Dojo.
	//
	//  description:
	//		All variants are case-insensitive and are separated by '-' as specified in [RFC 3066](http://www.ietf.org/rfc/rfc3066.txt).
	//		If no locale is specified, the dojo.locale is returned.  dojo.locale is defined by
	//		the user agent's locale unless overridden by djConfig.

	var result = locale ? locale.toLowerCase() : dojo.locale;
	if(result == "root"){
		result = "ROOT";
	}
	return result; // String
};

dojo.i18n._requireLocalization = function(/*String*/moduleName, /*String*/bundleName, /*String?*/locale, /*String?*/availableFlatLocales){
	//	summary:
	//		See dojo.requireLocalization()
	//	description:
	// 		Called by the bootstrap, but factored out so that it is only
	// 		included in the build when needed.

	var targetLocale = dojo.i18n.normalizeLocale(locale);
 	var bundlePackage = [moduleName, "nls", bundleName].join(".");
	// NOTE: 
	//		When loading these resources, the packaging does not match what is
	//		on disk.  This is an implementation detail, as this is just a
	//		private data structure to hold the loaded resources.  e.g.
	//		`tests/hello/nls/en-us/salutations.js` is loaded as the object
	//		`tests.hello.nls.salutations.en_us={...}` The structure on disk is
	//		intended to be most convenient for developers and translators, but
	//		in memory it is more logical and efficient to store in a different
	//		order.  Locales cannot use dashes, since the resulting path will
	//		not evaluate as valid JS, so we translate them to underscores.
	
	//Find the best-match locale to load if we have available flat locales.
	var bestLocale = "";
	if(availableFlatLocales){
		var flatLocales = availableFlatLocales.split(",");
		for(var i = 0; i < flatLocales.length; i++){
			//Locale must match from start of string.
			//Using ["indexOf"] so customBase builds do not see
			//this as a dojo._base.array dependency.
			if(targetLocale["indexOf"](flatLocales[i]) == 0){
				if(flatLocales[i].length > bestLocale.length){
					bestLocale = flatLocales[i];
				}
			}
		}
		if(!bestLocale){
			bestLocale = "ROOT";
		}		
	}

	//See if the desired locale is already loaded.
	var tempLocale = availableFlatLocales ? bestLocale : targetLocale;
	var bundle = dojo._loadedModules[bundlePackage];
	var localizedBundle = null;
	if(bundle){
		if(dojo.config.localizationComplete && bundle._built){return;}
		var jsLoc = tempLocale.replace(/-/g, '_');
		var translationPackage = bundlePackage+"."+jsLoc;
		localizedBundle = dojo._loadedModules[translationPackage];
	}

	if(!localizedBundle){
		bundle = dojo["provide"](bundlePackage);
		var syms = dojo._getModuleSymbols(moduleName);
		var modpath = syms.concat("nls").join("/");
		var parent;

		dojo.i18n._searchLocalePath(tempLocale, availableFlatLocales, function(loc){
			var jsLoc = loc.replace(/-/g, '_');
			var translationPackage = bundlePackage + "." + jsLoc;
			var loaded = false;
			if(!dojo._loadedModules[translationPackage]){
				// Mark loaded whether it's found or not, so that further load attempts will not be made
				dojo["provide"](translationPackage);
				var module = [modpath];
				if(loc != "ROOT"){module.push(loc);}
				module.push(bundleName);
				var filespec = module.join("/") + '.js';
				loaded = dojo._loadPath(filespec, null, function(hash){
					// Use singleton with prototype to point to parent bundle, then mix-in result from loadPath
					var clazz = function(){};
					clazz.prototype = parent;
					bundle[jsLoc] = new clazz();
					for(var j in hash){ bundle[jsLoc][j] = hash[j]; }
				});
			}else{
				loaded = true;
			}
			if(loaded && bundle[jsLoc]){
				parent = bundle[jsLoc];
			}else{
				bundle[jsLoc] = parent;
			}
			
			if(availableFlatLocales){
				//Stop the locale path searching if we know the availableFlatLocales, since
				//the first call to this function will load the only bundle that is needed.
				return true;
			}
		});
	}

	//Save the best locale bundle as the target locale bundle when we know the
	//the available bundles.
	if(availableFlatLocales && targetLocale != bestLocale){
		bundle[targetLocale.replace(/-/g, '_')] = bundle[bestLocale.replace(/-/g, '_')];
	}
};

(function(){
	// If other locales are used, dojo.requireLocalization should load them as
	// well, by default. 
	// 
	// Override dojo.requireLocalization to do load the default bundle, then
	// iterate through the extraLocale list and load those translations as
	// well, unless a particular locale was requested.

	var extra = dojo.config.extraLocale;
	if(extra){
		if(!extra instanceof Array){
			extra = [extra];
		}

		var req = dojo.i18n._requireLocalization;
		dojo.i18n._requireLocalization = function(m, b, locale, availableFlatLocales){
			req(m,b,locale, availableFlatLocales);
			if(locale){return;}
			for(var i=0; i<extra.length; i++){
				req(m,b,extra[i], availableFlatLocales);
			}
		};
	}
})();

dojo.i18n._searchLocalePath = function(/*String*/locale, /*Boolean*/down, /*Function*/searchFunc){
	//	summary:
	//		A helper method to assist in searching for locale-based resources.
	//		Will iterate through the variants of a particular locale, either up
	//		or down, executing a callback function.  For example, "en-us" and
	//		true will try "en-us" followed by "en" and finally "ROOT".

	locale = dojo.i18n.normalizeLocale(locale);

	var elements = locale.split('-');
	var searchlist = [];
	for(var i = elements.length; i > 0; i--){
		searchlist.push(elements.slice(0, i).join('-'));
	}
	searchlist.push(false);
	if(down){searchlist.reverse();}

	for(var j = searchlist.length - 1; j >= 0; j--){
		var loc = searchlist[j] || "ROOT";
		var stop = searchFunc(loc);
		if(stop){ break; }
	}
};

dojo.i18n._preloadLocalizations = function(/*String*/bundlePrefix, /*Array*/localesGenerated){
	//	summary:
	//		Load built, flattened resource bundles, if available for all
	//		locales used in the page. Only called by built layer files.

	function preload(locale){
		locale = dojo.i18n.normalizeLocale(locale);
		dojo.i18n._searchLocalePath(locale, true, function(loc){
			for(var i=0; i<localesGenerated.length;i++){
				if(localesGenerated[i] == loc){
					dojo["require"](bundlePrefix+"_"+loc);
					return true; // Boolean
				}
			}
			return false; // Boolean
		});
	}
	preload();
	var extra = dojo.config.extraLocale||[];
	for(var i=0; i<extra.length; i++){
		preload(extra[i]);
	}
};

}

if(!dojo._hasResource["com.ibm.data.JsonStore"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.data.JsonStore"] = true;
// A json store that can be used for the customize shelf
// dojo.data.ItemFileReadstore already is a JSON store, this store extends it and overwrites the _fetchItems function to do an AND instead of an OR search for the given keywords
// it also adds support for passing in parameters for an nls bundle and keywords

dojo.provide("com.ibm.data.JsonStore");







dojo.declare("com.ibm.data.JsonStore", 
		[dojo.data.ItemFileReadStore, com.ibm.data.ProxyHelper, com.ibm.data.CatalogMixin],
		{	
			nlsBundle: null,
		
			_getItemsFromLoadedData: function(/* Object */ dataObject){
				this.shelfBundle = dojo.i18n.getLocalization("com.ibm.bundles", "Shelf");
				
				var localizationPackageName = dataObject.localizationPackageName;
				var localizationBundleName = dataObject.localizationBundleName;
				if(localizationPackageName && localizationBundleName){
					this.nlsBundle = dojo.i18n.getLocalization(localizationPackageName, localizationBundleName);
				}
				this.inherited("_getItemsFromLoadedData",arguments);
			},
			
			mapItem: function(/*DatstoreItem*/item){
				var map = {};
				
				var label = this.getValue(item, "label", null);
				map["label"] = this.nlsBundle && this.nlsBundle[label] ? this.nlsBundle[label] : label;
				if(!map.label) map.label = this.shelfBundle["add_content_untitled"];
				
				var description = this.getValue(item, "description", null);
				map["description"] = this.nlsBundle && this.nlsBundle[description] ? this.nlsBundle[description] : description;
				
				map["url"] = this.getValue(item, "url", null);
				
				map["id"] = this.getValue(item, "id", null);
				
				map["thumbnail"] = this.getValue(item, "thumbnail", null);
				
				var help = this.getValue(item, "help", null);
				map["help"] = this.nlsBundle && this.nlsBundle[help] ? this.nlsBundle[help] : help;
				
				return map;
			},
		
			_fetchItems: function(/*Object*/ keywordArgs, /*Function*/ findCallback, /*Function*/ errorCallback){
				var self = this;
				var filter = function(requestArgs, arrayOfItems){
					
					var items = [];
					if(requestArgs.query){
						var filterKeywords = requestArgs.query.keywords;
						var ignoreCase = requestArgs.queryOptions ? requestArgs.queryOptions.ignoreCase : false; 
					
						var regexpList = {};
						for(var i = 0; i < filterKeywords.length; i++){
							var currFilter = filterKeywords[i];
							if(typeof currFilter === "string"){
								regexpList[currFilter] = dojo.data.util.filter.patternToRegExp("*"+currFilter+"*", ignoreCase);
							}
						}

						for(var i = 0; i < arrayOfItems.length; ++i){
							var match = true;
							var candidateItem = arrayOfItems[i];
							if(candidateItem === null){
								match = false; 
							} else {
								for(var j = 0; j < filterKeywords.length; j++){
									currFilter = filterKeywords[j];
									if(!self._containsValue(candidateItem, 'label', currFilter, regexpList[currFilter]) 
											&& !self._containsValue(candidateItem, 'description', currFilter, regexpList[currFilter])){
										match = false;
									}
								}
							}
							
							if(match){
								items.push(candidateItem);
							}
						}
						findCallback(items, requestArgs);
					} else {
						for(var i = 0; i < arrayOfItems.length; ++i){
							var item = arrayOfItems[i];
							if(item !== null){
								items.push(item);
							}
						}
						findCallback(items, requestArgs);
					}
			};

			if(this._loadFinished){
				filter(keywordArgs, this._getItemsArray(keywordArgs.queryOptions));
			} else {

				if(this._jsonFileUrl){
					if(this._loadInProgress){
						this._queuedFetches.push({args: keywordArgs, filter: filter});
					} else {
						this._loadInProgress = true;
						var getArgs = {
								url: self._jsonFileUrl, 
								handleAs: "json-comment-optional"
						};
						var getHandler = dojo.xhrGet(getArgs);
						getHandler.addCallback(function(data){
							try{
								self._getItemsFromLoadedData(data);
								self._loadFinished = true;
								self._loadInProgress = false;
				
								filter(keywordArgs, self._getItemsArray(keywordArgs.queryOptions));
								self._handleQueuedFetches();
							}catch(e){
								self._loadFinished = true;
								self._loadInProgress = false;
								errorCallback(e, keywordArgs);
							}
						});
						getHandler.addErrback(function(error){
							self._loadInProgress = false;
							errorCallback(error, keywordArgs);
						});
					}
				} else if(this._jsonData){
					try{
						this._loadFinished = true;
						this._getItemsFromLoadedData(this._jsonData);
						this._jsonData = null;
						filter(keywordArgs, this._getItemsArray(keywordArgs.queryOptions));
					}catch(e){
						errorCallback(e, keywordArgs);
					}
				} else {
					errorCallback(new Error("dojo.data.ItemFileReadStore: No JSON source data was provided as either URL or a nested Javascript object."), keywordArgs);
				}
			}
		}
});

}

if(!dojo._hasResource["dijit._base.focus"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._base.focus"] = true;
dojo.provide("dijit._base.focus");

// summary:
//		These functions are used to query or set the focus and selection.
//
//		Also, they trace when widgets become actived/deactivated,
//		so that the widget can fire _onFocus/_onBlur events.
//		"Active" here means something similar to "focused", but
//		"focus" isn't quite the right word because we keep track of
//		a whole stack of "active" widgets.  Example:  Combobutton --> Menu -->
//		MenuItem.   The onBlur event for Combobutton doesn't fire due to focusing
//		on the Menu or a MenuItem, since they are considered part of the
//		Combobutton widget.  It only happens when focus is shifted
//		somewhere completely different.

dojo.mixin(dijit,
{
	// _curFocus: DomNode
	//		Currently focused item on screen
	_curFocus: null,

	// _prevFocus: DomNode
	//		Previously focused item on screen
	_prevFocus: null,

	isCollapsed: function(){
		// summary:
		//		Returns true if there is no text selected
		var _document = dojo.doc;
		if(_document.selection){ // IE
			var s=_document.selection;
			if(s.type=='Text'){
				return !s.createRange().htmlText.length; // Boolean
			}else{ //Control range
				return !s.createRange().length; // Boolean
			}
		}else{
			var _window = dojo.global;
			var selection = _window.getSelection();
			
			if(dojo.isString(selection)){ // Safari
				// TODO: this is dead code; safari is taking the else branch.  remove after 1.3.
				return !selection; // Boolean
			}else{ // Mozilla/W3
				return !selection || selection.isCollapsed || !selection.toString(); // Boolean
			}
		}
	},

	getBookmark: function(){
		// summary:
		//		Retrieves a bookmark that can be used with moveToBookmark to return to the same range
		var bookmark, selection = dojo.doc.selection;
		if(selection){ // IE
			var range = selection.createRange();
			if(selection.type.toUpperCase()=='CONTROL'){
				if(range.length){
					bookmark=[];
					var i=0,len=range.length;
					while(i<len){
						bookmark.push(range.item(i++));
					}
				}else{
					bookmark=null;
				}
			}else{
				bookmark = range.getBookmark();
			}
		}else{
			if(window.getSelection){
				selection = dojo.global.getSelection();
				if(selection){
					range = selection.getRangeAt(0);
					bookmark = range.cloneRange();
				}
			}else{
				console.warn("No idea how to store the current selection for this browser!");
			}
		}
		return bookmark; // Array
	},

	moveToBookmark: function(/*Object*/bookmark){
		// summary:
		//		Moves current selection to a bookmark
		// bookmark:
		//		This should be a returned object from dojo.html.selection.getBookmark()
		var _document = dojo.doc;
		if(_document.selection){ // IE
			var range;
			if(dojo.isArray(bookmark)){
				range = _document.body.createControlRange();
				//range.addElement does not have call/apply method, so can not call it directly
				//range is not available in "range.addElement(item)", so can't use that either
				dojo.forEach(bookmark, function(n){
					range.addElement(n);
				});
			}else{
				range = _document.selection.createRange();
				range.moveToBookmark(bookmark);
			}
			range.select();
		}else{ //Moz/W3C
			var selection = dojo.global.getSelection && dojo.global.getSelection();
			if(selection && selection.removeAllRanges){
				selection.removeAllRanges();
				selection.addRange(bookmark);
			}else{
				console.warn("No idea how to restore selection for this browser!");
			}
		}
	},

	getFocus: function(/*Widget?*/menu, /*Window?*/openedForWindow){
		// summary:
		//		Returns the current focus and selection.
		//		Called when a popup appears (either a top level menu or a dialog),
		//		or when a toolbar/menubar receives focus
		//
		// menu:
		//		The menu that's being opened
		//
		// openedForWindow:
		//		iframe in which menu was opened
		//
		// returns:
		//		A handle to restore focus/selection

		return {
			// Node to return focus to
			node: menu && dojo.isDescendant(dijit._curFocus, menu.domNode) ? dijit._prevFocus : dijit._curFocus,

			// Previously selected text
			bookmark:
				!dojo.withGlobal(openedForWindow||dojo.global, dijit.isCollapsed) ?
				dojo.withGlobal(openedForWindow||dojo.global, dijit.getBookmark) :
				null,

			openedForWindow: openedForWindow
		}; // Object
	},

	focus: function(/*Object || DomNode */ handle){
		// summary:
		//		Sets the focused node and the selection according to argument.
		//		To set focus to an iframe's content, pass in the iframe itself.
		// handle:
		//		object returned by get(), or a DomNode

		if(!handle){ return; }

		var node = "node" in handle ? handle.node : handle,		// because handle is either DomNode or a composite object
			bookmark = handle.bookmark,
			openedForWindow = handle.openedForWindow;

		// Set the focus
		// Note that for iframe's we need to use the <iframe> to follow the parentNode chain,
		// but we need to set focus to iframe.contentWindow
		if(node){
			var focusNode = (node.tagName.toLowerCase()=="iframe") ? node.contentWindow : node;
			if(focusNode && focusNode.focus){
				try{
					// Gecko throws sometimes if setting focus is impossible,
					// node not displayed or something like that
					focusNode.focus();
				}catch(e){/*quiet*/}
			}			
			dijit._onFocusNode(node);
		}

		// set the selection
		// do not need to restore if current selection is not empty
		// (use keyboard to select a menu item)
		if(bookmark && dojo.withGlobal(openedForWindow||dojo.global, dijit.isCollapsed)){
			if(openedForWindow){
				openedForWindow.focus();
			}
			try{
				dojo.withGlobal(openedForWindow||dojo.global, dijit.moveToBookmark, null, [bookmark]);
			}catch(e){
				/*squelch IE internal error, see http://trac.dojotoolkit.org/ticket/1984 */
			}
		}
	},

	// _activeStack: Array
	//		List of currently active widgets (focused widget and it's ancestors)
	_activeStack: [],

	registerIframe: function(/*DomNode*/ iframe){
		// summary:
		//		Registers listeners on the specified iframe so that any click
		//		or focus event on that iframe (or anything in it) is reported
		//		as a focus/click event on the <iframe> itself.
		// description:
		//		Currently only used by editor.
		dijit.registerWin(iframe.contentWindow, iframe);
	},
		

	registerWin: function(/*Window?*/targetWindow, /*DomNode?*/ effectiveNode){
		// summary:
		//		Registers listeners on the specified window (either the main
		//		window or an iframe's window) to detect when the user has clicked somewhere
		//		or focused somewhere.
		// description:
		//		Users should call registerIframe() instead of this method.
		// targetWindow:
		//		If specified this is the window associated with the iframe,
		//		i.e. iframe.contentWindow.
		// effectiveNode:
		//		If specified, report any focus events inside targetWindow as
		//		an event on effectiveNode, rather than on evt.target.

		// TODO: make this function private in 2.0; Editor/users should call registerIframe(),
		// or if Editor stops using <iframe> altogether than we can probably just drop
		// the whole public API.

		dojo.connect(targetWindow.document, "onmousedown", function(evt){
			dijit._justMouseDowned = true;
			setTimeout(function(){ dijit._justMouseDowned = false; }, 0);
			dijit._onTouchNode(effectiveNode||evt.target||evt.srcElement);
		});
		//dojo.connect(targetWindow, "onscroll", ???);

		// Listen for blur and focus events on targetWindow's document.
		// IIRC, I'm using attachEvent() rather than dojo.connect() because focus/blur events don't bubble
		// through dojo.connect(), and also maybe to catch the focus events early, before onfocus handlers
		// fire.
		var doc = targetWindow.document;
		if(doc){
			if(dojo.isIE){
				doc.attachEvent('onactivate', function(evt){
					if(evt.srcElement.tagName.toLowerCase() != "#document"){
						dijit._onFocusNode(effectiveNode||evt.srcElement);
					}
				});
				doc.attachEvent('ondeactivate', function(evt){
					dijit._onBlurNode(effectiveNode||evt.srcElement);
				});
			}else{
				doc.addEventListener('focus', function(evt){
					dijit._onFocusNode(effectiveNode||evt.target);
				}, true);
				doc.addEventListener('blur', function(evt){
					dijit._onBlurNode(effectiveNode||evt.target);
				}, true);
			}
		}
		doc = null;	// prevent memory leak (apparent circular reference via closure)
	},

	_onBlurNode: function(/*DomNode*/ node){
		// summary:
		// 		Called when focus leaves a node.
		//		Usually ignored, _unless_ it *isn't* follwed by touching another node,
		//		which indicates that we tabbed off the last field on the page,
		//		in which case every widget is marked inactive
		dijit._prevFocus = dijit._curFocus;
		dijit._curFocus = null;

		if(dijit._justMouseDowned){
			// the mouse down caused a new widget to be marked as active; this blur event
			// is coming late, so ignore it.
			return;
		}

		// if the blur event isn't followed by a focus event then mark all widgets as inactive.
		if(dijit._clearActiveWidgetsTimer){
			clearTimeout(dijit._clearActiveWidgetsTimer);
		}
		dijit._clearActiveWidgetsTimer = setTimeout(function(){
			delete dijit._clearActiveWidgetsTimer;
			dijit._setStack([]);
			dijit._prevFocus = null;
		}, 100);
	},

	_onTouchNode: function(/*DomNode*/ node){
		// summary:
		//		Callback when node is focused or mouse-downed

		// ignore the recent blurNode event
		if(dijit._clearActiveWidgetsTimer){
			clearTimeout(dijit._clearActiveWidgetsTimer);
			delete dijit._clearActiveWidgetsTimer;
		}

		// compute stack of active widgets (ex: ComboButton --> Menu --> MenuItem)
		var newStack=[];
		try{
			while(node){
				if(node.dijitPopupParent){
					node=dijit.byId(node.dijitPopupParent).domNode;
				}else if(node.tagName && node.tagName.toLowerCase()=="body"){
					// is this the root of the document or just the root of an iframe?
					if(node===dojo.body()){
						// node is the root of the main document
						break;
					}
					// otherwise, find the iframe this node refers to (can't access it via parentNode,
					// need to do this trick instead). window.frameElement is supported in IE/FF/Webkit
					node=dijit.getDocumentWindow(node.ownerDocument).frameElement;
				}else{
					var id = node.getAttribute && node.getAttribute("widgetId");
					if(id){
						newStack.unshift(id);
					}
					node=node.parentNode;
				}
			}
		}catch(e){ /* squelch */ }

		dijit._setStack(newStack);
	},

	_onFocusNode: function(/*DomNode*/ node){
		// summary:
		//		Callback when node is focused

		if(!node){
			return;
		}

		if(node.nodeType == 9){
			// Ignore focus events on the document itself.  This is here so that
			// (for example) clicking the up/down arrows of a spinner
			// (which don't get focus) won't cause that widget to blur. (FF issue)
			return;
		}

		dijit._onTouchNode(node);

		if(node==dijit._curFocus){ return; }
		if(dijit._curFocus){
			dijit._prevFocus = dijit._curFocus;
		}
		dijit._curFocus = node;
		dojo.publish("focusNode", [node]);
	},

	_setStack: function(newStack){
		// summary:
		//		The stack of active widgets has changed.  Send out appropriate events and records new stack.

		var oldStack = dijit._activeStack;
		dijit._activeStack = newStack;

		// compare old stack to new stack to see how many elements they have in common
		for(var nCommon=0; nCommon<Math.min(oldStack.length, newStack.length); nCommon++){
			if(oldStack[nCommon] != newStack[nCommon]){
				break;
			}
		}

		// for all elements that have gone out of focus, send blur event
		for(var i=oldStack.length-1; i>=nCommon; i--){
			var widget = dijit.byId(oldStack[i]);
			if(widget){
				widget._focused = false;
				widget._hasBeenBlurred = true;
				if(widget._onBlur){
					widget._onBlur();
				}
				if (widget._setStateClass){
					widget._setStateClass();
				}
				dojo.publish("widgetBlur", [widget]);
			}
		}

		// for all element that have come into focus, send focus event
		for(i=nCommon; i<newStack.length; i++){
			widget = dijit.byId(newStack[i]);
			if(widget){
				widget._focused = true;
				if(widget._onFocus){
					widget._onFocus();
				}
				if (widget._setStateClass){
					widget._setStateClass();
				}
				dojo.publish("widgetFocus", [widget]);
			}
		}
	}
});

// register top window and all the iframes it contains
dojo.addOnLoad(function(){dijit.registerWin(window); });

}

if(!dojo._hasResource["dijit._base.manager"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._base.manager"] = true;
dojo.provide("dijit._base.manager");

dojo.declare("dijit.WidgetSet", null, {
	// summary:
	//		A set of widgets indexed by id. A default instance of this class is 
	//		available as `dijit.registry`
	//
	// example:
	//		Create a small list of widgets:
	//		|	var ws = new dijit.WidgetSet();
	//		|	ws.add(dijit.byId("one"));
	//		| 	ws.add(dijit.byId("two"));
	//		|	// destroy both:
	//		|	ws.forEach(function(w){ w.destroy(); });
	//
	// example:
	//		Using dijit.registry:
	//		|	dijit.registry.forEach(function(w){ /* do something */ });
	
	constructor: function(){
		this._hash = {};
	},

	add: function(/*Widget*/ widget){
		// summary:
		//		Add a widget to this list. If a duplicate ID is detected, a error is thrown.
		//
		// widget: dijit._Widget
		//		Any dijit._Widget subclass.
		if(this._hash[widget.id]){
			throw new Error("Tried to register widget with id==" + widget.id + " but that id is already registered");
		}
		this._hash[widget.id]=widget;
	},

	remove: function(/*String*/ id){
		// summary:
		//		Remove a widget from this WidgetSet. Does not destroy the widget; simply
		//		removes the reference.
		delete this._hash[id];
	},

	forEach: function(/*Function*/ func){
		// summary:
		//		Call specified function for each widget in this set.
		//
		// func:
		//		A callback function to run for each item. Is passed a the widget.
		//
		// example:
		//		Using the default `dijit.registry` instance:
		//		|	dijit.registry.forEach(function(widget){
		//		|			
		//		|	});
		for(var id in this._hash){
			func(this._hash[id]);
		}
	},

	filter: function(/*Function*/ filter){
		// summary:
		//		Filter down this WidgetSet to a smaller new WidgetSet
		//		Works the same as `dojo.filter` and `dojo.NodeList.filter`
		//		
		// filter:
		//		Callback function to test truthiness.
		//
		// example:
		//		Arbitrary: select the odd widgets in this list
		//		|	var i = 0;
		//		|	dijit.registry.filter(function(w){
		//		|		return ++i % 2 == 0;
		//		|	}).forEach(function(w){ /* odd ones */ });

		var res = new dijit.WidgetSet();
		this.forEach(function(widget){
			if(filter(widget)){ res.add(widget); }
		});
		return res; // dijit.WidgetSet
	},

	byId: function(/*String*/ id){
		// summary:
		//		Find a widget in this list by it's id. 
		// example:
		//		Test if an id is in a particular WidgetSet
		//		| var ws = new dijit.WidgetSet();
		//		| ws.add(dijit.byId("bar"));
		//		| var t = ws.byId("bar") // returns a widget
		//		| var x = ws.byId("foo"); // returns undefined
		
		return this._hash[id];	// dijit._Widget
	},

	byClass: function(/*String*/ cls){
		// summary:
		//		Reduce this widgetset to a new WidgetSet of a particular declaredClass
		// 
		// example:
		//		Find all titlePane's in a page:
		//		|	dijit.registry.byClass("dijit.TitlePane").forEach(function(tp){ tp.close(); });
		
		return this.filter(function(widget){ return widget.declaredClass==cls; });	// dijit.WidgetSet
	}
	
});

/*=====
dijit.registry = {
	// summary: A list of widgets on a page.
	// description: Is an instance of `dijit.WidgetSet`
};
=====*/
dijit.registry = new dijit.WidgetSet();

dijit._widgetTypeCtr = {};

dijit.getUniqueId = function(/*String*/widgetType){
	// summary: Generates a unique id for a given widgetType

	var id;
	do{
		id = widgetType + "_" +
			(widgetType in dijit._widgetTypeCtr ?
				++dijit._widgetTypeCtr[widgetType] : dijit._widgetTypeCtr[widgetType] = 0);
	}while(dijit.byId(id));
	return id; // String
};

dijit.findWidgets = function(/*DomNode*/ root){
	// summary:
	//		Search subtree under root, putting found widgets in outAry.
	//		Doesn't search for nested widgets (ie, widgets inside other widgets)
	
	var outAry = [];

	function getChildrenHelper(root){
		var list = dojo.isIE ? root.children : root.childNodes, i = 0, node;
		while(node = list[i++]){
			if(node.nodeType != 1){ continue; }
			var widgetId = node.getAttribute("widgetId");
			if(widgetId){
				var widget = dijit.byId(widgetId);
				outAry.push(widget);
			}else{
				getChildrenHelper(node);
			}
		}
	}

	getChildrenHelper(root);
	return outAry;
};

if(dojo.isIE){
	// Only run this for IE because we think it's only necessary in that case,
	// and because it causes problems on FF.  See bug #3531 for details.
	dojo.addOnWindowUnload(function(){
		dojo.forEach(dijit.findWidgets(dojo.body()), function(widget){
			if(widget.destroyRecursive){
				widget.destroyRecursive();
			}else if(widget.destroy){
				widget.destroy();
			}
		});
	});
}

dijit.byId = function(/*String|Widget*/id){
	// summary:
	//		Returns a widget by it's id, or if passed a widget, no-op (like dojo.byId())
	return (dojo.isString(id)) ? dijit.registry.byId(id) : id; // Widget
};

dijit.byNode = function(/* DOMNode */ node){
	// summary:
	//		Returns the widget corresponding to the given DOMNode
	return dijit.registry.byId(node.getAttribute("widgetId")); // Widget
};

dijit.getEnclosingWidget = function(/* DOMNode */ node){
	// summary:
	//		Returns the widget whose DOM tree contains the specified DOMNode, or null if
	//		the node is not contained within the DOM tree of any widget
	while(node){
		if(node.getAttribute && node.getAttribute("widgetId")){
			return dijit.registry.byId(node.getAttribute("widgetId"));
		}
		node = node.parentNode;
	}
	return null;
};

// elements that are tab-navigable if they have no tabindex value set
// (except for "a", which must have an href attribute)
dijit._tabElements = {
	area: true,
	button: true,
	input: true,
	object: true,
	select: true,
	textarea: true
};

dijit._isElementShown = function(/*Element*/elem){
	var style = dojo.style(elem);
	return (style.visibility != "hidden")
		&& (style.visibility != "collapsed")
		&& (style.display != "none")
		&& (dojo.attr(elem, "type") != "hidden");
}

dijit.isTabNavigable = function(/*Element*/elem){
	// summary:
	//		Tests if an element is tab-navigable
	if(dojo.hasAttr(elem, "disabled")){ return false; }
	var hasTabindex = dojo.hasAttr(elem, "tabindex");
	var tabindex = dojo.attr(elem, "tabindex");
	if(hasTabindex && tabindex >= 0) {
		return true; // boolean
	}
	var name = elem.nodeName.toLowerCase();
	if(((name == "a" && dojo.hasAttr(elem, "href"))
			|| dijit._tabElements[name])
		&& (!hasTabindex || tabindex >= 0)){
		return true; // boolean
	}
	return false; // boolean
};

dijit._getTabNavigable = function(/*DOMNode*/root){
	// summary:
	//		Finds descendants of the specified root node.
	//
	// description:
	//		Finds the following descendants of the specified root node:
	//		* the first tab-navigable element in document order
	//		  without a tabindex or with tabindex="0"
	//		* the last tab-navigable element in document order
	//		  without a tabindex or with tabindex="0"
	//		* the first element in document order with the lowest
	//		  positive tabindex value
	//		* the last element in document order with the highest
	//		  positive tabindex value
	var first, last, lowest, lowestTabindex, highest, highestTabindex;
	var walkTree = function(/*DOMNode*/parent){
		dojo.query("> *", parent).forEach(function(child){
			var isShown = dijit._isElementShown(child);
			if(isShown && dijit.isTabNavigable(child)){
				var tabindex = dojo.attr(child, "tabindex");
				if(!dojo.hasAttr(child, "tabindex") || tabindex == 0){
					if(!first){ first = child; }
					last = child;
				}else if(tabindex > 0){
					if(!lowest || tabindex < lowestTabindex){
						lowestTabindex = tabindex;
						lowest = child;
					}
					if(!highest || tabindex >= highestTabindex){
						highestTabindex = tabindex;
						highest = child;
					}
				}
			}
			if(isShown && child.nodeName.toUpperCase() != 'SELECT'){ walkTree(child) }
		});
	};
	if(dijit._isElementShown(root)){ walkTree(root) }
	return { first: first, last: last, lowest: lowest, highest: highest };
}
dijit.getFirstInTabbingOrder = function(/*String|DOMNode*/root){
	// summary:
	//		Finds the descendant of the specified root node
	//		that is first in the tabbing order
	var elems = dijit._getTabNavigable(dojo.byId(root));
	return elems.lowest ? elems.lowest : elems.first; // DomNode
};

dijit.getLastInTabbingOrder = function(/*String|DOMNode*/root){
	// summary:
	//		Finds the descendant of the specified root node
	//		that is last in the tabbing order
	var elems = dijit._getTabNavigable(dojo.byId(root));
	return elems.last ? elems.last : elems.highest; // DomNode
};

/*=====
dojo.mixin(dijit, {
	// defaultDuration: Integer
	//		The default animation speed (in ms) to use for all Dijit
	//		transitional animations, unless otherwise specified 
	//		on a per-instance basis. Defaults to 200, overrided by 
	//		`djConfig.defaultDuration`
	defaultDuration: 300
});
=====*/

dijit.defaultDuration = dojo.config["defaultDuration"] || 200;

}

if(!dojo._hasResource["dojo.AdapterRegistry"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.AdapterRegistry"] = true;
dojo.provide("dojo.AdapterRegistry");

dojo.AdapterRegistry = function(/*Boolean?*/ returnWrappers){
	//	summary:
	//		A registry to make contextual calling/searching easier.
	//	description:
	//		Objects of this class keep list of arrays in the form [name, check,
	//		wrap, directReturn] that are used to determine what the contextual
	//		result of a set of checked arguments is. All check/wrap functions
	//		in this registry should be of the same arity.
	//	example:
	//	|	// create a new registry
	//	|	var reg = new dojo.AdapterRegistry();
	//	|	reg.register("handleString",
	//	|		dojo.isString,
	//	|		function(str){
	//	|			// do something with the string here
	//	|		}
	//	|	);
	//	|	reg.register("handleArr",
	//	|		dojo.isArray,
	//	|		function(arr){
	//	|			// do something with the array here
	//	|		}
	//	|	);
	//	|
	//	|	// now we can pass reg.match() *either* an array or a string and
	//	|	// the value we pass will get handled by the right function
	//	|	reg.match("someValue"); // will call the first function
	//	|	reg.match(["someValue"]); // will call the second

	this.pairs = [];
	this.returnWrappers = returnWrappers || false; // Boolean
}

dojo.extend(dojo.AdapterRegistry, {
	register: function(/*String*/ name, /*Function*/ check, /*Function*/ wrap, /*Boolean?*/ directReturn, /*Boolean?*/ override){
		//	summary: 
		//		register a check function to determine if the wrap function or
		//		object gets selected
		//	name:
		//		a way to identify this matcher.
		//	check:
		//		a function that arguments are passed to from the adapter's
		//		match() function.  The check function should return true if the
		//		given arguments are appropriate for the wrap function.
		//	directReturn:
		//		If directReturn is true, the value passed in for wrap will be
		//		returned instead of being called. Alternately, the
		//		AdapterRegistry can be set globally to "return not call" using
		//		the returnWrappers property. Either way, this behavior allows
		//		the registry to act as a "search" function instead of a
		//		function interception library.
		//	override:
		//		If override is given and true, the check function will be given
		//		highest priority. Otherwise, it will be the lowest priority
		//		adapter.
		this.pairs[((override) ? "unshift" : "push")]([name, check, wrap, directReturn]);
	},

	match: function(/* ... */){
		// summary:
		//		Find an adapter for the given arguments. If no suitable adapter
		//		is found, throws an exception. match() accepts any number of
		//		arguments, all of which are passed to all matching functions
		//		from the registered pairs.
		for(var i = 0; i < this.pairs.length; i++){
			var pair = this.pairs[i];
			if(pair[1].apply(this, arguments)){
				if((pair[3])||(this.returnWrappers)){
					return pair[2];
				}else{
					return pair[2].apply(this, arguments);
				}
			}
		}
		throw new Error("No match found");
	},

	unregister: function(name){
		// summary: Remove a named adapter from the registry

		// FIXME: this is kind of a dumb way to handle this. On a large
		// registry this will be slow-ish and we can use the name as a lookup
		// should we choose to trade memory for speed.
		for(var i = 0; i < this.pairs.length; i++){
			var pair = this.pairs[i];
			if(pair[0] == name){
				this.pairs.splice(i, 1);
				return true;
			}
		}
		return false;
	}
});

}

if(!dojo._hasResource["dijit._base.place"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._base.place"] = true;
dojo.provide("dijit._base.place");



// ported from dojo.html.util

dijit.getViewport = function(){
	// summary:
	//		Returns the dimensions and scroll position of the viewable area of a browser window

	var scrollRoot = (dojo.doc.compatMode == 'BackCompat')? dojo.body() : dojo.doc.documentElement;

	// get scroll position
	var scroll = dojo._docScroll(); // scrollRoot.scrollTop/Left should work
	return { w: scrollRoot.clientWidth, h: scrollRoot.clientHeight, l: scroll.x, t: scroll.y };
};

/*=====
dijit.__Position = function(){
	// x: Integer
	//		horizontal coordinate in pixels, relative to document body
	// y: Integer
	//		vertical coordinate in pixels, relative to document body

	thix.x = x;
	this.y = y;
}
=====*/


dijit.placeOnScreen = function(
	/* DomNode */			node,
	/* dijit.__Position */	pos,
	/* String[] */			corners,
	/* dijit.__Position? */	padding){
	//	summary:
	//		Positions one of the node's corners at specified position
	//		such that node is fully visible in viewport.
	//	description:
	//		NOTE: node is assumed to be absolutely or relatively positioned.
	//	pos:
	//		Object like {x: 10, y: 20}
	//	corners:
	//		Array of Strings representing order to try corners in, like ["TR", "BL"].
	//		Possible values are:
	//			* "BL" - bottom left
	//			* "BR" - bottom right
	//			* "TL" - top left
	//			* "TR" - top right
	//	padding:
	//		set padding to put some buffer around the element you want to position.
	//	example:	
	//		Try to place node's top right corner at (10,20).
	//		If that makes node go (partially) off screen, then try placing
	//		bottom left corner at (10,20).
	//	|	placeOnScreen(node, {x: 10, y: 20}, ["TR", "BL"])

	var choices = dojo.map(corners, function(corner){
		var c = { corner: corner, pos: {x:pos.x,y:pos.y} };
		if(padding){
			c.pos.x += corner.charAt(1) == 'L' ? padding.x : -padding.x;
			c.pos.y += corner.charAt(0) == 'T' ? padding.y : -padding.y;
		}
		return c; 
	});

	return dijit._place(node, choices);
}

dijit._place = function(/*DomNode*/ node, /* Array */ choices, /* Function */ layoutNode){
	// summary:
	//		Given a list of spots to put node, put it at the first spot where it fits,
	//		of if it doesn't fit anywhere then the place with the least overflow
	// choices: Array
	//		Array of elements like: {corner: 'TL', pos: {x: 10, y: 20} }
	//		Above example says to put the top-left corner of the node at (10,20)
	// layoutNode: Function(node, aroundNodeCorner, nodeCorner)
	//		for things like tooltip, they are displayed differently (and have different dimensions)
	//		based on their orientation relative to the parent.   This adjusts the popup based on orientation.

	// get {x: 10, y: 10, w: 100, h:100} type obj representing position of
	// viewport over document
	var view = dijit.getViewport();

	// This won't work if the node is inside a <div style="position: relative">,
	// so reattach it to dojo.doc.body.   (Otherwise, the positioning will be wrong
	// and also it might get cutoff)
	if(!node.parentNode || String(node.parentNode.tagName).toLowerCase() != "body"){
		dojo.body().appendChild(node);
	}

	var best = null;
	dojo.some(choices, function(choice){
		var corner = choice.corner;
		var pos = choice.pos;

		// configure node to be displayed in given position relative to button
		// (need to do this in order to get an accurate size for the node, because
		// a tooltips size changes based on position, due to triangle)
		if(layoutNode){
			layoutNode(node, choice.aroundCorner, corner);
		}

		// get node's size
		var style = node.style;
		var oldDisplay = style.display;
		var oldVis = style.visibility;
		style.visibility = "hidden";
		style.display = "";
		var mb = dojo.marginBox(node);
		style.display = oldDisplay;
		style.visibility = oldVis;

		// coordinates and size of node with specified corner placed at pos,
		// and clipped by viewport
		var startX = (corner.charAt(1) == 'L' ? pos.x : Math.max(view.l, pos.x - mb.w)),
			startY = (corner.charAt(0) == 'T' ? pos.y : Math.max(view.t, pos.y -  mb.h)),
			endX = (corner.charAt(1) == 'L' ? Math.min(view.l + view.w, startX + mb.w) : pos.x),
			endY = (corner.charAt(0) == 'T' ? Math.min(view.t + view.h, startY + mb.h) : pos.y),
			width = endX - startX,
			height = endY - startY,
			overflow = (mb.w - width) + (mb.h - height);

		if(best == null || overflow < best.overflow){
			best = {
				corner: corner,
				aroundCorner: choice.aroundCorner,
				x: startX,
				y: startY,
				w: width,
				h: height,
				overflow: overflow
			};
		}
		return !overflow;
	});

	node.style.left = best.x + "px";
	node.style.top = best.y + "px";
	if(best.overflow && layoutNode){
		layoutNode(node, best.aroundCorner, best.corner);
	}
	return best;
}

dijit.placeOnScreenAroundNode = function(
	/* DomNode */		node,
	/* DomNode */		aroundNode,
	/* Object */		aroundCorners,
	/* Function? */		layoutNode){

	// summary:
	//		Position node adjacent or kitty-corner to aroundNode
	//		such that it's fully visible in viewport.
	//
	// description:
	//		Place node such that corner of node touches a corner of
	//		aroundNode, and that node is fully visible.
	//
	// aroundCorners:
	//		Ordered list of pairs of corners to try matching up.
	//		Each pair of corners is represented as a key/value in the hash,
	//		where the key corresponds to the aroundNode's corner, and
	//		the value corresponds to the node's corner:
	//
	//	|	{ aroundNodeCorner1: nodeCorner1, aroundNodeCorner2: nodeCorner2,  ...}
	//
	//		The following strings are used to represent the four corners:
	//			* "BL" - bottom left
	//			* "BR" - bottom right
	//			* "TL" - top left
	//			* "TR" - top right
	//
	// layoutNode: Function(node, aroundNodeCorner, nodeCorner)
	//		For things like tooltip, they are displayed differently (and have different dimensions)
	//		based on their orientation relative to the parent.   This adjusts the popup based on orientation.
	//
	// example:
	//	|	dijit.placeOnScreenAroundNode(node, aroundNode, {'BL':'TL', 'TR':'BR'}); 
	//		This will try to position node such that node's top-left corner is at the same position
	//		as the bottom left corner of the aroundNode (ie, put node below
	//		aroundNode, with left edges aligned).  If that fails it will try to put
	// 		the bottom-right corner of node where the top right corner of aroundNode is
	//		(ie, put node above aroundNode, with right edges aligned)
	//

	// get coordinates of aroundNode
	aroundNode = dojo.byId(aroundNode);
	var oldDisplay = aroundNode.style.display;
	aroundNode.style.display="";
	// #3172: use the slightly tighter border box instead of marginBox
	var aroundNodeW = aroundNode.offsetWidth; //mb.w; 
	var aroundNodeH = aroundNode.offsetHeight; //mb.h;
	var aroundNodePos = dojo.coords(aroundNode, true);
	aroundNode.style.display=oldDisplay;

	// place the node around the calculated rectangle
	return dijit._placeOnScreenAroundRect(node, 
		aroundNodePos.x, aroundNodePos.y, aroundNodeW, aroundNodeH,	// rectangle
		aroundCorners, layoutNode);
};

/*=====
dijit.__Rectangle = function(){
	// x: Integer
	//		horizontal offset in pixels, relative to document body
	// y: Integer
	//		vertical offset in pixels, relative to document body
	// width: Integer
	//		width in pixels
	// height: Integer
	//		height in pixels

	thix.x = x;
	this.y = y;
	thix.width = width;
	this.height = height;
}
=====*/


dijit.placeOnScreenAroundRectangle = function(
	/* DomNode */			node,
	/* dijit.__Rectangle */	aroundRect,
	/* Object */			aroundCorners,
	/* Function */			layoutNode){

	// summary:
	//		Like dijit.placeOnScreenAroundNode(), except that the "around"
	//		parameter is an arbitrary rectangle on the screen (x, y, width, height)
	//		instead of a dom node.

	return dijit._placeOnScreenAroundRect(node, 
		aroundRect.x, aroundRect.y, aroundRect.width, aroundRect.height,	// rectangle
		aroundCorners, layoutNode);
};

dijit._placeOnScreenAroundRect = function(
	/* DomNode */		node,
	/* Number */		x,
	/* Number */		y,
	/* Number */		width,
	/* Number */		height,
	/* Object */		aroundCorners,
	/* Function */		layoutNode){

	// summary:
	//		Like dijit.placeOnScreenAroundNode(), except it accepts coordinates
	//		of a rectangle to place node adjacent to.

	// TODO: combine with placeOnScreenAroundRectangle()

	// Generate list of possible positions for node
	var choices = [];
	for(var nodeCorner in aroundCorners){
		choices.push( {
			aroundCorner: nodeCorner,
			corner: aroundCorners[nodeCorner],
			pos: {
				x: x + (nodeCorner.charAt(1) == 'L' ? 0 : width),
				y: y + (nodeCorner.charAt(0) == 'T' ? 0 : height)
			}
		});
	}

	return dijit._place(node, choices, layoutNode);
};

dijit.placementRegistry = new dojo.AdapterRegistry();
dijit.placementRegistry.register("node",
	function(n, x){
		return typeof x == "object" &&
			typeof x.offsetWidth != "undefined" && typeof x.offsetHeight != "undefined";
	},
	dijit.placeOnScreenAroundNode);
dijit.placementRegistry.register("rect",
	function(n, x){
		return typeof x == "object" &&
			"x" in x && "y" in x && "width" in x && "height" in x;
	},
	dijit.placeOnScreenAroundRectangle);

dijit.placeOnScreenAroundElement = function(
	/* DomNode */		node,
	/* Object */		aroundElement,
	/* Object */		aroundCorners,
	/* Function */		layoutNode){

	// summary:
	//		Like dijit.placeOnScreenAroundNode(), except it accepts an arbitrary object
	//		for the "around" argument and finds a proper processor to place a node.

	return dijit.placementRegistry.match.apply(dijit.placementRegistry, arguments);
};

}

if(!dojo._hasResource["dijit._base.window"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._base.window"] = true;
dojo.provide("dijit._base.window");

// TODO: remove this in 2.0, it's not used anymore, or at least not internally

dijit.getDocumentWindow = function(doc){
	// summary:
	// 		Get window object associated with document doc

	// In some IE versions (at least 6.0), document.parentWindow does not return a
	// reference to the real window object (maybe a copy), so we must fix it as well
	// We use IE specific execScript to attach the real window reference to
	// document._parentWindow for later use
	if(dojo.isIE && window !== document.parentWindow && !doc._parentWindow){
		/*
		In IE 6, only the variable "window" can be used to connect events (others
		may be only copies).
		*/
		doc.parentWindow.execScript("document._parentWindow = window;", "Javascript");
		//to prevent memory leak, unset it after use
		//another possibility is to add an onUnload handler which seems overkill to me (liucougar)
		var win = doc._parentWindow;
		doc._parentWindow = null;
		return win;	//	Window
	}

	return doc._parentWindow || doc.parentWindow || doc.defaultView;	//	Window
}

}

if(!dojo._hasResource["dijit._base.popup"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._base.popup"] = true;
dojo.provide("dijit._base.popup");





dijit.popup = new function(){
	// summary:
	//		This class is used to show/hide widgets as popups.

	var stack = [],
		beginZIndex=1000,
		idGen = 1;

	this.prepare = function(/*DomNode*/ node){
		// summary:
		//		Prepares a node to be used as a popup
		//
		// description:
		//		Attaches node to dojo.doc.body, and
		//		positions it off screen, but not display:none, so that
		//		the widget doesn't appear in the page flow and/or cause a blank
		//		area at the bottom of the viewport (making scrollbar longer), but
		//		initialization of contained widgets works correctly

		var s = node.style;
		s.visibility = "hidden";	// so TAB key doesn't navigate to hidden popup
		s.position = "absolute";
		s.top = "-9999px";
		if(s.display == "none"){
			s.display="";
		}
		dojo.body().appendChild(node);
	};

/*=====
dijit.popup.__OpenArgs = function(){
	// popup: Widget
	//		widget to display
	// parent: Widget
	//		the button etc. that is displaying this popup
	// around: DomNode
	//		DOM node (typically a button); place popup relative to this node.  (Specify this *or* "x" and "y" parameters.)
	// x: Integer
	//		Absolute horizontal position (in pixels) to place node at.  (Specify this *or* "around" parameter.)
	// y: Integer
	//		Absolute vertical position (in pixels) to place node at.  (Specity this *or* "around" parameter.)
	// orient: Object || String
	//		When the around parameter is specified, orient should be an 
	//		ordered list of tuples of the form (around-node-corner, popup-node-corner).
	//		dijit.popup.open() tries to position the popup according to each tuple in the list, in order,
	//		until the popup appears fully within the viewport.
	//
	//		The default value is {BL:'TL', TL:'BL'}, which represents a list of two tuples:
	//			1. (BL, TL)
	//			2. (TL, BL)
	//		where BL means "bottom left" and "TL" means "top left".
	//		So by default, it first tries putting the popup below the around node, left-aligning them,
	//		and then tries to put it above the around node, still left-aligning them.   Note that the
	//		default is horizontally reversed when in RTL mode.
	//
	//		When an (x,y) position is specified rather than an around node, orient is either
	//		"R" or "L".  R (for right) means that it tries to put the popup to the right of the mouse,
	//		specifically positioning the popup's top-right corner at the mouse position, and if that doesn't
	//		fit in the viewport, then it tries, in order, the bottom-right corner, the top left corner,
	//		and the top-right corner.
	// onCancel: Function
	//		callback when user has canceled the popup by
	//			1. hitting ESC or
	//			2. by using the popup widget's proprietary cancel mechanism (like a cancel button in a dialog);
	//			   i.e. whenever popupWidget.onCancel() is called, args.onCancel is called
	// onClose: Function
	//		callback whenever this popup is closed
	// onExecute: Function
	//		callback when user "executed" on the popup/sub-popup by selecting a menu choice, etc. (top menu only)
	// padding: dijit.__Position
	//		adding a buffer around the opening position. This is only useful when around is not set.
	this.popup = popup;
	this.parent = parent;
	this.around = around;
	this.x = x;
	this.y = y;
	this.orient = orient;
	this.onCancel = onCancel;
	this.onClose = onClose;
	this.onExecute = onExecute;
	this.padding = padding;
}
=====*/
	this.open = function(/*dijit.popup.__OpenArgs*/ args){
		// summary:
		//		Popup the widget at the specified position
		//
		// example:
		//		opening at the mouse position
		//		|		dijit.popup.open({popup: menuWidget, x: evt.pageX, y: evt.pageY});
		//
		// example:
		//		opening the widget as a dropdown
		//		|		dijit.popup.open({parent: this, popup: menuWidget, around: this.domNode, onClose: function(){...}  });
		//
		//		Note that whatever widget called dijit.popup.open() should also listen to its own _onBlur callback
		//		(fired from _base/focus.js) to know that focus has moved somewhere else and thus the popup should be closed.

		var widget = args.popup,
			orient = args.orient || {'BL':'TL', 'TL':'BL'},
			around = args.around,
			id = (args.around && args.around.id) ? (args.around.id+"_dropdown") : ("popup_"+idGen++);

		// make wrapper div to hold widget and possibly hold iframe behind it.
		// we can't attach the iframe as a child of the widget.domNode because
		// widget.domNode might be a <table>, <ul>, etc.
		var wrapper = dojo.create("div",{
			id: id, 
			"class":"dijitPopup",
			style:{
				zIndex: beginZIndex + stack.length,
				visibility:"hidden"
			}
		}, dojo.body());
		dijit.setWaiRole(wrapper, "presentation");
		
		// prevent transient scrollbar causing misalign (#5776)
		wrapper.style.left = wrapper.style.top = "0px";		

		if(args.parent){
			wrapper.dijitPopupParent=args.parent.id;
		}

		var s = widget.domNode.style;
		s.display = "";
		s.visibility = "";
		s.position = "";
		s.top = "0px";
		wrapper.appendChild(widget.domNode);

		var iframe = new dijit.BackgroundIframe(wrapper);

		// position the wrapper node
		var best = around ?
			dijit.placeOnScreenAroundElement(wrapper, around, orient, widget.orient ? dojo.hitch(widget, "orient") : null) :
			dijit.placeOnScreen(wrapper, args, orient == 'R' ? ['TR','BR','TL','BL'] : ['TL','BL','TR','BR'], args.padding);

		wrapper.style.visibility = "visible";
		// TODO: use effects to fade in wrapper

		var handlers = [];

		// Compute the closest ancestor popup that's *not* a child of another popup.
		// Ex: For a TooltipDialog with a button that spawns a tree of menus, find the popup of the button.
		var getTopPopup = function(){
			for(var pi=stack.length-1; pi > 0 && stack[pi].parent === stack[pi-1].widget; pi--){
				/* do nothing, just trying to get right value for pi */
			}
			return stack[pi];
		}

		// provide default escape and tab key handling
		// (this will work for any widget, not just menu)
		handlers.push(dojo.connect(wrapper, "onkeypress", this, function(evt){
			if(evt.charOrCode == dojo.keys.ESCAPE && args.onCancel){
				dojo.stopEvent(evt);
				args.onCancel();
			}else if(evt.charOrCode === dojo.keys.TAB){
				dojo.stopEvent(evt);
				var topPopup = getTopPopup();
				if(topPopup && topPopup.onCancel){
					topPopup.onCancel();
				}
			}
		}));

		// watch for cancel/execute events on the popup and notify the caller
		// (for a menu, "execute" means clicking an item)
		if(widget.onCancel){
			handlers.push(dojo.connect(widget, "onCancel", null, args.onCancel));
		}

		handlers.push(dojo.connect(widget, widget.onExecute ? "onExecute" : "onChange", null, function(){
			var topPopup = getTopPopup();
			if(topPopup && topPopup.onExecute){
				topPopup.onExecute();
			}
		}));

		stack.push({
			wrapper: wrapper,
			iframe: iframe,
			widget: widget,
			parent: args.parent,
			onExecute: args.onExecute,
			onCancel: args.onCancel,
 			onClose: args.onClose,
			handlers: handlers
		});

		if(widget.onOpen){
			widget.onOpen(best);
		}

		return best;
	};

	this.close = function(/*Widget*/ popup){
		// summary:
		//		Close specified popup and any popups that it parented
		while(dojo.some(stack, function(elem){return elem.widget == popup;})){
			var top = stack.pop(),
				wrapper = top.wrapper,
				iframe = top.iframe,
				widget = top.widget,
				onClose = top.onClose;
	
			if(widget.onClose){
				widget.onClose();
			}
			dojo.forEach(top.handlers, dojo.disconnect);
	
			// #2685: check if the widget still has a domNode so ContentPane can change its URL without getting an error
			if(!widget||!widget.domNode){ return; }
			
			this.prepare(widget.domNode);

			iframe.destroy();
			dojo.destroy(wrapper);
	
			if(onClose){
				onClose();
			}
		}
	};
}();

dijit._frames = new function(){
	// summary: cache of iframes
	var queue = [];

	this.pop = function(){
		var iframe;
		if(queue.length){
			iframe = queue.pop();
			iframe.style.display="";
		}else{
			if(dojo.isIE){
				var burl = dojo.config["dojoBlankHtmlUrl"] || (dojo.moduleUrl("dojo", "resources/blank.html")+"") || "javascript:\"\"";
				var html="<iframe src='" + burl + "'"
					+ " style='position: absolute; left: 0px; top: 0px;"
					+ "z-index: -1; filter:Alpha(Opacity=\"0\");'>";
				iframe = dojo.doc.createElement(html);
			}else{
			 	iframe = dojo.create("iframe");
				iframe.src = 'javascript:""';
				iframe.className = "dijitBackgroundIframe";
			}
			iframe.tabIndex = -1; // Magic to prevent iframe from getting focus on tab keypress - as style didnt work.
			dojo.body().appendChild(iframe);
		}
		return iframe;
	};

	this.push = function(iframe){
		iframe.style.display="none";
		if(dojo.isIE){
			iframe.style.removeExpression("width");
			iframe.style.removeExpression("height");
		}
		queue.push(iframe);
	}
}();


dijit.BackgroundIframe = function(/* DomNode */node){
	// summary:
	//		For IE z-index schenanigans. id attribute is required.
	//
	// description:
	//		new dijit.BackgroundIframe(node)
	//			Makes a background iframe as a child of node, that fills
	//			area (and position) of node

	if(!node.id){ throw new Error("no id"); }
	if(dojo.isIE < 7 || (dojo.isFF < 3 && dojo.hasClass(dojo.body(), "dijit_a11y"))){
		var iframe = dijit._frames.pop();
		node.appendChild(iframe);
		if(dojo.isIE){
			iframe.style.setExpression("width", dojo._scopeName + ".doc.getElementById('" + node.id + "').offsetWidth");
			iframe.style.setExpression("height", dojo._scopeName + ".doc.getElementById('" + node.id + "').offsetHeight");
		}
		this.iframe = iframe;
	}
};

dojo.extend(dijit.BackgroundIframe, {
	destroy: function(){
		//	summary: destroy the iframe
		if(this.iframe){
			dijit._frames.push(this.iframe);
			delete this.iframe;
		}
	}
});

}

if(!dojo._hasResource["dijit._base.scroll"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._base.scroll"] = true;
dojo.provide("dijit._base.scroll");

dijit.scrollIntoView = function(/* DomNode */node){
	// summary:
	//		Scroll the passed node into view, if it is not.

	// don't rely on that node.scrollIntoView works just because the function is there
	// it doesnt work in Konqueror or Opera even though the function is there and probably
	//	not safari either
	// native scrollIntoView() causes FF3's whole window to scroll if there is no scroll bar 
	//	on the immediate parent
	// dont like browser sniffs implementations but sometimes you have to use it
	// It's not enough just to scroll the menu node into view if
	// node.scrollIntoView hides part of the parent's scrollbar,
	// so just manage the parent scrollbar ourselves

	//var testdir="H"; //debug
	try{ // catch unexpected/unrecreatable errors (#7808) since we can recover using a semi-acceptable native method
	node = dojo.byId(node);
	var doc = node.ownerDocument || dojo.doc;
	var body = doc.body || dojo.body();
	var html = doc.documentElement || body.parentNode;
	// if FF2 (which is perfect) or an untested browser, then use the native method

	if((!(dojo.isFF >= 3 || dojo.isIE || dojo.isWebKit) || node == body || node == html) && (typeof node.scrollIntoView == "function")){ // FF2 is perfect, too bad FF3 is not
		node.scrollIntoView(false); // short-circuit to native if possible
		return;
	}
	var ltr = dojo._isBodyLtr();
	var isIE8strict = dojo.isIE >= 8 && !compatMode;
	var rtl = !ltr && !isIE8strict; // IE8 flips scrolling so pretend it's ltr
	// body and html elements are all messed up due to browser bugs and inconsistencies related to doctype
	// normalize the values before proceeding (FF2 is not listed since its native behavior is perfect)
	// for computation simplification, client and offset width and height are the same for body and html
	// strict:       html:       |      body:       | compatMode:
	//           width   height  |  width   height  |------------
	//    ie*:  clientW  clientH | scrollW  clientH | CSS1Compat
	//    ff3:  clientW  clientH |HscrollW  clientH | CSS1Compat
	//    sf3:  clientW  clientH | clientW HclientH | CSS1Compat
	//    op9:  clientW  clientH |HscrollW  clientH | CSS1Compat
	// ---------------------------------------------|-----------
	//   none:        html:      |      body:       |
	//           width    height |  width   height  |
	//    ie*: BclientW BclientH | clientW  clientH | BackCompat
	//    ff3: BclientW BclientH | clientW  clientH | BackCompat
	//    sf3:  clientW  clientH | clientW HclientH | CSS1Compat
	//    op9: BclientW BclientH | clientW  clientH | BackCompat
	// ---------------------------------------------|-----------
	//  loose:        html:      |      body:       |
	//           width    height |  width   height  |
	//    ie*:  clientW  clientH | scrollW  clientH | CSS1Compat
	//    ff3: BclientW BclientH | clientW  clientH | BackCompat
	//    sf3:  clientW  clientH | clientW HclientH | CSS1Compat
	//    op9:  clientW  clientH |HscrollW  clientH | CSS1Compat
	var scrollRoot = body;
	var compatMode = doc.compatMode == 'BackCompat';
	if(compatMode){ // BODY is scrollable, HTML has same client size
		// body client values already OK
		html._offsetWidth = html._clientWidth = body._offsetWidth = body.clientWidth;
		html._offsetHeight = html._clientHeight = body._offsetHeight = body.clientHeight;
	}else{
		if(dojo.isWebKit){
			body._offsetWidth = body._clientWidth  = html.clientWidth;
			body._offsetHeight = body._clientHeight = html.clientHeight;
		}else{
			scrollRoot = html;
		}
		html._offsetHeight = html.clientHeight;
		html._offsetWidth  = html.clientWidth;
	}

	function isFixedPosition(element){
		var ie = dojo.isIE;
		return ((ie <= 6 || (ie >= 7 && compatMode))? false : (dojo.style(element, 'position').toLowerCase() == "fixed"));
	}

	function addPseudoAttrs(element){
		var parent = element.parentNode;
		var offsetParent = element.offsetParent;
		if(offsetParent == null || isFixedPosition(element)){ // position:fixed has no real offsetParent
			offsetParent = html; // prevents exeptions
			parent = (element == body)? html : null;
		}
		// all the V/H object members below are to reuse code for both directions
		element._offsetParent = offsetParent;
		element._parent = parent;
		//
		//
		var bp = dojo._getBorderExtents(element);
		element._borderStart = { H:(isIE8strict && !ltr)? (bp.w-bp.l):bp.l, V:bp.t };
		element._borderSize = { H:bp.w, V:bp.h };
		element._scrolledAmount = { H:element.scrollLeft, V:element.scrollTop };
		element._offsetSize = { H: element._offsetWidth||element.offsetWidth, V: element._offsetHeight||element.offsetHeight };
		//
		// IE8 flips everything in rtl mode except offsetLeft and borderLeft - so manually change offsetLeft to offsetRight here 
		element._offsetStart = { H:(isIE8strict && !ltr)? offsetParent.clientWidth-element.offsetLeft-element._offsetSize.H:element.offsetLeft, V:element.offsetTop };
		//
		element._clientSize = { H:element._clientWidth||element.clientWidth, V:element._clientHeight||element.clientHeight };
		if(element != body && element != html && element != node){
			for(var dir in element._offsetSize){ // for both x and y directions
				var scrollBarSize = element._offsetSize[dir] - element._clientSize[dir] - element._borderSize[dir];
				//if(dir==testdir)
				var hasScrollBar = element._clientSize[dir] > 0 && scrollBarSize > 0; // can't check for a specific scrollbar size since it changes dramatically as you zoom
				//if(dir==testdir)
				if(hasScrollBar){
					element._offsetSize[dir] -= scrollBarSize;
					if(dojo.isIE && rtl && dir=="H"){ element._offsetStart[dir] += scrollBarSize; }
				}
			}
		}
	}

	var element = node;
	while(element != null){
		if(isFixedPosition(element)){ node.scrollIntoView(false); return; } //TODO: handle without native call
		addPseudoAttrs(element);
		element = element._parent;
	}
	if(dojo.isIE && node._parent){ // if no parent, then offsetParent._borderStart may not tbe set
		var offsetParent = node._offsetParent;
		//
		node._offsetStart.H += offsetParent._borderStart.H;
		node._offsetStart.V += offsetParent._borderStart.V;
	}
	if(dojo.isIE >= 7 && scrollRoot == html && rtl && body._offsetStart && body._offsetStart.H == 0){ // IE7 bug
		var scroll = html.scrollWidth - html._offsetSize.H;
		if(scroll > 0){
			//
			body._offsetStart.H = -scroll;
		}
	}
	if(dojo.isIE <= 6 && !compatMode){
		html._offsetSize.H += html._borderSize.H;
		html._offsetSize.V += html._borderSize.V;
	}
	// eliminate offsetLeft/Top oddities by tweaking scroll for ease of computation
	if(rtl && body._offsetStart && scrollRoot == html && html._scrolledAmount){
		var ofs = body._offsetStart.H;
		if(ofs < 0){
			html._scrolledAmount.H += ofs;
			body._offsetStart.H = 0;
		}
	}
	element = node;
	while(element){
		var parent = element._parent;
		if(!parent){ break; }
			//
			if(parent.tagName == "TD"){
				var table = parent._parent._parent._parent; // point to TABLE
				if(parent != element._offsetParent && parent._offsetParent != element._offsetParent){
					parent = table; // child of TD has the same offsetParent as TABLE, so skip TD, TR, and TBODY (ie. verticalslider)
				}
			}
			// check if this node and its parent share the same offsetParent
			var relative = element._offsetParent == parent;
			//
			for(var dir in element._offsetStart){ // for both x and y directions
				var otherDir = dir=="H"? "V" : "H";
				if(rtl && dir=="H" && (parent != html) && (parent != body) && (dojo.isIE || dojo.isWebKit) && parent._clientSize.H > 0 && parent.scrollWidth > parent._clientSize.H){ // scroll starts on the right
					var delta = parent.scrollWidth - parent._clientSize.H;
					//
					if(delta > 0){
						parent._scrolledAmount.H -= delta;
					} // match FF3 which has cool negative scrollLeft values
				}
				if(parent._offsetParent.tagName == "TABLE"){ // make it consistent
					if(dojo.isIE){ // make it consistent with Safari and FF3 and exclude the starting TABLE border of TABLE children
						parent._offsetStart[dir] -= parent._offsetParent._borderStart[dir];
						parent._borderStart[dir] = parent._borderSize[dir] = 0;
					}
					else{
						parent._offsetStart[dir] += parent._offsetParent._borderStart[dir];
					}
				}
				//if(dir==testdir)
				if(dojo.isIE){
					//if(dir==testdir)
					parent._offsetStart[dir] += parent._offsetParent._borderStart[dir];
				}
				//if(dir==testdir)
				// underflow = visible gap between parent and this node taking scrolling into account
				// if negative, part of the node is obscured by the parent's beginning and should be scrolled to become visible
				var underflow = element._offsetStart[dir] - parent._scrolledAmount[dir] - (relative? 0 : parent._offsetStart[dir]) - parent._borderStart[dir];
				// if overflow is positive, number of pixels obscured by the parent's end
				var overflow = underflow + element._offsetSize[dir] - parent._offsetSize[dir] + parent._borderSize[dir];
				//if(dir==testdir)
				var scrollAttr = (dir=="H")? "scrollLeft" : "scrollTop";
				// see if we should scroll forward or backward
				var reverse = dir=="H" && rtl; // flip everything
				var underflowScroll = reverse? -overflow : underflow;
				var overflowScroll = reverse? -underflow : overflow;
				// don't scroll if the over/underflow signs are opposite since that means that
				// the node extends beyond parent's boundary in both/neither directions
				var scrollAmount = (underflowScroll*overflowScroll <= 0)? 0 : Math[(underflowScroll < 0)? "max" : "min"](underflowScroll, overflowScroll);
				//if(dir==testdir)
				if(scrollAmount != 0){
					var oldScroll = parent[scrollAttr];
					parent[scrollAttr] += (reverse)? -scrollAmount : scrollAmount; // actually perform the scroll
					var scrolledAmount = parent[scrollAttr] - oldScroll; // in case the scroll failed
					//if(dir==testdir)
				}
				if(relative){
					element._offsetStart[dir] += parent._offsetStart[dir];
				}
				element._offsetStart[dir] -= parent[scrollAttr];
			}
			element._parent = parent._parent;
			element._offsetParent = parent._offsetParent;
	}
	parent = node;
	var next;
	while(parent && parent.removeAttribute){
		next = parent.parentNode;
		parent.removeAttribute('_offsetParent');
		parent.removeAttribute('_parent');
		parent = next;
	}
	}catch(error){
		console.error('scrollIntoView: ' + error);
		node.scrollIntoView(false);
	}
};

}

if(!dojo._hasResource["dijit._base.sniff"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._base.sniff"] = true;
// summary:
//		Applies pre-set CSS classes to the top-level HTML node, based on:
// 			- browser (ex: dj_ie)
//			- browser version (ex: dj_ie6)
//			- box model (ex: dj_contentBox)
//			- text direction (ex: dijitRtl)
//
//		In addition, browser, browser version, and box model are
//		combined with an RTL flag when browser text is RTL.  ex: dj_ie-rtl.
//
//		Simply doing a require on this module will
//		establish this CSS.  Modified version of Morris' CSS hack.

dojo.provide("dijit._base.sniff");

(function(){
	
	var d = dojo,
		html = d.doc.documentElement,
		ie = d.isIE,
		opera = d.isOpera,
		maj = Math.floor,
		ff = d.isFF,
		boxModel = d.boxModel.replace(/-/,''),
		classes = {
			dj_ie: ie,
//			dj_ie55: ie == 5.5,
			dj_ie6: maj(ie) == 6,
			dj_ie7: maj(ie) == 7,
			dj_iequirks: ie && d.isQuirks,
			// NOTE: Opera not supported by dijit
			dj_opera: opera,
			dj_opera8: maj(opera) == 8,
			dj_opera9: maj(opera) == 9,
			dj_khtml: d.isKhtml,
			dj_webkit: d.isWebKit,
			dj_safari: d.isSafari,
			dj_gecko: d.isMozilla,
			dj_ff2: maj(ff) == 2,
			dj_ff3: maj(ff) == 3
		}; // no dojo unsupported browsers
		
	classes["dj_" + boxModel] = true;
	
	// apply browser, browser version, and box model class names
	for(var p in classes){
		if(classes[p]){
			if(html.className){
				html.className += " " + p;
			}else{
				html.className = p;
			}
		}
	}

	// If RTL mode then add dijitRtl flag plus repeat existing classes
	// with -rtl extension
	// (unshift is to make this code run after <body> node is loaded but before parser runs)
	dojo._loaders.unshift(function(){
		if(!dojo._isBodyLtr()){
			html.className += " dijitRtl";
			for(var p in classes){
				if(classes[p]){
					html.className += " " + p + "-rtl";
				}
			}
		}
	});
	
})();

}

if(!dojo._hasResource["dijit._base.typematic"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._base.typematic"] = true;
dojo.provide("dijit._base.typematic");

dijit.typematic = {
	// summary:
	//		These functions are used to repetitively call a user specified callback
	//		method when a specific key or mouse click over a specific DOM node is
	//		held down for a specific amount of time.
	//		Only 1 such event is allowed to occur on the browser page at 1 time.

	_fireEventAndReload: function(){
		this._timer = null;
		this._callback(++this._count, this._node, this._evt);
		this._currentTimeout = (this._currentTimeout < 0) ? this._initialDelay : ((this._subsequentDelay > 1) ? this._subsequentDelay : Math.round(this._currentTimeout * this._subsequentDelay));
		this._timer = setTimeout(dojo.hitch(this, "_fireEventAndReload"), this._currentTimeout);
	},

	trigger: function(/*Event*/ evt, /* Object */ _this, /*DOMNode*/ node, /* Function */ callback, /* Object */ obj, /* Number */ subsequentDelay, /* Number */ initialDelay){
		// summary:
		//	    Start a timed, repeating callback sequence.
		//	    If already started, the function call is ignored.
		//	    This method is not normally called by the user but can be
		//	    when the normal listener code is insufficient.
		// evt:
		//		key or mouse event object to pass to the user callback
		// _this:
		//		pointer to the user's widget space.
		// node:
		//		the DOM node object to pass the the callback function
		// callback:
		//		function to call until the sequence is stopped called with 3 parameters:
		// count:
		//		integer representing number of repeated calls (0..n) with -1 indicating the iteration has stopped
		// node:
		//		the DOM node object passed in
		// evt:
		//		key or mouse event object
		// obj:
		//		user space object used to uniquely identify each typematic sequence
		// subsequentDelay:
		//		if > 1, the number of milliseconds until the 3->n events occur
		//		or else the fractional time multiplier for the next event's delay, default=0.9
		// initialDelay:
		//		the number of milliseconds until the 2nd event occurs, default=500ms
		if(obj != this._obj){
			this.stop();
			this._initialDelay = initialDelay || 500;
			this._subsequentDelay = subsequentDelay || 0.90;
			this._obj = obj;
			this._evt = evt;
			this._node = node;
			this._currentTimeout = -1;
			this._count = -1;
			this._callback = dojo.hitch(_this, callback);
			this._fireEventAndReload();
		}
	},

	stop: function(){
		// summary:
		//	  Stop an ongoing timed, repeating callback sequence.
		if(this._timer){
			clearTimeout(this._timer);
			this._timer = null;
		}
		if(this._obj){
			this._callback(-1, this._node, this._evt);
			this._obj = null;
		}
	},

	addKeyListener: function(/*DOMNode*/ node, /*Object*/ keyObject, /*Object*/ _this, /*Function*/ callback, /*Number*/ subsequentDelay, /*Number*/ initialDelay){
		// summary:
		//		Start listening for a specific typematic key.
		//		See also the trigger method for other parameters.
		// keyObject:
		//		an object defining the key to listen for.
		// charOrCode:
		//		the printable character (string) or keyCode (number) to listen for.
		// keyCode:
		//		(deprecated - use charOrCode) the keyCode (number) to listen for (implies charCode = 0).
		// charCode:
		//		(deprecated - use charOrCode) the charCode (number) to listen for.
		// ctrlKey:
		//		desired ctrl key state to initiate the calback sequence:
		//			- pressed (true)
		//			- released (false)
		//			- either (unspecified)
		// altKey:
		//		same as ctrlKey but for the alt key
		// shiftKey:
		//		same as ctrlKey but for the shift key
		// returns:
		//		an array of dojo.connect handles
		if(keyObject.keyCode){
			keyObject.charOrCode = keyObject.keyCode;
			dojo.deprecated("keyCode attribute parameter for dijit.typematic.addKeyListener is deprecated. Use charOrCode instead.", "", "2.0");
		}else if(keyObject.charCode){
			keyObject.charOrCode = String.fromCharCode(keyObject.charCode);
			dojo.deprecated("charCode attribute parameter for dijit.typematic.addKeyListener is deprecated. Use charOrCode instead.", "", "2.0");
		}
		return [
			dojo.connect(node, "onkeypress", this, function(evt){
				if(evt.charOrCode == keyObject.charOrCode &&
				(keyObject.ctrlKey === undefined || keyObject.ctrlKey == evt.ctrlKey) &&
				(keyObject.altKey === undefined || keyObject.altKey == evt.ctrlKey) &&
				(keyObject.shiftKey === undefined || keyObject.shiftKey == evt.ctrlKey)){
					dojo.stopEvent(evt);
					dijit.typematic.trigger(keyObject, _this, node, callback, keyObject, subsequentDelay, initialDelay);
				}else if(dijit.typematic._obj == keyObject){
					dijit.typematic.stop();
				}
			}),
			dojo.connect(node, "onkeyup", this, function(evt){
				if(dijit.typematic._obj == keyObject){
					dijit.typematic.stop();
				}
			})
		];
	},

	addMouseListener: function(/*DOMNode*/ node, /*Object*/ _this, /*Function*/ callback, /*Number*/ subsequentDelay, /*Number*/ initialDelay){
		// summary:
		//		Start listening for a typematic mouse click.
		//		See the trigger method for other parameters.
		// returns:
		//		an array of dojo.connect handles
		var dc = dojo.connect;
		return [
			dc(node, "mousedown", this, function(evt){
				dojo.stopEvent(evt);
				dijit.typematic.trigger(evt, _this, node, callback, node, subsequentDelay, initialDelay);
			}),
			dc(node, "mouseup", this, function(evt){
				dojo.stopEvent(evt);
				dijit.typematic.stop();
			}),
			dc(node, "mouseout", this, function(evt){
				dojo.stopEvent(evt);
				dijit.typematic.stop();
			}),
			dc(node, "mousemove", this, function(evt){
				dojo.stopEvent(evt);
			}),
			dc(node, "dblclick", this, function(evt){
				dojo.stopEvent(evt);
				if(dojo.isIE){
					dijit.typematic.trigger(evt, _this, node, callback, node, subsequentDelay, initialDelay);
					setTimeout(dojo.hitch(this, dijit.typematic.stop), 50);
				}
			})
		];
	},

	addListener: function(/*Node*/ mouseNode, /*Node*/ keyNode, /*Object*/ keyObject, /*Object*/ _this, /*Function*/ callback, /*Number*/ subsequentDelay, /*Number*/ initialDelay){
		// summary:
		//		Start listening for a specific typematic key and mouseclick.
		//		This is a thin wrapper to addKeyListener and addMouseListener.
		//		See the addMouseListener and addKeyListener methods for other parameters.
		// mouseNode:
		//		the DOM node object to listen on for mouse events.
		// keyNode:
		//		the DOM node object to listen on for key events.
		// returns:
		//		an array of dojo.connect handles
		return this.addKeyListener(keyNode, keyObject, _this, callback, subsequentDelay, initialDelay).concat(
			this.addMouseListener(mouseNode, _this, callback, subsequentDelay, initialDelay));
	}
};

}

if(!dojo._hasResource["dijit._base.wai"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._base.wai"] = true;
dojo.provide("dijit._base.wai");

dijit.wai = {
	onload: function(){
		// summary:
		//		Detects if we are in high-contrast mode or not

		// This must be a named function and not an anonymous
		// function, so that the widget parsing code can make sure it
		// registers its onload function after this function.
		// DO NOT USE "this" within this function.

		// create div for testing if high contrast mode is on or images are turned off
		var div = dojo.create("div",{
			id: "a11yTestNode",
			style:{
				cssText:'border: 1px solid;'
					+ 'border-color:red green;'
					+ 'position: absolute;'
					+ 'height: 5px;'
					+ 'top: -999px;'
					+ 'background-image: url("' + (dojo.config.blankGif || dojo.moduleUrl("dojo", "resources/blank.gif")) + '");'
			}
		}, dojo.body());

		// test it
		var cs = dojo.getComputedStyle(div);
		if(cs){
			var bkImg = cs.backgroundImage;
			var needsA11y = (cs.borderTopColor==cs.borderRightColor) || (bkImg != null && (bkImg == "none" || bkImg == "url(invalid-url:)" ));
			dojo[needsA11y ? "addClass" : "removeClass"](dojo.body(), "dijit_a11y");
			if(dojo.isIE){
				div.outerHTML = "";		// prevent mixed-content warning, see http://support.microsoft.com/kb/925014
			}else{
				dojo.body().removeChild(div);
			}
		}
	}
};

// Test if computer is in high contrast mode.
// Make sure the a11y test runs first, before widgets are instantiated.
if(dojo.isIE || dojo.isMoz){	// NOTE: checking in Safari messes things up
	dojo._loaders.unshift(dijit.wai.onload);
}

dojo.mixin(dijit,
{
	_XhtmlRoles: /banner|contentinfo|definition|main|navigation|search|note|secondary|seealso/,

	hasWaiRole: function(/*Element*/ elem, /*String*/ role){
		// summary:
		//		Determines if an element has a particular non-XHTML role.
		// returns:
		//		True if elem has the specific non-XHTML role attribute and false if not.
		// 		For backwards compatibility if role parameter not provided, 
		// 		returns true if has non XHTML role 
		var waiRole = this.getWaiRole(elem);		
		return role ? (waiRole.indexOf(role) > -1) : (waiRole.length > 0);
	},

	getWaiRole: function(/*Element*/ elem){
		// summary:
		//		Gets the non-XHTML role for an element (which should be a wai role).
		// returns:
		//		The non-XHTML role of elem or an empty string if elem
		//		does not have a role.
		 return dojo.trim((dojo.attr(elem, "role") || "").replace(this._XhtmlRoles,"").replace("wairole:",""));
	},

	setWaiRole: function(/*Element*/ elem, /*String*/ role){
		// summary:
		//		Sets the role on an element.
		// description:
		//		In other than FF2 replace existing role attribute with new role.
		//		FF3 supports XHTML and ARIA roles so    
		//		if elem already has an XHTML role, append this role to XHTML role 
		//		and remove other ARIA roles.
		//		On Firefox 2 and below, "wairole:" is
		//		prepended to the provided role value.

		var curRole = dojo.attr(elem, "role") || "";
		if(dojo.isFF < 3 || !this._XhtmlRoles.test(curRole)){
			dojo.attr(elem, "role", dojo.isFF < 3 ? "wairole:" + role : role);
		}else{
			if((" "+ curRole +" ").indexOf(" " + role + " ") < 0){
				var clearXhtml = dojo.trim(curRole.replace(this._XhtmlRoles, ""));
				var cleanRole = dojo.trim(curRole.replace(clearXhtml, ""));	 
         		dojo.attr(elem, "role", cleanRole + (cleanRole ? ' ' : '') + role);
			}
		}
	},

	removeWaiRole: function(/*Element*/ elem, /*String*/ role){
		// summary:
		//		Removes the specified non-XHTML role from an element.
		// 		Removes role attribute if no specific role provided (for backwards compat.)

		var roleValue = dojo.attr(elem, "role"); 
		if(!roleValue){ return; }
		if(role){
			var searchRole = dojo.isFF < 3 ? "wairole:" + role : role;
			var t = dojo.trim((" " + roleValue + " ").replace(" " + searchRole + " ", " "));
			dojo.attr(elem, "role", t);
		}else{
			elem.removeAttribute("role");	
		}
	},

	hasWaiState: function(/*Element*/ elem, /*String*/ state){
		// summary:
		//		Determines if an element has a given state.
		// description:
		//		On Firefox 2 and below, we check for an attribute in namespace
		//		"http://www.w3.org/2005/07/aaa" with a name of the given state.
		//		On all other browsers, we check for an attribute
		//		called "aria-"+state.
		// returns:
		//		true if elem has a value for the given state and
		//		false if it does not.
		if(dojo.isFF < 3){
			return elem.hasAttributeNS("http://www.w3.org/2005/07/aaa", state);
		}
		return elem.hasAttribute ? elem.hasAttribute("aria-"+state) : !!elem.getAttribute("aria-"+state);
	},

	getWaiState: function(/*Element*/ elem, /*String*/ state){
		// summary:
		//		Gets the value of a state on an element.
		// description:
		//		On Firefox 2 and below, we check for an attribute in namespace
		//		"http://www.w3.org/2005/07/aaa" with a name of the given state.
		//		On all other browsers, we check for an attribute called
		//		"aria-"+state.
		// returns:
		//		The value of the requested state on elem
		//		or an empty string if elem has no value for state.
		if(dojo.isFF < 3){
			return elem.getAttributeNS("http://www.w3.org/2005/07/aaa", state);
		}
		return elem.getAttribute("aria-"+state) || "";
	},

	setWaiState: function(/*Element*/ elem, /*String*/ state, /*String*/ value){
		// summary:
		//		Sets a state on an element.
		// description:
		//		On Firefox 2 and below, we set an attribute in namespace
		//		"http://www.w3.org/2005/07/aaa" with a name of the given state.
		//		On all other browsers, we set an attribute called
		//		"aria-"+state.
		if(dojo.isFF < 3){
			elem.setAttributeNS("http://www.w3.org/2005/07/aaa",
				"aaa:"+state, value);
		}else{
			elem.setAttribute("aria-"+state, value);
		}
	},

	removeWaiState: function(/*Element*/ elem, /*String*/ state){
		// summary:
		//		Removes a state from an element.
		// description:
		//		On Firefox 2 and below, we remove the attribute in namespace
		//		"http://www.w3.org/2005/07/aaa" with a name of the given state.
		//		On all other browsers, we remove the attribute called
		//		"aria-"+state.
		if(dojo.isFF < 3){
			elem.removeAttributeNS("http://www.w3.org/2005/07/aaa", state);
		}else{
			elem.removeAttribute("aria-"+state);
		}
	}
});

}

if(!dojo._hasResource["dijit._base"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._base"] = true;
dojo.provide("dijit._base");











}

if(!dojo._hasResource["dijit._Widget"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._Widget"] = true;
dojo.provide("dijit._Widget");

dojo.require( "dijit._base" );

// This code is to assist deferring dojo.connect() calls in widgets (connecting to events on the widgets'
// DOM nodes) until someone actually needs to monitor that event.
dojo.connect(dojo, "connect", 
	function(/*Widget*/ widget, /*String*/ event){
		if(widget && dojo.isFunction(widget._onConnect)){
			widget._onConnect(event);
		}
	});

dijit._connectOnUseEventHandler = function(/*Event*/ event){};

//Keep track of where the last keydown event was, to help avoid generating
//spurious ondijitclick events when:
//1. focus is on a <button> or <a>
//2. user presses then releases the ENTER key
//3. onclick handler fires and shifts focus to another node, with an ondijitclick handler
//4. onkeyup event fires, causing the ondijitclick handler to fire
dijit._lastKeyDownNode = null;
if(dojo.isIE){
	dojo.doc.attachEvent('onkeydown', function(evt){
		//
		dijit._lastKeyDownNode = evt.srcElement;
	});
}else{
	dojo.doc.addEventListener('keydown', function(evt){
		//
		dijit._lastKeyDownNode = evt.target;
	}, true);
}

(function(){

var _attrReg = {};
var getAttrReg = function(dc){
	if(!_attrReg[dc]){
		var r = [];
		var attrs;
		var proto = dojo.getObject(dc).prototype;
		for(var fxName in proto){
			if(dojo.isFunction(proto[fxName]) && (attrs = fxName.match(/^_set([a-zA-Z]*)Attr$/)) && attrs[1]){
				r.push(attrs[1].charAt(0).toLowerCase() + attrs[1].substr(1));
			}
		}
		_attrReg[dc] = r;
	}
	return _attrReg[dc]||[];
}

dojo.declare("dijit._Widget", null, {
	// summary:
	//		Base class for all dijit widgets. 	

	// id: [const] String
	//		A unique, opaque ID string that can be assigned by users or by the
	//		system. If the developer passes an ID which is known not to be
	//		unique, the specified ID is ignored and the system-generated ID is
	//		used instead.
	id: "",

	// lang: [const] String
	//		Rarely used.  Overrides the default Dojo locale used to render this widget,
	//		as defined by the [HTML LANG](http://www.w3.org/TR/html401/struct/dirlang.html#adef-lang) attribute.
	//		Value must be among the list of locales specified during by the Dojo bootstrap,
	//		formatted according to [RFC 3066](http://www.ietf.org/rfc/rfc3066.txt) (like en-us).
	lang: "",

	// dir: [const] String
	//		Unsupported by Dijit, but here for completeness.  Dijit only supports setting text direction on the
	//		entire document.
	//		Bi-directional support, as defined by the [HTML DIR](http://www.w3.org/TR/html401/struct/dirlang.html#adef-dir)
	//		attribute. Either left-to-right "ltr" or right-to-left "rtl".
	dir: "",

	// class: String
	//		HTML class attribute
	"class": "",

	// style: String||Object
	//		HTML style attributes as cssText string or name/value hash
	style: "",

	// title: String
	//		HTML title attribute, used to specify the title of tabs, accordion panes, etc.
	title: "",

	// srcNodeRef: [readonly] DomNode
	//		pointer to original dom node
	srcNodeRef: null,

	// domNode: [readonly] DomNode
	//		This is our visible representation of the widget! Other DOM
	//		Nodes may by assigned to other properties, usually through the
	//		template system's dojoAttachPoint syntax, but the domNode
	//		property is the canonical "top level" node in widget UI.
	domNode: null,

	// containerNode: [readonly] DomNode
	//		Designates where children of the source dom node will be placed.
	//		"Children" in this case refers to both dom nodes and widgets.
	//		For example, for myWidget:
	//
	//		|	<div dojoType=myWidget>
	//		|		<b> here's a plain dom node
	//		|		<span dojoType=subWidget>and a widget</span>
	//		|		<i> and another plain dom node </i>
	//		|	</div>
	//
	//		containerNode would point to:
	//
	//		|		<b> here's a plain dom node
	//		|		<span dojoType=subWidget>and a widget</span>
	//		|		<i> and another plain dom node </i>
	//
	//		In templated widgets, "containerNode" is set via a
	//		dojoAttachPoint assignment.
	//
	//		containerNode must be defined for any widget that accepts innerHTML
	//		(like ContentPane or BorderContainer or even Button), and conversely
	//		is null for widgets that don't, like TextBox.
	containerNode: null,

	// attributeMap: [protected] Object
	//		attributeMap sets up a "binding" between attributes (aka properties)
	//		of the widget and the widget's DOM.
	//		Changes to widget attributes listed in attributeMap will be 
	//		reflected into the DOM.
	//
	//		For example, calling attr('title', 'hello')
	//		on a TitlePane will automatically cause the TitlePane's DOM to update
	//		with the new title.
	//
	//		attributeMap is a hash where the key is an attribute of the widget,
	//		and the value reflects a binding to a:
	//
	//		- DOM node attribute
	// |		focus: {node: "focusNode", type: "attribute"}
	// 		Maps this.focus to this.focusNode.focus
	//
	//		- DOM node innerHTML
	//	|		title: { node: "titleNode", type: "innerHTML" }
	//		Maps this.title to this.titleNode.innerHTML
	//
	//		- DOM node CSS class
	// |		myClass: { node: "domNode", type: "class" }
	//		Maps this.myClass to this.domNode.className
	//
	//		If the value is an array, then each element in the array matches one of the
	//		formats of the above list.
	//
	//		There are also some shorthands for backwards compatibility:
	//		- string --> { node: string, type: "attribute" }, for example:
	//	|	"focusNode" ---> { node: "focusNode", type: "attribute" }
	//		- "" --> { node: "domNode", type: "attribute" }
	attributeMap: {id:"", dir:"", lang:"", "class":"", style:"", title:""},

	// _deferredConnects: [protected] Object
	//		attributeMap addendum for event handlers that should be connected only on first use
	_deferredConnects: {
		onClick: "",
		onDblClick: "",
		onKeyDown: "",
		onKeyPress: "",
		onKeyUp: "",
		onMouseMove: "",
		onMouseDown: "",
		onMouseOut: "",
		onMouseOver: "",
		onMouseLeave: "",
		onMouseEnter: "",
		onMouseUp: ""},

	onClick: dijit._connectOnUseEventHandler,
	/*=====
	onClick: function(event){
		// summary: 
		//		Connect to this function to receive notifications of mouse click events.
		// event:
		//		mouse Event
		// tags:
		//		callback
	},
	=====*/
	onDblClick: dijit._connectOnUseEventHandler,
	/*=====
	onDblClick: function(event){
		// summary: 
		//		Connect to this function to receive notifications of mouse double click events.
		// event:
		//		mouse Event
		// tags:
		//		callback
	},
	=====*/
	onKeyDown: dijit._connectOnUseEventHandler,
	/*=====
	onKeyDown: function(event){
		// summary: 
		//		Connect to this function to receive notifications of keys being pressed down.
		// event:
		//		key Event
		// tags:
		//		callback
	},
	=====*/
	onKeyPress: dijit._connectOnUseEventHandler,
	/*=====
	onKeyPress: function(event){
		// summary: 
		//		Connect to this function to receive notifications of printable keys being typed.
		// event:
		//		key Event
		// tags:
		//		callback
	},
	=====*/
	onKeyUp: dijit._connectOnUseEventHandler,
	/*=====
	onKeyUp: function(event){
		// summary: 
		//		Connect to this function to receive notifications of keys being released.
		// event:
		//		key Event
		// tags:
		//		callback
	},
	=====*/
	onMouseDown: dijit._connectOnUseEventHandler,
	/*=====
	onMouseDown: function(event){
		// summary: 
		//		Connect to this function to receive notifications of when the mouse button is pressed down.
		// event:
		//		mouse Event
		// tags:
		//		callback
	},
	=====*/
	onMouseMove: dijit._connectOnUseEventHandler,
	/*=====
	onMouseMove: function(event){
		// summary: 
		//		Connect to this function to receive notifications of when the mouse moves over nodes contained within this widget.
		// event:
		//		mouse Event
		// tags:
		//		callback
	},
	=====*/
	onMouseOut: dijit._connectOnUseEventHandler,
	/*=====
	onMouseOut: function(event){
		// summary: 
		//		Connect to this function to receive notifications of when the mouse moves off of nodes contained within this widget.
		// event:
		//		mouse Event
		// tags:
		//		callback
	},
	=====*/
	onMouseOver: dijit._connectOnUseEventHandler,
	/*=====
	onMouseOver: function(event){
		// summary: 
		//		Connect to this function to receive notifications of when the mouse moves onto nodes contained within this widget.
		// event:
		//		mouse Event
		// tags:
		//		callback
	},
	=====*/
	onMouseLeave: dijit._connectOnUseEventHandler,
	/*=====
	onMouseLeave: function(event){
		// summary: 
		//		Connect to this function to receive notifications of when the mouse moves off of this widget.
		// event:
		//		mouse Event
		// tags:
		//		callback
	},
	=====*/
	onMouseEnter: dijit._connectOnUseEventHandler,
	/*=====
	onMouseEnter: function(event){
		// summary: 
		//		Connect to this function to receive notifications of when the mouse moves onto this widget.
		// event:
		//		mouse Event
		// tags:
		//		callback
	},
	=====*/
	onMouseUp: dijit._connectOnUseEventHandler,
	/*=====
	onMouseUp: function(event){
		// summary: 
		//		Connect to this function to receive notifications of when the mouse button is released.
		// event:
		//		mouse Event
		// tags:
		//		callback
	},
	=====*/

	// Constants used in templates
	
	// _blankGif: [protected] URL
	//		Used by <img> nodes in templates that really get there image via CSS background-image
	_blankGif: (dojo.config.blankGif || dojo.moduleUrl("dojo", "resources/blank.gif")),

	//////////// INITIALIZATION METHODS ///////////////////////////////////////

	postscript: function(/*Object?*/params, /*DomNode|String*/srcNodeRef){
		// summary:
		//		Kicks off widget instantiation.  See create() for details.
		// tags:
		//		private
		this.create(params, srcNodeRef);
	},

	create: function(/*Object?*/params, /*DomNode|String?*/srcNodeRef){
		// summary:
		//		Kick off the life-cycle of a widget
		// params:
		//		Hash of initialization parameters for widget, including
		//		scalar values (like title, duration etc.) and functions,
		//		typically callbacks like onClick.
		// srcNodeRef:
		//		If a srcNodeRef (dom node) is specified:
		//			- use srcNodeRef.innerHTML as my contents
		//			- if this is a behavioral widget then apply behavior
		//			  to that srcNodeRef 
		//			- otherwise, replace srcNodeRef with my generated DOM
		//			  tree
		// description:
		//		To understand the process by which widgets are instantiated, it
		//		is critical to understand what other methods create calls and
		//		which of them you'll want to override. Of course, adventurous
		//		developers could override create entirely, but this should
		//		only be done as a last resort.
		//
		//		Below is a list of the methods that are called, in the order
		//		they are fired, along with notes about what they do and if/when
		//		you should over-ride them in your widget:
		//
		// * postMixInProperties:
		//	|	* a stub function that you can over-ride to modify
		//		variables that may have been naively assigned by
		//		mixInProperties
		// * widget is added to manager object here
		// * buildRendering:
		//	|	* Subclasses use this method to handle all UI initialization
		//		Sets this.domNode.  Templated widgets do this automatically
		//		and otherwise it just uses the source dom node.
		// * postCreate:
		//	|	* a stub function that you can over-ride to modify take
		//		actions once the widget has been placed in the UI
		// tags:
		//		private

		// store pointer to original dom tree
		this.srcNodeRef = dojo.byId(srcNodeRef);

		// For garbage collection.  An array of handles returned by Widget.connect()
		// Each handle returned from Widget.connect() is an array of handles from dojo.connect()
		this._connects = [];

		// To avoid double-connects, remove entries from _deferredConnects
		// that have been setup manually by a subclass (ex, by dojoAttachEvent).
		// If a subclass has redefined a callback (ex: onClick) then assume it's being
		// connected to manually.
		this._deferredConnects = dojo.clone(this._deferredConnects);
		for(var attr in this.attributeMap){
			delete this._deferredConnects[attr]; // can't be in both attributeMap and _deferredConnects
		}
		for(attr in this._deferredConnects){
			if(this[attr] !== dijit._connectOnUseEventHandler){
				delete this._deferredConnects[attr];	// redefined, probably dojoAttachEvent exists
			}
		}

		//mixin our passed parameters
		if(this.srcNodeRef && (typeof this.srcNodeRef.id == "string")){ this.id = this.srcNodeRef.id; }
		if(params){
			this.params = params;
			dojo.mixin(this,params);
		}
		this.postMixInProperties();

		// generate an id for the widget if one wasn't specified
		// (be sure to do this before buildRendering() because that function might
		// expect the id to be there.)
		if(!this.id){
			this.id = dijit.getUniqueId(this.declaredClass.replace(/\./g,"_"));
		}
		dijit.registry.add(this);

		this.buildRendering();

		if(this.domNode){
			// Copy attributes listed in attributeMap into the [newly created] DOM for the widget.
			this._applyAttributes();

			var source = this.srcNodeRef;
			if(source && source.parentNode){
				source.parentNode.replaceChild(this.domNode, source);
			}

			// If the developer has specified a handler as a widget parameter
			// (ex: new Button({onClick: ...})
			// then naturally need to connect from dom node to that handler immediately, 
			for(attr in this.params){
				this._onConnect(attr);
			}
		}
		
		if(this.domNode){
			this.domNode.setAttribute("widgetId", this.id);
		}
		this.postCreate();

		// If srcNodeRef has been processed and removed from the DOM (e.g. TemplatedWidget) then delete it to allow GC.
		if(this.srcNodeRef && !this.srcNodeRef.parentNode){
			delete this.srcNodeRef;
		}	

		this._created = true;
	},

	_applyAttributes: function(){
		// summary:
		//		Step during widget creation to copy all widget attributes to the
		//		DOM as per attributeMap and _setXXXAttr functions.
		// description:
		//		Skips over blank/false attribute values, unless they were explicitly specified
		//		as parameters to the widget, since those are the default anyway,
		//		and setting tabIndex="" is different than not setting tabIndex at all.
		//
		//		It processes the attributes in the attribute map first, and then
		//		it goes through and processes the attributes for the _setXXXAttr
		//		functions that have been specified
		// tags:
		//		private
		var condAttrApply = function(attr, scope){
			if( (scope.params && attr in scope.params) || scope[attr]){
				scope.attr(attr, scope[attr]);
			}
		};
		for(var attr in this.attributeMap){
			condAttrApply(attr, this);
		}
		dojo.forEach(getAttrReg(this.declaredClass), function(a){
			if(!(a in this.attributeMap)){
				condAttrApply(a, this);
			}
		}, this);
	},

	postMixInProperties: function(){
		// summary:
		//		Called after the parameters to the widget have been read-in,
		//		but before the widget template is instantiated. Especially
		//		useful to set properties that are referenced in the widget
		//		template.
		// tags:
		//		protected
	},

	buildRendering: function(){
		// summary:
		//		Construct the UI for this widget, setting this.domNode.  Most
		//		widgets will mixin `dijit._Templated`, which implements this
		//		method.
		// tags:
		//		protected
		this.domNode = this.srcNodeRef || dojo.create('div');
	},

	postCreate: function(){
		// summary:
		//		Called after a widget's dom has been setup
		// tags:
		//		protected
	},

	startup: function(){
		// summary:
		//		Called after a widget's children, and other widgets on the page, have been created.
		//		Provides an opportunity to manipulate any children before they are displayed.
		//		This is useful for composite widgets that need to control or layout sub-widgets.
		//		Many layout widgets can use this as a wiring phase.
		this._started = true;
	},

	//////////// DESTROY FUNCTIONS ////////////////////////////////

	destroyRecursive: function(/*Boolean?*/ preserveDom){
		// summary:
		// 		Destroy this widget and it's descendants. This is the generic
		// 		"destructor" function that all widget users should call to
		// 		cleanly discard with a widget. Once a widget is destroyed, it's
		// 		removed from the manager object.
		// preserveDom:
		//		If true, this method will leave the original Dom structure
		//		alone of descendant Widgets. Note: This will NOT work with
		//		dijit._Templated widgets.

		this.destroyDescendants(preserveDom);
		this.destroy(preserveDom);
	},

	destroy: function(/*Boolean*/ preserveDom){
		// summary:
		// 		Destroy this widget, but not its descendants.
		//		Will, however, destroy internal widgets such as those used within a template.
		// preserveDom: Boolean
		//		If true, this method will leave the original Dom structure alone.
		//		Note: This will not yet work with _Templated widgets

		this.uninitialize();
		dojo.forEach(this._connects, function(array){
			dojo.forEach(array, dojo.disconnect);
		});

		// destroy widgets created as part of template, etc.
		dojo.forEach(this._supportingWidgets||[], function(w){ 
			if(w.destroy){
				w.destroy();
			}
		});
		
		this.destroyRendering(preserveDom);
		dijit.registry.remove(this.id);
	},

	destroyRendering: function(/*Boolean?*/ preserveDom){
		// summary:
		//		Destroys the DOM nodes associated with this widget
		// preserveDom:
		//		If true, this method will leave the original Dom structure alone
		//		during tear-down. Note: this will not work with _Templated
		//		widgets yet. 
		// tags:
		//		protected

		if(this.bgIframe){
			this.bgIframe.destroy(preserveDom);
			delete this.bgIframe;
		}

		if(this.domNode){
			if(preserveDom){
				dojo.removeAttr(this.domNode, "widgetId");
			}else{
				dojo.destroy(this.domNode);
			}
			delete this.domNode;
		}

		if(this.srcNodeRef){
			if(!preserveDom){
				dojo.destroy(this.srcNodeRef);
			}
			delete this.srcNodeRef;
		}
	},

	destroyDescendants: function(/*Boolean?*/ preserveDom){
		// summary:
		//		Recursively destroy the children of this widget and their
		//		descendants.
		// preserveDom:
		//		If true, the preserveDom attribute is passed to all descendant
		//		widget's .destroy() method. Not for use with _Templated
		//		widgets.

		// get all direct descendants and destroy them recursively
		dojo.forEach(this.getChildren(), function(widget){ 
			if(widget.destroyRecursive){
				widget.destroyRecursive(preserveDom);
			}
		});
	},


	uninitialize: function(){
		// summary:
		//		Stub function. Override to implement custom widget tear-down
		//		behavior.
		// tags:
		//		protected
		return false;
	},

	////////////////// MISCELLANEOUS METHODS ///////////////////

	onFocus: function(){
		// summary:
		//		Called when the widget becomes "active" because
		//		it or a widget inside of it either has focus, or has recently
		//		been clicked.
		// tags:
		//		callback
	},

	onBlur: function(){
		// summary:
		//		Called when the widget stops being "active" because
		//		focus moved to something outside of it, or the user
		//		clicked somewhere outside of it, or the widget was
		//		hidden.
		// tags:
		//		callback
	},

	_onFocus: function(e){
		// summary:
		//		This is where widgets do processing for when they are active,
		//		such as changing CSS classes.  See onFocus() for more details.
		// tags:
		//		protected
		this.onFocus();
	},

	_onBlur: function(){
		// summary:
		//		This is where widgets do processing for when they stop being active,
		//		such as changing CSS classes.  See onBlur() for more details.
		// tags:
		//		protected
		this.onBlur();
	},

	_onConnect: function(/*String*/ event){
		// summary:
		//		Called when someone connects to one of my handlers.
		//		"Turn on" that handler if it isn't active yet.
		//
		//		This is also called for every single initialization parameter
		//		so need to do nothing for parameters like "id".
		// tags:
		//		private
		if(event in this._deferredConnects){
			var mapNode = this[this._deferredConnects[event]||'domNode'];
			this.connect(mapNode, event.toLowerCase(), event);
			delete this._deferredConnects[event];
		}
	},

	_setClassAttr: function(/*String*/ value){
		// summary:
		//		Custom setter for the CSS "class" attribute
		// tags:
		//		protected
		var mapNode = this[this.attributeMap["class"]||'domNode'];
		dojo.removeClass(mapNode, this["class"])
		this["class"] = value;
		dojo.addClass(mapNode, value);
	},

	_setStyleAttr: function(/*String||Object*/ value){
		// summary:
		//		Sets the style attribut of the widget according to value,
		//		which is either a hash like {height: "5px", width: "3px"}
		//		or a plain string
		// description:
		//		Determines which node to set the style on based on style setting
		//		in attributeMap.
		// tags:
		//		protected

		var mapNode = this[this.attributeMap["style"]||'domNode'];
		
		// Note: technically we should revert any style setting made in a previous call
		// to his method, but that's difficult to keep track of.

		if(dojo.isObject(value)){
			dojo.style(mapNode, value);
		}else{
			if(mapNode.style.cssText){
				mapNode.style.cssText += "; " + value;
			}else{
				mapNode.style.cssText = value;
			}
		}

		this["style"] = value;
	},

	setAttribute: function(/*String*/ attr, /*anything*/ value){
		// summary:
		//		Deprecated.  Use attr() instead.
		// tags:
		//		deprecated
		dojo.deprecated(this.declaredClass+"::setAttribute() is deprecated. Use attr() instead.", "", "2.0");
		this.attr(attr, value);
	},
	
	_attrToDom: function(/*String*/ attr, /*String*/ value){
		// summary:
		//		Reflect a widget attribute (title, tabIndex, duration etc.) to
		//		the widget DOM, as specified in attributeMap.
		//
		// description:
		//		Also sets this["attr"] to the new value.
		//		Note some attributes like "type"
		//		cannot be processed this way as they are not mutable.
		//
		// tags:
		//		private

		var commands = this.attributeMap[attr];
		dojo.forEach( dojo.isArray(commands) ? commands : [commands], function(command){

			// Get target node and what we are doing to that node
			var mapNode = this[command.node || command || "domNode"];	// DOM node
			var type = command.type || "attribute";	// class, innerHTML, or attribute
	
			switch(type){
				case "attribute":
					if(dojo.isFunction(value)){ // functions execute in the context of the widget
						value = dojo.hitch(this, value);
					}
					if(/^on[A-Z][a-zA-Z]*$/.test(attr)){ // eg. onSubmit needs to be onsubmit
						attr = attr.toLowerCase();
					}
					dojo.attr(mapNode, attr, value);
					break;
				case "innerHTML":
					mapNode.innerHTML = value;
					break;
				case "class":
					dojo.removeClass(mapNode, this[attr]);
					dojo.addClass(mapNode, value);
					break;
			}
		}, this);
		this[attr] = value;
	},

	attr: function(/*String|Object*/name, /*Object?*/value){
		//	summary:
		//		Set or get properties on a widget instance.
		//	name:
		//		The property to get or set. If an object is passed here and not
		//		a string, its keys are used as names of attributes to be set
		//		and the value of the object as values to set in the widget.
		//	value:
		//		Optional. If provided, attr() operates as a setter. If omitted,
		//		the current value of the named property is returned.
		//	description:
		//		Get or set named properties on a widget. If no value is
		//		provided, the current value of the attribute is returned,
		//		potentially via a getter method. If a value is provided, then
		//		the method acts as a setter, assigning the value to the name,
		//		potentially calling any explicitly provided setters to handle
		//		the operation. For instance, if the widget has properties "foo"
		//		and "bar" and a method named "_setFooAttr", calling:
		//	|	myWidget.attr("foo", "Howdy!");
		//		would be equivalent to calling:
		//	|	widget._setFooAttr("Howdy!");
		//		while calling:
		//	|	myWidget.attr("bar", "Howdy!");
		//		would be the same as writing:
		//	|	widget.bar = "Howdy!";
		//		It also tries to copy the changes to the widget's DOM according
		//		to settings in attributeMap (see description of `dijit._Widget.attributeMap`
		//		for details)
		//		For example, calling:
		//	|	myTitlePane.attr("title", "Howdy!");
		//		will do
		//	|	myTitlePane.title = "Howdy!";
		//	|	myTitlePane.title.innerHTML = "Howdy!";
		//		It works for dom node attributes too.  Calling
		//	|	widget.attr("disabled", true)
		//		will set the disabled attribute on the widget's focusNode,
		//		among other housekeeping for a change in disabled state.

		//	open questions:
		//		- how to handle build shortcut for attributes which want to map
		//		into DOM attributes?
		//		- what relationship should setAttribute()/attr() have to
		//		layout() calls?
		var args = arguments.length;
		if(args == 1 && !dojo.isString(name)){
			for(var x in name){ this.attr(x, name[x]); }
			return this;
		}
		var names = this._getAttrNames(name);
		if(args == 2){ // setter
			if(this[names.s]){
				// use the explicit setter
				return this[names.s](value) || this;
			}else{
				// if param is specified as DOM node attribute, copy it
				if(name in this.attributeMap){
					this._attrToDom(name, value);
				}

				// FIXME: what about function assignments? Any way to connect() here?
				this[name] = value;
			}
			return this;
		}else{ // getter
			if(this[names.g]){
				return this[names.g]();
			}else{
				return this[name];
			}
		}
	},

	_attrPairNames: {},		// shared between all widgets
	_getAttrNames: function(name){
		// summary:
		//		Helper function for Widget.attr().
		//		Caches attribute name values so we don't do the string ops every time.
		// tags:
		//		private

		var apn = this._attrPairNames;
		if(apn[name]){ return apn[name]; }
		var uc = name.charAt(0).toUpperCase() + name.substr(1);
		return apn[name] = {
			n: name+"Node",
			s: "_set"+uc+"Attr",
			g: "_get"+uc+"Attr"
		};
	},

	toString: function(){
		// summary:
		//		Returns a string that represents the widget. When a widget is
		//		cast to a string, this method will be used to generate the
		//		output. Currently, it does not implement any sort of reversable
		//		serialization.
		return '[Widget ' + this.declaredClass + ', ' + (this.id || 'NO ID') + ']'; // String
	},

	getDescendants: function(){
		// summary:
		//		Returns all the widgets that contained by this, i.e., all widgets underneath this.containerNode.
		//		This method should generally be avoided as it returns widgets declared in templates, which are
		//		supposed to be internal/hidden, but it's left here for back-compat reasons.

		if(this.containerNode){
			var list = dojo.query('[widgetId]', this.containerNode);
			return list.map(dijit.byNode);		// Array
		}else{
			return [];
		}
	},

	getChildren: function(){
		// summary:
		//		Returns all the widgets contained by this, i.e., all widgets underneath this.containerNode.
		//		Does not return nested widgets, nor widgets that are part of this widget's template.
		if(this.containerNode){
			return dijit.findWidgets(this.containerNode);
		}else{
			return [];
		}
	},

	// nodesWithKeyClick: [private] String[]
	//		List of nodes that correctly handle click events via native browser support,
	//		and don't need dijit's help
	nodesWithKeyClick: ["input", "button"],

	connect: function(
			/*Object|null*/ obj,
			/*String|Function*/ event,
			/*String|Function*/ method){
		// summary:
		//		Connects specified obj/event to specified method of this object
		//		and registers for disconnect() on widget destroy.
		// description:
		//		Provide widget-specific analog to dojo.connect, except with the
		//		implicit use of this widget as the target object.
		//		This version of connect also provides a special "ondijitclick"
		//		event which triggers on a click or space or enter keyup
		// example:
		//	|	var btn = new dijit.form.Button();
		//	|	// when foo.bar() is called, call the listener we're going to
		//	|	// provide in the scope of btn
		//	|	btn.connect(foo, "bar", function(){ 
		//	|		
		//	|	});
		// tags:
		//		protected

		var d = dojo;
		var dc = dojo.connect;
		var handles =[];
		if(event == "ondijitclick"){
			// add key based click activation for unsupported nodes.
			// do all processing onkey up to prevent spurious clicks
			// for details see comments at top of this file where _lastKeyDownNode is defined
			if(!this.nodesWithKeyClick[obj.tagName.toLowerCase()]){
				var m = d.hitch(this, method);
				handles.push(
					dc(obj, "onkeydown", this, function(e){
						//
						if((e.keyCode == d.keys.ENTER || e.keyCode == d.keys.SPACE) &&
							!e.ctrlKey && !e.shiftKey && !e.altKey && !e.metaKey){
							// needed on IE for when focus changes between keydown and keyup - otherwise dropdown menus do not work
							dijit._lastKeyDownNode = e.target;
							d.stopEvent(e);		// stop event to prevent scrolling on space key in IE
						}
			 		}),
					dc(obj, "onkeyup", this, function(e){
						//
						if( (e.keyCode == d.keys.ENTER || e.keyCode == d.keys.SPACE) &&
							e.target === dijit._lastKeyDownNode &&
							!e.ctrlKey && !e.shiftKey && !e.altKey && !e.metaKey){
								//need reset here or have problems in FF when focus returns to trigger element after closing popup/alert
								dijit._lastKeyDownNode = null;  
								return m(e);
						}
					})
				);
			}
			event = "onclick";
		}
		handles.push(dc(obj, event, this, method));

		// return handles for FormElement and ComboBox
		this._connects.push(handles);
		return handles;
	},

	disconnect: function(/*Object*/ handles){
		// summary:
		//		Disconnects handle created by this.connect.
		//		Also removes handle from this widget's list of connects
		// tags:
		//		protected
		for(var i=0; i<this._connects.length; i++){
			if(this._connects[i]==handles){
				dojo.forEach(handles, dojo.disconnect);
				this._connects.splice(i, 1);
				return;
			}
		}
	},

	isLeftToRight: function(){
		// summary:
		//		Checks the page for text direction
		// tags:
		//		protected
		return dojo._isBodyLtr(); //Boolean
	},

	isFocusable: function(){
		// summary:
		//		Return true if this widget can currently be focused
		//		and false if not
		return this.focus && (dojo.style(this.domNode, "display") != "none");
	},
	
	placeAt: function(/* String|DomNode|_Widget */reference, /* String?|Int? */position){
		// summary:
		//		Place this widget's domNode reference somewhere in the DOM based
		//		on standard dojo.place conventions, or passing a Widget reference that
		//		contains and addChild member.
		//
		// description:
		//		A convenience function provided in all _Widgets, providing a simple
		//		shorthand mechanism to put an existing (or newly created) Widget
		//		somewhere in the dom, and allow chaining.
		//
		// reference: 
		//		The String id of a domNode, a domNode reference, or a reference to a Widget posessing 
		//		an addChild method.
		//
		// position: 
		//		If passed a string or domNode reference, the position argument
		//		accepts a string just as dojo.place does, one of: "first", "last", 
		//		"before", or "after". 
		//
		//		If passed a _Widget reference, and that widget reference has an ".addChild" method, 
		//		it will be called passing this widget instance into that method, supplying the optional
		//		position index passed.
		//
		// returns: dijit._Widget
		//		Provides a useful return of the newly created dijit._Widget instance so you 
		//		can "chain" this function by instantiating, placing, then saving the return value
		//		to a variable. 
		//
		// example:
		// | 	// create a Button with no srcNodeRef, and place it in the body:
		// | 	var button = new dijit.form.Button({ label:"click" }).placeAt(dojo.body());
		// | 	// now, 'button' is still the widget reference to the newly created button
		// | 	dojo.connect(button, "onClick", function(e){  });
		//
		// example:
		// |	// create a button out of a node with id="src" and append it to id="wrapper":
		// | 	var button = new dijit.form.Button({},"src").placeAt("wrapper");
		//
		// example:
		// |	// place a new button as the first element of some div
		// |	var button = new dijit.form.Button({ label:"click" }).placeAt("wrapper","first");
		//
		// example: 
		// |	// create a contentpane and add it to a TabContainer
		// |	var tc = dijit.byId("myTabs");
		// |	new dijit.layout.ContentPane({ href:"foo.html", title:"Wow!" }).placeAt(tc)

		if(reference["declaredClass"] && reference["addChild"]){
			reference.addChild(this, position);
		}else{
			dojo.place(this.domNode, reference, position);
		}
		return this;
	}

});

})();

}

if(!dojo._hasResource["dojo.parser"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.parser"] = true;
dojo.provide("dojo.parser");


dojo.parser = new function(){
	// summary: The Dom/Widget parsing package

	var d = dojo;
	this._attrName = d._scopeName + "Type";
	this._query = "[" + this._attrName + "]";

	var _anonCtr = 0, _anon = {};
	var nameAnonFunc = function(/*Function*/anonFuncPtr, /*Object*/thisObj){
		// summary:
		//		Creates a reference to anonFuncPtr in thisObj with a completely
		//		unique name. The new name is returned as a String. 
		var nso = thisObj || _anon;
		if(dojo.isIE){
			var cn = anonFuncPtr["__dojoNameCache"];
			if(cn && nso[cn] === anonFuncPtr){
				return cn;
			}
		}
		var name;
		do{
			name = "__" + _anonCtr++;
		}while(name in nso)
		nso[name] = anonFuncPtr;
		return name; // String
	}

	function val2type(/*Object*/ value){
		// summary:
		//		Returns name of type of given value.

		if(d.isString(value)){ return "string"; }
		if(typeof value == "number"){ return "number"; }
		if(typeof value == "boolean"){ return "boolean"; }
		if(d.isFunction(value)){ return "function"; }
		if(d.isArray(value)){ return "array"; } // typeof [] == "object"
		if(value instanceof Date) { return "date"; } // assume timestamp
		if(value instanceof d._Url){ return "url"; }
		return "object";
	}

	function str2obj(/*String*/ value, /*String*/ type){
		// summary:
		//		Convert given string value to given type
		switch(type){
			case "string":
				return value;
			case "number":
				return value.length ? Number(value) : NaN;
			case "boolean":
				// for checked/disabled value might be "" or "checked".  interpret as true.
				return typeof value == "boolean" ? value : !(value.toLowerCase()=="false");
			case "function":
				if(d.isFunction(value)){
					// IE gives us a function, even when we say something like onClick="foo"
					// (in which case it gives us an invalid function "function(){ foo }"). 
					//  Therefore, convert to string
					value=value.toString();
					value=d.trim(value.substring(value.indexOf('{')+1, value.length-1));
				}
				try{
					if(value.search(/[^\w\.]+/i) != -1){
						// TODO: "this" here won't work
						value = nameAnonFunc(new Function(value), this);
					}
					return d.getObject(value, false);
				}catch(e){ return new Function(); }
			case "array":
				return value ? value.split(/\s*,\s*/) : [];
			case "date":
				switch(value){
					case "": return new Date("");	// the NaN of dates
					case "now": return new Date();	// current date
					default: return d.date.stamp.fromISOString(value);
				}
			case "url":
				return d.baseUrl + value;
			default:
				return d.fromJson(value);
		}
	}

	var instanceClasses = {
		// map from fully qualified name (like "dijit.Button") to structure like
		// { cls: dijit.Button, params: {label: "string", disabled: "boolean"} }
	};
	
	// Widgets like BorderContainer add properties to _Widget via dojo.extend().
	// If BorderContainer is loaded after _Widget's parameter list has been cached,
	// we need to refresh that parameter list (for _Widget and all widgets that extend _Widget).
	dojo.connect(dojo, "extend", function(){
		instanceClasses = {};
	});

	function getClassInfo(/*String*/ className){
		// className:
		//		fully qualified name (like "dijit.form.Button")
		// returns:
		//		structure like
		//			{ 
		//				cls: dijit.Button, 
		//				params: { label: "string", disabled: "boolean"}
		//			}

		if(!instanceClasses[className]){
			// get pointer to widget class
			var cls = d.getObject(className);
			if(!d.isFunction(cls)){
				throw new Error("Could not load class '" + className +
					"'. Did you spell the name correctly and use a full path, like 'dijit.form.Button'?");
			}
			var proto = cls.prototype;
	
			// get table of parameter names & types
			var params = {}, dummyClass = {};
			for(var name in proto){
				if(name.charAt(0)=="_"){ continue; } 	// skip internal properties
				if(name in dummyClass){ continue; }		// skip "constructor" and "toString"
				var defVal = proto[name];
				params[name]=val2type(defVal);
			}

			instanceClasses[className] = { cls: cls, params: params };
		}
		return instanceClasses[className];
	}

	this._functionFromScript = function(script){
		var preamble = "";
		var suffix = "";
		var argsStr = script.getAttribute("args");
		if(argsStr){
			d.forEach(argsStr.split(/\s*,\s*/), function(part, idx){
				preamble += "var "+part+" = arguments["+idx+"]; ";
			});
		}
		var withStr = script.getAttribute("with");
		if(withStr && withStr.length){
			d.forEach(withStr.split(/\s*,\s*/), function(part){
				preamble += "with("+part+"){";
				suffix += "}";
			});
		}
		return new Function(preamble+script.innerHTML+suffix);
	}

	this.instantiate = function(/* Array */nodes, /* Object? */mixin){
		// summary:
		//		Takes array of nodes, and turns them into class instances and
		//		potentially calls a layout method to allow them to connect with
		//		any children		
		// mixin: Object
		//		An object that will be mixed in with each node in the array.
		//		Values in the mixin will override values in the node, if they
		//		exist.
		var thelist = [], dp = dojo.parser;
		mixin = mixin||{};
		d.forEach(nodes, function(node){
			if(!node){ return; }
			var type = dp._attrName in mixin?mixin[dp._attrName]:node.getAttribute(dp._attrName);
			if(!type || !type.length){ return; }
			var clsInfo = getClassInfo(type),
				clazz = clsInfo.cls,
				ps = clazz._noScript || clazz.prototype._noScript;

			// read parameters (ie, attributes).
			// clsInfo.params lists expected params like {"checked": "boolean", "n": "number"}
			var params = {},
				attributes = node.attributes;
			for(var name in clsInfo.params){
				var item = name in mixin?{value:mixin[name],specified:true}:attributes.getNamedItem(name);
				if(!item || (!item.specified && (!dojo.isIE || name.toLowerCase()!="value"))){ continue; }
				var value = item.value;
				// Deal with IE quirks for 'class' and 'style'
				switch(name){
				case "class":
					value = "className" in mixin?mixin.className:node.className;
					break;
				case "style":
					value = "style" in mixin?mixin.style:(node.style && node.style.cssText); // FIXME: Opera?
				}
				var _type = clsInfo.params[name];
				if(typeof value == "string"){
					params[name] = str2obj(value, _type);
				}else{
					params[name] = value;
				}
			}

			// Process <script type="dojo/*"> script tags
			// <script type="dojo/method" event="foo"> tags are added to params, and passed to
			// the widget on instantiation.
			// <script type="dojo/method"> tags (with no event) are executed after instantiation
			// <script type="dojo/connect" event="foo"> tags are dojo.connected after instantiation
			// note: dojo/* script tags cannot exist in self closing widgets, like <input />
			if(!ps){
				var connects = [],	// functions to connect after instantiation
					calls = [];		// functions to call after instantiation

				d.query("> script[type^='dojo/']", node).orphan().forEach(function(script){
					var event = script.getAttribute("event"),
						type = script.getAttribute("type"),
						nf = d.parser._functionFromScript(script);
					if(event){
						if(type == "dojo/connect"){
							connects.push({event: event, func: nf});
						}else{
							params[event] = nf;
						}
					}else{
						calls.push(nf);
					}
				});
			}

			var markupFactory = clazz["markupFactory"];
			if(!markupFactory && clazz["prototype"]){
				markupFactory = clazz.prototype["markupFactory"];
			}
			// create the instance
			var instance = markupFactory ? markupFactory(params, node, clazz) : new clazz(params, node);
			thelist.push(instance);

			// map it to the JS namespace if that makes sense
			var jsname = node.getAttribute("jsId");
			if(jsname){
				d.setObject(jsname, instance);
			}

			// process connections and startup functions
			if(!ps){
				d.forEach(connects, function(connect){
					d.connect(instance, connect.event, null, connect.func);
				});
				d.forEach(calls, function(func){
					func.call(instance);
				});
			}
		});

		// Call startup on each top level instance if it makes sense (as for
		// widgets).  Parent widgets will recursively call startup on their
		// (non-top level) children
		d.forEach(thelist, function(instance){
			if(	instance  && 
				instance.startup &&
				!instance._started && 
				(!instance.getParent || !instance.getParent())
			){
				instance.startup();
			}
		});
		return thelist;
	};

	this.parse = function(/*DomNode?*/ rootNode){
		// summary:
		//		Search specified node (or root node) recursively for class instances,
		//		and instantiate them Searches for
		//		dojoType="qualified.class.name"
		var list = d.query(this._query, rootNode);
		// go build the object instances
		var instances = this.instantiate(list);
		return instances;
	};
}();

//Register the parser callback. It should be the first callback
//after the a11y test.

(function(){
	var parseRunner = function(){ 
		if(dojo.config["parseOnLoad"] == true){
			dojo.parser.parse(); 
		}
	};

	// FIXME: need to clobber cross-dependency!!
	if(dojo.exists("dijit.wai.onload") && (dijit.wai.onload === dojo._loaders[0])){
		dojo._loaders.splice(1, 0, parseRunner);
	}else{
		dojo._loaders.unshift(parseRunner);
	}
})();

}

if(!dojo._hasResource["dijit._Templated"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._Templated"] = true;
dojo.provide("dijit._Templated");





dojo.declare("dijit._Templated",
	null,
	{
		//	summary:
		//		Mixin for widgets that are instantiated from a template
		// 

		// templateString: [protected] String
		//		A string that represents the widget template. Pre-empts the
		//		templatePath. In builds that have their strings "interned", the
		//		templatePath is converted to an inline templateString, thereby
		//		preventing a synchronous network call.
		templateString: null,

		// templatePath: [protected] String
		//		Path to template (HTML file) for this widget relative to dojo.baseUrl
		templatePath: null,

		// widgetsInTemplate: [protected] Boolean
		//		Should we parse the template to find widgets that might be
		//		declared in markup inside it?  False by default.
		widgetsInTemplate: false,

		// skipNodeCache: [protected] Boolean
		//		If using a cached widget template node poses issues for a
		//		particular widget class, it can set this property to ensure
		//		that its template is always re-built from a string
		_skipNodeCache: false,

		_stringRepl: function(tmpl){
			// summary:
			//		Does substitution of ${foo} type properties in template string
			// tags:
			//		private
			var className = this.declaredClass, _this = this;
			// Cache contains a string because we need to do property replacement
			// do the property replacement
			return dojo.string.substitute(tmpl, this, function(value, key){
				if(key.charAt(0) == '!'){ value = dojo.getObject(key.substr(1), false, _this); }
				if(typeof value == "undefined"){ throw new Error(className+" template:"+key); } // a debugging aide
				if(value == null){ return ""; }

				// Substitution keys beginning with ! will skip the transform step,
				// in case a user wishes to insert unescaped markup, e.g. ${!foo}
				return key.charAt(0) == "!" ? value :
					// Safer substitution, see heading "Attribute values" in
					// http://www.w3.org/TR/REC-html40/appendix/notes.html#h-B.3.2
					value.toString().replace(/"/g,"&quot;"); //TODO: add &amp? use encodeXML method?
			}, this);
		},

		// method over-ride
		buildRendering: function(){
			// summary:
			//		Construct the UI for this widget from a template, setting this.domNode.
			// tags:
			//		protected

			// Lookup cached version of template, and download to cache if it
			// isn't there already.  Returns either a DomNode or a string, depending on
			// whether or not the template contains ${foo} replacement parameters.
			var cached = dijit._Templated.getCachedTemplate(this.templatePath, this.templateString, this._skipNodeCache);

			var node;
			if(dojo.isString(cached)){
				node = dojo._toDom(this._stringRepl(cached));
			}else{
				// if it's a node, all we have to do is clone it
				node = cached.cloneNode(true);
			}

			this.domNode = node;

			// recurse through the node, looking for, and attaching to, our
			// attachment points and events, which should be defined on the template node.
			this._attachTemplateNodes(node);

			if(this.widgetsInTemplate){
				//Make sure dojoType is used for parsing widgets in template.
				//The dojo.parser.query could be changed from multiversion support.
				var parser = dojo.parser, qry, attr;
				if(parser._query != "[dojoType]"){
					qry = parser._query;
					attr = parser._attrName;
					parser._query = "[dojoType]";
					parser._attrName = "dojoType";
				}

				var cw = (this._supportingWidgets = dojo.parser.parse(node));

				//Restore the query. 
				if(qry){
					parser._query = qry;
					parser._attrName = attr;
				}

				this._attachTemplateNodes(cw, function(n,p){
					return n[p];
				});
			}

			this._fillContent(this.srcNodeRef);
		},

		_fillContent: function(/*DomNode*/ source){
			// summary:
			//		Relocate source contents to templated container node.
			//		this.containerNode must be able to receive children, or exceptions will be thrown.
			// tags:
			//		protected
			var dest = this.containerNode;
			if(source && dest){
				while(source.hasChildNodes()){
					dest.appendChild(source.firstChild);
				}
			}
		},

		_attachTemplateNodes: function(rootNode, getAttrFunc){
			// summary:
			//		Iterate through the template and attach functions and nodes accordingly.	
			// description:		
			//		Map widget properties and functions to the handlers specified in
			//		the dom node and it's descendants. This function iterates over all
			//		nodes and looks for these properties:
			//			* dojoAttachPoint
			//			* dojoAttachEvent	
			//			* waiRole
			//			* waiState
			// rootNode: DomNode|Array[Widgets]
			//		the node to search for properties. All children will be searched.
			// getAttrFunc: Function?
			//		a function which will be used to obtain property for a given
			//		DomNode/Widget
			// tags:
			//		private

			getAttrFunc = getAttrFunc || function(n,p){ return n.getAttribute(p); };

			var nodes = dojo.isArray(rootNode) ? rootNode : (rootNode.all || rootNode.getElementsByTagName("*"));
			var x = dojo.isArray(rootNode) ? 0 : -1;
			for(; x<nodes.length; x++){
				var baseNode = (x == -1) ? rootNode : nodes[x];
				if(this.widgetsInTemplate && getAttrFunc(baseNode, "dojoType")){
					continue;
				}
				// Process dojoAttachPoint
				var attachPoint = getAttrFunc(baseNode, "dojoAttachPoint");
				if(attachPoint){
					var point, points = attachPoint.split(/\s*,\s*/);
					while((point = points.shift())){
						if(dojo.isArray(this[point])){
							this[point].push(baseNode);
						}else{
							this[point]=baseNode;
						}
					}
				}

				// Process dojoAttachEvent
				var attachEvent = getAttrFunc(baseNode, "dojoAttachEvent");
				if(attachEvent){
					// NOTE: we want to support attributes that have the form
					// "domEvent: nativeEvent; ..."
					var event, events = attachEvent.split(/\s*,\s*/);
					var trim = dojo.trim;
					while((event = events.shift())){
						if(event){
							var thisFunc = null;
							if(event.indexOf(":") != -1){
								// oh, if only JS had tuple assignment
								var funcNameArr = event.split(":");
								event = trim(funcNameArr[0]);
								thisFunc = trim(funcNameArr[1]);
							}else{
								event = trim(event);
							}
							if(!thisFunc){
								thisFunc = event;
							}
							this.connect(baseNode, event, thisFunc);
						}
					}
				}

				// waiRole, waiState
				var role = getAttrFunc(baseNode, "waiRole");
				if(role){
					dijit.setWaiRole(baseNode, role);
				}
				var values = getAttrFunc(baseNode, "waiState");
				if(values){
					dojo.forEach(values.split(/\s*,\s*/), function(stateValue){
						if(stateValue.indexOf('-') != -1){
							var pair = stateValue.split('-');
							dijit.setWaiState(baseNode, pair[0], pair[1]);
						}
					});
				}
			}
		}
	}
);

// key is either templatePath or templateString; object is either string or DOM tree
dijit._Templated._templateCache = {};

dijit._Templated.getCachedTemplate = function(templatePath, templateString, alwaysUseString){
	// summary:
	//		Static method to get a template based on the templatePath or
	//		templateString key
	// templatePath: String
	//		The URL to get the template from. dojo.uri.Uri is often passed as well.
	// templateString: String?
	//		a string to use in lieu of fetching the template from a URL. Takes precedence
	//		over templatePath
	// returns: Mixed
	//		Either string (if there are ${} variables that need to be replaced) or just
	//		a DOM tree (if the node can be cloned directly)

	// is it already cached?
	var tmplts = dijit._Templated._templateCache;
	var key = templateString || templatePath;
	var cached = tmplts[key];
	if(cached){
		if(!cached.ownerDocument || cached.ownerDocument == dojo.doc){
			// string or node of the same document
			return cached;
		}
		// destroy the old cached node of a different document
		dojo.destroy(cached);
	}

	// If necessary, load template string from template path
	if(!templateString){
		templateString = dijit._Templated._sanitizeTemplateString(dojo.trim(dojo._getText(templatePath)));
	}

	templateString = dojo.string.trim(templateString);

	if(alwaysUseString || templateString.match(/\$\{([^\}]+)\}/g)){
		// there are variables in the template so all we can do is cache the string
		return (tmplts[key] = templateString); //String
	}else{
		// there are no variables in the template so we can cache the DOM tree
		return (tmplts[key] = dojo._toDom(templateString)); //Node
	}
};

dijit._Templated._sanitizeTemplateString = function(/*String*/tString){
	// summary: 
	//		Strips <?xml ...?> declarations so that external SVG and XML
	// 		documents can be added to a document without worry. Also, if the string
	//		is an HTML document, only the part inside the body tag is returned.
	if(tString){
		tString = tString.replace(/^\s*<\?xml(\s)+version=[\'\"](\d)*.(\d)*[\'\"](\s)*\?>/im, "");
		var matches = tString.match(/<body[^>]*>\s*([\s\S]+)\s*<\/body>/im);
		if(matches){
			tString = matches[1];
		}
	}else{
		tString = "";
	}
	return tString; //String
};


if(dojo.isIE){
	dojo.addOnWindowUnload(function(){
		var cache = dijit._Templated._templateCache;
		for(var key in cache){
			var value = cache[key];
			if(!isNaN(value.nodeType)){ // isNode equivalent
				dojo.destroy(value);
			}
			delete cache[key];
		}
	});
}

// These arguments can be specified for widgets which are used in templates.
// Since any widget can be specified as sub widgets in template, mix it
// into the base widget class.  (This is a hack, but it's effective.)
dojo.extend(dijit._Widget,{
	dojoAttachEvent: "",
	dojoAttachPoint: "",
	waiRole: "",
	waiState:""
});

}

if(!dojo._hasResource["dijit.form._FormWidget"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.form._FormWidget"] = true;
dojo.provide("dijit.form._FormWidget");




dojo.declare("dijit.form._FormWidget", [dijit._Widget, dijit._Templated],
	{
	//
	// summary:
	//		Base class for widgets corresponding to native HTML elements such as <checkbox> or <button>,
	//		which can be children of a <form> node or a `dijit.form.Form` widget.
	//
	// description:
	//		Represents a single HTML element.
	//		All these widgets should have these attributes just like native HTML input elements.
	//		You can set them during widget construction or afterwards, via `dijit._Widget.attr`.
	//
	//	They also share some common methods.

	// baseClass: [protected] String
	//		Root CSS class of the widget (ex: dijitTextBox), used to add CSS classes of widget
	//		(ex: "dijitTextBox dijitTextBoxInvalid dijitTextBoxFocused dijitTextBoxInvalidFocused")
	//		See _setStateClass().
	baseClass: "",

	// name: String
	//		Name used when submitting form; same as "name" attribute or plain HTML elements
	name: "",

	// alt: String
	//		Corresponds to the native HTML <input> element's attribute.
	alt: "",

	// value: String
	//		Corresponds to the native HTML <input> element's attribute.
	value: "",

	// type: String
	//		Corresponds to the native HTML <input> element's attribute.
	type: "text",

	// tabIndex: Integer
	//		Order fields are traversed when user hits the tab key
	tabIndex: "0",

	// disabled: Boolean
	//		Should this widget respond to user input?
	//		In markup, this is specified as "disabled='disabled'", or just "disabled".
	disabled: false,

	// readOnly: Boolean
	//		Should this widget respond to user input?
	//		In markup, this is specified as "readOnly".
	//		Similar to disabled except readOnly form values are submitted.
	readOnly: false,

	// intermediateChanges: Boolean
	//		Fires onChange for each value change or only on demand
	intermediateChanges: false,

	// scrollOnFocus: Boolean
	//		On focus, should this widget scroll into view?
	scrollOnFocus: true,

	// These mixins assume that the focus node is an INPUT, as many but not all _FormWidgets are.
	attributeMap: dojo.delegate(dijit._Widget.prototype.attributeMap, {
		value: "focusNode",
		disabled: "focusNode",
		readOnly: "focusNode",
		id: "focusNode",
		tabIndex: "focusNode",
		alt: "focusNode"
	}),

	postMixInProperties: function(){
		// Setup name=foo string to be referenced from the template (but only if a name has been specified)
		// Unfortunately we can't use attributeMap to set the name due to IE limitations, see #8660
		this.nameAttrSetting = this.name ? ("name='" + this.name + "'") : "";
		this.inherited(arguments);
	},

	_setDisabledAttr: function(/*Boolean*/ value){
		this.disabled = value;
		dojo.attr(this.focusNode, 'disabled', value);
		dijit.setWaiState(this.focusNode, "disabled", value);

				if(value){
					//reset those, because after the domNode is disabled, we can no longer receive
					//mouse related events, see #4200
					this._hovering = false;
					this._active = false;
					// remove the tabIndex, especially for FF
					this.focusNode.removeAttribute('tabIndex');
				}else{
					this.focusNode.setAttribute('tabIndex', this.tabIndex);
				}
				this._setStateClass();
	},

	setDisabled: function(/*Boolean*/ disabled){
		// summary:
		//		Deprecated.   Use attr('disabled', ...) instead.
		dojo.deprecated("setDisabled("+disabled+") is deprecated. Use attr('disabled',"+disabled+") instead.", "", "2.0");
		this.attr('disabled', disabled);
	},

	_onFocus: function(e){
		if(this.scrollOnFocus){
			dijit.scrollIntoView(this.domNode);
		}
		this.inherited(arguments);
	},

	_onMouse : function(/*Event*/ event){
		// summary:
		//	Sets _hovering, _active, and stateModifier properties depending on mouse state,
		//	then calls setStateClass() to set appropriate CSS classes for this.domNode.
		//
		//	To get a different CSS class for hover, send onmouseover and onmouseout events to this method.
		//	To get a different CSS class while mouse button is depressed, send onmousedown to this method.

		var mouseNode = event.currentTarget;
		if(mouseNode && mouseNode.getAttribute){
			this.stateModifier = mouseNode.getAttribute("stateModifier") || "";
		}

		if(!this.disabled){
			switch(event.type){
				case "mouseenter":
				case "mouseover":
					this._hovering = true;
					this._active = this._mouseDown;
					break;

				case "mouseout":
				case "mouseleave":
					this._hovering = false;
					this._active = false;
					break;

				case "mousedown" :
					this._active = true;
					this._mouseDown = true;
					// set a global event to handle mouseup, so it fires properly
					//	even if the cursor leaves the button
					var mouseUpConnector = this.connect(dojo.body(), "onmouseup", function(){
						//if user clicks on the button, even if the mouse is released outside of it,
						//this button should get focus (which mimics native browser buttons)
						if(this._mouseDown && this.isFocusable()){
							this.focus();
						}
						this._active = false;
						this._mouseDown = false;
						this._setStateClass();
						this.disconnect(mouseUpConnector);
					});
					break;
			}
			this._setStateClass();
		}
	},

	isFocusable: function(){
		// summary:
		//		Tells if this widget is focusable or not.   Used internally by dijit.
		// tags:
		//		protected
		return !this.disabled && !this.readOnly && this.focusNode && (dojo.style(this.domNode, "display") != "none");
	},

	focus: function(){
		// summary:
		//		Put focus on this widget
		dijit.focus(this.focusNode);
	},

	_setStateClass: function(){
		// summary:
		//		Update the visual state of the widget by setting the css classes on this.domNode
		//		(or this.stateNode if defined) by combining this.baseClass with
		//		various suffixes that represent the current widget state(s).
		//
		// description:
		//		In the case where a widget has multiple
		//		states, it sets the class based on all possible
		//	 	combinations.  For example, an invalid form widget that is being hovered
		//		will be "dijitInput dijitInputInvalid dijitInputHover dijitInputInvalidHover".
		//
		//		For complex widgets with multiple regions, there can be various hover/active states,
		//		such as "Hover" or "CloseButtonHover" (for tab buttons).
		//		This is controlled by a stateModifier="CloseButton" attribute on the close button node.
		//
		//		The widget may have one or more of the following states, determined
		//		by this.state, this.checked, this.valid, and this.selected:
		//			- Error - ValidationTextBox sets this.state to "Error" if the current input value is invalid
		//			- Checked - ex: a checkmark or a ToggleButton in a checked state, will have this.checked==true
		//			- Selected - ex: currently selected tab will have this.selected==true
		//
		//		In addition, it may have one or more of the following states,
		//		based on this.disabled and flags set in _onMouse (this._active, this._hovering, this._focused):
		//			- Disabled	- if the widget is disabled
		//			- Active		- if the mouse (or space/enter key?) is being pressed down
		//			- Focused		- if the widget has focus
		//			- Hover		- if the mouse is over the widget

		// Compute new set of classes
		var newStateClasses = this.baseClass.split(" ");

		function multiply(modifier){
			newStateClasses = newStateClasses.concat(dojo.map(newStateClasses, function(c){ return c+modifier; }), "dijit"+modifier);
		}

		if(this.checked){
			multiply("Checked");
		}
		if(this.state){
			multiply(this.state);
		}
		if(this.selected){
			multiply("Selected");
		}

		if(this.disabled){
			multiply("Disabled");
		}else if(this.readOnly){
			multiply("ReadOnly");
		}else if(this._active){
			multiply(this.stateModifier+"Active");
		}else{
			if(this._focused){
				multiply("Focused");
			}
			if(this._hovering){
				multiply(this.stateModifier+"Hover");
			}
		}

		// Remove old state classes and add new ones.
		// For performance concerns we only write into domNode.className once.
		var tn = this.stateNode || this.domNode,
			classHash = {};	// set of all classes (state and otherwise) for node

		dojo.forEach(tn.className.split(" "), function(c){ classHash[c] = true; });

		if("_stateClasses" in this){
			dojo.forEach(this._stateClasses, function(c){ delete classHash[c]; });
		}

		dojo.forEach(newStateClasses, function(c){ classHash[c] = true; });

		var newClasses = [];
		for(var c in classHash){
			newClasses.push(c);
		}
		tn.className = newClasses.join(" ");

		this._stateClasses = newStateClasses;
	},

	compare: function(/*anything*/val1, /*anything*/val2){
		// summary:
		//		Compare 2 values (as returned by attr('value') for this widget).
		// tags:
		//		protected
		if((typeof val1 == "number") && (typeof val2 == "number")){
			return (isNaN(val1) && isNaN(val2))? 0 : (val1-val2);
		}else if(val1 > val2){ return 1; }
		else if(val1 < val2){ return -1; }
		else { return 0; }
	},

	onChange: function(newValue){
		// summary:
		//		Callback when this widget's value is changed.
		// tags:
		//		callback
	},

	// _onChangeActive: [private] Boolean
	//		Indicates that changes to the value should call onChange() callback.
	//		This is false during widget initialization, to avoid calling onChange()
	//		when the initial value is set.
	_onChangeActive: false,

	_handleOnChange: function(/*anything*/ newValue, /* Boolean? */ priorityChange){
		// summary:
		//		Called when the value of the widget is set.  Calls onChange() if appropriate
		// newValue:
		//		the new value
		// priorityChange:
		//		For a slider, for example, dragging the slider is priorityChange==false,
		//		but on mouse up, it's priorityChange==true.  If intermediateChanges==true,
		//		onChange is only called form priorityChange=true events.
		// tags:
		//		private
		this._lastValue = newValue;
		if(this._lastValueReported == undefined && (priorityChange === null || !this._onChangeActive)){
			// this block executes not for a change, but during initialization,
			// and is used to store away the original value (or for ToggleButton, the original checked state)
			this._resetValue = this._lastValueReported = newValue;
		}
		if((this.intermediateChanges || priorityChange || priorityChange === undefined) &&
			((typeof newValue != typeof this._lastValueReported) ||
				this.compare(newValue, this._lastValueReported) != 0)){
			this._lastValueReported = newValue;
			if(this._onChangeActive){ this.onChange(newValue); }
		}
	},

	create: function(){
		// Overrides _Widget.create()
		this.inherited(arguments);
		this._onChangeActive = true;
		this._setStateClass();
	},

	destroy: function(){
		if(this._layoutHackHandle){
			clearTimeout(this._layoutHackHandle);
		}
		this.inherited(arguments);
	},

	setValue: function(/*String*/ value){
		// summary:
		//		Deprecated.   Use attr('value', ...) instead.
		dojo.deprecated("dijit.form._FormWidget:setValue("+value+") is deprecated.  Use attr('value',"+value+") instead.", "", "2.0");
		this.attr('value', value);
	},

	getValue: function(){
		// summary:
		//		Deprecated.   Use attr('value') instead.
		dojo.deprecated(this.declaredClass+"::getValue() is deprecated. Use attr('value') instead.", "", "2.0");
		return this.attr('value');
	},

	_layoutHack: function(){
		// summary:
		//		Work around table sizing bugs on FF2 by forcing redraw

		if(dojo.isFF == 2 && !this._layoutHackHandle){
			var node=this.domNode;
			var old = node.style.opacity;
			node.style.opacity = "0.999";
			this._layoutHackHandle = setTimeout(dojo.hitch(this, function(){
				this._layoutHackHandle = null;
				node.style.opacity = old;
			}), 0);
		}
	}
});

dojo.declare("dijit.form._FormValueWidget", dijit.form._FormWidget,
{
	// summary:
	//		Base class for widgets corresponding to native HTML elements such as <input> or <select> that have user changeable values.
	// description:
	//		Each _FormValueWidget represents a single input value, and has a (possibly hidden) <input> element,
	//		to which it serializes it's input value, so that form submission (either normal submission or via FormBind?)
	//		works as expected.

	// Don't attempt to mixin the 'type', 'name' attributes here programatically -- they must be declared
	// directly in the template as read by the parser in order to function. IE is known to specifically
	// require the 'name' attribute at element creation time.   See #8484, #8660.
	// TODO: unclear what that {value: ""} is for; FormWidget.attributeMap copies value to focusNode,
	// so maybe {value: ""} is so the value *doesn't* get copied to focusNode?
	// Seems like we really want value removed from attributeMap altogether
	// (although there's no easy way to do that now)
	attributeMap: dojo.delegate(dijit.form._FormWidget.prototype.attributeMap, { value: "" }),

	postCreate: function(){
		if(dojo.isIE || dojo.isWebKit){ // IE won't stop the event with keypress and Safari won't send an ESCAPE to keypress at all
			this.connect(this.focusNode || this.domNode, "onkeydown", this._onKeyDown);
		}
		// Update our reset value if it hasn't yet been set (because this.attr
		// is only called when there *is* a value
		if(this._resetValue === undefined){
			this._resetValue = this.value;
		}
	},

	_setValueAttr: function(/*anything*/ newValue, /*Boolean, optional*/ priorityChange){
		// summary:
		//		Hook so attr('value', value) works.
		// description:
		//		Sets the value of the widget.
		//		If the value has changed, then fire onChange event, unless priorityChange
		//		is specified as null (or false?)
		this.value = newValue;
		this._handleOnChange(newValue, priorityChange);
	},

	_getValueAttr: function(/*String*/ value){
		// summary:
		//		Hook so attr('value') works.
		return this._lastValue;
	},

	undo: function(){
		// summary:
		//		Restore the value to the last value passed to onChange
		this._setValueAttr(this._lastValueReported, false);
	},

	reset: function(){
		// summary:
		//		Reset the widget's value to what it was at initialization time
		this._hasBeenBlurred = false;
		this._setValueAttr(this._resetValue, true);
	},

	_onKeyDown: function(e){
		if(e.keyCode == dojo.keys.ESCAPE && !e.ctrlKey && !e.altKey){
			var te;
			if(dojo.isIE){ 
				e.preventDefault(); // default behavior needs to be stopped here since keypress is too late
				te = document.createEventObject();
				te.keyCode = dojo.keys.ESCAPE;
				te.shiftKey = e.shiftKey;
				e.srcElement.fireEvent('onkeypress', te);
			}else if(dojo.isWebKit){ // ESCAPE needs help making it into keypress
				te = document.createEvent('Events');
				te.initEvent('keypress', true, true);
				te.keyCode = dojo.keys.ESCAPE;
				te.shiftKey = e.shiftKey;
				e.target.dispatchEvent(te);
			}
		}
	}
});

}

if(!dojo._hasResource["dijit.form.TextBox"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.form.TextBox"] = true;
dojo.provide("dijit.form.TextBox");



dojo.declare(
	"dijit.form.TextBox",
	dijit.form._FormValueWidget,
	{
		//	summary:
		//		A base class for textbox form inputs

		//	trim: Boolean
		//		Removes leading and trailing whitespace if true.  Default is false.
		trim: false,

		//	uppercase: Boolean
		//		Converts all characters to uppercase if true.  Default is false.
		uppercase: false,

		//	lowercase: Boolean
		//		Converts all characters to lowercase if true.  Default is false.
		lowercase: false,

		//	propercase: Boolean
		//		Converts the first character of each word to uppercase if true.
		propercase: false,

		//	maxLength: String
		//		HTML INPUT tag maxLength declaration.
		maxLength: "",

		templateString:"<input class=\"dijit dijitReset dijitLeft\" dojoAttachPoint='textbox,focusNode'\n\tdojoAttachEvent='onmouseenter:_onMouse,onmouseleave:_onMouse'\n\tautocomplete=\"off\" type=\"${type}\" ${nameAttrSetting}\n\t/>\n",
		baseClass: "dijitTextBox",

		attributeMap: dojo.delegate(dijit.form._FormValueWidget.prototype.attributeMap, {
			maxLength: "focusNode" 
		}),

		_getValueAttr: function(){
			// summary:
			//		Hook so attr('value') works as we like.
			// description:
			//		For `dijit.form.TextBox` this basically returns the value of the <input>.
			//
			//		For `dijit.form.MappedTextBox` subclasses, which have both
			//		a "displayed value" and a separate "submit value",
			//		This treats the "displayed value" as the master value, computing the
			//		submit value from it via this.parse().
			return this.parse(this.attr('displayedValue'), this.constraints);
		},

		_setValueAttr: function(value, /*Boolean?*/ priorityChange, /*String?*/ formattedValue){
			// summary:
			//		Hook so attr('value', ...) works.
			//
			// description: 
			//		Sets the value of the widget to "value" which can be of
			//		any type as determined by the widget.
			//
			// value:
			//		The visual element value is also set to a corresponding,
			//		but not necessarily the same, value.
			//
			// formattedValue:
			//		If specified, used to set the visual element value,
			//		otherwise a computed visual value is used.
			//
			// priorityChange:
			//		If true, an onChange event is fired immediately instead of 
			//		waiting for the next blur event.

			var filteredValue;
			if(value !== undefined){
				// TODO: this is calling filter() on both the display value and the actual value.
				// I added a comment to the filter() definition about this, but it should be changed.
				filteredValue = this.filter(value);
				if(typeof formattedValue != "string"){
					if(filteredValue !== null && ((typeof filteredValue != "number") || !isNaN(filteredValue))){
						formattedValue = this.filter(this.format(filteredValue, this.constraints));
					}else{ formattedValue = ''; }
				}
			}
			if(formattedValue != null && formattedValue != undefined && ((typeof formattedValue) != "number" || !isNaN(formattedValue)) && this.textbox.value != formattedValue){
				this.textbox.value = formattedValue;
			}
			this.inherited(arguments, [filteredValue, priorityChange]);
		},

		// displayedValue: String
		//		For subclasses like ComboBox where the displayed value
		//		(ex: Kentucky) and the serialized value (ex: KY) are different,
		//		this represents the displayed value.
		//
		//		Setting 'displayedValue' through attr('displayedValue', ...)
		//		updates 'value', and vice-versa.  Othewise 'value' is updated
		//		from 'displayedValue' periodically, like onBlur etc.
		//
		//		TODO: move declaration to MappedTextBox?
		//		Problem is that ComboBox references displayedValue,
		//		for benefit of FilteringSelect.
		displayedValue: "",

		getDisplayedValue: function(){
			// summary:
			//		Deprecated.   Use attr('displayedValue') instead.
			// tags:
			//		deprecated
			dojo.deprecated(this.declaredClass+"::getDisplayedValue() is deprecated. Use attr('displayedValue') instead.", "", "2.0");
			return this.attr('displayedValue');
		},

		_getDisplayedValueAttr: function(){
			// summary:
			//		Hook so attr('displayedValue') works.
			// description:
			//		Returns the displayed value (what the user sees on the screen),
			// 		after filtering (ie, trimming spaces etc.).
			//
			//		For some subclasses of TextBox (like ComboBox), the displayed value
			//		is different from the serialized value that's actually 
			//		sent to the server (see dijit.form.ValidationTextBox.serialize)
			
			return this.filter(this.textbox.value);
		},

		setDisplayedValue: function(/*String*/value){
			// summary:
			//		Deprecated.   Use attr('displayedValue', ...) instead.
			// tags:
			//		deprecated
			dojo.deprecated(this.declaredClass+"::setDisplayedValue() is deprecated. Use attr('displayedValue', ...) instead.", "", "2.0");
			this.attr('displayedValue', value);
		},
			
		_setDisplayedValueAttr: function(/*String*/value){
			// summary:
			//		Hook so attr('displayedValue', ...) works.
			//	description: 
			//		Sets the value of the visual element to the string "value".
			//		The widget value is also set to a corresponding,
			//		but not necessarily the same, value.

			if(value === null || value === undefined){ value = '' }
			else if(typeof value != "string"){ value = String(value) }
			this.textbox.value = value;
			this._setValueAttr(this.attr('value'), undefined, value);
		},

		format: function(/* String */ value, /* Object */ constraints){
			// summary:
			//		Replacable function to convert a value to a properly formatted string.
			// tags:
			//		protected extension
			return ((value == null || value == undefined) ? "" : (value.toString ? value.toString() : value));
		},

		parse: function(/* String */ value, /* Object */ constraints){
			// summary:
			//		Replacable function to convert a formatted string to a value
			// tags:
			//		protected extension

			return value;	// String
		},

		_refreshState: function(){
			// summary:
			//		After the user types some characters, etc., this method is
			//		called to check the field for validity etc.  The base method
			//		in `dijit.form.TextBox` does nothing, but subclasses override.
			// tags:
			//		protected
		},

		_onInput: function(e){
			if(e && e.type && /key/i.test(e.type) && e.keyCode){
				switch(e.keyCode){
					case dojo.keys.SHIFT:
					case dojo.keys.ALT:
					case dojo.keys.CTRL:
					case dojo.keys.TAB:
						return;
				}
			}
			if(this.intermediateChanges){
				var _this = this;
				// the setTimeout allows the key to post to the widget input box
				setTimeout(function(){ _this._handleOnChange(_this.attr('value'), false); }, 0);
			}
			this._refreshState();
		},

		postCreate: function(){
			// setting the value here is needed since value="" in the template causes "undefined"
			// and setting in the DOM (instead of the JS object) helps with form reset actions
			this.textbox.setAttribute("value", this.textbox.value); // DOM and JS values shuld be the same
			this.inherited(arguments);
			if(dojo.isMoz || dojo.isOpera){
				this.connect(this.textbox, "oninput", this._onInput);
			}else{
				this.connect(this.textbox, "onkeydown", this._onInput);
				this.connect(this.textbox, "onkeyup", this._onInput);
				this.connect(this.textbox, "onpaste", this._onInput);
				this.connect(this.textbox, "oncut", this._onInput);
			}

			/*#5297:if(this.srcNodeRef){
				dojo.style(this.textbox, "cssText", this.style);
				this.textbox.className += " " + this["class"];
			}*/
			this._layoutHack();
		},

		_blankValue: '', // if the textbox is blank, what value should be reported
		filter: function(val){
			// summary:
			//		Auto-corrections (such as trimming) that are applied to textbox
			//		value on blur or form submit.
			// description:
			//		For MappedTextBox subclasses, this is called twice
			// 			- once with the display value
			//			- once the value as set/returned by attr('value', ...)
			//		and attr('value'), ex: a Number for NumberTextBox.
			//
			//		In the latter case it does corrections like converting null to NaN.  In
			//		the former case the NumberTextBox.filter() method calls this.inherited()
			//		to execute standard trimming code in TextBox.filter().
			//
			//		TODO: break this into two methods in 2.0
			//
			// tags:
			//		protected extension
			if(val === null){ return this._blankValue; }
			if(typeof val != "string"){ return val; }
			if(this.trim){
				val = dojo.trim(val);
			}
			if(this.uppercase){
				val = val.toUpperCase();
			}
			if(this.lowercase){
				val = val.toLowerCase();
			}
			if(this.propercase){
				val = val.replace(/[^\s]+/g, function(word){
					return word.substring(0,1).toUpperCase() + word.substring(1);
				});
			}
			return val;
		},

		_setBlurValue: function(){
			this._setValueAttr(this.attr('value'), true);
		},

		_onBlur: function(e){
			if(this.disabled){ return; }
			this._setBlurValue();
			this.inherited(arguments);
		},

		_onFocus: function(e){
			if(this.disabled){ return; }
			this._refreshState();
			this.inherited(arguments);
		},

		reset: function(){
			// Overrides dijit._FormWidget.reset().
			// Additionally resets the displayed textbox value to ''
			this.textbox.value = '';
			this.inherited(arguments);
		}
	}
);

dijit.selectInputText = function(/*DomNode*/element, /*Number?*/ start, /*Number?*/ stop){
	// summary:
	//		Select text in the input element argument, from start (default 0), to stop (default end).

	// TODO: use functions in _editor/selection.js?
	var _window = dojo.global;
	var _document = dojo.doc;
	element = dojo.byId(element);
	if(isNaN(start)){ start = 0; }
	if(isNaN(stop)){ stop = element.value ? element.value.length : 0; }
	element.focus();
	if(_document["selection"] && dojo.body()["createTextRange"]){ // IE
		if(element.createTextRange){
			var range = element.createTextRange();
			with(range){
				collapse(true);
				moveStart("character", start);
				moveEnd("character", stop);
				select();
			}
		}
	}else if(_window["getSelection"]){
		var selection = _window.getSelection();	// TODO: unused, remove
		// FIXME: does this work on Safari?
		if(element.setSelectionRange){
			element.setSelectionRange(start, stop);
		}
	}
};

}

if(!dojo._hasResource["dijit.Tooltip"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.Tooltip"] = true;
dojo.provide("dijit.Tooltip");




dojo.declare(
	"dijit._MasterTooltip",
	[dijit._Widget, dijit._Templated],
	{
		// summary:
		//		Internal widget that holds the actual tooltip markup,
		//		which occurs once per page.
		//		Called by Tooltip widgets which are just containers to hold
		//		the markup
		// tags:
		//		protected

		// duration: Integer
		//		Milliseconds to fade in/fade out
		duration: dijit.defaultDuration,

		templateString:"<div class=\"dijitTooltip dijitTooltipLeft\" id=\"dojoTooltip\">\n\t<div class=\"dijitTooltipContainer dijitTooltipContents\" dojoAttachPoint=\"containerNode\" waiRole='alert'></div>\n\t<div class=\"dijitTooltipConnector\"></div>\n</div>\n",

		postCreate: function(){
			dojo.body().appendChild(this.domNode);

			this.bgIframe = new dijit.BackgroundIframe(this.domNode);

			// Setup fade-in and fade-out functions.
			this.fadeIn = dojo.fadeIn({ node: this.domNode, duration: this.duration, onEnd: dojo.hitch(this, "_onShow") });
			this.fadeOut = dojo.fadeOut({ node: this.domNode, duration: this.duration, onEnd: dojo.hitch(this, "_onHide") });

		},

		show: function(/*String*/ innerHTML, /*DomNode*/ aroundNode, /*String[]?*/ position){
			// summary:
			//		Display tooltip w/specified contents to right of specified node
			//		(To left if there's no space on the right, or if LTR==right)

			if(this.aroundNode && this.aroundNode === aroundNode){
				return;
			}

			if(this.fadeOut.status() == "playing"){
				// previous tooltip is being hidden; wait until the hide completes then show new one
				this._onDeck=arguments;
				return;
			}
			this.containerNode.innerHTML=innerHTML;

			// Firefox bug. when innerHTML changes to be shorter than previous
			// one, the node size will not be updated until it moves.
			this.domNode.style.top = (this.domNode.offsetTop + 1) + "px";

			// position the element and change CSS according to position[] (a list of positions to try)
			var align = {};
			var ltr = this.isLeftToRight();
			dojo.forEach( (position && position.length) ? position : dijit.Tooltip.defaultPosition, function(pos){
				switch(pos){
					case "after":				
						align[ltr ? "BR" : "BL"] = ltr ? "BL" : "BR";
						break;
					case "before":
						align[ltr ? "BL" : "BR"] = ltr ? "BR" : "BL";
						break;
					case "below":
						// first try to align left borders, next try to align right borders (or reverse for RTL mode)
						align[ltr ? "BL" : "BR"] = ltr ? "TL" : "TR";
						align[ltr ? "BR" : "BL"] = ltr ? "TR" : "TL";
						break;
					case "above":
					default:
						// first try to align left borders, next try to align right borders (or reverse for RTL mode)
						align[ltr ? "TL" : "TR"] = ltr ? "BL" : "BR";
						align[ltr ? "TR" : "TL"] = ltr ? "BR" : "BL";
						break;
				}
			});
			var pos = dijit.placeOnScreenAroundElement(this.domNode, aroundNode, align, dojo.hitch(this, "orient"));

			// show it
			dojo.style(this.domNode, "opacity", 0);
			this.fadeIn.play();
			this.isShowingNow = true;
			this.aroundNode = aroundNode;
		},

		orient: function(/* DomNode */ node, /* String */ aroundCorner, /* String */ tooltipCorner){
			// summary:
			//		Private function to set CSS for tooltip node based on which position it's in.
			//		This is called by the dijit popup code.
			// tags:
			//		protected

			node.className = "dijitTooltip " +
				{
					"BL-TL": "dijitTooltipBelow dijitTooltipABLeft",
					"TL-BL": "dijitTooltipAbove dijitTooltipABLeft",
					"BR-TR": "dijitTooltipBelow dijitTooltipABRight",
					"TR-BR": "dijitTooltipAbove dijitTooltipABRight",
					"BR-BL": "dijitTooltipRight",
					"BL-BR": "dijitTooltipLeft"
				}[aroundCorner + "-" + tooltipCorner];
		},

		_onShow: function(){
			// summary:
			//		Called at end of fade-in operation
			// tags:
			//		protected
			if(dojo.isIE){
				// the arrow won't show up on a node w/an opacity filter
				this.domNode.style.filter="";
			}
		},

		hide: function(aroundNode){
			// summary:
			//		Hide the tooltip
			if(this._onDeck && this._onDeck[1] == aroundNode){
				// this hide request is for a show() that hasn't even started yet;
				// just cancel the pending show()
				this._onDeck=null;
			}else if(this.aroundNode === aroundNode){
				// this hide request is for the currently displayed tooltip
				this.fadeIn.stop();
				this.isShowingNow = false;
				this.aroundNode = null;
				this.fadeOut.play();
			}else{
				// just ignore the call, it's for a tooltip that has already been erased
			}
		},

		_onHide: function(){
			// summary:
			//		Called at end of fade-out operation
			// tags:
			//		protected

			this.domNode.style.cssText="";	// to position offscreen again
			if(this._onDeck){
				// a show request has been queued up; do it now
				this.show.apply(this, this._onDeck);
				this._onDeck=null;
			}
		}

	}
);

dijit.showTooltip = function(/*String*/ innerHTML, /*DomNode*/ aroundNode, /*String[]?*/ position){
	// summary:
	//		Display tooltip w/specified contents in specified position.
	//		See description of dijit.Tooltip.defaultPosition for details on position parameter.
	//		If position is not specified then dijit.Tooltip.defaultPosition is used.
	if(!dijit._masterTT){ dijit._masterTT = new dijit._MasterTooltip(); }
	return dijit._masterTT.show(innerHTML, aroundNode, position);
};

dijit.hideTooltip = function(aroundNode){
	// summary:
	//		Hide the tooltip
	if(!dijit._masterTT){ dijit._masterTT = new dijit._MasterTooltip(); }
	return dijit._masterTT.hide(aroundNode);
};

dojo.declare(
	"dijit.Tooltip",
	dijit._Widget,
	{
		// summary
		//		Pops up a tooltip (a help message) when you hover over a node.

		// label: String
		//		Text to display in the tooltip.
		//		Specified as innerHTML when creating the widget from markup.
		label: "",

		// showDelay: Integer
		//		Number of milliseconds to wait after hovering over/focusing on the object, before
		//		the tooltip is displayed.
		showDelay: 400,

		// connectId: [const] String[]
		//		Id's of domNodes to attach the tooltip to.
		//		When user hovers over any of the specified dom nodes, the tooltip will appear.
		//
		//		Note: Currently connectId can only be specified on initialization, it cannot
		//		be changed via attr('connectId', ...)
		//
		//		Note: in 2.0 this will be renamed to connectIds for less confusion.
		connectId: [],

		// position: String[]
		//		See description of `dijit.Tooltip.defaultPosition` for details on position parameter.
		position: [],

		_setConnectIdAttr: function(ids){
			// TODO: erase old conections

			this._connectNodes = [];

			// TODO: rename connectId to connectIds for 2.0, and remove this code converting from string to array
			this.connectId = dojo.isArrayLike(ids) ? ids : [ids];
			
			dojo.forEach(this.connectId, function(id) {
				var node = dojo.byId(id);
				if (node) {
					this._connectNodes.push(node);
					dojo.forEach(["onMouseEnter", "onMouseLeave", "onFocus", "onBlur"], function(event){
						this.connect(node, event.toLowerCase(), "_"+event);
					}, this);
					if(dojo.isIE){
						// BiDi workaround
						node.style.zoom = 1;
					}
				}
			}, this);
		},

		postCreate: function(){	
			dojo.addClass(this.domNode,"dijitTooltipData");
		},

		_onMouseEnter: function(/*Event*/ e){
			// summary:
			//		Handler for mouseenter event on the target node
			// tags:
			//		private
			this._onHover(e);
		},

		_onMouseLeave: function(/*Event*/ e){
			// summary:
			//		Handler for mouseleave event on the target node
			// tags:
			//		private
			this._onUnHover(e);
		},

		_onFocus: function(/*Event*/ e){
			// summary:
			//		Handler for focus event on the target node
			// tags:
			//		private

			// TODO: this is dangerously named, as the dijit focus manager calls
			// _onFocus() on any widget that gets focus (whereas in this class we
			// are connecting onfocus on the *target* DOM node to this method

			this._focus = true;
			this._onHover(e);
			this.inherited(arguments);
		},
		
		_onBlur: function(/*Event*/ e){
			// summary:
			//		Handler for blur event on the target node
			// tags:
			//		private

			// TODO: rename; see above comment

			this._focus = false;
			this._onUnHover(e);
			this.inherited(arguments);
		},

		_onHover: function(/*Event*/ e){
			// summary:
			//		Despite the name of this method, it actually handles both hover and focus
			//		events on the target node, setting a timer to show the tooltip.
			// tags:
			//		private
			if(!this._showTimer){
				var target = e.target;
				this._showTimer = setTimeout(dojo.hitch(this, function(){this.open(target)}), this.showDelay);
			}
		},

		_onUnHover: function(/*Event*/ e){
			// summary:
			//		Despite the name of this method, it actually handles both mouseleave and blur
			//		events on the target node, hiding the tooltip.
			// tags:
			//		private

			// keep a tooltip open if the associated element still has focus (even though the
			// mouse moved away)
			if(this._focus){ return; }

			if(this._showTimer){
				clearTimeout(this._showTimer);
				delete this._showTimer;
			}
			this.close();
		},

		open: function(/*DomNode*/ target){
 			// summary:
			//		Display the tooltip; usually not called directly.
			// tags:
			//		private

			target = target || this._connectNodes[0];
			if(!target){ return; }

			if(this._showTimer){
				clearTimeout(this._showTimer);
				delete this._showTimer;
			}
			dijit.showTooltip(this.label || this.domNode.innerHTML, target, this.position);
			
			this._connectNode = target;
		},

		close: function(){
			// summary:
			//		Hide the tooltip or cancel timer for show of tooltip
			// tags:
			//		private

			if(this._connectNode){
				// if tooltip is currently shown
				dijit.hideTooltip(this._connectNode);
				delete this._connectNode;
			}
			if(this._showTimer){
				// if tooltip is scheduled to be shown (after a brief delay)
				clearTimeout(this._showTimer);
				delete this._showTimer;
			}
		},

		uninitialize: function(){
			this.close();
		}
	}
);

// dijit.Tooltip.defaultPosition: String[]
//		This variable controls the position of tooltips, if the position is not specified to
//		the Tooltip widget or *TextBox widget itself.  It's an array of strings with the following values:
//
//			* before: places tooltip to the left of the target node/widget, or to the right in
//			  the case of RTL scripts like Hebrew and Arabic
//			* after: places tooltip to the right of the target node/widget, or to the left in
//			  the case of RTL scripts like Hebrew and Arabic
//			* above: tooltip goes above target node
//			* below: tooltip goes below target node
//
//		The list is positions is tried, in order, until a position is found where the tooltip fits
//		within the viewport.
//
//		Be careful setting this parameter.  A value of "above" may work fine until the user scrolls
//		the screen so that there's no room above the target node.   Nodes with drop downs, like
//		DropDownButton or FilteringSelect, are especially problematic, in that you need to be sure
//		that the drop down and tooltip don't overlap, even when the viewport is scrolled so that there
//		is only room below (or above) the target node, but not both.
dijit.Tooltip.defaultPosition = ["after", "before"];

}

if(!dojo._hasResource["dijit.form.ValidationTextBox"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.form.ValidationTextBox"] = true;
dojo.provide("dijit.form.ValidationTextBox");








/*=====
	dijit.form.ValidationTextBox.__Constraints = function(){
		// locale: String
		//		locale used for validation, picks up value from this widget's lang attribute
		// _flags_: anything
		//		various flags passed to regExpGen function
		this.locale = "";
		this._flags_ = "";
	}
=====*/

dojo.declare(
	"dijit.form.ValidationTextBox",
	dijit.form.TextBox,
	{
		// summary:
		//		Base class for textbox widgets with the ability to validate content of various types and provide user feedback.
		// tags:
		//		protected

		templateString:"<div class=\"dijit dijitReset dijitInlineTable dijitLeft\"\n\tid=\"widget_${id}\"\n\tdojoAttachEvent=\"onmouseenter:_onMouse,onmouseleave:_onMouse,onmousedown:_onMouse\" waiRole=\"presentation\"\n\t><div style=\"overflow:hidden;\"\n\t\t><div class=\"dijitReset dijitValidationIcon\"><br></div\n\t\t><div class=\"dijitReset dijitValidationIconText\">&Chi;</div\n\t\t><div class=\"dijitReset dijitInputField\"\n\t\t\t><input class=\"dijitReset\" dojoAttachPoint='textbox,focusNode' autocomplete=\"off\"\n\t\t\t${nameAttrSetting} type='${type}'\n\t\t/></div\n\t></div\n></div>\n",
		baseClass: "dijitTextBox",

		// required: Boolean
		//		User is required to enter data into this field.
		required: false,

		// promptMessage: String
		//		If defined, display this hint string immediately on focus to the textbox, if empty.
		//		Think of this like a tooltip that tells the user what to do, not an error message
		//		that tells the user what they've done wrong.
		//
		//		Message disappears when user starts typing.
		promptMessage: "",

		// invalidMessage: String
		// 		The message to display if value is invalid.
		invalidMessage: "$_unset_$", // read from the message file if not overridden

		// constraints: dijit.form.ValidationTextBox.__Constraints
		//		user-defined object needed to pass parameters to the validator functions
		constraints: {},

		// regExp: [extension protected] String
		//		regular expression string used to validate the input
		//		Do not specify both regExp and regExpGen
		regExp: ".*",

		regExpGen: function(/*dijit.form.ValidationTextBox.__Constraints*/constraints){
			// summary:
			//		Overridable function used to generate regExp when dependent on constraints.
			//		Do not specify both regExp and regExpGen.
			// tags:
			//		extension protected
			return this.regExp;     // String
		},

		// state: [readonly] String
		//		Shows current state (ie, validation result) of input (Normal, Warning, or Error)
		state: "",

		// tooltipPosition: String[]
		//		See description of `dijit.Tooltip.defaultPosition` for details on this parameter.
		tooltipPosition: [],

		_setValueAttr: function(){
			// summary:
			//		Hook so attr('value', ...) works.
			this.inherited(arguments);
			this.validate(this._focused);
		},

		validator: function(/*anything*/value, /*dijit.form.ValidationTextBox.__Constraints*/constraints){
			// summary:
			//		Overridable function used to validate the text input against the regular expression.
			// tags:
			//		protected
			return (new RegExp("^(?:" + this.regExpGen(constraints) + ")"+(this.required?"":"?")+"$")).test(value) &&
				(!this.required || !this._isEmpty(value)) &&
				(this._isEmpty(value) || this.parse(value, constraints) !== undefined); // Boolean
		},

		_isValidSubset: function(){
			// summary:
			//		Returns true if the value is either already valid or could be made valid by appending characters.
			//		This is used for validation while the user [may be] still typing.
			return this.textbox.value.search(this._partialre) == 0;
		},

		isValid: function(/*Boolean*/ isFocused){
			// summary:
			//		Tests if value is valid.
			//		Can override with your own routine in a subclass.
			// tags:
			//		protected
			return this.validator(this.textbox.value, this.constraints);
		},

		_isEmpty: function(value){
			// summary:
			//		Checks for whitespace
			return /^\s*$/.test(value); // Boolean
		},

		getErrorMessage: function(/*Boolean*/ isFocused){
			// summary:
			//		Return an error message to show if appropriate
			// tags:
			//		protected
			return this.invalidMessage; // String
		},

		getPromptMessage: function(/*Boolean*/ isFocused){
			// summary:
			//		Return a hint message to show when widget is first focused
			// tags:
			//		protected
			return this.promptMessage; // String
		},

		_maskValidSubsetError: true,
		validate: function(/*Boolean*/ isFocused){
			// summary:
			//		Called by oninit, onblur, and onkeypress.
			// description:
			//		Show missing or invalid messages if appropriate, and highlight textbox field.
			// tags:
			//		protected
			var message = "";
			var isValid = this.disabled || this.isValid(isFocused);
			if(isValid){ this._maskValidSubsetError = true; }
			var isValidSubset = !isValid && isFocused && this._isValidSubset();
			var isEmpty = this._isEmpty(this.textbox.value);
			this.state = (isValid || (!this._hasBeenBlurred && isEmpty) || isValidSubset) ? "" : "Error";
			if(this.state == "Error"){ this._maskValidSubsetError = false; }
			this._setStateClass();
			dijit.setWaiState(this.focusNode, "invalid", isValid ? "false" : "true");
			if(isFocused){
				if(isEmpty){
					message = this.getPromptMessage(true);
				}
				if(!message && (this.state == "Error" || (isValidSubset && !this._maskValidSubsetError))){
					message = this.getErrorMessage(true);
				}
			}
			this.displayMessage(message);
			return isValid;
		},

		// _message: String
		//		Currently displayed message
		_message: "",

		displayMessage: function(/*String*/ message){
			// summary:
			//		Overridable method to display validation errors/hints.
			//		By default uses a tooltip.
			// tags:
			//		extension
			if(this._message == message){ return; }
			this._message = message;
			dijit.hideTooltip(this.domNode);
			if(message){
				dijit.showTooltip(message, this.domNode, this.tooltipPosition);
			}
		},

		_refreshState: function(){
			// Overrides TextBox._refreshState()
			this.validate(this._focused);
			this.inherited(arguments);
		},

		//////////// INITIALIZATION METHODS ///////////////////////////////////////

		constructor: function(){
			this.constraints = {};
		},

		postMixInProperties: function(){
			this.inherited(arguments);
			this.constraints.locale = this.lang;
			this.messages = dojo.i18n.getLocalization("dijit.form", "validate", this.lang);
			if(this.invalidMessage == "$_unset_$"){ this.invalidMessage = this.messages.invalidMessage; }
			var p = this.regExpGen(this.constraints);
			this.regExp = p;
			var partialre = "";
			// parse the regexp and produce a new regexp that matches valid subsets
			// if the regexp is .* then there's no use in matching subsets since everything is valid
			if(p != ".*"){ this.regExp.replace(/\\.|\[\]|\[.*?[^\\]{1}\]|\{.*?\}|\(\?[=:!]|./g,
				function (re){
					switch(re.charAt(0)){
						case '{':
						case '+':
						case '?':
						case '*':
						case '^':
						case '$':
						case '|':
						case '(': partialre += re; break;
						case ")": partialre += "|$)"; break;
						 default: partialre += "(?:"+re+"|$)"; break;
					}
				}
			);}
			try{ // this is needed for now since the above regexp parsing needs more test verification
				"".search(partialre);
			}catch(e){ // should never be here unless the original RE is bad or the parsing is bad
				partialre = this.regExp;
				console.warn('RegExp error in ' + this.declaredClass + ': ' + this.regExp);
			} // should never be here unless the original RE is bad or the parsing is bad
			this._partialre = "^(?:" + partialre + ")$";
		},

		_setDisabledAttr: function(/*Boolean*/ value){
			this.inherited(arguments);	// call FormValueWidget._setDisabledAttr()
			if(this.valueNode){
				this.valueNode.disabled = value;
			}
			this._refreshState();
		},
		
		_setRequiredAttr: function(/*Boolean*/ value){
			this.required = value;
			dijit.setWaiState(this.focusNode,"required", value);
			this._refreshState();				
		},

		postCreate: function(){
			if(dojo.isIE){ // IE INPUT tag fontFamily has to be set directly using STYLE
				var s = dojo.getComputedStyle(this.focusNode);
				if(s){
					var ff = s.fontFamily;
					if(ff){
						this.focusNode.style.fontFamily = ff;
					}
				}
			}
			this.inherited(arguments);
		},

		reset:function(){
			// Overrides dijit.form.TextBox.reset() by also
			// hiding errors about partial matches
			this._maskValidSubsetError = true;
			this.inherited(arguments);
		}
	}
);

dojo.declare(
	"dijit.form.MappedTextBox",
	dijit.form.ValidationTextBox,
	{
		// summary:
		//		A dijit.form.ValidationTextBox subclass which provides a base class for widgets that have
		//		a visible formatted display value, and a serializable
		//		value in a hidden input field which is actually sent to the server.
		// description:
		//		The visible display may
		//		be locale-dependent and interactive.  The value sent to the server is stored in a hidden
		//		input field which uses the `name` attribute declared by the original widget.  That value sent
		//		to the server is defined by the dijit.form.MappedTextBox.serialize method and is typically
		//		locale-neutral.
		// tags:
		//		protected

		postMixInProperties: function(){
			this.inherited(arguments);
			
			// we want the name attribute to go to the hidden <input>, not the displayed <input>,
			// so override _FormWidget.postMixInProperties() setting of nameAttrSetting
			this.nameAttrSetting = "";
		},

		serialize: function(/*anything*/val, /*Object?*/options){
			// summary:
			//		Overridable function used to convert the attr('value') result to a canonical
			//		(non-localized) string.  For example, will print dates in ISO format, and
			//		numbers the same way as they are represented in javascript.
			// tags:
			//		protected extension
			return val.toString ? val.toString() : ""; // String
		},

		toString: function(){
			// summary:
			//		Returns widget as a printable string using the widget's value
			// tags:
			//		protected
			var val = this.filter(this.attr('value')); // call filter in case value is nonstring and filter has been customized
			return val != null ? (typeof val == "string" ? val : this.serialize(val, this.constraints)) : ""; // String
		},

		validate: function(){
			// Overrides `dijit.form.TextBox.validate`
			this.valueNode.value = this.toString();
			return this.inherited(arguments);
		},

		buildRendering: function(){
			// Overrides `dijit._Templated.buildRendering`

			this.inherited(arguments);

			// Create a hidden <input> node with the serialized value used for submit
			// (as opposed to the displayed value)
			this.valueNode = dojo.create("input", {
				style: { display: "none" },
				type: this.type,
				name: this.name
			}, this.textbox, "after");
		},

		_setDisabledAttr: function(/*Boolean*/ value){
			this.inherited(arguments);
			dojo.attr(this.valueNode, 'disabled', value);
		},

		reset:function(){
			// Overrides `dijit.form.ValidationTextBox.reset` to
			// reset the hidden textbox value to ''
			this.valueNode.value = '';
			this.inherited(arguments);
		}
	}
);

/*=====
	dijit.form.RangeBoundTextBox.__Constraints = function(){
		// min: Number
		//		Minimum signed value.  Default is -Infinity
		// max: Number
		//		Maximum signed value.  Default is +Infinity
		this.min = min;
		this.max = max;
	}
=====*/

dojo.declare(
	"dijit.form.RangeBoundTextBox",
	dijit.form.MappedTextBox,
	{
		// summary:
		//		Base class for textbox form widgets which defines a range of valid values.

		// rangeMessage: String
		//		The message to display if value is out-of-range
		rangeMessage: "",

		/*=====
		// constraints: dijit.form.RangeBoundTextBox.__Constraints
		constraints: {},
		======*/

		rangeCheck: function(/*Number*/ primitive, /*dijit.form.RangeBoundTextBox.__Constraints*/ constraints){
			// summary:
			//		Overridable function used to validate the range of the numeric input value.
			// tags:
			//		protected
			var isMin = "min" in constraints;
			var isMax = "max" in constraints;
			if(isMin || isMax){
				return (!isMin || this.compare(primitive,constraints.min) >= 0) &&
					(!isMax || this.compare(primitive,constraints.max) <= 0);
			}
			return true; // Boolean
		},

		isInRange: function(/*Boolean*/ isFocused){
			// summary:
			//		Tests if the value is in the min/max range specified in constraints
			// tags:
			//		protected
			return this.rangeCheck(this.attr('value'), this.constraints);
		},

		_isDefinitelyOutOfRange: function(){
			// summary:
			//		Returns true if the value is out of range and will remain
			//		out of range even if the user types more characters
			var val = this.attr('value');
			var isTooLittle = false;
			var isTooMuch = false;
			if("min" in this.constraints){
				var min = this.constraints.min;
				val = this.compare(val, ((typeof min == "number") && min >= 0 && val !=0)? 0 : min);
				isTooLittle = (typeof val == "number") && val < 0;
			}
			if("max" in this.constraints){
				var max = this.constraints.max;
				val = this.compare(val, ((typeof max != "number") || max > 0)? max : 0);
				isTooMuch = (typeof val == "number") && val > 0;
			}
			return isTooLittle || isTooMuch;
		},

		_isValidSubset: function(){
			// summary:
			//		Overrides `dijit.form.ValidationTextBox._isValidSubset`.
			//		Returns true if the input is syntactically valid, and either within
			//		range or could be made in range by more typing.
			return this.inherited(arguments) && !this._isDefinitelyOutOfRange();
		},

		isValid: function(/*Boolean*/ isFocused){
			// Overrides dijit.form.ValidationTextBox.isValid to check that the value is also in range.
			return this.inherited(arguments) &&
				((this._isEmpty(this.textbox.value) && !this.required) || this.isInRange(isFocused)); // Boolean
		},

		getErrorMessage: function(/*Boolean*/ isFocused){
			// Overrides dijit.form.ValidationTextBox.getErrorMessage to print "out of range" message if appropriate
			if(dijit.form.RangeBoundTextBox.superclass.isValid.call(this, false) && !this.isInRange(isFocused)){ return this.rangeMessage; } // String
			return this.inherited(arguments);
		},

		postMixInProperties: function(){
			this.inherited(arguments);
			if(!this.rangeMessage){
				this.messages = dojo.i18n.getLocalization("dijit.form", "validate", this.lang);
				this.rangeMessage = this.messages.rangeMessage;
			}
		},

		postCreate: function(){
			this.inherited(arguments);
			if(this.constraints.min !== undefined){
				dijit.setWaiState(this.focusNode, "valuemin", this.constraints.min);
			}
			if(this.constraints.max !== undefined){
				dijit.setWaiState(this.focusNode, "valuemax", this.constraints.max);
			}
		},
		
		_setValueAttr: function(/*Number*/ value, /*Boolean?*/ priorityChange){
			// summary:
			//		Hook so attr('value', ...) works.

			dijit.setWaiState(this.focusNode, "valuenow", value);
			this.inherited(arguments);
		}
	}
);

}

if(!dojo._hasResource["dijit._Container"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._Container"] = true;
dojo.provide("dijit._Container");

dojo.declare("dijit._Container",
	null,
	{
		// summary:
		//		Mixin for widgets that contain a set of widget children.
		// description:
		//		Use this mixin for widgets that needs to know about and
		//		keep track of their widget children. Suitable for widgets like BorderContainer
		//		and TabContainer which contain (only) a set of child widgets.
		//
		//		It's not suitable for widgets like ContentPane
		//		which contains mixed HTML (plain DOM nodes in addition to widgets),
		//		and where contained widgets are not necessarily directly below
		//		this.containerNode.   In that case calls like addChild(node, position)
		//		wouldn't make sense.

		// isContainer: [protected] Boolean
		//		Just a flag indicating that this widget descends from dijit._Container
		isContainer: true,

		buildRendering: function(){
			this.inherited(arguments);
			if(!this.containerNode){
				// all widgets with descendants must set containerNode
   				this.containerNode = this.domNode;
			}
		},

		addChild: function(/*Widget*/ widget, /*int?*/ insertIndex){
			// summary:
			//		Makes the given widget a child of this widget.
			// description:
			//		Inserts specified child widget's dom node as a child of this widget's
			//		container node, and possibly does other processing (such as layout).

			var refNode = this.containerNode;
			if(insertIndex && typeof insertIndex == "number"){
				var children = this.getChildren();
				if(children && children.length >= insertIndex){
					refNode = children[insertIndex-1].domNode;
					insertIndex = "after";
				}
			}
			dojo.place(widget.domNode, refNode, insertIndex);

			// If I've been started but the child widget hasn't been started,
			// start it now.  Make sure to do this after widget has been
			// inserted into the DOM tree, so it can see that it's being controlled by me,
			// so it doesn't try to size itself.
			if(this._started && !widget._started){
				widget.startup();
			}
		},

		removeChild: function(/*Widget or int*/ widget){
			// summary:
			//		Removes the passed widget instance from this widget but does
			//		not destroy it.  You can also pass in an integer indicating
			//		the index within the container to remove
			if(typeof widget == "number" && widget > 0){
				widget = this.getChildren()[widget];
			}
			// If we cannot find the widget, just return
			if(!widget || !widget.domNode){ return; }
			
			var node = widget.domNode;
			node.parentNode.removeChild(node);	// detach but don't destroy
		},

		_nextElement: function(node){
			// summary:
			//      Find the next (non-text, non-comment etc) node
			// tags:
			//      private
			do{
				node = node.nextSibling;
			}while(node && node.nodeType != 1);
			return node;
		},

		_firstElement: function(node){
			// summary:
			//      Find the first (non-text, non-comment etc) node
			// tags:
			//      private
			node = node.firstChild;
			if(node && node.nodeType != 1){
				node = this._nextElement(node);
			}
			return node;
		},

		getChildren: function(){
			// summary:
			//		Returns array of children widgets.
			// description:
			//		Returns the widgets that are directly under this.containerNode.
			return dojo.query("> [widgetId]", this.containerNode).map(dijit.byNode); // Widget[]
		},

		hasChildren: function(){
			// summary:
			//		Returns true if widget has children, i.e. if this.containerNode contains something.
			return !!this._firstElement(this.containerNode); // Boolean
		},

		destroyDescendants: function(/*Boolean*/ preserveDom){
			// summary:
			//      Destroys all the widgets inside this.containerNode,
			//      but not this widget itself
			dojo.forEach(this.getChildren(), function(child){ child.destroyRecursive(preserveDom); });
		},
	
		_getSiblingOfChild: function(/*Widget*/ child, /*int*/ dir){
			// summary:
			//		Get the next or previous widget sibling of child
			// dir:
			//		if 1, get the next sibling
			//		if -1, get the previous sibling
			// tags:
			//      private
			var node = child.domNode;
			var which = (dir>0 ? "nextSibling" : "previousSibling");
			do{
				node = node[which];
			}while(node && (node.nodeType != 1 || !dijit.byNode(node)));
			return node ? dijit.byNode(node) : null;
		},
		
		getIndexOfChild: function(/*Widget*/ child){
			// summary:
			//		Gets the index of the child in this container or -1 if not found
			var children = this.getChildren();
			for(var i=0, c; c=children[i]; i++){
				if(c == child){ 
					return i; // int
				}
			}
			return -1; // int
		}
	}
);

}

if(!dojo._hasResource["dijit.form.Button"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.form.Button"] = true;
dojo.provide("dijit.form.Button");




dojo.declare("dijit.form.Button",
	dijit.form._FormWidget,
	{
	// summary:
	//		Basically the same thing as a normal HTML button, but with special styling.
	// description:
	//		Buttons can display a label, an icon, or both.
	//		A label should always be specified (through innerHTML) or the label
	//		attribute.  It can be hidden via showLabel=false.
	// example:
	// |	<button dojoType="dijit.form.Button" onClick="...">Hello world</button>
	// 
	// example:
	// |	var button1 = new dijit.form.Button({label: "hello world", onClick: foo});
	// |	dojo.body().appendChild(button1.domNode);

	// label: HTML String
	//		Text to display in button.
	//		If the label is hidden (showLabel=false) then and no title has
	//		been specified, then label is also set as title attribute of icon.
	label: "",

	// showLabel: Boolean
	//		Set this to true to hide the label text and display only the icon.
	//		(If showLabel=false then iconClass must be specified.)
	//		Especially useful for toolbars.  
	//		If showLabel=true, the label will become the title (a.k.a. tooltip/hint) of the icon.
	//
	//		The exception case is for computers in high-contrast mode, where the label
	//		will still be displayed, since the icon doesn't appear.
	showLabel: true,

	// iconClass: String
	//		Class to apply to div in button to make it display an icon
	iconClass: "",

	// type: String
	//		Defines the type of button.  "button", "submit", or "reset".
	type: "button",

	baseClass: "dijitButton",

	templateString:"<span class=\"dijit dijitReset dijitLeft dijitInline\"\n\tdojoAttachEvent=\"ondijitclick:_onButtonClick,onmouseenter:_onMouse,onmouseleave:_onMouse,onmousedown:_onMouse\"\n\t><span class=\"dijitReset dijitRight dijitInline\"\n\t\t><span class=\"dijitReset dijitInline dijitButtonNode\"\n\t\t\t><button class=\"dijitReset dijitStretch dijitButtonContents\"\n\t\t\t\tdojoAttachPoint=\"titleNode,focusNode\" \n\t\t\t\t${nameAttrSetting} type=\"${type}\" value=\"${value}\" waiRole=\"button\" waiState=\"labelledby-${id}_label\"\n\t\t\t\t><span class=\"dijitReset dijitInline\" dojoAttachPoint=\"iconNode\" \n\t\t\t\t\t><span class=\"dijitReset dijitToggleButtonIconChar\">&#10003;</span \n\t\t\t\t></span \n\t\t\t\t><span class=\"dijitReset dijitInline dijitButtonText\" \n\t\t\t\t\tid=\"${id}_label\"  \n\t\t\t\t\tdojoAttachPoint=\"containerNode\"\n\t\t\t\t></span\n\t\t\t></button\n\t\t></span\n\t></span\n></span>\n",

	attributeMap: dojo.delegate(dijit.form._FormWidget.prototype.attributeMap, {
		label: { node: "containerNode", type: "innerHTML" },
		iconClass: { node: "iconNode", type: "class" }
	}),
		

	_onClick: function(/*Event*/ e){
		// summary:
		//		Internal function to handle click actions
		if(this.disabled || this.readOnly){
			return false;
		}
		this._clicked(); // widget click actions
		return this.onClick(e); // user click actions
	},

	_onButtonClick: function(/*Event*/ e){
		// summary:
		//		Handler when the user activates the button portion.
		//		If is activated via a keystroke, stop the event unless is submit or reset.
		if(e.type!='click' && !(this.type=="submit" || this.type=="reset")){
			dojo.stopEvent(e);
		}
		if(this._onClick(e) === false){ // returning nothing is same as true
			e.preventDefault(); // needed for checkbox
		}else if(this.type=="submit" && !this.focusNode.form){ // see if a nonform widget needs to be signalled
			for(var node=this.domNode; node.parentNode/*#5935*/; node=node.parentNode){
				var widget=dijit.byNode(node);
				if(widget && typeof widget._onSubmit == "function"){
					widget._onSubmit(e);
					break;
				}
			}
		}
	},

	_setValueAttr: function(/*String*/ value){
		// Verify that value cannot be set for BUTTON elements.
		var attr = this.attributeMap.value || '';
		if(this[attr.node||attr||'domNode'].tagName == 'BUTTON'){
			// On IE, setting value actually overrides innerHTML, so disallow for everyone for consistency
			if(value != this.value){
				
			}
		}
	},

	_fillContent: function(/*DomNode*/ source){
		// Overrides _Templated._fillcContent().
		// If button label is specified as srcNodeRef.innerHTML rather than
		// this.params.label, handle it here.
		if(source && !("label" in this.params)){
			this.attr('label', source.innerHTML);
		}
	},

	postCreate: function(){
		if (this.showLabel == false){
			dojo.addClass(this.containerNode,"dijitDisplayNone");
		}
		dojo.setSelectable(this.focusNode, false);
		this.inherited(arguments);
	},

	onClick: function(/*Event*/ e){
		// summary:
		//		Callback for when button is clicked.
		//		If type="submit", return true to perform submit, or false to cancel it.
		// type:
		//		callback
		return true;		// Boolean
	},

	_clicked: function(/*Event*/ e){
		// summary:
		//		Internal overridable function for when the button is clicked
	},

	setLabel: function(/*String*/ content){
		// summary:
		//		Deprecated.  Use attr('label', ...) instead.
		dojo.deprecated("dijit.form.Button.setLabel() is deprecated.  Use attr('label', ...) instead.", "", "2.0");
		this.attr("label", content);
	},
	_setLabelAttr: function(/*String*/ content){
		// summary:
		//		Hook for attr('label', ...) to work.
		// description:
		//		Set the label (text) of the button; takes an HTML string.
		this.containerNode.innerHTML = this.label = content;
		this._layoutHack();
		if (this.showLabel == false && !this.params.title){
			this.titleNode.title = dojo.trim(this.containerNode.innerText || this.containerNode.textContent || '');
		}
	}		
});


dojo.declare("dijit.form.DropDownButton", [dijit.form.Button, dijit._Container], {
	// summary:
	//		A button with a drop down
	//
	// example:
	// |	<button dojoType="dijit.form.DropDownButton" label="Hello world">
	// |		<div dojotype="dijit.Menu">...</div>
	// |	</button>
	//
	// example:
	// |	var button1 = new dijit.form.DropDownButton({ label: "hi", dropDown: new dijit.Menu(...) });
	// |	dojo.body().appendChild(button1);
	// 	
	
	baseClass : "dijitDropDownButton",

	templateString:"<span class=\"dijit dijitReset dijitLeft dijitInline\"\n\tdojoAttachEvent=\"onmouseenter:_onMouse,onmouseleave:_onMouse,onmousedown:_onMouse,onclick:_onDropDownClick,onkeydown:_onDropDownKeydown,onblur:_onDropDownBlur,onkeypress:_onKey\"\n\t><span class='dijitReset dijitRight dijitInline'\n\t\t><span class='dijitReset dijitInline dijitButtonNode'\n\t\t\t><button class=\"dijitReset dijitStretch dijitButtonContents\" \n\t\t\t\t${nameAttrSetting} type=\"${type}\" value=\"${value}\"\n\t\t\t\tdojoAttachPoint=\"focusNode,titleNode\" \n\t\t\t\twaiRole=\"button\" waiState=\"haspopup-true,labelledby-${id}_label\"\n\t\t\t\t><span class=\"dijitReset dijitInline\" \n\t\t\t\t\tdojoAttachPoint=\"iconNode\"\n\t\t\t\t></span\n\t\t\t\t><span class=\"dijitReset dijitInline dijitButtonText\"  \n\t\t\t\t\tdojoAttachPoint=\"containerNode,popupStateNode\" \n\t\t\t\t\tid=\"${id}_label\"\n\t\t\t\t></span\n\t\t\t\t><span class=\"dijitReset dijitInline dijitArrowButtonInner\">&thinsp;</span\n\t\t\t\t><span class=\"dijitReset dijitInline dijitArrowButtonChar\">&#9660;</span\n\t\t\t></button\n\t\t></span\n\t></span\n></span>\n",

	_fillContent: function(){
		// Overrides Button._fillContent().
		//
		// My inner HTML contains both the button contents and a drop down widget, like
		// <DropDownButton>  <span>push me</span>  <Menu> ... </Menu> </DropDownButton>
		// The first node is assumed to be the button content. The widget is the popup.

		if(this.srcNodeRef){ // programatically created buttons might not define srcNodeRef
			//FIXME: figure out how to filter out the widget and use all remaining nodes as button
			//	content, not just nodes[0]
			var nodes = dojo.query("*", this.srcNodeRef);
			dijit.form.DropDownButton.superclass._fillContent.call(this, nodes[0]);

			// save pointer to srcNode so we can grab the drop down widget after it's instantiated
			this.dropDownContainer = this.srcNodeRef;
		}
	},

	startup: function(){
		if(this._started){ return; }

		// the child widget from srcNodeRef is the dropdown widget.  Insert it in the page DOM,
		// make it invisible, and store a reference to pass to the popup code.
		if(!this.dropDown){
			var dropDownNode = dojo.query("[widgetId]", this.dropDownContainer)[0];
			this.dropDown = dijit.byNode(dropDownNode);
			delete this.dropDownContainer;
		}
		dijit.popup.prepare(this.dropDown.domNode);

		this.inherited(arguments);
	},

	destroyDescendants: function(){
		if(this.dropDown){
			this.dropDown.destroyRecursive();
			delete this.dropDown;
		}
		this.inherited(arguments);
	},

	_onArrowClick: function(/*Event*/ e){
		// summary:
		//		Handler for when the user mouse clicks on menu popup node
		if(this.disabled || this.readOnly){ return; }
		this._toggleDropDown();
	},

	_onDropDownClick: function(/*Event*/ e){
		// on Firefox 2 on the Mac it is possible to fire onclick
		// by pressing enter down on a second element and transferring
		// focus to the DropDownButton;
		// we want to prevent opening our menu in this situation
		// and only do so if we have seen a keydown on this button;
		// e.detail != 0 means that we were fired by mouse
		var isMacFFlessThan3 = dojo.isFF && dojo.isFF < 3
			&& navigator.appVersion.indexOf("Macintosh") != -1;
		if(!isMacFFlessThan3 || e.detail != 0 || this._seenKeydown){
			this._onArrowClick(e);
		}
		this._seenKeydown = false;
	},

	_onDropDownKeydown: function(/*Event*/ e){
		this._seenKeydown = true;
	},

	_onDropDownBlur: function(/*Event*/ e){
		this._seenKeydown = false;
	},

	_onKey: function(/*Event*/ e){
		// summary:
		//		Handler when the user presses a key on drop down widget
		if(this.disabled || this.readOnly){ return; }
		if(e.charOrCode == dojo.keys.DOWN_ARROW){
			if(!this.dropDown || this.dropDown.domNode.style.visibility=="hidden"){
				dojo.stopEvent(e);
				this._toggleDropDown();
			}
		}
	},

	_onBlur: function(){
		// summary:
		//		Called magically when focus has shifted away from this widget and it's dropdown
		this._closeDropDown();
		// don't focus on button.  the user has explicitly focused on something else.
		this.inherited(arguments);
	},

	_toggleDropDown: function(){
		// summary:
		//		Toggle the drop-down widget; if it is up, close it; if not, open it.
		if(this.disabled || this.readOnly){ return; }
		dijit.focus(this.popupStateNode);
		var dropDown = this.dropDown;
		if(!dropDown){ return; }
		if(!this._opened){
			// If there's an href, then load that first, so we don't get a flicker
			if(dropDown.href && !dropDown.isLoaded){
				var self = this;
				var handler = dojo.connect(dropDown, "onLoad", function(){
					dojo.disconnect(handler);
					self._openDropDown();
				});
				dropDown.refresh();
				return;
			}else{
				this._openDropDown();
			}
		}else{
			this._closeDropDown();
		}
	},

	_openDropDown: function(){
		var dropDown = this.dropDown;
		var oldWidth=dropDown.domNode.style.width;
		var self = this;

		dijit.popup.open({
			parent: this,
			popup: dropDown,
			around: this.domNode,
			orient:
				// TODO: add user-defined positioning option, like in Tooltip.js
				this.isLeftToRight() ? {'BL':'TL', 'BR':'TR', 'TL':'BL', 'TR':'BR'}
				: {'BR':'TR', 'BL':'TL', 'TR':'BR', 'TL':'BL'},
			onExecute: function(){
				self._closeDropDown(true);
			},
			onCancel: function(){
				self._closeDropDown(true);
			},
			onClose: function(){
				dropDown.domNode.style.width = oldWidth;
				self.popupStateNode.removeAttribute("popupActive");
				self._opened = false;
			}
		});
		if(this.domNode.offsetWidth > dropDown.domNode.offsetWidth){
			var adjustNode = null;
			if(!this.isLeftToRight()){
				adjustNode = dropDown.domNode.parentNode;
				var oldRight = adjustNode.offsetLeft + adjustNode.offsetWidth;
			}
			// make menu at least as wide as the button
			dojo.marginBox(dropDown.domNode, {w: this.domNode.offsetWidth});
			if(adjustNode){
				adjustNode.style.left = oldRight - this.domNode.offsetWidth + "px";
			}
		}
		this.popupStateNode.setAttribute("popupActive", "true");
		this._opened=true;
		if(dropDown.focus){
			dropDown.focus();
		}
		// TODO: set this.checked and call setStateClass(), to affect button look while drop down is shown
	},
	
	_closeDropDown: function(/*Boolean*/ focus){
		if(this._opened){
			dijit.popup.close(this.dropDown);
			if(focus){ this.focus(); }
			this._opened = false;			
		}
	}
});

dojo.declare("dijit.form.ComboButton", dijit.form.DropDownButton, {
	// summary:
	//		A combination button and drop-down button.
	//		Users can click one side to "press" the button, or click an arrow
	//		icon to display the drop down.
	//
	// example:
	// |	<button dojoType="dijit.form.ComboButton" onClick="...">
	// |		<span>Hello world</span>
	// |		<div dojoType="dijit.Menu">...</div>
	// |	</button>
	//
	// example:
	// |	var button1 = new dijit.form.ComboButton({label: "hello world", onClick: foo, dropDown: "myMenu"});
	// |	dojo.body().appendChild(button1.domNode);
	// 

	templateString:"<table class='dijit dijitReset dijitInline dijitLeft'\n\tcellspacing='0' cellpadding='0' waiRole=\"presentation\"\n\t><tbody waiRole=\"presentation\"><tr waiRole=\"presentation\"\n\t\t><td class=\"dijitReset dijitStretch dijitButtonContents dijitButtonNode\"\n\t\t\tdojoAttachEvent=\"ondijitclick:_onButtonClick,onmouseenter:_onMouse,onmouseleave:_onMouse,onmousedown:_onMouse\"  dojoAttachPoint=\"titleNode\"\n\t\t\twaiRole=\"button\" waiState=\"labelledby-${id}_label\"\n\t\t\t><div class=\"dijitReset dijitInline\" dojoAttachPoint=\"iconNode\" waiRole=\"presentation\"></div\n\t\t\t><div class=\"dijitReset dijitInline dijitButtonText\" id=\"${id}_label\" dojoAttachPoint=\"containerNode\" waiRole=\"presentation\"></div\n\t\t></td\n\t\t><td class='dijitReset dijitRight dijitButtonNode dijitArrowButton dijitDownArrowButton'\n\t\t\tdojoAttachPoint=\"popupStateNode,focusNode\"\n\t\t\tdojoAttachEvent=\"ondijitclick:_onArrowClick, onkeypress:_onKey,onmouseenter:_onMouse,onmouseleave:_onMouse\"\n\t\t\tstateModifier=\"DownArrow\"\n\t\t\ttitle=\"${optionsTitle}\" ${nameAttrSetting}\n\t\t\twaiRole=\"button\" waiState=\"haspopup-true\"\n\t\t\t><div class=\"dijitReset dijitArrowButtonInner\" waiRole=\"presentation\">&thinsp;</div\n\t\t\t><div class=\"dijitReset dijitArrowButtonChar\" waiRole=\"presentation\">&#9660;</div\n\t\t></td\n\t></tr></tbody\n></table>\n",

	attributeMap: dojo.mixin(dojo.clone(dijit.form.Button.prototype.attributeMap), {
		id:"",
		tabIndex: ["focusNode", "titleNode"]
	}),

	// optionsTitle: String
	//		Text that describes the options menu (accessibility)
	optionsTitle: "",

	baseClass: "dijitComboButton",

	_focusedNode: null,

	postCreate: function(){
		this.inherited(arguments);
		this._focalNodes = [this.titleNode, this.popupStateNode];
		dojo.forEach(this._focalNodes, dojo.hitch(this, function(node){
			if(dojo.isIE){
				this.connect(node, "onactivate", this._onNodeFocus);
				this.connect(node, "ondeactivate", this._onNodeBlur);
			}else{
				this.connect(node, "onfocus", this._onNodeFocus);
				this.connect(node, "onblur", this._onNodeBlur);
			}
		}));
	},

	focusFocalNode: function(node){
		// summary:
		//		Focus the focal node node.
		// description:
		//		Called by _KeyNavContainer for (when example) this button is in a toolbar.
		// tags:
		//		protected
		this._focusedNode = node;
		dijit.focus(node);
	},

	hasNextFocalNode: function(){
		// summary:
		//		Returns true if this widget has no node currently
		//		focused or if there is a node following the focused one.
		//		False is returned if the last node has focus.
		// description:
		//		Called by _KeyNavContainer for (when example) this button is in a toolbar.
		// tags:
		//		protected
		return this._focusedNode !== this.getFocalNodes()[1];
	},

	focusNext: function(){
		// summary:
		//		Focus the focal node following the current node with focus,
		//		or the first one if no node currently has focus.
		// description:
		//		Called by _KeyNavContainer for (when example) this button is in a toolbar.
		// tags:
		//		protected
		this._focusedNode = this.getFocalNodes()[this._focusedNode ? 1 : 0];
		dijit.focus(this._focusedNode);
	},

	hasPrevFocalNode: function(){
		// summary:
		//		Returns true if this widget has no node currently
		//		focused or if there is a node before the focused one.
		//		False is returned if the first node has focus.
		// description:
		//		Called by _KeyNavContainer for (when example) this button is in a toolbar.
		// tags:
		//		protected
		return this._focusedNode !== this.getFocalNodes()[0];
	},

	focusPrev: function(){
		// summary:
		//		Focus the focal node before the current node with focus
		//		or the last one if no node currently has focus.
		// description:
		//		Called by _KeyNavContainer for (when example) this button is in a toolbar.
		// tags:
		//		protected
		this._focusedNode = this.getFocalNodes()[this._focusedNode ? 0 : 1];
		dijit.focus(this._focusedNode);
	},

	getFocalNodes: function(){
		// summary:
		//		Returns an array of focal nodes for this widget.
		// description:
		//		Called by _KeyNavContainer for (when example) this button is in a toolbar.
		// tags:
		//		protected
		return this._focalNodes;
	},

	_onNodeFocus: function(evt){
		this._focusedNode = evt.currentTarget;
		var fnc = this._focusedNode == this.focusNode ? "dijitDownArrowButtonFocused" : "dijitButtonContentsFocused";
		dojo.addClass(this._focusedNode, fnc);
	},

	_onNodeBlur: function(evt){
		var fnc = evt.currentTarget == this.focusNode ? "dijitDownArrowButtonFocused" : "dijitButtonContentsFocused";
		dojo.removeClass(evt.currentTarget, fnc);
	},

	_onBlur: function(){
		this.inherited(arguments);
		this._focusedNode = null;
	}
});

dojo.declare("dijit.form.ToggleButton", dijit.form.Button, {
	// summary:
	//		A button that can be in two states (checked or not).
	//		Can be base class for things like tabs or checkbox or radio buttons

	baseClass: "dijitToggleButton",

	// checked: Boolean
	//		Corresponds to the native HTML <input> element's attribute.
	//		In markup, specified as "checked='checked'" or just "checked".
	//		True if the button is depressed, or the checkbox is checked,
	//		or the radio button is selected, etc.
	checked: false,

	attributeMap: dojo.mixin(dojo.clone(dijit.form.Button.prototype.attributeMap),
		{checked:"focusNode"}),

	_clicked: function(/*Event*/ evt){
		this.attr('checked', !this.checked);
	},

	_setCheckedAttr: function(/*Boolean*/ value){
		this.checked = value;
		dojo.attr(this.focusNode || this.domNode, "checked", value);
		dijit.setWaiState(this.focusNode || this.domNode, "pressed", value);
		this._setStateClass();		
		this._handleOnChange(value, true);
	},

	setChecked: function(/*Boolean*/ checked){
		// summary:
		//		Deprecated.   Use attr('checked', true/false) instead.
		dojo.deprecated("setChecked("+checked+") is deprecated. Use attr('checked',"+checked+") instead.", "", "2.0");
		this.attr('checked', checked);
	},
	
	reset: function(){
		// summary:
		//		Reset the widget's value to what it was at initialization time

		this._hasBeenBlurred = false;

		// set checked state to original setting
		this.attr('checked', this.params.checked || false);
	}
});

}

if(!dojo._hasResource["dijit.InlineEditBox"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.InlineEditBox"] = true;
dojo.provide("dijit.InlineEditBox");










dojo.declare("dijit.InlineEditBox",
	dijit._Widget,
	{
	// summary:
	//		An element with in-line edit capabilitites
	//
	// description:
	//		Behavior for an existing node (`<p>`, `<div>`, `<span>`, etc.) so that
	// 		when you click it, an editor shows up in place of the original
	//		text.  Optionally, Save and Cancel button are displayed below the edit widget.
	//		When Save is clicked, the text is pulled from the edit
	//		widget and redisplayed and the edit widget is again hidden.
	//		By default a plain Textarea widget is used as the editor (or for
	//		inline values a TextBox), but you can specify an editor such as
	//		dijit.Editor (for editing HTML) or a Slider (for adjusting a number).
	//		An edit widget must support the following API to be used:
	//			- displayedValue or value as initialization parameter,
	//			and available through attr('displayedValue') / attr('value')
	//			- void focus()
	//			- DOM-node focusNode = node containing editable text

	// editing: [readonly] Boolean
	//		Is the node currently in edit mode?
	editing: false,

	// autoSave: Boolean
	//		Changing the value automatically saves it; don't have to push save button
	//		(and save button isn't even displayed)
	autoSave: true,

	// buttonSave: String
	//		Save button label
	buttonSave: "",

	// buttonCancel: String
	//		Cancel button label
	buttonCancel: "",

	// renderAsHtml: Boolean
	//		Set this to true if the specified Editor's value should be interpreted as HTML
	//		rather than plain text (ex: `dijit.Editor`)
	renderAsHtml: false,

	// editor: String
	//		Class name for Editor widget
	editor: "dijit.form.TextBox",

	// editorParams: Object
	//		Set of parameters for editor, like {required: true}
	editorParams: {},

	onChange: function(value){
		// summary:
		//		Set this handler to be notified of changes to value.
		// tags:
		//		callback
	},
	
	onCancel: function(){
		// summary:
		//		Set this handler to be notified when editing is cancelled.
		// tags:
		//		callback
	},

	// width: String
	//		Width of editor.  By default it's width=100% (ie, block mode).
	width: "100%",

	// value: String
	//		The display value of the widget in read-only mode
	value: "",

	// noValueIndicator: [const] String
	//		The text that gets displayed when there is no value (so that the user has a place to click to edit)
	noValueIndicator: "<span style='font-family: wingdings; text-decoration: underline;'>&nbsp;&nbsp;&nbsp;&nbsp;&#x270d;&nbsp;&nbsp;&nbsp;&nbsp;</span>",

	constructor: function(){
		// summary:
		//		Sets up private arrays etc.
		// tags:
		//		private
		this.editorParams = {};
	},

	postMixInProperties: function(){
		this.inherited(arguments);

		// save pointer to original source node, since Widget nulls-out srcNodeRef
		this.displayNode = this.srcNodeRef;

		// connect handlers to the display node
		var events = {
			ondijitclick: "_onClick",
			onmouseover: "_onMouseOver",
			onmouseout: "_onMouseOut",
			onfocus: "_onMouseOver",
			onblur: "_onMouseOut"			
		};
		for(var name in events){
			this.connect(this.displayNode, name, events[name]);
		}
		dijit.setWaiRole(this.displayNode, "button");
		if(!this.displayNode.getAttribute("tabIndex")){
			this.displayNode.setAttribute("tabIndex", 0);
		}

		this.attr('value', this.value || this.displayNode.innerHTML);
	},

	setDisabled: function(/*Boolean*/ disabled){
		// summary:
		//		Deprecated.   Use attr('disable', ...) instead.
		// tags:
		//		deprecated
		dojo.deprecated("dijit.InlineEditBox.setDisabled() is deprecated.  Use attr('disabled', bool) instead.", "", "2.0");
		this.attr('disabled', disabled);
	},
	_setDisabledAttr: function(/*Boolean*/ disabled){
		// summary: 
		//		Hook to make attr("disabled", ...) work.
		//		Set disabled state of widget.
		this.disabled = disabled;
		dijit.setWaiState(this.domNode, "disabled", disabled);
	},

	_onMouseOver: function(){
		// summary:
		//		Handler for onmouseover event.
		// tags:
		//		private
		dojo.addClass(this.displayNode, this.disabled ? "dijitDisabledClickableRegion" : "dijitClickableRegion");
	},

	_onMouseOut: function(){
		// summary:
		//		Handler for onmouseout event.
		// tags:
		//		private
		dojo.removeClass(this.displayNode, this.disabled ? "dijitDisabledClickableRegion" : "dijitClickableRegion");
	},

	_onClick: function(/*Event*/ e){
		// summary:
		//		Handler for onclick event.
		// tags:
		//		private
		if(this.disabled){ return; }
		if(e){ dojo.stopEvent(e); }
		this._onMouseOut();

		// Since FF gets upset if you move a node while in an event handler for that node...
		setTimeout(dojo.hitch(this, "edit"), 0);
	},

	edit: function(){
		// summary:
		//		Display the editor widget in place of the original (read only) markup.
		// tags:
		//		private

		if(this.disabled || this.editing){ return; }
		this.editing = true;

		var editValue = 
				(this.renderAsHtml ?
				this.value :
				this.value.replace(/\s*\r?\n\s*/g,"").replace(/<br\/?>/gi,"\n").replace(/&gt;/g,">").replace(/&lt;/g,"<").replace(/&amp;/g,"&").replace(/&quot;/g,"\""));

		// Placeholder for edit widget
		// Put place holder (and eventually editWidget) before the display node so that it's positioned correctly
		// when Calendar dropdown appears, which happens automatically on focus.
		var placeholder = dojo.create("span", null, this.domNode, "before");

		var ew = this.editWidget = new dijit._InlineEditor({
			value: dojo.trim(editValue),
			autoSave: this.autoSave,
			buttonSave: this.buttonSave,
			buttonCancel: this.buttonCancel,
			renderAsHtml: this.renderAsHtml,
			editor: this.editor,
			editorParams: this.editorParams,
			sourceStyle: dojo.getComputedStyle(this.displayNode),
			save: dojo.hitch(this, "save"),
			cancel: dojo.hitch(this, "cancel"),
			width: this.width
		}, placeholder);

		// to avoid screen jitter, we first create the editor with position:absolute, visibility:hidden,
		// and then when it's finished rendering, we switch from display mode to editor
		var ews = ew.domNode.style;
		this.displayNode.style.display="none";
		ews.position = "static";
		ews.visibility = "visible";

		// Replace the display widget with edit widget, leaving them both displayed for a brief time so that
		// focus can be shifted without incident.  (browser may needs some time to render the editor.)
		this.domNode = ew.domNode;
		setTimeout(function(){
			ew.focus();
			ew._resetValue = ew.getValue();
		}, 100);
	},

	_showText: function(/*Boolean*/ focus){
		// summary:
		//		Revert to display mode, and optionally focus on display node
		// tags:
		//		private

		// display the read-only text and then quickly hide the editor (to avoid screen jitter)
		this.displayNode.style.display="";
		var ew = this.editWidget;
		var ews = ew.domNode.style;
		ews.position="absolute";
		ews.visibility="hidden";

		this.domNode = this.displayNode;

		if(focus){
			dijit.focus(this.displayNode);
		}
		ews.display = "none";
		// give the browser some time to render the display node and then shift focus to it
		// and hide the edit widget before garbage collecting the edit widget
		setTimeout(function(){
			ew.destroy();
			delete ew;
			if(dojo.isIE){
				// messing with the DOM tab order can cause IE to focus the body - so restore
				dijit.focus(dijit.getFocus());
			}
		}, 1000); // no hurry - wait for things to quiesce
	},

	save: function(/*Boolean*/ focus){
		// summary:
		//		Save the contents of the editor and revert to display mode.
		// focus: Boolean
		//		Focus on the display mode text
		// tags:
		//		private
		if(this.disabled || !this.editing){ return; }
		this.editing = false;

		var value = this.editWidget.getValue() + "";
		this.attr('value', this.renderAsHtml? value
			: value.replace(/&/gm, "&amp;").replace(/</gm, "&lt;").replace(/>/gm, "&gt;").replace(/"/gm, "&quot;").replace(/\n/g, "<br>")
		);

		// tell the world that we have changed
		this.onChange(value);

		this._showText(focus);	
	},

	setValue: function(/*String*/ val){
		// summary:
		//		Deprecated.   Use attr('value', ...) instead.
		// tags:
		//		deprecated
		dojo.deprecated("dijit.InlineEditBox.setValue() is deprecated.  Use attr('value', ...) instead.", "", "2.0");
		return this.attr("value", val);
	},
	_setValueAttr: function(/*String*/ val){
		// summary:
		// 		Hook to make attr("value", ...) work.
		//		Inserts specified HTML value into this node, or an "input needed" character if node is blank.
		this.value = val;
		this.displayNode.innerHTML = dojo.trim(val) || this.noValueIndicator;
	},

	getValue: function(){
		// summary:
		//		Deprecated.   Use attr('value') instead.
		// tags:
		//		deprecated
		dojo.deprecated("dijit.InlineEditBox.getValue() is deprecated.  Use attr('value') instead.", "", "2.0");
		return this.attr("value");
	},

	cancel: function(/*Boolean*/ focus){
		// summary:
		//		Revert to display mode, discarding any changes made in the editor
		// tags:
		//		private

		this.editing = false;
		
		// tell the world that we have no changes
		this.onCancel();
		
		this._showText(focus);
	}
});

dojo.declare(
	"dijit._InlineEditor",
	 [dijit._Widget, dijit._Templated],
{
	// summary:
	// 		Internal widget used by InlineEditBox, displayed when in editing mode
	//		to display the editor and maybe save/cancel buttons.  Calling code should
	//		connect to save/cancel methods to detect when editing is finished
	//
	//		Has mainly the same parameters as InlineEditBox, plus these values:
	//
	// style: Object
	//		Set of CSS attributes of display node, to replicate in editor
	//
	// value: String
	//		Value as an HTML string or plain text string, depending on renderAsHTML flag

	templateString:"<span dojoAttachPoint=\"editNode\" waiRole=\"presentation\" style=\"position: absolute; visibility:hidden\" class=\"dijitReset dijitInline\"\n\tdojoAttachEvent=\"onkeypress: _onKeyPress\" \n\t><span dojoAttachPoint=\"editorPlaceholder\"></span\n\t><span dojoAttachPoint=\"buttonContainer\"\n\t\t><button class='saveButton' dojoAttachPoint=\"saveButton\" dojoType=\"dijit.form.Button\" dojoAttachEvent=\"onClick:save\" disabled=\"true\" label=\"${buttonSave}\"></button\n\t\t><button class='cancelButton' dojoAttachPoint=\"cancelButton\" dojoType=\"dijit.form.Button\" dojoAttachEvent=\"onClick:cancel\" label=\"${buttonCancel}\"></button\n\t></span\n></span>\n",
	widgetsInTemplate: true,

	postMixInProperties: function(){
		this.inherited(arguments);
		this.messages = dojo.i18n.getLocalization("dijit", "common", this.lang);
		dojo.forEach(["buttonSave", "buttonCancel"], function(prop){
			if(!this[prop]){ this[prop] = this.messages[prop]; }
		}, this);
	},

	postCreate: function(){
		// Create edit widget in place in the template
		var cls = dojo.getObject(this.editor);

		// Copy the style from the source
		// Don't copy ALL properties though, just the necessary/applicable ones
		var srcStyle = this.sourceStyle;
		var editStyle = "line-height:" + srcStyle.lineHeight + ";";
		dojo.forEach(["Weight","Family","Size","Style"], function(prop){
			editStyle += "font-"+prop+":"+srcStyle["font"+prop]+";";
		}, this);
		dojo.forEach(["marginTop","marginBottom","marginLeft", "marginRight"], function(prop){
			this.domNode.style[prop] = srcStyle[prop];
		}, this);
		if(this.width=="100%"){
			// block mode
			editStyle += "width:100%;";
			this.domNode.style.display = "block";
		}else{
			// inline-block mode
			editStyle += "width:" + (this.width + (Number(this.width)==this.width ? "px" : "")) + ";";
		}
		this.editorParams.style = editStyle;
		this.editorParams[ "displayedValue" in cls.prototype ? "displayedValue" : "value"] = this.value;
		var ew = this.editWidget = new cls(this.editorParams, this.editorPlaceholder);

		this.connect(ew, "onChange", "_onChange");

		// Monitor keypress on the edit widget.   Note that edit widgets do a stopEvent() on ESC key (to
		// prevent Dialog from closing when the user just wants to revert the value in the edit widget),
		// so this is the only way we can see the key press event.
		this.connect(ew, "onKeyPress", "_onKeyPress");
		this.connect(ew, "onKeyUp", "_onKeyPress"); // in case ESC was eaten but changed value

		if(this.autoSave){
			this.buttonContainer.style.display="none";
		}
	},

	destroy: function(){
		this.editWidget.destroy();
		this.inherited(arguments);
	},

	getValue: function(){
		// summary:
		//		Return the [display] value of the edit widget
		var ew = this.editWidget;
		return ew.attr("displayedValue" in ew ? "displayedValue" : "value");
	},

	_onKeyPress: function(e){
		// summary:
		//		Handler for keypress in the edit box (see template).
		// description:
		//		For autoSave widgets, if Esc/Enter, call cancel/save.
		//		For non-autoSave widgets, enable save button if the text value is
		//		different than the original value.
		// tags:
		//		private

		if(this._exitInProgress){
			return;
		}
		if(this.autoSave){
			if(e.altKey || e.ctrlKey){ return; }
			// If Enter/Esc pressed, treat as save/cancel.
			if(e.charOrCode == dojo.keys.ESCAPE){
				dojo.stopEvent(e);
				this._exitInProgress = true;
				this.cancel(true);
			}else if(e.charOrCode == dojo.keys.ENTER && this.editWidget.focusNode.tagName == "INPUT"){
				dojo.stopEvent(e);
				this._exitInProgress = true;
				this.save(true);
			}else if(e.charOrCode === dojo.keys.TAB){
				this._exitInProgress = true;
				// allow the TAB to change focus before we mess with the DOM: #6227
				// Expounding by request:
				// 	The current focus is on the edit widget input field.
				//	save() will hide and destroy this widget.
				//	We want the focus to jump from the currently hidden
				//	displayNode, but since it's hidden, it's impossible to
				//	unhide it, focus it, and then have the browser focus
				//	away from it to the next focusable element since each
				//	of these events is asynchronous and the focus-to-next-element
				//	is already queued.
				//	So we allow the browser time to unqueue the move-focus event 
				//	before we do all the hide/show stuff.
				setTimeout(dojo.hitch(this, "save", false), 0);
			}
		}else{
			var _this = this;
			// Delay before calling getValue().
			// The delay gives the browser a chance to update the native value.
			setTimeout(
				function(){
					_this._onChange(); // handle save button
				}, 100);
		}
	},

	_onBlur: function(){
		// summary:
		//		Called when focus moves outside the editor
		// tags:
		//		private

		this.inherited(arguments);
		if(this._exitInProgress){
			// when user clicks the "save" button, focus is shifted back to display text, causing this
			// function to be called, but in that case don't do anything
			return;
		}
		if(this.autoSave){
			this._exitInProgress = true;
			if(this.getValue() == this._resetValue){
				this.cancel(false);
			}else{
				this.save(false);
			}
		}
	},

	_onChange: function(){
		// summary:
		//		Called when the underlying widget fires an onChange event,
		//		which means that the user has finished entering the value
		// tags:
		//		private

		if(this._exitInProgress){
			// TODO: the onChange event might happen after the return key for an async widget
			// like FilteringSelect.  Shouldn't be deleting the edit widget on end-of-edit
			return;
		}
		if(this.autoSave){
			this._exitInProgress = true;
			this.save(true);
		}else{
			// in case the keypress event didn't get through (old problem with Textarea that has been fixed
			// in theory) or if the keypress event comes too quickly and the value inside the Textarea hasn't
			// been updated yet)
			this.saveButton.attr("disabled", (this.getValue() == this._resetValue) || !this.enableSave());
		}
	},
	
	enableSave: function(){
		// summary:
		//		User overridable function returning a Boolean to indicate
		// 		if the Save button should be enabled or not - usually due to invalid conditions
		// tags:
		//		extension
		return this.editWidget.isValid ? this.editWidget.isValid() : true;
	},

	focus: function(){
		// summary:
		//		Focus on the edit widget.
		this.editWidget.focus();
		dijit.selectInputText(this.editWidget.focusNode);
	}
});

}

if(!dojo._hasResource["dijit._Contained"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._Contained"] = true;
dojo.provide("dijit._Contained");

dojo.declare("dijit._Contained",
		null,
		{
			// summary
			//		Mixin for widgets that are children of a container widget
			//
			// example:
			// | 	// make a basic custom widget that knows about it's parents
			// |	dojo.declare("my.customClass",[dijit._Widget,dijit._Contained],{});
			// 
			getParent: function(){
				// summary:
				//		Returns the parent widget of this widget, assuming the parent
				//		implements dijit._Container
				for(var p=this.domNode.parentNode; p; p=p.parentNode){
					var id = p.getAttribute && p.getAttribute("widgetId");
					if(id){
						var parent = dijit.byId(id);
						return parent.isContainer ? parent : null;
					}
				}
				return null;
			},

			_getSibling: function(which){
				// summary:
				//      Returns next or previous sibling
				// which:
				//      Either "next" or "previous"
				// tags:
				//      private
				var node = this.domNode;
				do{
					node = node[which+"Sibling"];
				}while(node && node.nodeType != 1);
				if(!node){ return null; } // null
				var id = node.getAttribute("widgetId");
				return dijit.byId(id);
			},

			getPreviousSibling: function(){
				// summary:
				//		Returns null if this is the first child of the parent,
				//		otherwise returns the next element sibling to the "left".

				return this._getSibling("previous"); // Mixed
			},

			getNextSibling: function(){
				// summary:
				//		Returns null if this is the last child of the parent,
				//		otherwise returns the next element sibling to the "right".

				return this._getSibling("next"); // Mixed
			},
			
			getIndexInParent: function(){
				// summary:
				//		Returns the index of this widget within its container parent.
				//		It returns -1 if the parent does not exist, or if the parent
				//		is not a dijit._Container
				
				var p = this.getParent();
				if(!p || !p.getIndexOfChild){
					return -1; // int
				}
				return p.getIndexOfChild(this); // int
			}
		}
	);


}

if(!dojo._hasResource["dijit.layout._LayoutWidget"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.layout._LayoutWidget"] = true;
dojo.provide("dijit.layout._LayoutWidget");





dojo.declare("dijit.layout._LayoutWidget",
	[dijit._Widget, dijit._Container, dijit._Contained],
	{
		// summary:
		//		Base class for a _Container widget which is responsible for laying out its children.
		//		Widgets which mixin this code must define layout() to lay out the children.

		// baseClass: [protected extension] String
		//		This class name is applied to the widget's domNode
		//		and also may be used to generate names for sub nodes,
		//		like for example dijitTabContainer-content.
		baseClass: "dijitLayoutContainer",

		// isLayoutContainer: [private deprecated] Boolean
		//		TODO: this is unused, but maybe it *should* be used for a child to
		//		detect whether the parent is going to call resize() on it or not
		//		(see calls to getParent() and resize() in this file)
		isLayoutContainer: true,

		postCreate: function(){
			dojo.addClass(this.domNode, "dijitContainer");
			dojo.addClass(this.domNode, this.baseClass);
			
			// TODO: this.inherited()
		},

		startup: function(){
			// summary:
			//		Called after all the widgets have been instantiated and their
			//		dom nodes have been inserted somewhere under dojo.doc.body.
			//
			//		Widgets should override this method to do any initialization
			//		dependent on other widgets existing, and then call
			//		this superclass method to finish things off.
			//
			//		startup() in subclasses shouldn't do anything
			//		size related because the size of the widget hasn't been set yet.

			if(this._started){ return; }

			// TODO: seems like this code should be in _Container.startup().
			// Then things that don't extend LayoutContainer (like GridContainer)
			// would get the behavior for free.
			dojo.forEach(this.getChildren(), function(child){ child.startup(); });

			// If I am a top level widget
			if(!this.getParent || !this.getParent()){
				// Do recursive sizing and layout of all my descendants
				// (passing in no argument to resize means that it has to glean the size itself)
				this.resize();

				// Since my parent isn't a layout container, and my style is width=height=100% (or something similar),
				// then I need to watch when the window resizes, and size myself accordingly.
				// (Passing in no arguments to resize means that it has to glean the size itself.)
				// TODO: make one global listener to avoid getViewport() per widget.
				this._viewport = dijit.getViewport();
				this.connect(dojo.global, 'onresize', function(){
					var newViewport = dijit.getViewport();
					if(newViewport.w != this._viewport.w ||  newViewport.h != this._viewport.h){
						this._viewport = newViewport;
						this.resize();
					}
				});
			}
			
			this.inherited(arguments);
		},

		resize: function(changeSize, resultSize){
			// summary:
			//		Call this to resize a widget, or after its size has changed.
			// description:
			//		Change size mode:
			//			When changeSize is specified, changes the marginBox of this widget
			//			 and forces it to relayout its contents accordingly.
			//			changeSize may specify height, width, or both.
			//
			//			If resultSize is specified it indicates the size the widget will
			//			become after changeSize has been applied.
			//
			//		Notification mode:
			//			When changeSize is null, indicates that the caller has already changed
			//			the size of the widget, or perhaps it changed because the browser
			//			window was resized.  Tells widget to relayout it's contents accordingly.
			//
			//			If resultSize is also specified it indicates the size the widget has
			//			become.
			//
			//		In either mode, this method also:
			//			1. Sets this._borderBox and this._contentBox to the new size of
			//				the widget.  Queries the current domNode size if necessary.
			//			2. Calls layout() to resize contents (and maybe adjust child widgets).	
			//
			// changeSize: Object?
			//		Sets the widget to this margin-box size and position.
			//		May include any/all of the following properties:
			//	|	{w: int, h: int, l: int, t: int}
			//
			// resultSize: Object?
			//		The margin-box size of this widget after applying changeSize (if 
			//		changeSize is specified).  If caller knows this size and
			//		passes it in, we don't need to query the browser to get the size.
			//	|	{w: int, h: int}

			var node = this.domNode;

			// set margin box size, unless it wasn't specified, in which case use current size
			if(changeSize){
				dojo.marginBox(node, changeSize);

				// set offset of the node
				if(changeSize.t){ node.style.top = changeSize.t + "px"; }
				if(changeSize.l){ node.style.left = changeSize.l + "px"; }
			}

			// If either height or width wasn't specified by the user, then query node for it.
			// But note that setting the margin box and then immediately querying dimensions may return
			// inaccurate results, so try not to depend on it.
			var mb = resultSize || {};
			dojo.mixin(mb, changeSize || {});	// changeSize overrides resultSize
			if ( !("h" in mb) || !("w" in mb) ){
				mb = dojo.mixin(dojo.marginBox(node), mb);	// just use dojo.marginBox() to fill in missing values
			}

			// Compute and save the size of my border box and content box
			// (w/out calling dojo.contentBox() since that may fail if size was recently set)
			var cs = dojo.getComputedStyle(node);
			var me = dojo._getMarginExtents(node, cs);
			var be = dojo._getBorderExtents(node, cs);
			var bb = (this._borderBox = {
				w: mb.w - (me.w + be.w),
				h: mb.h - (me.h + be.h)
			});
			var pe = dojo._getPadExtents(node, cs);
			this._contentBox = {
				l: dojo._toPixelValue(node, cs.paddingLeft),
				t: dojo._toPixelValue(node, cs.paddingTop),
				w: bb.w - pe.w,
				h: bb.h - pe.h
			};

			// Callback for widget to adjust size of it's children
			this.layout();
		},

		layout: function(){
			// summary:
			//		Widgets override this method to size and position their contents/children.
			//		When this is called this._contentBox is guaranteed to be set (see resize()).
			//
			//		This is called after startup(), and also when the widget's size has been
			//		changed.
			// tags:
			//		protected extension
		},

		_setupChild: function(/*Widget*/child){
			// summary:
			//		Common setup for initial children and children which are added after startup
			// tags:
			//		protected extension

			dojo.addClass(child.domNode, this.baseClass+"-child");
			if(child.baseClass){
				dojo.addClass(child.domNode, this.baseClass+"-"+child.baseClass);
			}
		},

		addChild: function(/*Widget*/ child, /*Integer?*/ insertIndex){
			// Overrides _Container.addChild() to call _setupChild()
			this.inherited(arguments);
			if(this._started){
				this._setupChild(child);
			}
		},

		removeChild: function(/*Widget*/ child){
			// Overrides _Container.removeChild() to remove class added by _setupChild()
			dojo.removeClass(child.domNode, this.baseClass+"-child");
			if(child.baseClass){
				dojo.removeClass(child.domNode, this.baseClass+"-"+child.baseClass);
			}
			this.inherited(arguments);
		}
	}
);

dijit.layout.marginBox2contentBox = function(/*DomNode*/ node, /*Object*/ mb){
	// summary:
	//		Given the margin-box size of a node, return its content box size.
	//		Functions like dojo.contentBox() but is more reliable since it doesn't have
	//		to wait for the browser to compute sizes.
	var cs = dojo.getComputedStyle(node);
	var me = dojo._getMarginExtents(node, cs);
	var pb = dojo._getPadBorderExtents(node, cs);
	return {
		l: dojo._toPixelValue(node, cs.paddingLeft),
		t: dojo._toPixelValue(node, cs.paddingTop),
		w: mb.w - (me.w + pb.w),
		h: mb.h - (me.h + pb.h)
	};
};

(function(){
	var capitalize = function(word){
		return word.substring(0,1).toUpperCase() + word.substring(1);
	};

	var size = function(widget, dim){
		// size the child
		widget.resize ? widget.resize(dim) : dojo.marginBox(widget.domNode, dim);

		// record child's size, but favor our own numbers when we have them.
		// the browser lies sometimes
		dojo.mixin(widget, dojo.marginBox(widget.domNode));
		dojo.mixin(widget, dim);
	};

	dijit.layout.layoutChildren = function(/*DomNode*/ container, /*Object*/ dim, /*Object[]*/ children){
		// summary
		//		Layout a bunch of child dom nodes within a parent dom node
		// container:
		//		parent node
		// dim:
		//		{l, t, w, h} object specifying dimensions of container into which to place children
		// children:
		//		an array like [ {domNode: foo, layoutAlign: "bottom" }, {domNode: bar, layoutAlign: "client"} ]

		// copy dim because we are going to modify it
		dim = dojo.mixin({}, dim);

		dojo.addClass(container, "dijitLayoutContainer");

		// Move "client" elements to the end of the array for layout.  a11y dictates that the author
		// needs to be able to put them in the document in tab-order, but this algorithm requires that
		// client be last.
		children = dojo.filter(children, function(item){ return item.layoutAlign != "client"; })
			.concat(dojo.filter(children, function(item){ return item.layoutAlign == "client"; }));

		// set positions/sizes
		dojo.forEach(children, function(child){
			var elm = child.domNode,
				pos = child.layoutAlign;

			// set elem to upper left corner of unused space; may move it later
			var elmStyle = elm.style;
			elmStyle.left = dim.l+"px";
			elmStyle.top = dim.t+"px";
			elmStyle.bottom = elmStyle.right = "auto";

			dojo.addClass(elm, "dijitAlign" + capitalize(pos));

			// set size && adjust record of remaining space.
			// note that setting the width of a <div> may affect it's height.
			if(pos == "top" || pos == "bottom"){
				size(child, { w: dim.w });
				dim.h -= child.h;
				if(pos=="top"){
					dim.t += child.h;
				}else{
					elmStyle.top = dim.t + dim.h + "px";
				}
			}else if(pos == "left" || pos == "right"){
				size(child, { h: dim.h });
				dim.w -= child.w;
				if(pos == "left"){
					dim.l += child.w;
				}else{
					elmStyle.left = dim.l + dim.w + "px";
				}
			}else if(pos == "client"){
				size(child, dim);
			}
		});
	};

})();

}

if(!dojo._hasResource["dojo.html"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.html"] = true;
dojo.provide("dojo.html");

// the parser might be needed..
 

(function(){ // private scope, sort of a namespace

	// idCounter is incremented with each instantiation to allow asignment of a unique id for tracking, logging purposes
	var idCounter = 0; 

	dojo.html._secureForInnerHtml = function(/*String*/ cont){
		// summary:
		//		removes !DOCTYPE and title elements from the html string.
		// 
		//		khtml is picky about dom faults, you can't attach a style or <title> node as child of body
		//		must go into head, so we need to cut out those tags
		//	cont:
		//		An html string for insertion into the dom
		//	
		return cont.replace(/(?:\s*<!DOCTYPE\s[^>]+>|<title[^>]*>[\s\S]*?<\/title>)/ig, ""); // String
	};

/*====
	dojo.html._emptyNode = function(node){
		// summary:
		//		removes all child nodes from the given node
		//	node: DOMNode
		//		the parent element
	};
=====*/
	dojo.html._emptyNode = dojo.empty;

	dojo.html._setNodeContent = function(/* DomNode */ node, /* String|DomNode|NodeList */ cont, /* Boolean? */ shouldEmptyFirst){
		// summary:
		//		inserts the given content into the given node
		//		overlaps similiar functionality in dijit.layout.ContentPane._setContent
		//	node:
		//		the parent element
		//	content:
		//		the content to be set on the parent element. 
		//		This can be an html string, a node reference or a NodeList, dojo.NodeList, Array or other enumerable list of nodes
		// shouldEmptyFirst
		//		if shouldEmptyFirst is true, the node will first be emptied of all content before the new content is inserted
		//		defaults to false
		if(shouldEmptyFirst){
			dojo.html._emptyNode(node); 
		}

		if(typeof cont == "string"){
			// there's some hoops to jump through before we can set innerHTML on the would-be parent element. 
	
			// rationale for this block:
			// if node is a table derivate tag, some browsers dont allow innerHTML on those
			// TODO: <select>, <dl>? what other elements will give surprises if you naively set innerHTML?
			
			var pre = '', post = '', walk = 0, name = node.nodeName.toLowerCase();
			switch(name){
				case 'tr':
					pre = '<tr>'; post = '</tr>';
					walk += 1;//fallthrough
				case 'tbody': case 'thead':// children of THEAD is of same type as TBODY
					pre = '<tbody>' + pre; post += '</tbody>';
					walk += 1;// falltrough
				case 'table':
					pre = '<table>' + pre; post += '</table>';
					walk += 1;
					break;
			}
			if(walk){
				var n = node.ownerDocument.createElement('div');
				n.innerHTML = pre + cont + post;
				do{
					n = n.firstChild;
				}while(--walk);
				// now we can safely add the child nodes...
				dojo.forEach(n.childNodes, function(n){
					node.appendChild(n.cloneNode(true));
				});
			}else{
				// innerHTML the content as-is into the node (element)
				// should we ever support setting content on non-element node types? 
				// e.g. text nodes, comments, etc.?
				node.innerHTML = cont;
			}

		}else{
			// DomNode or NodeList
			if(cont.nodeType){ // domNode (htmlNode 1 or textNode 3)
				node.appendChild(cont);
			}else{// nodelist or array such as dojo.Nodelist
				dojo.forEach(cont, function(n){
					node.appendChild(n.cloneNode(true));
				});
			}
		}
		// return DomNode
		return node;
	};

	// we wrap up the content-setting operation in a object
	dojo.declare("dojo.html._ContentSetter", null, 
		{
			// node: DomNode|String
			//		An node which will be the parent element that we set content into
			node: "",

			// content: String|DomNode|DomNode[]
			//		The content to be placed in the node. Can be an HTML string, a node reference, or a enumerable list of nodes
			content: "",
			
			// id: String?
			//		Usually only used internally, and auto-generated with each instance 
			id: "",

			// cleanContent: Boolean
			//		Should the content be treated as a full html document, 
			//		and the real content stripped of <html>, <body> wrapper before injection
			cleanContent: false,
			
			// extractContent: Boolean
			//		Should the content be treated as a full html document, and the real content stripped of <html>, <body> wrapper before injection
			extractContent: false,

			// parseContent: Boolean
			//		Should the node by passed to the parser after the new content is set
			parseContent: false,
			
			// lifecyle methods
			constructor: function(/* Object */params, /* String|DomNode */node){
				//	summary:
				//		Provides a configurable, extensible object to wrap the setting on content on a node
				//		call the set() method to actually set the content..
 
				// the original params are mixed directly into the instance "this"
				dojo.mixin(this, params || {});

				// give precedence to params.node vs. the node argument
				// and ensure its a node, not an id string
				node = this.node = dojo.byId( this.node || node );
	
				if(!this.id){
					this.id = [
						"Setter",
						(node) ? node.id || node.tagName : "", 
						idCounter++
					].join("_");
				}

				if(! (this.node || node)){
					new Error(this.declaredClass + ": no node provided to " + this.id);
				}
			},
			set: function(/* String|DomNode|NodeList? */ cont, /* Object? */ params){
				// summary:
				//		front-end to the set-content sequence 
				//	cont:
				//		An html string, node or enumerable list of nodes for insertion into the dom
				//		If not provided, the object's content property will be used
				if(undefined !== cont){
					this.content = cont;
				}
				// in the re-use scenario, set needs to be able to mixin new configuration
				if(params){
					this._mixin(params);
				}

				this.onBegin();
				this.setContent();
				this.onEnd();

				return this.node;
			},
			setContent: function(){
				// summary:
				//		sets the content on the node 

				var node = this.node; 
				if(!node) {
					console.error("setContent given no node");
				}
				try{
					node = dojo.html._setNodeContent(node, this.content);
				}catch(e){
					// check if a domfault occurs when we are appending this.errorMessage
					// like for instance if domNode is a UL and we try append a DIV
	
					// FIXME: need to allow the user to provide a content error message string
					var errMess = this.onContentError(e); 
					try{
						node.innerHTML = errMess;
					}catch(e){
						console.error('Fatal ' + this.declaredClass + '.setContent could not change content due to '+e.message, e);
					}
				}
				// always put back the node for the next method
				this.node = node; // DomNode
			},
			
			empty: function() {
				// summary
				//	cleanly empty out existing content

				// destroy any widgets from a previous run
				// NOTE: if you dont want this you'll need to empty 
				// the parseResults array property yourself to avoid bad things happenning
				if(this.parseResults && this.parseResults.length) {
					dojo.forEach(this.parseResults, function(w) {
						if(w.destroy){
							w.destroy();
						}
					});
					delete this.parseResults;
				}
				// this is fast, but if you know its already empty or safe, you could 
				// override empty to skip this step
				dojo.html._emptyNode(this.node);
			},
	
			onBegin: function(){
				// summary
				//		Called after instantiation, but before set(); 
				//		It allows modification of any of the object properties 
				//		- including the node and content provided - before the set operation actually takes place
				//		This default implementation checks for cleanContent and extractContent flags to 
				//		optionally pre-process html string content
				var cont = this.content;
	
				if(dojo.isString(cont)){
					if(this.cleanContent){
						cont = dojo.html._secureForInnerHtml(cont);
					}
  
					if(this.extractContent){
						var match = cont.match(/<body[^>]*>\s*([\s\S]+)\s*<\/body>/im);
						if(match){ cont = match[1]; }
					}
				}

				// clean out the node and any cruft associated with it - like widgets
				this.empty();
				
				this.content = cont;
				return this.node; /* DomNode */
			},
	
			onEnd: function(){
				// summary
				//		Called after set(), when the new content has been pushed into the node
				//		It provides an opportunity for post-processing before handing back the node to the caller
				//		This default implementation checks a parseContent flag to optionally run the dojo parser over the new content
				if(this.parseContent){
					// populates this.parseResults if you need those..
					this._parse();
				}
				return this.node; /* DomNode */
			},
	
			tearDown: function(){
				// summary
				//		manually reset the Setter instance if its being re-used for example for another set()
				// description
				//		tearDown() is not called automatically. 
				//		In normal use, the Setter instance properties are simply allowed to fall out of scope
				//		but the tearDown method can be called to explicitly reset this instance.
				delete this.parseResults; 
				delete this.node; 
				delete this.content; 
			},
  
			onContentError: function(err){
				return "Error occured setting content: " + err; 
			},
			
			_mixin: function(params){
				// mix properties/methods into the instance
				// TODO: the intention with tearDown is to put the Setter's state 
				// back to that of the original constructor (vs. deleting/resetting everything regardless of ctor params)
				// so we could do something here to move the original properties aside for later restoration
				var empty = {}, key;
				for(key in params){
					if(key in empty){ continue; }
					// TODO: here's our opportunity to mask the properties we dont consider configurable/overridable
					// .. but history shows we'll almost always guess wrong
					this[key] = params[key]; 
				}
			},
			_parse: function(){
				// summary: 
				//		runs the dojo parser over the node contents, storing any results in this.parseResults
				//		Any errors resulting from parsing are passed to _onError for handling

				var rootNode = this.node;
				try{
					// store the results (widgets, whatever) for potential retrieval
					this.parseResults = dojo.parser.parse(rootNode, true);
				}catch(e){
					this._onError('Content', e, "Error parsing in _ContentSetter#"+this.id);
				}
			},
  
			_onError: function(type, err, consoleText){
				// summary:
				//		shows user the string that is returned by on[type]Error
				//		overide/implement on[type]Error and return your own string to customize
				var errText = this['on' + type + 'Error'].call(this, err);
				if(consoleText){
					console.error(consoleText, err);
				}else if(errText){ // a empty string won't change current content
					dojo.html._setNodeContent(this.node, errText, true);
				}
			}
	}); // end dojo.declare()

	dojo.html.set = function(/* DomNode */ node, /* String|DomNode|NodeList */ cont, /* Object? */ params){
			// summary:
			//		inserts (replaces) the given content into the given node. dojo.place(cont, node, "only")
			//		may be a better choice for simple HTML insertion.
			// description:
			//		Unless you need to use the params capabilities of this method, you should use
			//		dojo.place(cont, node, "only"). dojo.place() has more robust support for injecting
			//		an HTML string into the DOM, but it only handles inserting an HTML string as DOM
			//		elements, or inserting a DOM node. dojo.place does not handle NodeList insertions
			//		or the other capabilities as defined by the params object for this method.
			//	node:
			//		the parent element that will receive the content
			//	cont:
			//		the content to be set on the parent element. 
			//		This can be an html string, a node reference or a NodeList, dojo.NodeList, Array or other enumerable list of nodes
			//	params: 
			//		Optional flags/properties to configure the content-setting. See dojo.html._ContentSetter
			//	example:
			//		A safe string/node/nodelist content replacement/injection with hooks for extension
			//		Example Usage: 
			//		dojo.html.set(node, "some string"); 
			//		dojo.html.set(node, contentNode, {options}); 
			//		dojo.html.set(node, myNode.childNodes, {options}); 
		if(undefined == cont){
			console.warn("dojo.html.set: no cont argument provided, using empty string");
			cont = "";
		}	
		if(!params){
			// simple and fast
			return dojo.html._setNodeContent(node, cont, true);
		}else{ 
			// more options but slower
			// note the arguments are reversed in order, to match the convention for instantiation via the parser
			var op = new dojo.html._ContentSetter(dojo.mixin( 
					params, 
					{ content: cont, node: node } 
			));
			return op.set();
		}
	};
})();

}

if(!dojo._hasResource["dijit.layout.ContentPane"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.layout.ContentPane"] = true;
dojo.provide("dijit.layout.ContentPane");



	// for dijit.layout.marginBox2contentBox()






dojo.declare(
	"dijit.layout.ContentPane", dijit._Widget,
{
	// summary:
	//		A widget that acts as a container for mixed HTML and widgets, and includes an Ajax interface
	// description:
	//		A widget that can be used as a standalone widget
	//		or as a baseclass for other widgets
	//		Handles replacement of document fragment using either external uri or javascript
	//		generated markup or DOM content, instantiating widgets within that content.
	//		Don't confuse it with an iframe, it only needs/wants document fragments.
	//		It's useful as a child of LayoutContainer, SplitContainer, or TabContainer.
	//		But note that those classes can contain any widget as a child.
	// example:
	//		Some quick samples:
	//		To change the innerHTML use .attr('content', '<b>new content</b>')
	//
	//		Or you can send it a NodeList, .attr('content', dojo.query('div [class=selected]', userSelection))
	//		please note that the nodes in NodeList will copied, not moved
	//
	//		To do a ajax update use .attr('href', url)

	// href: String
	//		The href of the content that displays now.
	//		Set this at construction if you want to load data externally when the
	//		pane is shown.	(Set preload=true to load it immediately.)
	//		Changing href after creation doesn't have any effect; use attr('href', ...);
	href: "",

/*=====
	// content: String || DomNode || NodeList || dijit._Widget
	//		The innerHTML of the ContentPane.
	//		Note that the initialization parameter / argument to attr("content", ...)
	//		can be a String, DomNode, Nodelist, or _Widget.
	content: "",
=====*/

	// extractContent: Boolean
	//		Extract visible content from inside of <body> .... </body>.
	//		I.e., strip <html> and <head> (and it's contents) from the href
	extractContent: false,

	// parseOnLoad: Boolean
	//		Parse content and create the widgets, if any.
	parseOnLoad:	true,

	// preventCache: Boolean
	//		Prevent caching of data from href's by appending a timestamp to the href.
	preventCache:	false,

	// preload: Boolean
	//		Force load of data on initialization even if pane is hidden.
	preload: false,

	// refreshOnShow: Boolean
	//		Refresh (re-download) content when pane goes from hidden to shown
	refreshOnShow: false,

	// loadingMessage: String
	//		Message that shows while downloading
	loadingMessage: "<span class='dijitContentPaneLoading'>${loadingState}</span>", 

	// errorMessage: String
	//		Message that shows if an error occurs
	errorMessage: "<span class='dijitContentPaneError'>${errorState}</span>", 

	// isLoaded: [readonly] Boolean
	//		True if the ContentPane has data in it, either specified
	//		during initialization (via href or inline content), or set
	//		via attr('content', ...) / attr('href', ...)
	//
	//		False if it doesn't have any content, or if ContentPane is
	//		still in the process of downloading href.
	isLoaded: false,

	baseClass: "dijitContentPane",

	// doLayout: Boolean
	//		- false - don't adjust size of children
	//		- true - if there is a single visible child widget, set it's size to
	//				however big the ContentPane is
	doLayout: true,

	// ioArgs: Object
	//		Parameters to pass to xhrGet() request, for example:
	// |	<div dojoType="dijit.layout.ContentPane" href="./bar" ioArgs="{timeout: 500}">
	ioArgs: {},

	// isContainer: [protected] Boolean
	//		Just a flag indicating that this widget will call resize() on
	//		its children.   _LayoutWidget based widgets check for
	//
	//	|		if(!this.getParent || !this.getParent()){
	//
	//		and if getParent() returns false because !parent.isContainer,
	//		then they resize themselves on initialization.
	isContainer: true,

	postMixInProperties: function(){
		this.inherited(arguments);
		var messages = dojo.i18n.getLocalization("dijit", "loading", this.lang);
		this.loadingMessage = dojo.string.substitute(this.loadingMessage, messages);
		this.errorMessage = dojo.string.substitute(this.errorMessage, messages);
		
		// Detect if we were initialized with data
		if(!this.href && this.srcNodeRef && this.srcNodeRef.innerHTML){
			this.isLoaded = true;
		}
	},

	buildRendering: function(){
		// Overrides Widget.buildRendering().
		// Since we have no template we need to set this.containerNode ourselves.
		// For subclasses of ContentPane do have a template, does nothing.
		this.inherited(arguments);
		if(!this.containerNode){
			// make getDescendants() work
			this.containerNode = this.domNode;
		}
	},

	postCreate: function(){
		// remove the title attribute so it doesn't show up when hovering
		// over a node
		this.domNode.title = "";

		if (!dojo.attr(this.domNode,"role")){
			dijit.setWaiRole(this.domNode, "group");
		}

		dojo.addClass(this.domNode, this.baseClass);
	},

	startup: function(){
		// summary:
		//		See `dijit.layout._LayoutWidget.startup` for description.
		//		Although ContentPane doesn't extend _LayoutWidget, it does implement
		//		the same API.
		if(this._started){ return; }

		if(this.isLoaded){
			dojo.forEach(this.getChildren(), function(child){
				child.startup();
			});

			// If we have static content in the content pane (specified during
			// initialization) then we need to do layout now... unless we are
			// a child of a TabContainer etc. in which case wait until the TabContainer
			// calls resize() on us.
			if(this.doLayout){
				this._checkIfSingleChild();
			}
			if(!this._singleChild || !dijit._Contained.prototype.getParent.call(this)){
				this._scheduleLayout();
			}
		}
		
		// If we have an href then check if we should load it now
		this._loadCheck();

		this.inherited(arguments);
	},

	_checkIfSingleChild: function(){
		// summary:
		//		Test if we have exactly one visible widget as a child,
		//		and if so assume that we are a container for that widget,
		//		and should propogate startup() and resize() calls to it.
		//		Skips over things like data stores since they aren't visible.

		var childNodes = dojo.query(">", this.containerNode),
			childWidgetNodes = childNodes.filter(function(node){
				return dojo.hasAttr(node, "dojoType") || dojo.hasAttr(node, "widgetId");
			}),
			candidateWidgets = dojo.filter(childWidgetNodes.map(dijit.byNode), function(widget){
				return widget && widget.domNode && widget.resize;
			});

		if(
			// all child nodes are widgets
			childNodes.length == childWidgetNodes.length &&

			// all but one are invisible (like dojo.data)
			candidateWidgets.length == 1
		){
			this._singleChild = candidateWidgets[0];
		}else{
			delete this._singleChild;
		}
	},

	setHref: function(/*String|Uri*/ href){
		// summary:
		//		Deprecated.   Use attr('href', ...) instead.
		dojo.deprecated("dijit.layout.ContentPane.setHref() is deprecated. Use attr('href', ...) instead.", "", "2.0");
		return this.attr("href", href);
	},
	_setHrefAttr: function(/*String|Uri*/ href){
		// summary:
		//		Hook so attr("href", ...) works.
		// description:
		//		Reset the (external defined) content of this pane and replace with new url
		//		Note: It delays the download until widget is shown if preload is false.
		//	href:
		//		url to the page you want to get, must be within the same domain as your mainpage

		// Cancel any in-flight requests (an attr('href') will cancel any in-flight attr('href', ...))
		this.cancel();

		this.href = href;

		// _setHrefAttr() is called during creation and by the user, after creation.
		// only in the second case do we actually load the URL; otherwise it's done in startup()
		if(this._created && (this.preload || this._isShown())){
			// we return result of refresh() here to avoid code dup. in dojox.layout.ContentPane
			return this.refresh();
		}else{
			// Set flag to indicate that href needs to be loaded the next time the
			// ContentPane is made visible
			this._hrefChanged = true;
		}
	},

	setContent: function(/*String|DomNode|Nodelist*/data){
		// summary:
		//		Deprecated.   Use attr('content', ...) instead.
		dojo.deprecated("dijit.layout.ContentPane.setContent() is deprecated.  Use attr('content', ...) instead.", "", "2.0");
		this.attr("content", data);
	},
	_setContentAttr: function(/*String|DomNode|Nodelist*/data){
		// summary:
		//		Hook to make attr("content", ...) work.
		//		Replaces old content with data content, include style classes from old content
		//	data:
		//		the new Content may be String, DomNode or NodeList
		//
		//		if data is a NodeList (or an array of nodes) nodes are copied
		//		so you can import nodes from another document implicitly

		// clear href so we can't run refresh and clear content
		// refresh should only work if we downloaded the content
		this.href = "";

		// Cancel any in-flight requests (an attr('content') will cancel any in-flight attr('href', ...))
		this.cancel();

		this._setContent(data || "");

		this._isDownloaded = false; // mark that content is from a attr('content') not an attr('href')
	},
	_getContentAttr: function(){
		// summary:
		//		Hook to make attr("content") work
		return this.containerNode.innerHTML;
	},

	cancel: function(){
		// summary:
		//		Cancels an in-flight download of content
		if(this._xhrDfd && (this._xhrDfd.fired == -1)){
			this._xhrDfd.cancel();
		}
		delete this._xhrDfd; // garbage collect
	},

	uninitialize: function(){
		if(this._beingDestroyed){
			this.cancel();
		}
	},

	destroyRecursive: function(/*Boolean*/ preserveDom){
		// summary:
		//		Destroy the ContentPane and its contents

		// if we have multiple controllers destroying us, bail after the first
		if(this._beingDestroyed){
			return;
		}
		this._beingDestroyed = true;
		this.inherited(arguments);
	},

	resize: function(size){
		// summary:
		//		See `dijit.layout._LayoutWidget.resize` for description.
		//		Although ContentPane doesn't extend _LayoutWidget, it does implement
		//		the same API.

		dojo.marginBox(this.domNode, size);

		// Compute content box size in case we [later] need to size child
		// If either height or width wasn't specified by the user, then query node for it.
		// But note that setting the margin box and then immediately querying dimensions may return
		// inaccurate results, so try not to depend on it.
		var node = this.containerNode,
			mb = dojo.mixin(dojo.marginBox(node), size||{});

		var cb = (this._contentBox = dijit.layout.marginBox2contentBox(node, mb));

		// If we have a single widget child then size it to fit snugly within my borders
		if(this._singleChild && this._singleChild.resize){
			// note: if widget has padding this._contentBox will have l and t set,
			// but don't pass them to resize() or it will doubly-offset the child
			this._singleChild.resize({w: cb.w, h: cb.h});
		}
	},

	_isShown: function(){
		// summary:
		//		Returns true if the content is currently shown
		if("open" in this){
			return this.open;		// for TitlePane, etc.
		}else{
			var node = this.domNode;
			return (node.style.display != 'none')  && (node.style.visibility != 'hidden') && !dojo.hasClass(node, "dijitHidden");
		}
	},

	_onShow: function(){
		// summary:
		//		Called when the ContentPane is made visible
		// description:
		//		For a plain ContentPane, this is called on initialization, from startup().
		//		If the ContentPane is a hidden pane of a TabContainer etc., then it's
		//		called whever the pane is made visible.
		//
		//		Does processing necessary, including href download and layout/resize of
		//		child widget(s)

		if(this._needLayout){
			// If a layout has been scheduled for when we become visible, do it now
			this._layoutChildren();
		}

		// Do lazy-load of URL
		this._loadCheck();

		// call onShow, if we have one
		if(this.onShow){
			this.onShow();
		}
	},

	_loadCheck: function(){
		// summary:
		//		Call this to load href contents if necessary.
		// description:
		//		Call when !ContentPane has been made visible [from prior hidden state],
		//		or href has been changed, or on startup, etc.

		if(
			(this.href && !this._xhrDfd) &&		// if there's an href that isn't already being loaded
			(!this.isLoaded || this._hrefChanged || this.refreshOnShow) && 	// and we need a [re]load
			(this.preload || this._isShown())	// and now is the time to [re]load
		){
			delete this._hrefChanged;
			this.refresh();
		}
	},

	refresh: function(){
		// summary:
		//		[Re]download contents of href and display
		// description:
		//		1. cancels any currently in-flight requests
		//		2. posts "loading..." message
		//		3. sends XHR to download new data

		// cancel possible prior inflight request
		this.cancel();

		// display loading message
		this._setContent(this.onDownloadStart(), true);

		var self = this;
		var getArgs = {
			preventCache: (this.preventCache || this.refreshOnShow),
			url: this.href,
			handleAs: "text"
		};
		if(dojo.isObject(this.ioArgs)){
			dojo.mixin(getArgs, this.ioArgs);
		}

		var hand = (this._xhrDfd = (this.ioMethod || dojo.xhrGet)(getArgs));

		hand.addCallback(function(html){
			try{
				self._isDownloaded = true;
				self._setContent(html, false);
				self.onDownloadEnd();
			}catch(err){
				self._onError('Content', err); // onContentError
			}
			delete self._xhrDfd;
			return html;
		});

		hand.addErrback(function(err){
			if(!hand.canceled){
				// show error message in the pane
				self._onError('Download', err); // onDownloadError
			}
			delete self._xhrDfd;
			return err;
		});
	},

	_onLoadHandler: function(data){
		// summary:
		//		This is called whenever new content is being loaded
		this.isLoaded = true;
		try{
			this.onLoad(data);			
		}catch(e){
			console.error('Error '+this.widgetId+' running custom onLoad code: ' + e.message);
		}
	},

	_onUnloadHandler: function(){
		// summary:
		//		This is called whenever the content is being unloaded
		this.isLoaded = false;
		try{
			this.onUnload();
		}catch(e){
			console.error('Error '+this.widgetId+' running custom onUnload code: ' + e.message);
		}
	},

	destroyDescendants: function(){
		// summary:
		//		Destroy all the widgets inside the ContentPane and empty containerNode

		// Make sure we call onUnload (but only when the ContentPane has real content)
		if(this.isLoaded){
			this._onUnloadHandler();
		}

		// Even if this.isLoaded == false there might still be a "Loading..." message
		// to erase, so continue...

		// For historical reasons we need to delete all widgets under this.containerNode,
		// even ones that the user has created manually.
		var setter = this._contentSetter;
		dojo.forEach(this.getChildren(), function(widget){
			if(widget.destroyRecursive){
				widget.destroyRecursive();
			}
		});
		if(setter){
			// Most of the widgets in setter.parseResults have already been destroyed, but
			// things like Menu that have been moved to <body> haven't yet
			dojo.forEach(setter.parseResults, function(widget){
				if(widget.destroyRecursive && widget.domNode && widget.domNode.parentNode == dojo.body()){
					widget.destroyRecursive();
				}
			});
			delete setter.parseResults;
		}
		
		// And then clear away all the DOM nodes
		dojo.html._emptyNode(this.containerNode);
	},

	_setContent: function(cont, isFakeContent){
		// summary: 
		//		Insert the content into the container node

		// first get rid of child widgets
		this.destroyDescendants();

		// Delete any state information we have about current contents
		delete this._singleChild;

		// dojo.html.set will take care of the rest of the details
		// we provide an overide for the error handling to ensure the widget gets the errors 
		// configure the setter instance with only the relevant widget instance properties
		// NOTE: unless we hook into attr, or provide property setters for each property, 
		// we need to re-configure the ContentSetter with each use
		var setter = this._contentSetter; 
		if(! (setter && setter instanceof dojo.html._ContentSetter)) {
			setter = this._contentSetter = new dojo.html._ContentSetter({
				node: this.containerNode,
				_onError: dojo.hitch(this, this._onError),
				onContentError: dojo.hitch(this, function(e){
					// fires if a domfault occurs when we are appending this.errorMessage
					// like for instance if domNode is a UL and we try append a DIV
					var errMess = this.onContentError(e);
					try{
						this.containerNode.innerHTML = errMess;
					}catch(e){
						console.error('Fatal '+this.id+' could not change content due to '+e.message, e);
					}
				})/*,
				_onError */
			});
		};

		var setterParams = dojo.mixin({
			cleanContent: this.cleanContent, 
			extractContent: this.extractContent, 
			parseContent: this.parseOnLoad 
		}, this._contentSetterParams || {});
		
		dojo.mixin(setter, setterParams); 

		setter.set( (dojo.isObject(cont) && cont.domNode) ? cont.domNode : cont );

		// setter params must be pulled afresh from the ContentPane each time
		delete this._contentSetterParams;

		if(!isFakeContent){
			dojo.forEach(this.getChildren(), function(child){
				child.startup();
			});

			if(this.doLayout){
				this._checkIfSingleChild();
			}

			// Call resize() on each of my child layout widgets,
			// or resize() on my single child layout widget...
			// either now (if I'm currently visible)
			// or when I become visible
			this._scheduleLayout();
			
			this._onLoadHandler(cont);
		}
	},

	_onError: function(type, err, consoleText){
		// shows user the string that is returned by on[type]Error
		// overide on[type]Error and return your own string to customize
		var errText = this['on' + type + 'Error'].call(this, err);
		if(consoleText){
			console.error(consoleText, err);
		}else if(errText){// a empty string won't change current content
			this._setContent(errText, true);
		}
	},
	
	_scheduleLayout: function(){
		// summary:
		//		Call resize() on each of my child layout widgets, either now
		//		(if I'm currently visible) or when I become visible
		if(this._isShown()){
			this._layoutChildren();
		}else{
			this._needLayout = true;
		}
	},

	_layoutChildren: function(){
		// summary:
		//		Since I am a Container widget, each of my children expects me to
		//		call resize() or layout() on them.
		// description:
		//		Should be called on initialization and also whenever we get new content
		//		(from an href, or from attr('content', ...))... but deferred until
		//		the ContentPane is visible

		if(this._singleChild && this._singleChild.resize){
			var cb = this._contentBox || dojo.contentBox(this.containerNode);
			this._singleChild.resize({w: cb.w, h: cb.h});
		}else{
			// All my child widgets are independently sized (rather than matching my size),
			// but I still need to call resize() on each child to make it layout.
			dojo.forEach(this.getChildren(), function(widget){
				if(widget.resize){
					widget.resize();
				}
			});
		}
		delete this._needLayout;
	},

	// EVENT's, should be overide-able
	onLoad: function(data){
		// summary:
		//		Event hook, is called after everything is loaded and widgetified
		// tags:
		//		callback
	},

	onUnload: function(){
		// summary:
		//		Event hook, is called before old content is cleared
		// tags:
		//		callback
	},

	onDownloadStart: function(){
		// summary:
		//		Called before download starts.
		// description:
		//		The string returned by this function will be the html
		//		that tells the user we are loading something.
		//		Override with your own function if you want to change text.
		// tags:
		//		extension
		return this.loadingMessage;
	},

	onContentError: function(/*Error*/ error){
		// summary:
		//		Called on DOM faults, require faults etc. in content.
		//
		//		In order to display an error message in the pane, return
		//		the error message from this method, as an HTML string.
		//
		//		By default (if this method is not overriden), it returns
		//		nothing, so the error message is just printed to the console.
		// tags:
		//		extension
	},

	onDownloadError: function(/*Error*/ error){
		// summary:
		//		Called when download error occurs.
		//
		//		In order to display an error message in the pane, return
		//		the error message from this method, as an HTML string.
		//
		//		Default behavior (if this method is not overriden) is to display
		//		the error message inside the pane.
		// tags:
		//		extension
		return this.errorMessage;
	},

	onDownloadEnd: function(){
		// summary:
		//		Called when download is finished.
		// tags:
		//		callback
	}
});

}

if(!dojo._hasResource["dijit.form._FormMixin"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.form._FormMixin"] = true;
dojo.provide("dijit.form._FormMixin");

dojo.declare("dijit.form._FormMixin", null,
	{
	// summary:
	//		Mixin for containers of form widgets (i.e. widgets that represent a single value
	//		and can be children of a <form> node or dijit.form.Form widget)
	// description:
	//		Can extract all the form widgets
	//		values and combine them into a single javascript object, or alternately
	//		take such an object and set the values for all the contained
	//		form widgets

/*=====
    // value: Object
	//		Name/value hash for each form element.
	//		If there are multiple elements w/the same name, value is an array,
	//		unless they are radio buttons in which case value is a scalar since only
	//		one can be checked at a time.
	//
	//		If the name is a dot separated list (like a.b.c.d), it's a nested structure.
	//		Only works on widget form elements.
	// example:
	//	| { name: "John Smith", interests: ["sports", "movies"] }
=====*/
	
	//	TODO:
	//	* Repeater
	//	* better handling for arrays.  Often form elements have names with [] like
	//	* people[3].sex (for a list of people [{name: Bill, sex: M}, ...])
	//
	//	

		reset: function(){
			dojo.forEach(this.getDescendants(), function(widget){
				if(widget.reset){
					widget.reset();
				}
			});
		},

		validate: function(){
			// summary: returns if the form is valid - same as isValid - but
			//			provides a few additional (ui-specific) features.
			//			1 - it will highlight any sub-widgets that are not
			//				valid
			//			2 - it will call focus() on the first invalid 
			//				sub-widget
			var didFocus = false;
			return dojo.every(dojo.map(this.getDescendants(), function(widget){
				// Need to set this so that "required" widgets get their 
				// state set.
				widget._hasBeenBlurred = true;
				var valid = widget.disabled || !widget.validate || widget.validate();
				if (!valid && !didFocus) {
					// Set focus of the first non-valid widget
					dijit.scrollIntoView(widget.containerNode||widget.domNode);
					widget.focus();
					didFocus = true;
				}
	 			return valid;
	 		}), function(item) { return item; });
		},
	
		setValues: function(val){
			dojo.deprecated(this.declaredClass+"::setValues() is deprecated. Use attr('value', val) instead.", "", "2.0");
			return this.attr('value', val);
		},
		_setValueAttr: function(/*object*/obj){
			// summary: Fill in form values from according to an Object (in the format returned by attr('value'))

			// generate map from name --> [list of widgets with that name]
			var map = { };
			dojo.forEach(this.getDescendants(), function(widget){
				if(!widget.name){ return; }
				var entry = map[widget.name] || (map[widget.name] = [] );
				entry.push(widget);
			});

			for(var name in map){
				if(!map.hasOwnProperty(name)){
					continue;
				}
				var widgets = map[name],						// array of widgets w/this name
					values = dojo.getObject(name, false, obj);	// list of values for those widgets

				if(values===undefined){
					continue;
				}
				if(!dojo.isArray(values)){
					values = [ values ];
				}
				if(typeof widgets[0].checked == 'boolean'){
					// for checkbox/radio, values is a list of which widgets should be checked
					dojo.forEach(widgets, function(w, i){
						w.attr('value', dojo.indexOf(values, w.value) != -1);
					});
				}else if(widgets[0]._multiValue){
					// it takes an array (e.g. multi-select)
					widgets[0].attr('value', values);
				}else{
					// otherwise, values is a list of values to be assigned sequentially to each widget
					dojo.forEach(widgets, function(w, i){
						w.attr('value', values[i]);
					});					
				}
			}

			/***
			 * 	TODO: code for plain input boxes (this shouldn't run for inputs that are part of widgets)

			dojo.forEach(this.containerNode.elements, function(element){
				if (element.name == ''){return};	// like "continue"	
				var namePath = element.name.split(".");
				var myObj=obj;
				var name=namePath[namePath.length-1];
				for(var j=1,len2=namePath.length;j<len2;++j){
					var p=namePath[j - 1];
					// repeater support block
					var nameA=p.split("[");
					if (nameA.length > 1){
						if(typeof(myObj[nameA[0]]) == "undefined"){
							myObj[nameA[0]]=[ ];
						} // if

						nameIndex=parseInt(nameA[1]);
						if(typeof(myObj[nameA[0]][nameIndex]) == "undefined"){
							myObj[nameA[0]][nameIndex] = { };
						}
						myObj=myObj[nameA[0]][nameIndex];
						continue;
					} // repeater support ends

					if(typeof(myObj[p]) == "undefined"){
						myObj=undefined;
						break;
					};
					myObj=myObj[p];
				}

				if (typeof(myObj) == "undefined"){
					return;		// like "continue"
				}
				if (typeof(myObj[name]) == "undefined" && this.ignoreNullValues){
					return;		// like "continue"
				}

				// TODO: widget values (just call attr('value', ...) on the widget)

				switch(element.type){
					case "checkbox":
						element.checked = (name in myObj) &&
							dojo.some(myObj[name], function(val){ return val==element.value; });
						break;
					case "radio":
						element.checked = (name in myObj) && myObj[name]==element.value;
						break;
					case "select-multiple":
						element.selectedIndex=-1;
						dojo.forEach(element.options, function(option){
							option.selected = dojo.some(myObj[name], function(val){ return option.value == val; });
						});
						break;
					case "select-one":
						element.selectedIndex="0";
						dojo.forEach(element.options, function(option){
							option.selected = option.value == myObj[name];
						});
						break;
					case "hidden":
					case "text":
					case "textarea":
					case "password":
						element.value = myObj[name] || "";
						break;
				}
	  		});
	  		*/
		},

		getValues: function(){
			dojo.deprecated(this.declaredClass+"::getValues() is deprecated. Use attr('value') instead.", "", "2.0");
			return this.attr('value');
		},
		_getValueAttr: function(){
			// summary:
			// 		Returns Object representing form values.
			// description:
			//		Returns name/value hash for each form element.
			//		If there are multiple elements w/the same name, value is an array,
			//		unless they are radio buttons in which case value is a scalar since only
			//		one can be checked at a time.
			//
			//		If the name is a dot separated list (like a.b.c.d), creates a nested structure.
			//		Only works on widget form elements.
			// example:
			//		| { name: "John Smith", interests: ["sports", "movies"] }

			// get widget values
			var obj = { };
			dojo.forEach(this.getDescendants(), function(widget){
				var name = widget.name;
				if(!name||widget.disabled){ return; }

				// Single value widget (checkbox, radio, or plain <input> type widget
				var value = widget.attr('value');

				// Store widget's value(s) as a scalar, except for checkboxes which are automatically arrays
				if(typeof widget.checked == 'boolean'){
					if(/Radio/.test(widget.declaredClass)){
						// radio button
						if(value !== false){
							dojo.setObject(name, value, obj);
						}else{
							// give radio widgets a default of null
							value = dojo.getObject(name, false, obj);
							if(value === undefined){
								dojo.setObject(name, null, obj);
							}
						}
					}else{
						// checkbox/toggle button
						var ary=dojo.getObject(name, false, obj);
						if(!ary){
							ary=[];
							dojo.setObject(name, ary, obj);
						}
						if(value !== false){
							ary.push(value);
						}
					}
				}else{
					// plain input
					dojo.setObject(name, value, obj);
				}
			});

			/***
			 * code for plain input boxes (see also dojo.formToObject, can we use that instead of this code?
			 * but it doesn't understand [] notation, presumably)
			var obj = { };
			dojo.forEach(this.containerNode.elements, function(elm){
				if (!elm.name)	{
					return;		// like "continue"
				}
				var namePath = elm.name.split(".");
				var myObj=obj;
				var name=namePath[namePath.length-1];
				for(var j=1,len2=namePath.length;j<len2;++j){
					var nameIndex = null;
					var p=namePath[j - 1];
					var nameA=p.split("[");
					if (nameA.length > 1){
						if(typeof(myObj[nameA[0]]) == "undefined"){
							myObj[nameA[0]]=[ ];
						} // if
						nameIndex=parseInt(nameA[1]);
						if(typeof(myObj[nameA[0]][nameIndex]) == "undefined"){
							myObj[nameA[0]][nameIndex] = { };
						}
					} else if(typeof(myObj[nameA[0]]) == "undefined"){
						myObj[nameA[0]] = { }
					} // if

					if (nameA.length == 1){
						myObj=myObj[nameA[0]];
					} else{
						myObj=myObj[nameA[0]][nameIndex];
					} // if
				} // for

				if ((elm.type != "select-multiple" && elm.type != "checkbox" && elm.type != "radio") || (elm.type=="radio" && elm.checked)){
					if(name == name.split("[")[0]){
						myObj[name]=elm.value;
					} else{
						// can not set value when there is no name
					}
				} else if (elm.type == "checkbox" && elm.checked){
					if(typeof(myObj[name]) == 'undefined'){
						myObj[name]=[ ];
					}
					myObj[name].push(elm.value);
				} else if (elm.type == "select-multiple"){
					if(typeof(myObj[name]) == 'undefined'){
						myObj[name]=[ ];
					}
					for (var jdx=0,len3=elm.options.length; jdx<len3; ++jdx){
						if (elm.options[jdx].selected){
							myObj[name].push(elm.options[jdx].value);
						}
					}
				} // if
				name=undefined;
			}); // forEach
			***/
			return obj;
		},

		// TODO: ComboBox might need time to process a recently input value.  This should be async?
	 	isValid: function(){
	 		// summary:
	 		//		Returns true if all of the widgets are valid
	 		
	 		// This also populate this._invalidWidgets[] array with list of invalid widgets...
	 		// TODO: put that into separate function?   It's confusing to have that as a side effect
	 		// of a method named isValid().

			this._invalidWidgets = dojo.filter(this.getDescendants(), function(widget){
				return !widget.disabled && widget.isValid && !widget.isValid();
	 		});
			return !this._invalidWidgets.length;
		},
		
		
		onValidStateChange: function(isValid){
			// summary:
			//		Stub function to connect to if you want to do something
			//		(like disable/enable a submit button) when the valid 
			//		state changes on the form as a whole.
		},
		
		_widgetChange: function(widget){
			// summary:
			//		Connected to a widget's onChange function - update our 
			//		valid state, if needed.
			var isValid = this._lastValidState;
			if(!widget || this._lastValidState===undefined){
				// We have passed a null widget, or we haven't been validated
				// yet - let's re-check all our children
				// This happens when we connect (or reconnect) our children
				isValid = this.isValid();
				if(this._lastValidState===undefined){
					// Set this so that we don't fire an onValidStateChange 
					// the first time
					this._lastValidState = isValid;
				}
			}else if(widget.isValid){
				this._invalidWidgets = dojo.filter(this._invalidWidgets||[], function(w){
					return (w != widget);
				}, this);
				if(!widget.isValid() && !widget.attr("disabled")){
					this._invalidWidgets.push(widget);
				}
				isValid = (this._invalidWidgets.length === 0);
			}
			if (isValid !== this._lastValidState){
				this._lastValidState = isValid;
				this.onValidStateChange(isValid);
			}
		},
		
		connectChildren: function(){
			// summary:
			//		Connects to the onChange function of all children to
			//		track valid state changes.  You can call this function
			//		directly, ex. in the event that you programmatically
			//		add a widget to the form *after* the form has been
			//		initialized.
			dojo.forEach(this._changeConnections, dojo.hitch(this, "disconnect"));
			var _this = this;
			
			// we connect to validate - so that it better reflects the states
			// of the widgets - also, we only connect if it has a validate
			// function (to avoid too many unneeded connections)
			var conns = this._changeConnections = [];
			dojo.forEach(dojo.filter(this.getDescendants(),
				function(item){ return item.validate; }
			),
			function(widget){
				// We are interested in whenever the widget is validated - or
				// whenever the disabled attribute on that widget is changed
				conns.push(_this.connect(widget, "validate", 
									dojo.hitch(_this, "_widgetChange", widget)));
				conns.push(_this.connect(widget, "_setDisabledAttr", 
									dojo.hitch(_this, "_widgetChange", widget)));
			});

			// Call the widget change function to update the valid state, in 
			// case something is different now.
			this._widgetChange(null);
		},
		
		startup: function(){
			this.inherited(arguments);
			// Initialize our valid state tracking.  Needs to be done in startup
			// because it's not guaranteed that our children are initialized 
			// yet.
			this._changeConnections = [];
			this.connectChildren();
		}
	});

}

if(!dojo._hasResource["dijit.form.Form"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.form.Form"] = true;
dojo.provide("dijit.form.Form");





dojo.declare(
	"dijit.form.Form",
	[dijit._Widget, dijit._Templated, dijit.form._FormMixin],
	{
		// summary:
		//		Widget corresponding to HTML form tag, for validation and serialization
		//
		// example:
		//	|	<form dojoType="dijit.form.Form" id="myForm">
		//	|		Name: <input type="text" name="name" />
		//	|	</form>
		//	|	myObj = {name: "John Doe"};
		//	|	dijit.byId('myForm').attr('value', myObj);
		//	|
		//	|	myObj=dijit.byId('myForm').attr('value');

		// HTML <FORM> attributes

		// name: String?
		//		Name of form for scripting.
		name: "",

		// action: String?
		//		Server-side form handler.
		action: "",

		// method: String?
		//		HTTP method used to submit the form, either "GET" or "POST".
		method: "",

		// encType: String?
		//		Encoding type for the form, ex: application/x-www-form-urlencoded.
		encType: "",

		// accept-charset: String?
		//		List of supported charsets.
		"accept-charset": "",

		// accept: String?
		//		List of MIME types for file upload.
		accept: "",

		// target: String?
		//		Target frame for the document to be opened in.
		target: "",

		templateString: "<form dojoAttachPoint='containerNode' dojoAttachEvent='onreset:_onReset,onsubmit:_onSubmit' ${nameAttrSetting}></form>",

		attributeMap: dojo.delegate(dijit._Widget.prototype.attributeMap, {
			action: "", 
			method: "", 
			encType: "", 
			"accept-charset": "", 
			accept: "", 
			target: ""
		}),

		postMixInProperties: function(){
			// Setup name=foo string to be referenced from the template (but only if a name has been specified)
			// Unfortunately we can't use attributeMap to set the name due to IE limitations, see #8660
			this.nameAttrSetting = this.name ? ("name='" + this.name + "'") : "";
			this.inherited(arguments);
		},

		execute: function(/*Object*/ formContents){
			// summary:
			//		Deprecated: use submit()
			// tags:
			//		deprecated
		},

		onExecute: function(){
			// summary:
			//		Deprecated: use onSubmit()
			// tags:
			//		deprecated
		},

		_setEncTypeAttr: function(/*String*/ value){
			this.encType = value;
			dojo.attr(this.domNode, "encType", value);
			if(dojo.isIE){ this.domNode.encoding = value; }
		},

		postCreate: function(){
			// IE tries to hide encType
			// TODO: this code should be in parser, not here.
			if(dojo.isIE && this.srcNodeRef && this.srcNodeRef.attributes){
				var item = this.srcNodeRef.attributes.getNamedItem('encType');
				if(item && !item.specified && (typeof item.value == "string")){
					this.attr('encType', item.value);
				}
			}
			this.inherited(arguments);
		},

		onReset: function(/*Event?*/ e){
			// summary:
			//		Callback when user resets the form. This method is intended
			//		to be over-ridden. When the `reset` method is called
			//		programmatically, the return value from `onReset` is used
			//		to compute whether or not resetting should proceed
			// tags:
			//		callback
			return true; // Boolean
		},

		_onReset: function(e){
			// create fake event so we can know if preventDefault() is called
			var faux = {
				returnValue: true, // the IE way
				preventDefault: function(){  // not IE
							this.returnValue = false;
						},
				stopPropagation: function(){}, currentTarget: e.currentTarget, target: e.target
			};
			// if return value is not exactly false, and haven't called preventDefault(), then reset
			if(!(this.onReset(faux) === false) && faux.returnValue){
				this.reset();
			}
			dojo.stopEvent(e);
			return false;
		},

		_onSubmit: function(e){
			var fp = dijit.form.Form.prototype;
			// TODO: remove this if statement beginning with 2.0
			if(this.execute != fp.execute || this.onExecute != fp.onExecute){
				dojo.deprecated("dijit.form.Form:execute()/onExecute() are deprecated. Use onSubmit() instead.", "", "2.0");
				this.onExecute();
				this.execute(this.getValues());
			}
			if(this.onSubmit(e) === false){ // only exactly false stops submit
				dojo.stopEvent(e);
			}
		},
		
		onSubmit: function(/*Event?*/e){ 
			// summary:
			//		Callback when user submits the form.
			// description:
			//		This method is intended to be over-ridden, but by default it checks and
			//		returns the validity of form elements. When the `submit`
			//		method is called programmatically, the return value from
			//		`onSubmit` is used to compute whether or not submission
			//		should proceed
			// tags:
			//		extension

			return this.isValid(); // Boolean
		},

		submit: function(){
			// summary:
			//		programmatically submit form if and only if the `onSubmit` returns true
			if(!(this.onSubmit() === false)){
				this.containerNode.submit();
			}
		}
	}
);

}

if(!dojo._hasResource["dijit.form.CheckBox"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.form.CheckBox"] = true;
dojo.provide("dijit.form.CheckBox");



dojo.declare(
	"dijit.form.CheckBox",
	dijit.form.ToggleButton,
	{
		// summary:
		// 		Same as an HTML checkbox, but with fancy styling.
		//
		// description:
		// User interacts with real html inputs.
		// On onclick (which occurs by mouse click, space-bar, or
		// using the arrow keys to switch the selected radio button),
		// we update the state of the checkbox/radio.
		//
		// There are two modes:
		//   1. High contrast mode
		//   2. Normal mode
		// In case 1, the regular html inputs are shown and used by the user.
		// In case 2, the regular html inputs are invisible but still used by
		// the user. They are turned quasi-invisible and overlay the background-image.

		templateString:"<div class=\"dijitReset dijitInline\" waiRole=\"presentation\"\n\t><input\n\t \t${nameAttrSetting} type=\"${type}\" ${checkedAttrSetting}\n\t\tclass=\"dijitReset dijitCheckBoxInput\"\n\t\tdojoAttachPoint=\"focusNode\"\n\t \tdojoAttachEvent=\"onmouseover:_onMouse,onmouseout:_onMouse,onclick:_onClick\"\n/></div>\n",

		baseClass: "dijitCheckBox",

		// type: [private] String
		//		type attribute on <input> node.
		//		Overrides `dijit.form.Button.type`.   Users should not change this value.
		type: "checkbox",

		// value: String
		//		As an initialization parameter, equivalent to value field on normal checkbox
		//		(if checked, the value is passed as the value when form is submitted).
		//
		//		However, attr('value') will return either the string or false depending on
		//		whether or not the checkbox is checked.
		//
		//		attr('value', string) will check the checkbox and change the value to the
		//		specified string
		//
		//		attr('value', boolean) will change the checked state.
		value: "on",

		_setValueAttr: function(/*String or Boolean*/ newValue){
			// summary:
			//		Handler for value= attribute to constructor, and also calls to
			//		attr('value', val).
			// description:
			//		During initialization, just saves as attribute to the <input type=checkbox>.
			//		
			//		After initialization,
			//		when passed a boolean, controls whether or not the CheckBox is checked.
			//		If passed a string, changes the value attribute of the CheckBox (the one
			//		specified as "value" when the CheckBox was constructed (ex: <input
			//		dojoType="dijit.CheckBox" value="chicken">)
			if(typeof newValue == "string"){
				this.value = newValue;
				dojo.attr(this.focusNode, 'value', newValue);
				newValue = true;
			}
			if(this._created){
				this.attr('checked', newValue);
			}
		},
		_getValueAttr: function(){
			// summary:
			//		Hook so attr('value') works.
			// description:
			//		If the CheckBox is checked, returns the value attribute.
			//		Otherwise returns false.
			return (this.checked ? this.value : false);
		},

		postMixInProperties: function(){
			if(this.value == ""){
				this.value = "on";
			}

			// Need to set initial checked state as part of template, so that form submit works.
			// dojo.attr(node, "checked", bool) doesn't work on IEuntil node has been attached
			// to <body>, see #8666
			this.checkedAttrSetting = this.checked ? "checked" : "";

			this.inherited(arguments);
		},
		
		 _fillContent: function(/*DomNode*/ source){
			// Override Button::_fillContent() since it doesn't make sense for CheckBox,
			// since CheckBox doesn't even have a container
		},

		reset: function(){
			// Override ToggleButton.reset()

			this._hasBeenBlurred = false;

			this.attr('checked', this.params.checked || false);

			// Handle unlikely event that the <input type=checkbox> value attribute has changed
			this.value = this.params.value || "on";
			dojo.attr(this.focusNode, 'value', this.value);
		},
		
		_onFocus: function(){
			if(this.id){
				dojo.query("label[for='"+this.id+"']").addClass("dijitFocusedLabel");
			}
		},

		_onBlur: function(){
			if(this.id){
				dojo.query("label[for='"+this.id+"']").removeClass("dijitFocusedLabel");
			}
		}
	}
);

dojo.declare(
	"dijit.form.RadioButton",
	dijit.form.CheckBox,
	{
		// summary:
		// 		Same as an HTML radio, but with fancy styling.

		type: "radio",
		baseClass: "dijitRadio",

		_setCheckedAttr: function(/*Boolean*/ value){
			// If I am being checked then have to deselect currently checked radio button
			this.inherited(arguments);
			if(!this._created){ return; }
			if(value){
				var _this = this;
				// search for radio buttons with the same name that need to be unchecked
				dojo.query("INPUT[type=radio]", this.focusNode.form||dojo.doc).forEach( // can't use name= since dojo.query doesn't support [] in the name
					function(inputNode){
						if(inputNode.name == _this.name && inputNode != _this.focusNode && inputNode.form == _this.focusNode.form){
							var widget = dijit.getEnclosingWidget(inputNode);
							if(widget && widget.checked){
								widget.attr('checked', false);
							}
						}
					}
				);
			}
		},

		_clicked: function(/*Event*/ e){
			if(!this.checked){
				this.attr('checked', true);
			}
		}
	}
);

}

if(!dojo._hasResource["com.ibm.widgets.InlineEditorWrapper"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.widgets.InlineEditorWrapper"] = true;
dojo.provide("com.ibm.widgets.InlineEditorWrapper");






// mix this into any other widget to get wrapped inline editor support with an optional popup
// advanced editor
dojo.declare("com.ibm.widgets.InlineEditorWrapper",
			null,
			{
				embeddedEditorWidget: "dijit.form.TextBox",
				embeddedEditorParams: {},
				
				popupWidget: "com.ibm.widgets.InlineEditorPopup",
				popupParams: {},
				
				postMixInProperties: function() {
					this.inherited(arguments);
					this.popupParams = dojo.mixin({}, this.popupParams);
				},
				
				postCreate: function() {
					this.inherited(arguments);
					if(!this._supportingWidgets) this._supportingWidgets = [];
					
					this._supportingWidgets.push(this.editor = new com.ibm.widgets.WrappedInlineEditBox({
						value: this.label,
						title: this.title,
						editor: this.embeddedEditorWidget,
						editorParams: this.embeddedEditorParams,
						canExit: dojo.hitch(this, function(){
							if(this.popupFocused || (this.editorFocused && !this.editor._wantsFocus)) {
								this.editor.editWidget._exitInProgress = false;
								return false;
							}
							return true;
						}),
						saveIsValid: function() {
							if(this.disabled || !this.editing || me.popupFocused || (
								this.editWidget.editWidget &&
								this.editWidget.editWidget.validate &&
								!this.editWidget.editWidget.validate()
								)) {
									this.editWidget._exitInProgress = false;
									return false;
							}
							return true;
						}
					}, this.editor));
					
					var _save = this.editor.save;
					var me = this;
					
					var _edit = dojo.hitch(this.editor, this.editor.edit);
					this.editor.edit = dojo.hitch(this, function() {
						this.editor.attr("value", this.defaultValue);
						_edit();
						
						// disable popup for checking private or public
						//this.editorPopup = this._getPopup();
						if(this.editorPopup) {
							this.editorPopup.attr("value", this.popupDefaultValue);
							dijit.popup.open({
								parent: this,
								popup: this.editorPopup,
								around: this.domNode,
								onCancel: dojo.hitch(this, this.editor.cancel),
								onClose: function(){ }
							});
						}
					});
					
					this.connect(this.editor, "onChange", "_onChange");
					this.connect(this.editor, "onCancel", "_onCancel");
					this.connect(this.editor, "edit", "onEdit");
				},
				_getPopup: function() {
					if(this.editorPopup) return this.editorPopup;
					if(!this.popupWidget) return null;
					var cls = dojo.getObject(this.popupWidget);
					if(cls) {
						this.editorPopup = new cls(this.popupParams);
						dijit.popup.prepare(this.editorPopup.domNode);
						this.editorPopup.startup();
						this.popupDefaultValue = this.editorPopup.attr("value");
						this.connect(this.editorPopup, "onFocus", function() {
							this.popupFocused = true;
							this.editorFocused = false;
						});
						this.connect(this.editorPopup, "onBlur", function() {
							this.popupFocused = false;
							setTimeout(dojo.hitch(this, function(){
								if(!this.editorFocused && this.editor.editWidget) {
									this.editor.editWidget._onBlur();
								}
							}),50);
						});
						this.connect(this.editor, "onFocus", function(){
							this.editorFocused = true;
							this.popupFocused = false;
						});
						this.connect(this.editor, "onBlur", function(){
							this.editorFocused = false;
						});
						
						return this.editorPopup;
					}
					return null;
				},
				startup: function() {
					this.editor.startup();
				},
				isEditing: function() {
					return this.editor && this.editor.editing;
				},
				_onChange: function(value) {
					// change the value back to its default, and call onChange with the
					// saved value
					this.editor.attr("value", this.label);
					var compositeValue = {label: value};
					if(this.editorPopup) {
						compositeValue = dojo.mixin(this.editorPopup.attr("value"), compositeValue);
						dijit.popup.close(this.editorPopup);
					}
					this.onChange(compositeValue, this.editor._wantsFocus);
				},
				onChange: function(value, focus) {
					// summary: Extension point for getting notifications about when this editor
					//		changes values.
					// value: New value of the inline editor
					// focus: Boolean indicating whether or not focus should stay on the inline editor
					//		usually because the ENTER key was pressed to save the value as opposed to
					//		an onblur event.
				},
				_onCancel: function() {
					this.editor.attr("value", this.label);
					if(this.editorPopup) dijit.popup.close(this.editorPopup);
					this.onCancel(this.editor._wantsFocus);
				},
				onCancel: function(focus) {
					// summary: Extension point for getting notifications about when this editor
					//		is canceled during an edit operation.
				},
				onEdit: function() {
					// summary: Extension point for getting notifications about when this editor
					//		goes into edit mode.
				}
			}
);

dojo.declare("com.ibm.widgets.WrappedInlineEditBox",
	dijit.InlineEditBox,
	{
		waitTime: 50,
		
		_wantsFocus: false,
		
		constructor: function() {
			this._connections = [];
		},
		canExit: function() {
			return true;
		},
		waitToExit: function(fname, argsArray) {
			setTimeout(dojo.hitch(this, function(){
				if(this.canExit() && this[fname + "IsValid"]()) {
					dijit.InlineEditBox.prototype[fname].apply(this, argsArray);
					this._wantsFocus = false;
				}
			}), this.waitTime);
		},
		saveIsValid: function() {
			return true;
		},
		cancelIsValid: function() {
			return true;
		},
		save: function(focus) {
			this._wantsFocus = focus;
			this.waitToExit("save", arguments);
		},
		cancel: function(focus) {
			this._wantsFocus = focus;
			this.waitToExit("cancel", arguments);
		},
		edit: function() {
			this.inherited(arguments);
			this._wantsFocus = false;
			var ew = this.editWidget;
			this._connections.push(dojo.connect(ew, "focus", this, "onFocus"));
			this._connections.push(dojo.connect(ew.editWidget, "onFocus", this, "onFocus"));
			this._connections.push(dojo.connect(ew, "onBlur", this, "onBlur"));
			var destroyConnection = dojo.connect(ew.editWidget, "destroy", this, function(){
				dojo.forEach(this._connections, dojo.disconnect);
				dojo.disconnect(destroyConnection);
			});
		}
	}
);

dojo.declare("com.ibm.widgets.InlineEditorPopup",
	dijit.layout.ContentPane,
	{
		"class": "inlineEditorPopup",
		
		content: 
			'<form dojoType="dijit.form.Form" encType="multipart/form-data" action="" method="POST" onSubmit="return false;" onReset="return false;">'
				+'<input name="isPrivate" checked="checked" dojoType="dijit.form.CheckBox">'
				+'<label for="isPrivate">Make this my private page</label>'
			+'</form>',

		onFocus: function() {
			
		},
			
		_getValueAttr: function() {
			var childWidgets = dojo.query("> [widgetId]", this.containerNode).map(dijit.byNode);
			if(childWidgets.length > 0)	return childWidgets[0].attr("value");
			return null;
		},
		_setValueAttr: function(value) {
			var childWidgets = dojo.query("> [widgetId]", this.containerNode).map(dijit.byNode);
			if(childWidgets.length > 0)	childWidgets[0].attr("value", value);
		}
	}
);

}

if(!dojo._hasResource["dijit._KeyNavContainer"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._KeyNavContainer"] = true;
dojo.provide("dijit._KeyNavContainer");


dojo.declare("dijit._KeyNavContainer",
	[dijit._Container],
	{

		// summary:
		//		A _Container with keyboard navigation of its children.
		// description:
		//		To use this mixin, call connectKeyNavHandlers() in
		//		postCreate() and call startupKeyNavChildren() in startup().
		//		It provides normalized keyboard and focusing code for Container
		//		widgets.
/*=====
		// focusedChild: [protected] Widget
		//		The currently focused child widget, or null if there isn't one
		focusedChild: null,
=====*/

		// tabIndex: Integer
		//		Tab index of the container; same as HTML tabindex attribute.
		//		Note then when user tabs into the container, focus is immediately
		//		moved to the first item in the container.
		tabIndex: "0",


		_keyNavCodes: {},

		connectKeyNavHandlers: function(/*dojo.keys[]*/ prevKeyCodes, /*dojo.keys[]*/ nextKeyCodes){
			// summary:
			//		Call in postCreate() to attach the keyboard handlers
			//		to the container.
			// preKeyCodes: dojo.keys[]
			//		Key codes for navigating to the previous child.
			// nextKeyCodes: dojo.keys[]
			//		Key codes for navigating to the next child.
			// tags:
			//		protected

			var keyCodes = this._keyNavCodes = {};
			var prev = dojo.hitch(this, this.focusPrev);
			var next = dojo.hitch(this, this.focusNext);
			dojo.forEach(prevKeyCodes, function(code){ keyCodes[code] = prev; });
			dojo.forEach(nextKeyCodes, function(code){ keyCodes[code] = next; });
			this.connect(this.domNode, "onkeypress", "_onContainerKeypress");
			this.connect(this.domNode, "onfocus", "_onContainerFocus");
		},

		startupKeyNavChildren: function(){
			// summary:
			//		Call in startup() to set child tabindexes to -1
			// tags:
			//		protected
			dojo.forEach(this.getChildren(), dojo.hitch(this, "_startupChild"));
		},

		addChild: function(/*Widget*/ widget, /*int?*/ insertIndex){
			// summary:
			//		Add a child to our _Container
			dijit._KeyNavContainer.superclass.addChild.apply(this, arguments);
			this._startupChild(widget);
		},

		focus: function(){
			// summary:
			//		Default focus() implementation: focus the first child.
			this.focusFirstChild();
		},

		focusFirstChild: function(){
			// summary:
			//		Focus the first focusable child in the container.
			// tags:
			//		protected
			this.focusChild(this._getFirstFocusableChild());
		},

		focusNext: function(){
			// summary:
			//		Focus the next widget or focal node (for widgets
			//		with multiple focal nodes) within this container.
			// tags:
			//		protected
			if(this.focusedChild && this.focusedChild.hasNextFocalNode
					&& this.focusedChild.hasNextFocalNode()){
				this.focusedChild.focusNext();
				return;
			}
			var child = this._getNextFocusableChild(this.focusedChild, 1);
			if(child.getFocalNodes){
				this.focusChild(child, child.getFocalNodes()[0]);
			}else{
				this.focusChild(child);
			}
		},

		focusPrev: function(){
			// summary:
			//		Focus the previous widget or focal node (for widgets
			//		with multiple focal nodes) within this container.
			// tags:
			//		protected
			if(this.focusedChild && this.focusedChild.hasPrevFocalNode
					&& this.focusedChild.hasPrevFocalNode()){
				this.focusedChild.focusPrev();
				return;
			}
			var child = this._getNextFocusableChild(this.focusedChild, -1);
			if(child.getFocalNodes){
				var nodes = child.getFocalNodes();
				this.focusChild(child, nodes[nodes.length-1]);
			}else{
				this.focusChild(child);
			}
		},

		focusChild: function(/*Widget*/ widget, /*Node?*/ node){
			// summary:
			//		Focus widget. Optionally focus 'node' within widget.
			// tags:
			//		protected
			if(widget){
				if(this.focusedChild && widget !== this.focusedChild){
					this._onChildBlur(this.focusedChild);
				}
				this.focusedChild = widget;
				if(node && widget.focusFocalNode){
					widget.focusFocalNode(node);
				}else{
					widget.focus();
				}
			}
		},

		_startupChild: function(/*Widget*/ widget){
			// summary:
			//		Set tabindex="-1" on focusable widgets so that we
			// 		can focus them programmatically and by clicking.
			//		Connect focus and blur handlers.
			// tags:
			//		private
			if(widget.getFocalNodes){
				dojo.forEach(widget.getFocalNodes(), function(node){
					dojo.attr(node, "tabindex", -1);
					this._connectNode(node);
				}, this);
			}else{
				var node = widget.focusNode || widget.domNode;
				if(widget.isFocusable()){
					dojo.attr(node, "tabindex", -1);
				}
				this._connectNode(node);
			}
		},

		_connectNode: function(/*Element*/ node){
			// summary:
			//		Monitor focus and blur events on the node
			// tags:
			//		private
			this.connect(node, "onfocus", "_onNodeFocus");
			this.connect(node, "onblur", "_onNodeBlur");
		},

		_onContainerFocus: function(evt){
			// summary:
			//		Handler for when the container gets focus
			// description:
			//		Initially the container itself has a tabIndex, but when it gets
			//		focus, switch focus to first child...
			// tags:
			//		private

			// Note that we can't use _onFocus() because switching focus from the
			// _onFocus() handler confuses the focus.js code
			// (because it causes _onFocusNode() to be called recursively)

			// focus bubbles on Firefox,
			// so just make sure that focus has really gone to the container
			if(evt.target !== this.domNode){ return; }

			this.focusFirstChild();
			
			// and then remove the container's tabIndex,
			// so that tab or shift-tab will go to the fields after/before
			// the container, rather than the container itself
			dojo.removeAttr(this.domNode, "tabIndex");
		},

		_onBlur: function(evt){
			// When focus is moved away the container, and it's descendant (popup) widgets,
			// then restore the container's tabIndex so that user can tab to it again.
			// Note that using _onBlur() so that this doesn't happen when focus is shifted
			// to one of my child widgets (typically a popup)
			if(this.tabIndex){
				dojo.attr(this.domNode, "tabindex", this.tabIndex);
			}
			// TODO: this.inherited(arguments);
		},

		_onContainerKeypress: function(evt){
			// summary:
			//		When a key is pressed, if it's an arrow key etc. then
			//		it's handled here.
			// tags:
			//		private
			if(evt.ctrlKey || evt.altKey){ return; }
			var func = this._keyNavCodes[evt.charOrCode];
			if(func){
				func();
				dojo.stopEvent(evt);
			}
		},

		_onNodeFocus: function(evt){
			// summary:
			//		Handler for onfocus event on a child node
			// tags:
			//		private

			// record the child that has been focused
			var widget = dijit.getEnclosingWidget(evt.target);
			if(widget && widget.isFocusable()){
				this.focusedChild = widget;
			}
			dojo.stopEvent(evt);
		},

		_onNodeBlur: function(evt){
			// summary:
			//		Handler for onblur event on a child node
			// tags:
			//		private
			dojo.stopEvent(evt);
		},

		_onChildBlur: function(/*Widget*/ widget){
			// summary:
			//		Called when focus leaves a child widget to go
			//		to a sibling widget.
			// tags:
			//		protected
		},

		_getFirstFocusableChild: function(){
			// summary:
			//		Returns first child that can be focused
			return this._getNextFocusableChild(null, 1);
		},

		_getNextFocusableChild: function(child, dir){
			// summary:
			//		Returns the next or previous focusable child, compared
			//		to "child"
			// child: Widget
			//		The current widget
			// dir: Integer
			//		* 1 = after
			//		* -1 = before
			if(child){
				child = this._getSiblingOfChild(child, dir);
			}
			var children = this.getChildren();
			for(var i=0; i < children.length; i++){
				if(!child){
					child = children[(dir>0) ? 0 : (children.length-1)];
				}
				if(child.isFocusable()){
					return child;
				}
				child = this._getSiblingOfChild(child, dir);
			}
			// no focusable child found
			return null;
		}
	}
);

}

if(!dojo._hasResource["com.ibm.widgets.TabBar"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.widgets.TabBar"] = true;
dojo.provide( "com.ibm.widgets.TabBar" );






/*
 * Provides Menu widgets using OneUI structure and styles by subclassing dijit.Menu widgets
 * and modifying the templates
 */


dojo.declare( "com.ibm.widgets.TabBar",
			[dijit._Widget, dijit._Templated, dijit._KeyNavContainer],
			{
				// summary: 
				//		Holds a set of tabs in a bar widget.  Provides logic to manage popups
				// 		for each tab (specified by the 'popup' property of the tab widget) if
				//		present.
				
				// class: String class applied to the root node in this widget
				"class": "lotusTabContainer",
				
				// tabListClass: String class applied to the unorderered list node in this 
				// 		widget
				tabListClass: "lotusTabs",
				
				// tabClass: String the class passed in as the class of each tab widget
				//		that is added as a child to this tab bar.  If empty or null, the
				//		tab widget will assume whatever its default class is.
				tabClass: "lotusTab",
				
				// tagWidget: String the name of the widget class to instantiate for each
				//		tab in this tab bar.  Alternatively, simply calling the addChild
				//		function with any widget as the argument will add that widget to
				//		this tab bar, although it may not look appropriate.
				tabWidget: "com.ibm.widgets.Tab",
				
				// tabStrip: Boolean indicating if an additional CSS class is applied to the
				//		root DOM node of this widget which has the value of the class+"Strip"
				//		Example - class = "lotusTabContainer", with tabStrip = true, an additional
				//		class "lotusTabContainerStrip" is added as well.
				tabStrip: false,
				
				tabIndex: "0",
				
				templateString: '<div tabIndex="${tabIndex}" class="${class}" waiRole="navigation" dojoAttachPoint="focusNode">'
									+'<ul class="${tabListClass}" waiRole="tablist" dojoAttachPoint="containerNode,tabList" dojoAttachEvent="onkeypress:_onKeyPress"></ul>'
								+'</div>',
				
				attributeMap: dojo.mixin(dojo.clone(dijit._Widget.prototype.attributeMap), {
					tabListClass: {node: "containerNode", type: "class" }
				}),
				
				_setClassAttr: function(/*String*/ value){
					this["class"] = value;
					this.domNode["className"] = value;
				},
				
				postCreate: function() {
					this.inherited(arguments);
					if(this.tabStrip) dojo.addClass(this.tabList, this["class"] + "Strip");
					var ltr = this.isLeftToRight(),
						k = dojo.keys;
					this.connectKeyNavHandlers(
						ltr ? [k.LEFT_ARROW] : [k.RIGHT_ARROW],
						ltr ? [k.RIGHT_ARROW] : [k.LEFT_ARROW]
					);
				},
				
				startup: function() {
					this.startupKeyNavChildren();
					this.inherited(arguments);
				},
				
				_fillContent: function(/*DomNode*/ source){
					var dest = this.containerNode;
					if(source && dest) {
						var nodes = dojo.query("> ul", source);
						if(nodes.length > 0) {
							this.preloaded = true;
							this.tabListClass = nodes[0]["className"];
							this.containerNode["className"] = this.tabListClass;
							source = nodes[0];
						}
					}
					return this.inherited(arguments);
				},
				
				_onKeyPress: function(evt){
					if(evt.ctrlKey || evt.altKey) return;
					switch(evt.charOrCode) {
						 case dojo.keys.DOWN_ARROW:
						 	this._moveToPopup(evt);
						 	dojo.stopEvent(evt);
						 	break;
					}	
				},
				_onNodeBlur: function(evt){
					// when focus leaves a child,
					// reinstate the container's tabindex
					/*
					var item = dijit.getEnclosingWidget(evt.target);
					this._onChildBlur(item);
					*/
					this._startCloseTimer();
					this.inherited(arguments);
				},
				_onChildBlur: function(item) {
					if(item.popup) dijit.popup.close(item.popup);
					item._blur();
				},
				_moveToPopup: function(/*Event*/ evt){
					if(this.focusedChild && this.focusedChild.popup && !this.focusedChild.disabled) {
						this._openPopup(this.focusedChild, true);
					}
				},
				_moveToNextPopup: function() {
					this.focusNext();
				},
				_openPopup: function(item, focus) {
					var popup = item.popup;
					if(!popup) return false;
					if(this.currentPopup == popup) {
						if(focus && popup.focus) {
							popup.focus();
						}
						return false;
					}
					var me = this;
					var ori = {'BL':'TL', 'TL':'BL'};
					if (!this.isLeftToRight())
					{
						ori = {'BR':'TR', 'TR':'BR'};
					}
					dijit.popup.open({
						parent: this,
						popup: popup,
						orient: ori,
						around: item.domNode,
						onCancel: function() {
							if(popup.close) popup.close();
							else dijit.popup.close(popup);
							item.focus();
							me.currentPopup = null;
						},
						onClose: function() {
							me.currentPopup = null;
						}
					});
					
					this.currentPopup = popup;
					
					if(focus && popup.focus) {
						popup.focus();
					}
					
					return true;
				},
				
				_closePopup: function() {
					if(this.currentPopup) {
						if(this.currentPopup.close) this.currentPopup.close();
						else dijit.popup.close(this.currentPopup);
					}
					this.currentPopup = null;
				},
				
				_startCloseTimer: function() {
					if(this.currentPopup) {
						if(this.currentPopup._startCloseTimer) {
							// the popup supports the _startCloseTimer function, call it
							this.currentPopup._startCloseTimer();
						}
						else {
							// if it does not, close it immediately
							this._closePopup();
						}
					}
				},
				
				_stopCloseTimer: function() {
					if(this.currentPopup && this.currentPopup._stopCloseTimer) {
						this.currentPopup._stopCloseTimer();
					}
				},
				_onItemAccent: function(child, focus) {
					if(child.attr("disabled")) return;
					// stop any close timers
					this._stopCloseTimer();
					if(this.currentPopup) {
						if(this.currentPopup.canClose && !this.currentPopup.canClose()) return;
						if(this.currentPopup != child.popup) {
							// close the existing popup if it's not the one associated with hovered item
							// close it immediately without allowing any animation or effect so that
							// the new menu that's being opened will display correctly
							dijit.popup.close(this.currentPopup);
						}
					}
					// open the hovered item popup
					this._openPopup(child, focus);
				},
				onItemFocus: function(child) {
					//this._onItemAccent(child, false);
				},
				onItemClick: function(child, evt) {
					if(child.attr("disabled")) return;
					child.onClick(evt);
				},
				onItemHover: function(child, evt) {
					this._onItemAccent(child, false);
				},
				onItemUnhover: function(item) {
					this._startCloseTimer();
				}
			}
);

dojo.declare( "com.ibm.widgets._TabBase",
			[dijit._Widget, dijit._Templated, dijit._Contained],
			{
				"class": "lotusTab",
				_setDisabledAttr: function(/*Boolean*/ value){
					this.disabled = value;
					dojo[value ? "addClass" : "removeClass"](this.domNode, "disabled");
					dijit.setWaiState(this.focusNode, 'disabled', value ? 'true' : 'false');
				},
				_setClassAttr: function(/*String*/ value){
					this["class"] = value;
					this.domNode["className"] = value;
				},
				focus: function(){
					dijit.focus(this.focusNode);
				},
				onFocus: function() {
					this.getParent().onItemFocus(this);
				},
				_onHover: function(evt) {
					this.getParent().onItemHover(this, evt);
				},
				_onUnhover: function(evt) {
					this.getParent().onItemUnhover(this, evt);
				},
				_blur: function() {
					// called by parent to perform any blur action on this item
				}
			}
);

dojo.declare( "com.ibm.widgets.Tab",
			com.ibm.widgets._TabBase,
			{
				iconClass: "",
				href: "",
				label: "",
				
				templateString:"<li class=\"${class}\" dojoAttachEvent=\"onclick:_onClick,onmouseenter:_onHover,onmouseleave:_onUnhover\"\n\t><div waiRole=\"presentation\" dojoAttachPoint=\"containerNode\"\n\t\t><span class=\"dragHandle\" waiRole=\"presentation\" dojoAttachPoint=\"dndHandleNode\"\n\t\t\t><span class=\"dragHandleInner\" waiRole=\"presentation\"\n\t\t\t\t><img dojoAttachPoint=\"iconNode\" alt=\"\" src=\"${_blankGif}\" waiRole=\"presentation\" \n\t\t\t\t/><span waiRole=\"presentation\" class=\"dragHandleA11y\">|</span\n\t\t\t></span\n\t\t></span\n\t\t><a dojoAttachPoint=\"focusNode,linkNode,labelNode\" href=\"javascript:;\" onclick=\"javascript:return false;\" waiRole=\"menuitem\"></a\n\t\t><span class=\"modelHasChildrenIcon\" waiRole=\"presentation\" dojoAttachPoint=\"hasChildrenIconNode\"\n\t\t\t><img src=\"${_blankGif}\" alt=\"\" waiRole=\"presentation\" class=\"dijitArrowButtonInner\"\n\t\t\t/><span waiRole=\"presentation\" class=\"dijitArrowButtonChar\">&#9660;</span\n\t\t></span\n\t\t><div class=\"dndMagicZone\" waiRole=\"presentation\"\n\t\t></div\n\t></div\n></li>\n",
								
				attributeMap: dojo.mixin(dojo.clone(dijit._Widget.prototype.attributeMap), {
					label: {node: "labelNode", type: "innerHTML"},
					href: {node: "linkNode", type: "attribute"},
					iconClass: {node: "iconNode", type: "class" }
				}),
				_setDndHandleAttr: function(value) {
					this.dndHandle = value;
					dojo[value ? "addClass" : "removeClass"](this.dndHandleNode, "dojoDndHandle");
				},
				postCreate: function() {
					this.inherited(arguments);
					if(this.popup) {
						this.setPopup(this.popup);
					}
				},
				
				_fillContent: function(/*DomNode*/ source){
					var dest = this.containerNode;
					var handled = false;
					if(source && dest) {
						var nodes = dojo.query("a", source);
						if(nodes.length > 0) {
							handled = true;
							this.linkNode.setAttribute("href", nodes[0].getAttribute("href"));
							while(nodes[0].hasChildNodes()) {
								this.linkNode.appendChild(nodes[0].firstChild);
							}
						}
					}
					if(!handled) return this.inherited(arguments);
				},
				
				setPopup: function(popup) {
					this.popup = popup;
					this.popup.anchor = this;
					this.popup.startup();
					dijit.setWaiState(this.linkNode, "haspopup", "true");
				},
				destroyPopup: function() {
					if(this.popup) {
						this.popup.destroyRecursive();
						delete this.popup;
						dijit.setWaiState(this.linkNode, "haspopup", "false");
					}
				},
				destroyDescendants: function() {
					this.destroyPopup();
					this.inherited(arguments);
				},
				
				startup: function() {
					this.inherited(arguments);
					if(this.popup) this.popup.startup();
				},
				_onClick: function(evt) {
					var p = this.getParent();
					if(p) {
						p.onItemClick(this, evt);
						dojo.stopEvent(evt);
					}
				},
				onClick: function(evt) {
					
				}
			}
);


dojo.declare( "com.ibm.widgets.ShowEditorTab",
			com.ibm.widgets._TabBase,
			{
				"class": "showEditorTab",
				templateString:	'<li class="${class}" waiRole="menuitem" dojoAttachPoint="containerNode" dojoAttachEvent="onclick:onClick">'
									+'<a dojoAttachPoint="focusNode" class="tabLabel" onclick="javascript:return false;" href="javascript:void(0);">${label}</a>'
								+'</li>',

				
				postCreate: function() {
					this.inherited(arguments);
					dojo.setSelectable(this.domNode, true);
					if(this.popupWidget) {
						var cls = dojo.getObject(this.popupWidget);
						this.popup = new cls(this.popupParams);
						this.connect(this.popup, "onChange", "onChange");
						this.connect(this.popup, "onCancel", "onCancel");
						this.connect(this.popup, "focus", "onEdit");
					}
				},
				onFocus: function() {
					
				},
				onChange: function(value) {
					
				},
				onCancel: function() {
					
				},
				onEdit: function() {
					
				},
				onClick: function(evt) {
					if (this.popup){
						// Check if there is a page manager and bring up the save changes dialog.
						if (typeof ibmPortalConfig != "undefined" && typeof ibmPortalConfig.savePageManager != "undefined" && typeof ibmPortalConfig.savePageManager.leavePage != "undefined") {
							var dialog = this.popup;
							var dialogOpen = function() { dialog.focus(); };
							ibmPortalConfig.savePageManager.leavePage(dialogOpen);
						}
						else if (typeof com.ibm.mm.builder.utils.pageUtil != "undefined") {
							var dialog = this.popup;
							var cb = dojo.hitch(this, function(){
   								dialog.focus();	
   							});
							com.ibm.mm.builder.utils.pageUtil.savePageWithConfirm(cb);
						}
						else {
							this.popup.focus();
						}
					}
				}
			}
);

dojo.declare( "com.ibm.widgets.EditorTab",
			[com.ibm.widgets._TabBase, com.ibm.widgets.InlineEditorWrapper],
			{
				templateString:"<li class=\"inlineEditor ${class}\" waiRole=\"presentation\" dojoAttachPoint=\"containerNode\" dojoAttachEvent=\"onclick:onClick,onmouseenter:_onHover,onmouseleave:_onUnhover\"\n\t><div\n\t\t><a dojoAttachPoint=\"editor,focusNode\" href=\"javascript:;\" class=\"tabLabel\" waiRole=\"tab\" onclick=\"javascript:return false;\">${label}</a\n\t></div\n></li>\n",
				
				"class": "lotusTab",
				
				postCreate: function() {
					this.inherited(arguments);
					dojo.setSelectable(this.domNode, true);
				}	
			}
);

}

if(!dojo._hasResource["dijit.MenuItem"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.MenuItem"] = true;
dojo.provide("dijit.MenuItem");





dojo.declare("dijit.MenuItem",
		[dijit._Widget, dijit._Templated, dijit._Contained],
		{
		// summary:
		//		A line item in a Menu Widget

		// Make 3 columns
		// icon, label, and expand arrow (BiDi-dependent) indicating sub-menu
		templateString:"<tr class=\"dijitReset dijitMenuItem\" dojoAttachPoint=\"focusNode\" waiRole=\"menuitem\" tabIndex=\"-1\"\n\t\tdojoAttachEvent=\"onmouseenter:_onHover,onmouseleave:_onUnhover,ondijitclick:_onClick\">\n\t<td class=\"dijitReset\" waiRole=\"presentation\">\n\t\t<img src=\"${_blankGif}\" alt=\"\" class=\"dijitMenuItemIcon\" dojoAttachPoint=\"iconNode\">\n\t</td>\n\t<td class=\"dijitReset dijitMenuItemLabel\" colspan=\"2\" dojoAttachPoint=\"containerNode\"></td>\n\t<td class=\"dijitReset dijitMenuItemAccelKey\" style=\"display: none\" dojoAttachPoint=\"accelKeyNode\"></td>\n\t<td class=\"dijitReset dijitMenuArrowCell\" waiRole=\"presentation\">\n\t\t<div dojoAttachPoint=\"arrowWrapper\" style=\"visibility: hidden\">\n\t\t\t<img src=\"${_blankGif}\" alt=\"\" class=\"dijitMenuExpand\">\n\t\t\t<span class=\"dijitMenuExpandA11y\">+</span>\n\t\t</div>\n\t</td>\n</tr>\n",

		attributeMap: dojo.delegate(dijit._Widget.prototype.attributeMap, {
			label: { node: "containerNode", type: "innerHTML" },
			iconClass: { node: "iconNode", type: "class" }
		}),

		// label: String
		//		Menu text
		label: '',

		// iconClass: String
		//		Class to apply to DOMNode to make it display an icon.
		iconClass: "",

		// accelKey: String
		//		Text for the accelerator (shortcut) key combination.
		//		Note that although Menu can display accelerator keys there
		//		is no infrastructure to actually catch and execute these
		//		accelerators.
		accelKey: "",

		// disabled: Boolean
		//		If true, the menu item is disabled.
		//		If false, the menu item is enabled.
		disabled: false,

		_fillContent: function(/*DomNode*/ source){
			// If button label is specified as srcNodeRef.innerHTML rather than
			// this.params.label, handle it here.
			if(source && !("label" in this.params)){
				this.attr('label', source.innerHTML);
			}
		},

		postCreate: function(){
			dojo.setSelectable(this.domNode, false);
			dojo.attr(this.containerNode, "id", this.id+"_text");
			dijit.setWaiState(this.domNode, "labelledby", this.id+"_text");
		},

		_onHover: function(){
			// summary:
			//		Handler when mouse is moved onto menu item
			// tags:
			//		protected
			dojo.addClass(this.domNode, 'dijitMenuItemHover');
			this.getParent().onItemHover(this);
		},

		_onUnhover: function(){
			// summary:
			//		Handler when mouse is moved off of menu item,
			//		possibly to a child menu, or maybe to a sibling
			//		menuitem or somewhere else entirely.
			// tags:
			//		protected

			// if we are unhovering the currently selected item
			// then unselect it
			dojo.removeClass(this.domNode, 'dijitMenuItemHover');
			this.getParent().onItemUnhover(this);
		},

		_onClick: function(evt){
			// summary:
			//		Internal handler for click events on MenuItem.
			// tags:
			//		private
			this.getParent().onItemClick(this, evt);
			dojo.stopEvent(evt);
		},

		onClick: function(/*Event*/ evt){
			// summary:
			//		User defined function to handle clicks
			// tags:
			//		callback
		},

		focus: function(){
			// summary:
			//		Focus on this MenuItem
			try{
				dijit.focus(this.focusNode);
			}catch(e){
				// this throws on IE (at least) in some scenarios
			}
		},

		_onFocus: function(){
			// summary:
			//		This is called by the focus manager when focus
			//		goes to this MenuItem or a child menu.
			// tags:
			//		protected
			this._setSelected(true);

			// TODO: this.inherited(arguments);
		},

		_setSelected: function(selected){
			// summary:
			//		Indicate that this node is the currently selected one
			// tags:
			//		private

			/***
			 * TODO: remove this method and calls to it, when _onBlur() is working for MenuItem.
			 * Currently _onBlur() gets called when focus is moved from the MenuItem to a child menu.
			 * That's not supposed to happen, but the problem is:
			 * In order to allow dijit.popup's getTopPopup() to work,a sub menu's popupParent
			 * points to the parent Menu, bypassing the parent MenuItem... thus the
			 * MenuItem is not in the chain of active widgets and gets a premature call to
			 * _onBlur()
			 */
			
			dojo.toggleClass(this.domNode, "dijitMenuItemSelected", selected);
		},

		setLabel: function(/*String*/ content){
			// summary:
			//		Deprecated.   Use attr('label', ...) instead.
			// tags:
			//		deprecated
			dojo.deprecated("dijit.MenuItem.setLabel() is deprecated.  Use attr('label', ...) instead.", "", "2.0");
			this.attr("label", content);
		},

		setDisabled: function(/*Boolean*/ disabled){
			// summary:
			//		Deprecated.   Use attr('disabled', bool) instead.
			// tags:
			//		deprecated
			dojo.deprecated("dijit.Menu.setDisabled() is deprecated.  Use attr('disabled', bool) instead.", "", "2.0");
			this.attr('disabled', disabled);
		},
		_setDisabledAttr: function(/*Boolean*/ value){
			// summary:
			//		Hook for attr('disabled', ...) to work.
			//		Enable or disable this menu item.
			this.disabled = value;
			dojo[value ? "addClass" : "removeClass"](this.domNode, 'dijitMenuItemDisabled');
			dijit.setWaiState(this.focusNode, 'disabled', value ? 'true' : 'false');
		},
		_setAccelKeyAttr: function(/*String*/ value){
			// summary:
			//		Hook for attr('accelKey', ...) to work.
			//		Set accelKey on this menu item.
			this.accelKey=value;

			this.accelKeyNode.style.display=value?"":"none";
			this.accelKeyNode.innerHTML=value;
			//have to use colSpan to make it work in IE
			dojo.attr(this.containerNode,'colSpan',value?"1":"2");
		}
	});

}

if(!dojo._hasResource["dijit.PopupMenuItem"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.PopupMenuItem"] = true;
dojo.provide("dijit.PopupMenuItem");



dojo.declare("dijit.PopupMenuItem",
		dijit.MenuItem,
		{
		_fillContent: function(){
			// summary: 
			//		When Menu is declared in markup, this code gets the menu label and
			//		the popup widget from the srcNodeRef.
			// description:
			//		srcNodeRefinnerHTML contains both the menu item text and a popup widget
			//		The first part holds the menu item text and the second part is the popup
			// example: 
			// |	<div dojoType="dijit.PopupMenuItem">
			// |		<span>pick me</span>
			// |		<popup> ... </popup>
			// |	</div>
			// tags:
			//		protected

			if(this.srcNodeRef){
				var nodes = dojo.query("*", this.srcNodeRef);
				dijit.PopupMenuItem.superclass._fillContent.call(this, nodes[0]);

				// save pointer to srcNode so we can grab the drop down widget after it's instantiated
				this.dropDownContainer = this.srcNodeRef;
			}
		},

		startup: function(){
			if(this._started){ return; }
			this.inherited(arguments);

			// we didn't copy the dropdown widget from the this.srcNodeRef, so it's in no-man's
			// land now.  move it to dojo.doc.body.
			if(!this.popup){
				var node = dojo.query("[widgetId]", this.dropDownContainer)[0];
				this.popup = dijit.byNode(node);
			}
			dojo.body().appendChild(this.popup.domNode);

			this.popup.domNode.style.display="none";
			if(this.arrowWrapper){
				dojo.style(this.arrowWrapper, "visibility", "");
			}
			dijit.setWaiState(this.focusNode, "haspopup", "true");
		},
		
		destroyDescendants: function(){
			if(this.popup){
				this.popup.destroyRecursive();
				delete this.popup;
			}
			this.inherited(arguments);
		}
	});


}

if(!dojo._hasResource["dijit.CheckedMenuItem"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.CheckedMenuItem"] = true;
dojo.provide("dijit.CheckedMenuItem");



dojo.declare("dijit.CheckedMenuItem",
		dijit.MenuItem,
		{
		// summary:
		//		A checkbox-like menu item for toggling on and off
		
		templateString:"<tr class=\"dijitReset dijitMenuItem\" dojoAttachPoint=\"focusNode\" waiRole=\"menuitemcheckbox\" tabIndex=\"-1\"\n\t\tdojoAttachEvent=\"onmouseenter:_onHover,onmouseleave:_onUnhover,ondijitclick:_onClick\">\n\t<td class=\"dijitReset\" waiRole=\"presentation\">\n\t\t<img src=\"${_blankGif}\" alt=\"\" class=\"dijitMenuItemIcon dijitCheckedMenuItemIcon\" dojoAttachPoint=\"iconNode\">\n\t\t<span class=\"dijitCheckedMenuItemIconChar\">&#10003;</span>\n\t</td>\n\t<td class=\"dijitReset dijitMenuItemLabel\" colspan=\"2\" dojoAttachPoint=\"containerNode,labelNode\"></td>\n\t<td class=\"dijitReset dijitMenuItemAccelKey\" style=\"display: none\" dojoAttachPoint=\"accelKeyNode\"></td>\n\t<td class=\"dijitReset dijitMenuArrowCell\" waiRole=\"presentation\">\n\t</td>\n</tr>\n",

		// checked: Boolean
		//		Our checked state
		checked: false,
		_setCheckedAttr: function(/*Boolean*/ checked){
			// summary:
			//		Hook so attr('checked', bool) works.
			//		Sets the class and state for the check box.
			dojo.toggleClass(this.domNode, "dijitCheckedMenuItemChecked", checked);
			dijit.setWaiState(this.domNode, "checked", checked);
			this.checked = checked;
		},

		onChange: function(/*Boolean*/ checked){
			// summary:
			//		User defined function to handle check/uncheck events
			// tags:
			//		callback
		},

		_onClick: function(/*Event*/ e){
			// summary:
			//		Clicking this item just toggles its state
			// tags:
			//		private
			if(!this.disabled){
				this.attr("checked", !this.checked);
				this.onChange(this.checked);
			}
			this.inherited(arguments);
		}
	});

}

if(!dojo._hasResource["dijit.MenuSeparator"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.MenuSeparator"] = true;
dojo.provide("dijit.MenuSeparator");





dojo.declare("dijit.MenuSeparator",
		[dijit._Widget, dijit._Templated, dijit._Contained],
		{
		// summary:
		//		A line between two menu items

		templateString:"<tr class=\"dijitMenuSeparator\">\n\t<td colspan=\"4\">\n\t\t<div class=\"dijitMenuSeparatorTop\"></div>\n\t\t<div class=\"dijitMenuSeparatorBottom\"></div>\n\t</td>\n</tr>\n",

		postCreate: function(){
			dojo.setSelectable(this.domNode, false);
		},
		
		isFocusable: function(){
			// summary:
			//		Override to always return false
			// tags:
			//		protected

			return false; // Boolean
		}
	});


}

if(!dojo._hasResource["dijit.Menu"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.Menu"] = true;
dojo.provide("dijit.Menu");





dojo.declare("dijit._MenuBase",
	[dijit._Widget, dijit._Templated, dijit._KeyNavContainer],
{
	// summary:
	//		Base class for Menu and MenuBar

	// parentMenu: [readonly] Widget
	//		pointer to menu that displayed me
	parentMenu: null,

	// popupDelay: Integer
	//		number of milliseconds before hovering (without clicking) causes the popup to automatically open.
	popupDelay: 500,

	startup: function(){
		if(this._started){ return; }

		dojo.forEach(this.getChildren(), function(child){ child.startup(); });
		this.startupKeyNavChildren();

		this.inherited(arguments);
	},

	onExecute: function(){
		// summary:
		//		Attach point for notification about when a menu item has been executed.
		//		This is an internal mechanism used for Menus to signal to their parent to
		//		close them, because they are about to execute the onClick handler.   In
		//		general developers should not attach to or override this method.
		// tags:
		//		protected
	},

	onCancel: function(/*Boolean*/ closeAll){
		// summary:
		//		Attach point for notification about when the user cancels the current menu
		//		This is an internal mechanism used for Menus to signal to their parent to
		//		close them.  In general developers should not attach to or override this method.
		// tags:
		//		protected
	},

	_moveToPopup: function(/*Event*/ evt){
		// summary:
		//		This handles the right arrow key (left arrow key on RTL systems),
		//		which will either open a submenu, or move to the next item in the
		//		ancestor MenuBar
		// tags:
		//		private

		if(this.focusedChild && this.focusedChild.popup && !this.focusedChild.disabled){
			this.focusedChild._onClick(evt);
		}else{
			var topMenu = this._getTopMenu();
			if(topMenu && topMenu._isMenuBar){
				topMenu.focusNext();
			}
		}
	},

	onItemHover: function(/*MenuItem*/ item){
		// summary:
		//		Called when cursor is over a MenuItem.
		// tags:
		//		protected

		// Don't do anything unless user has "activated" the menu by:
		//		1) clicking it
		//		2) tabbing into it
		//		3) opening it from a parent menu (which automatically focuses it)
		if(this.isActive){
			this.focusChild(item);
	
			if(this.focusedChild.popup && !this.focusedChild.disabled && !this.hover_timer){
				this.hover_timer = setTimeout(dojo.hitch(this, "_openPopup"), this.popupDelay);
			}
		}
	},

	_onChildBlur: function(item){
		// summary:
		//		Called when a child MenuItem becomes inactive because focus
		//		has been removed from the MenuItem *and* it's descendant menus.
		// tags:
		//		private

		item._setSelected(false);

		// Close all popups that are open and descendants of this menu
		dijit.popup.close(item.popup);
		this._stopPopupTimer();
	},

	onItemUnhover: function(/*MenuItem*/ item){
		// summary:
		//		Callback fires when mouse exits a MenuItem
		// tags:
		//		protected
		if(this.isActive){
			this._stopPopupTimer();
		}
	},

	_stopPopupTimer: function(){
		// summary:
		//		Cancels the popup timer because the user has stop hovering
		//		on the MenuItem, etc.
		// tags:
		//		private
		if(this.hover_timer){
			clearTimeout(this.hover_timer);
			this.hover_timer = null;
		}
	},

	_getTopMenu: function(){
		// summary:
		//		Returns the top menu in this chain of Menus
		// tags:
		//		private
		for(var top=this; top.parentMenu; top=top.parentMenu);
		return top;
	},

	onItemClick: function(/*Widget*/ item, /*Event*/ evt){
		// summary:
		//		Handle clicks on an item.
		// tags:
		//		private
		if(item.disabled){ return false; }

		this.focusChild(item);

		if(item.popup){
			if(!this.is_open){
				this._openPopup();
			}
		}else{
			// before calling user defined handler, close hierarchy of menus
			// and restore focus to place it was when menu was opened
			this.onExecute();

			// user defined handler for click
			item.onClick(evt);
		}
	},

	_openPopup: function(){
		// summary:
		//		Open the popup to the side of/underneath the current menu item
		// tags:
		//		protected

		this._stopPopupTimer();
		var from_item = this.focusedChild;
		var popup = from_item.popup;

		if(popup.isShowingNow){ return; }
		popup.parentMenu = this;
		var self = this;
		dijit.popup.open({
			parent: this,
			popup: popup,
			around: from_item.domNode,
			orient: this._orient || (this.isLeftToRight() ? 
									{'TR': 'TL', 'TL': 'TR', 'BR': 'BL', 'BL': 'BR'} : 
									{'TL': 'TR', 'TR': 'TL', 'BL': 'BR', 'BR': 'BL'}),
			onCancel: function(){
				// called when the child menu is canceled
				dijit.popup.close(popup);
				from_item.focus();	// put focus back on my node
				self.currentPopup = null;
			},
			onExecute: dojo.hitch(this, "_onDescendantExecute")
		});

		this.currentPopup = popup;

		if(popup.focus){
			// If user is opening the popup via keyboard (right arrow, or down arrow for MenuBar),
			// if the cursor happens to collide with the popup, it will generate an onmouseover event
			// even though the mouse wasn't moved.   Use a setTimeout() to call popup.focus so that
			// our focus() call overrides the onmouseover event, rather than vice-versa.  (#8742)
			setTimeout(dojo.hitch(popup, "focus"), 0);
		}
	},

	onOpen: function(/*Event*/ e){
		// summary:
		//		Callback when this menu is opened.
		//		This is called by the popup manager as notification that the menu
		//		was opened.
		// tags:
		//		private

		this.isShowingNow = true;
	},

	onClose: function(){
		// summary:
		//		Callback when this menu is closed.
		//		This is called by the popup manager as notification that the menu
		//		was closed.
		// tags:
		//		private

		this._stopPopupTimer();
		this.parentMenu = null;
		this.isShowingNow = false;
		this.currentPopup = null;
		if(this.focusedChild){
			this._onChildBlur(this.focusedChild);
			this.focusedChild = null;
		}
	},

	_onFocus: function(){
		// summary:
		//		Called when this Menu gets focus from:
		//			1) clicking it
		//			2) tabbing into it
		//			3) being opened by a parent menu.
		//		This is not called just from mouse hover.
		// tags:
		//		protected
		this.isActive = true;
		dojo.addClass(this.domNode, "dijitMenuActive");
		dojo.removeClass(this.domNode, "dijitMenuPassive");
		this.inherited(arguments);
	},
	
	_onBlur: function(){
		// summary:
		//		Called when focus is moved away from this Menu and it's submenus.
		// tags:
		//		protected
		this.isActive = false;
		dojo.removeClass(this.domNode, "dijitMenuActive");
		dojo.addClass(this.domNode, "dijitMenuPassive");

		// If user blurs/clicks away from a MenuBar (or always visible Menu), then close all popped up submenus etc.
		this.onClose();

		this.inherited(arguments);
	},

	_onDescendantExecute: function(){
		// summary:
		//		Called when submenu is clicked.  Close hierarchy of menus.
		// tags:
		//		private
		this.onClose();
	}
});

dojo.declare("dijit.Menu",
	dijit._MenuBase,
	{
	// summary
	//		A context menu you can assign to multiple elements

	// TODO: most of the code in here is just for context menu (right-click menu)
	// support.  In retrospect that should have been a separate class (dijit.ContextMenu).
	// Split them for 2.0

	constructor: function(){
		this._bindings = [];
	},

	templateString:"<table class=\"dijit dijitMenu dijitMenuPassive dijitReset dijitMenuTable\" waiRole=\"menu\" tabIndex=\"${tabIndex}\" dojoAttachEvent=\"onkeypress:_onKeyPress\">\n\t<tbody class=\"dijitReset\" dojoAttachPoint=\"containerNode\"></tbody>\n</table>\n",

	// targetNodeIds: [const] String[]
	//		Array of dom node ids of nodes to attach to.
	//		Fill this with nodeIds upon widget creation and it becomes context menu for those nodes.
	targetNodeIds: [],

	// contextMenuForWindow: [const] Boolean
	//		If true, right clicking anywhere on the window will cause this context menu to open.
	//		If false, must specify targetNodeIds.
	contextMenuForWindow: false,

	// leftClickToOpen: [const] Boolean
	//		If true, menu will open on left click instead of right click, similiar to a file menu.
	leftClickToOpen: false,
	
	// _contextMenuWithMouse: [private] Boolean
	//		Used to record mouse and keyboard events to determine if a context
	//		menu is being opened with the keyboard or the mouse.
	_contextMenuWithMouse: false,

	postCreate: function(){
		if(this.contextMenuForWindow){
			this.bindDomNode(dojo.body());
		}else{
			// TODO: should have _setTargetNodeIds() method to handle initialization and a possible
			// later attr('targetNodeIds', ...) call.   There's also a problem that targetNodeIds[]
			// gets stale after calls to bindDomNode()/unBindDomNode() as it still is just the original list (see #9610)
			dojo.forEach(this.targetNodeIds, this.bindDomNode, this);
		}
		var k = dojo.keys, l = this.isLeftToRight();
		this._openSubMenuKey = l ? k.RIGHT_ARROW : k.LEFT_ARROW;
		this._closeSubMenuKey = l ? k.LEFT_ARROW : k.RIGHT_ARROW;
		this.connectKeyNavHandlers([k.UP_ARROW], [k.DOWN_ARROW]);
	},

	_onKeyPress: function(/*Event*/ evt){
		// summary:
		//		Handle keyboard based menu navigation.
		// tags:
		//		protected

		if(evt.ctrlKey || evt.altKey){ return; }

		switch(evt.charOrCode){
			case this._openSubMenuKey:
				this._moveToPopup(evt);
				dojo.stopEvent(evt);
				break;
			case this._closeSubMenuKey:
				if(this.parentMenu){
					if(this.parentMenu._isMenuBar){
						this.parentMenu.focusPrev();
					}else{
						this.onCancel(false);
					}
				}else{
					dojo.stopEvent(evt);
				}
				break;
		}
	},

	// thanks burstlib!
	_iframeContentWindow: function(/* HTMLIFrameElement */iframe_el){
		// summary:
		//		Returns the window reference of the passed iframe
		// tags:
		//		private
		var win = dijit.getDocumentWindow(this._iframeContentDocument(iframe_el)) ||
			// Moz. TODO: is this available when defaultView isn't?
			this._iframeContentDocument(iframe_el)['__parent__'] ||
			(iframe_el.name && dojo.doc.frames[iframe_el.name]) || null;
		return win;	//	Window
	},

	_iframeContentDocument: function(/* HTMLIFrameElement */iframe_el){
		// summary:
		//		Returns a reference to the document object inside iframe_el
		// tags:
		//		protected
		var doc = iframe_el.contentDocument // W3
			|| (iframe_el.contentWindow && iframe_el.contentWindow.document) // IE
			|| (iframe_el.name && dojo.doc.frames[iframe_el.name] && dojo.doc.frames[iframe_el.name].document)
			|| null;
		return doc;	//	HTMLDocument
	},

	bindDomNode: function(/*String|DomNode*/ node){
		// summary:
		//		Attach menu to given node
		node = dojo.byId(node);

		var cn;	// Connect node

		// Support context menus on iframes.   Rather than binding to the iframe itself we need
		// to bind to the <body> node inside the iframe.
		if(node.tagName.toLowerCase() == "iframe"){
			var iframe = node,
				win = this._iframeContentWindow(iframe);
			cn = dojo.withGlobal(win, dojo.body);
		}else{
			// to capture these events at the top level,
			// attach to document, not body
			cn = (node == dojo.body() ? dojo.doc : node);
		}

		// "binding" is the object to track our connection to the node (ie, the parameter to bindDomNode())
		var binding = {
			node: cn,
			iframe: iframe
		};
		node[this.id] = this._bindings.push(binding);

		// Setup the connections to monitor click etc., unless we are connecting to an iframe which hasn't finished
		// loading yet, in which case we need to wait for the onload event first, and then connect
		var doConnects = dojo.hitch(this, function(cn){
			return [
				dojo.connect(cn, (this.leftClickToOpen)?"onclick":"oncontextmenu", this, function(evt){
					this._openMyself(evt, cn, iframe);
				}),
				dojo.connect(cn, "onkeydown", this, "_contextKey"),
				dojo.connect(cn, "onmousedown", this, "_contextMouse")
			];
		});
		binding.connects = cn ? doConnects(cn) : [];

		if(iframe){
			// Setup handler to [re]bind to the iframe when the contents are initially loaded,
			// and every time the contents change.
			// Need to do this b/c we are actually binding to the iframe's <body> node.
			// Note: can't use dojo.connect(), see #9609.
			
			binding.onloadHandler = dojo.hitch(this, function(){
				// want to remove old connections, but IE throws exceptions when trying to
				// access the <body> node because it's already gone, or at least in a state of limbo

				var win = this._iframeContentWindow(iframe);
					cn = dojo.withGlobal(win, dojo.body);
				binding.connects = doConnects(cn);
			});
			if(iframe.addEventListener){
				iframe.addEventListener("load", binding.onloadHandler, false);
			}else{
				iframe.attachEvent("onload", binding.onloadHandler);
			}
		}
	},

	unBindDomNode: function(/*String|DomNode*/ nodeName){
		// summary:
		//		Detach menu from given node

		var node;
		try {
			node = dojo.byId(nodeName);
		}catch(e){
			// On IE the dojo.byId() call will get an exception if the attach point was
			// the <body> node of an <iframe> that has since been reloaded (and thus the
			// <body> node is in a limbo state of destruction.
			return;
		}

		if(node && node[this.id]){
			var bid = node[this.id]-1, b = this._bindings[bid];
			dojo.forEach(b.connects, dojo.disconnect);

			// Remove listener for iframe onload events
			var iframe = b.iframe;
			if(iframe){
				if(iframe.removeEventListener){
					iframe.removeEventListener("load", b.onloadHandler, false);
				}else{
					iframe.detachEvent("onload", b.onloadHandler);
				}
			}

			delete this._bindings[bid];
		}
	},

	_contextKey: function(e){
		// summary:
		//		Code to handle popping up editor using F10 key rather than mouse
		// tags:
		//		private
		this._contextMenuWithMouse = false;
		if(e.keyCode == dojo.keys.F10){
			dojo.stopEvent(e);
			if(e.shiftKey && e.type=="keydown"){
				// FF: copying the wrong property from e will cause the system
				// context menu to appear in spite of stopEvent. Don't know
				// exactly which properties cause this effect.
				var _e = { target: e.target, pageX: e.pageX, pageY: e.pageY };
				_e.preventDefault = _e.stopPropagation = function(){};
				// IE: without the delay, focus work in "open" causes the system
				// context menu to appear in spite of stopEvent.
				window.setTimeout(dojo.hitch(this, function(){ this._openMyself(_e); }), 1);
			}
		}
	},

	_contextMouse: function(e){
		// summary:
		//		Helper to remember when we opened the context menu with the mouse instead
		//		of with the keyboard
		// tags:
		//		private
		this._contextMenuWithMouse = true;
	},

	_openMyself: function(/*Event*/ e, /*DomNode?*/ node, /*DomNode?*/ iframe){
		// summary:
		//		Internal function for opening myself when the user
		//		does a right-click or something similar.
		// node:
		//		The node that is being clicked
		// iframe:
		//		If an <iframe> is being clicked, iframe points to that iframe and node
		//		points to the iframe's body.
		// tags:
		//		private

		if(this.leftClickToOpen&&e.button>0){
			return;
		}
		dojo.stopEvent(e);

		// Get coordinates.
		// If we are opening the menu with the mouse or on safari open
		// the menu at the mouse cursor
		// (Safari does not have a keyboard command to open the context menu
		// and we don't currently have a reliable way to determine
		// _contextMenuWithMouse on Safari)
		var x,y;
		if(dojo.isSafari || this._contextMenuWithMouse){
			x=e.pageX;
			y=e.pageY;
			
			if(iframe){
				// Event is on <body> node of an <iframe>, convert coordinates to match main document
				var od = e.target.ownerDocument,
					ifc = dojo.coords(iframe),
					win = this._iframeContentWindow(iframe),
					scroll = dojo.withGlobal(win, "_docScroll", dojo); 

				var cs = dojo.getComputedStyle(iframe),
					tp = dojo._toPixelValue,
					left = (dojo.isIE && dojo.isQuirks ? 0 : tp(iframe, cs.paddingLeft)) + (dojo.isIE && dojo.isQuirks ? tp(iframe, cs.borderLeftWidth) : 0) + tp(iframe, cs.marginLeft),
					top = (dojo.isIE && dojo.isQuirks ? 0 : tp(iframe, cs.paddingTop)) + (dojo.isIE && dojo.isQuirks ? tp(iframe, cs.borderTopWidth) : 0) + tp(iframe, cs.marginTop);

				x += ifc.l + left - scroll.x;
				y += ifc.t + top - scroll.y;
			}
		}else{
			// otherwise open near e.target
			var coords = dojo.coords(e.target, true);
			x = coords.x + 10;
			y = coords.y + 10;
		}

		var self=this;
		var savedFocus = dijit.getFocus(this);
		function closeAndRestoreFocus(){
			// user has clicked on a menu or popup
			dijit.focus(savedFocus);
			dijit.popup.close(self);
		}
		dijit.popup.open({
			popup: this,
			x: x,
			y: y,
			onExecute: closeAndRestoreFocus,
			onCancel: closeAndRestoreFocus,
			orient: this.isLeftToRight() ? 'L' : 'R'
		});
		this.focus();

		this._onBlur = function(){
			this.inherited('_onBlur', arguments);
			// Usually the parent closes the child widget but if this is a context
			// menu then there is no parent
			dijit.popup.close(this);
			// don't try to restore focus; user has clicked another part of the screen
			// and set focus there
		};
	},

	uninitialize: function(){
 		dojo.forEach(this._bindings, function(b){ if(b){ this.unBindDomNode(b.node); } }, this);
 		this.inherited(arguments);
	}
}
);

// Back-compat (TODO: remove in 2.0)






}

if(!dojo._hasResource["com.ibm.widgets.TimedMenu"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.widgets.TimedMenu"] = true;
dojo.provide("com.ibm.widgets.TimedMenu");

dojo.declare("com.ibm.widgets.TimedMenu",
			null,
			{
				_onHover: function() {
					this._enter();
				},
				_onUnhover: function() {
					this._exit();
				},
				_onNodeFocus: function(evt){
					this._enter();
					this.inherited(arguments);
				},
				_onNodeBlur: function(evt){
					this._exit();
					this.inherited(arguments);
				},
				_exit: function() {
					this._startCloseTimer();
					if(this.parentMenu && this.parentMenu._startCloseTimer) {
						// if we have a parent that has this function (ie, an instance of the same class),
						// tell it to start its timer too
						this.parentMenu._startCloseTimer();
					}
				},
				_enter: function() {
					this._stopCloseTimer();
				},
				_startCloseTimer: function() {
					// summary: Starts the timer to close this menu if it's not already set.
					//		Marks this menu to be closed and marks the parent menu to be closed too.
					if(!this._closeTimer) {
						this._isClosing = true;
						if(this.parentMenu) this.parentMenu._isClosing = true;
						if(this.closeDelay == 0) {
							this.close();
						} 
						else {
							this._closeTimer = setTimeout(dojo.hitch(this, function(){
								this._closeTimer = null;
								this.close();
							}), this.closeDelay);
						}
					}
				},
				_stopCloseTimer: function() {
					// summary: Stops the timer that closes this menu if it's set.
					//		Clears this menu from being closed and stops the parent
					//		from being closed if it exists.
					this._isClosing = false;
					if(this.parentMenu && this.parentMenu._stopCloseTimer) this.parentMenu._stopCloseTimer();
					if(this._closeTimer) {
						clearTimeout(this._closeTimer);
						this._closeTimer = null;
					}
				},
				canClose: function() {
					// summary: Indicates whether or not this menu can close right now.  Is
					//		used to keep menus from closing when they are editing or in other
					//		conditions.
					return true;
				},
				close: function() {
					// summary: Closes this menu upon the condition that the menu is still set for
					//		close when this is called (typically after some delay).  Will also
					//		call the parent's close function if it exists.
					if(this._isClosing && this.canClose())	{
						var parentMenu = this.parentMenu;
						this.closeAction();
						if(parentMenu && parentMenu.close) parentMenu.close();
					}
				},
				closeAction: function() {
					// summary: Closes this menu.  Can be overriden to animate the close operation or
					//		do something different.  Default is simply to close the menu.  Is called
					//		after delays have already been processed, so take care not to wait for
					//		the expected delay again unless that is the desired action.
					dijit.popup.close(this);
				}
			}
);

}

if(!dojo._hasResource["dojo.dnd.common"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.dnd.common"] = true;
dojo.provide("dojo.dnd.common");

dojo.dnd._isMac = navigator.appVersion.indexOf("Macintosh") >= 0;
dojo.dnd._copyKey = dojo.dnd._isMac ? "metaKey" : "ctrlKey";

dojo.dnd.getCopyKeyState = function(e) {
	// summary: abstracts away the difference between selection on Mac and PC,
	//	and returns the state of the "copy" key to be pressed.
	// e: Event: mouse event
	return e[dojo.dnd._copyKey];	// Boolean
};

dojo.dnd._uniqueId = 0;
dojo.dnd.getUniqueId = function(){
	// summary: returns a unique string for use with any DOM element
	var id;
	do{
		id = dojo._scopeName + "Unique" + (++dojo.dnd._uniqueId);
	}while(dojo.byId(id));
	return id;
};

dojo.dnd._empty = {};

dojo.dnd.isFormElement = function(/*Event*/ e){
	// summary: returns true, if user clicked on a form element
	var t = e.target;
	if(t.nodeType == 3 /*TEXT_NODE*/){
		t = t.parentNode;
	}
	return " button textarea input select option ".indexOf(" " + t.tagName.toLowerCase() + " ") >= 0;	// Boolean
};

// doesn't take into account when multiple buttons are pressed
dojo.dnd._lmb = dojo.isIE ? 1 : 0;	// left mouse button

dojo.dnd._isLmbPressed = dojo.isIE ?
	function(e){ return e.button & 1; } : // intentional bit-and
	function(e){ return e.button === 0; };

}

if(!dojo._hasResource["dojo.dnd.Container"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.dnd.Container"] = true;
dojo.provide("dojo.dnd.Container");




/*
	Container states:
		""		- normal state
		"Over"	- mouse over a container
	Container item states:
		""		- normal state
		"Over"	- mouse over a container item
*/

dojo.declare("dojo.dnd.Container", null, {
	// summary: a Container object, which knows when mouse hovers over it, 
	//	and over which element it hovers
	
	// object attributes (for markup)
	skipForm: false,
	
	constructor: function(node, params){
		// summary: a constructor of the Container
		// node: Node: node or node's id to build the container on
		// params: Object: a dict of parameters, recognized parameters are:
		//	creator: Function: a creator function, which takes a data item, and returns an object like that:
		//		{node: newNode, data: usedData, type: arrayOfStrings}
		//	skipForm: Boolean: don't start the drag operation, if clicked on form elements
		//	dropParent: Node: node or node's id to use as the parent node for dropped items
		//		(must be underneath the 'node' parameter in the DOM)
		//	_skipStartup: Boolean: skip startup(), which collects children, for deferred initialization
		//		(this is used in the markup mode)
		this.node = dojo.byId(node);
		if(!params){ params = {}; }
		this.creator = params.creator || null;
		this.skipForm = params.skipForm;
		this.parent = params.dropParent && dojo.byId(params.dropParent);
		
		// class-specific variables
		this.map = {};
		this.current = null;

		// states
		this.containerState = "";
		dojo.addClass(this.node, "dojoDndContainer");
		
		// mark up children
		if(!(params && params._skipStartup)){
			this.startup();
		}

		// set up events
		this.events = [
			dojo.connect(this.node, "onmouseover", this, "onMouseOver"),
			dojo.connect(this.node, "onmouseout",  this, "onMouseOut"),
			// cancel text selection and text dragging
			dojo.connect(this.node, "ondragstart",   this, "onSelectStart"),
			dojo.connect(this.node, "onselectstart", this, "onSelectStart")
		];
	},
	
	// object attributes (for markup)
	creator: function(){},	// creator function, dummy at the moment
	
	// abstract access to the map
	getItem: function(/*String*/ key){
		// summary: returns a data item by its key (id)
		return this.map[key];	// Object
	},
	setItem: function(/*String*/ key, /*Object*/ data){
		// summary: associates a data item with its key (id)
		this.map[key] = data;
	},
	delItem: function(/*String*/ key){
		// summary: removes a data item from the map by its key (id)
		delete this.map[key];
	},
	forInItems: function(/*Function*/ f, /*Object?*/ o){
		// summary: iterates over a data map skipping members, which 
		//	are present in the empty object (IE and/or 3rd-party libraries).
		o = o || dojo.global;
		var m = this.map, e = dojo.dnd._empty;
		for(var i in m){
			if(i in e){ continue; }
			f.call(o, m[i], i, this);
		}
		return o;	// Object
	},
	clearItems: function(){
		// summary: removes all data items from the map
		this.map = {};
	},
	
	// methods
	getAllNodes: function(){
		// summary: returns a list (an array) of all valid child nodes
		return dojo.query("> .dojoDndItem", this.parent);	// NodeList
	},
	sync: function(){
		// summary: synch up the node list with the data map
		var map = {};
		this.getAllNodes().forEach(function(node){
			if(node.id){
				var item = this.getItem(node.id);
				if(item){
					map[node.id] = item;
					return;
				}
			}else{
				node.id = dojo.dnd.getUniqueId();
			}
			var type = node.getAttribute("dndType"),
				data = node.getAttribute("dndData");
			map[node.id] = {
				data: data || node.innerHTML,
				type: type ? type.split(/\s*,\s*/) : ["text"]
			};
		}, this);
		this.map = map;
		return this;	// self
	},
	insertNodes: function(data, before, anchor){
		// summary: inserts an array of new nodes before/after an anchor node
		// data: Array: a list of data items, which should be processed by the creator function
		// before: Boolean: insert before the anchor, if true, and after the anchor otherwise
		// anchor: Node: the anchor node to be used as a point of insertion
		if(!this.parent.firstChild){
			anchor = null;
		}else if(before){
			if(!anchor){
				anchor = this.parent.firstChild;
			}
		}else{
			if(anchor){
				anchor = anchor.nextSibling;
			}
		}
		if(anchor){
			for(var i = 0; i < data.length; ++i){
				var t = this._normalizedCreator(data[i]);
				this.setItem(t.node.id, {data: t.data, type: t.type});
				this.parent.insertBefore(t.node, anchor);
			}
		}else{
			for(var i = 0; i < data.length; ++i){
				var t = this._normalizedCreator(data[i]);
				this.setItem(t.node.id, {data: t.data, type: t.type});
				this.parent.appendChild(t.node);
			}
		}
		return this;	// self
	},
	destroy: function(){
		// summary: prepares the object to be garbage-collected
		dojo.forEach(this.events, dojo.disconnect);
		this.clearItems();
		this.node = this.parent = this.current = null;
	},

	// markup methods
	markupFactory: function(params, node){
		params._skipStartup = true;
		return new dojo.dnd.Container(node, params);
	},
	startup: function(){
		// summary: collects valid child items and populate the map
		
		// set up the real parent node
		if(!this.parent){
			// use the standard algorithm, if not assigned
			this.parent = this.node;
			if(this.parent.tagName.toLowerCase() == "table"){
				var c = this.parent.getElementsByTagName("tbody");
				if(c && c.length){ this.parent = c[0]; }
			}
		}
		this.defaultCreator = dojo.dnd._defaultCreator(this.parent);

		// process specially marked children
		this.sync();
	},

	// mouse events
	onMouseOver: function(e){
		// summary: event processor for onmouseover
		// e: Event: mouse event
		var n = e.relatedTarget;
		while(n){
			if(n == this.node){ break; }
			try{
				n = n.parentNode;
			}catch(x){
				n = null;
			}
		}
		if(!n){
			this._changeState("Container", "Over");
			this.onOverEvent();
		}
		n = this._getChildByEvent(e);
		if(this.current == n){ return; }
		if(this.current){ this._removeItemClass(this.current, "Over"); }
		if(n){ this._addItemClass(n, "Over"); }
		this.current = n;
	},
	onMouseOut: function(e){
		// summary: event processor for onmouseout
		// e: Event: mouse event
		for(var n = e.relatedTarget; n;){
			if(n == this.node){ return; }
			try{
				n = n.parentNode;
			}catch(x){
				n = null;
			}
		}
		if(this.current){
			this._removeItemClass(this.current, "Over");
			this.current = null;
		}
		this._changeState("Container", "");
		this.onOutEvent();
	},
	onSelectStart: function(e){
		// summary: event processor for onselectevent and ondragevent
		// e: Event: mouse event
		if(!this.skipForm || !dojo.dnd.isFormElement(e)){
			dojo.stopEvent(e);
		}
	},
	
	// utilities
	onOverEvent: function(){
		// summary: this function is called once, when mouse is over our container
	},
	onOutEvent: function(){
		// summary: this function is called once, when mouse is out of our container
	},
	_changeState: function(type, newState){
		// summary: changes a named state to new state value
		// type: String: a name of the state to change
		// newState: String: new state
		var prefix = "dojoDnd" + type;
		var state  = type.toLowerCase() + "State";
		//dojo.replaceClass(this.node, prefix + newState, prefix + this[state]);
		dojo.removeClass(this.node, prefix + this[state]);
		dojo.addClass(this.node, prefix + newState);
		this[state] = newState;
	},
	_addItemClass: function(node, type){
		// summary: adds a class with prefix "dojoDndItem"
		// node: Node: a node
		// type: String: a variable suffix for a class name
		dojo.addClass(node, "dojoDndItem" + type);
	},
	_removeItemClass: function(node, type){
		// summary: removes a class with prefix "dojoDndItem"
		// node: Node: a node
		// type: String: a variable suffix for a class name
		dojo.removeClass(node, "dojoDndItem" + type);
	},
	_getChildByEvent: function(e){
		// summary: gets a child, which is under the mouse at the moment, or null
		// e: Event: a mouse event
		var node = e.target;
		if(node){
			for(var parent = node.parentNode; parent; node = parent, parent = node.parentNode){
				if(parent == this.parent && dojo.hasClass(node, "dojoDndItem")){ return node; }
			}
		}
		return null;
	},
	_normalizedCreator: function(item, hint){
		// summary: adds all necessary data to the output of the user-supplied creator function
		var t = (this.creator || this.defaultCreator).call(this, item, hint);
		if(!dojo.isArray(t.type)){ t.type = ["text"]; }
		if(!t.node.id){ t.node.id = dojo.dnd.getUniqueId(); }
		dojo.addClass(t.node, "dojoDndItem");
		return t;
	}
});

dojo.dnd._createNode = function(tag){
	// summary: returns a function, which creates an element of given tag 
	//	(SPAN by default) and sets its innerHTML to given text
	// tag: String: a tag name or empty for SPAN
	if(!tag){ return dojo.dnd._createSpan; }
	return function(text){	// Function
		return dojo.create(tag, {innerHTML: text});	// Node
	};
};

dojo.dnd._createTrTd = function(text){
	// summary: creates a TR/TD structure with given text as an innerHTML of TD
	// text: String: a text for TD
	var tr = dojo.create("tr");
	dojo.create("td", {innerHTML: text}, tr);
	return tr;	// Node
};

dojo.dnd._createSpan = function(text){
	// summary: creates a SPAN element with given text as its innerHTML
	// text: String: a text for SPAN
	return dojo.create("span", {innerHTML: text});	// Node
};

// dojo.dnd._defaultCreatorNodes: Object: a dicitionary, which maps container tag names to child tag names
dojo.dnd._defaultCreatorNodes = {ul: "li", ol: "li", div: "div", p: "div"};

dojo.dnd._defaultCreator = function(node){
	// summary: takes a parent node, and returns an appropriate creator function
	// node: Node: a container node
	var tag = node.tagName.toLowerCase();
	var c = tag == "tbody" || tag == "thead" ? dojo.dnd._createTrTd :
			dojo.dnd._createNode(dojo.dnd._defaultCreatorNodes[tag]);
	return function(item, hint){	// Function
		var isObj = item && dojo.isObject(item), data, type, n;
		if(isObj && item.tagName && item.nodeType && item.getAttribute){
			// process a DOM node
			data = item.getAttribute("dndData") || item.innerHTML;
			type = item.getAttribute("dndType");
			type = type ? type.split(/\s*,\s*/) : ["text"];
			n = item;	// this node is going to be moved rather than copied
		}else{
			// process a DnD item object or a string
			data = (isObj && item.data) ? item.data : item;
			type = (isObj && item.type) ? item.type : ["text"];
			n = (hint == "avatar" ? dojo.dnd._createSpan : c)(String(data));
		}
		n.id = dojo.dnd.getUniqueId();
		return {node: n, data: data, type: type};
	};
};

}

if(!dojo._hasResource["dojo.dnd.Selector"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.dnd.Selector"] = true;
dojo.provide("dojo.dnd.Selector");




/*
	Container item states:
		""			- an item is not selected
		"Selected"	- an item is selected
		"Anchor"	- an item is selected, and is an anchor for a "shift" selection
*/

dojo.declare("dojo.dnd.Selector", dojo.dnd.Container, {
	// summary: a Selector object, which knows how to select its children
	
	constructor: function(node, params){
		// summary: a constructor of the Selector
		// node: Node: node or node's id to build the selector on
		// params: Object: a dict of parameters, recognized parameters are:
		//	singular: Boolean
		//		allows selection of only one element, if true
		//		the rest of parameters are passed to the container
		//	autoSync: Boolean
		//		autosynchronizes the source with its list of DnD nodes,
		//		false by default
		if(!params){ params = {}; }
		this.singular = params.singular;
		this.autoSync = params.autoSync;
		// class-specific variables
		this.selection = {};
		this.anchor = null;
		this.simpleSelection = false;
		// set up events
		this.events.push(
			dojo.connect(this.node, "onmousedown", this, "onMouseDown"),
			dojo.connect(this.node, "onmouseup",   this, "onMouseUp"));
	},
	
	// object attributes (for markup)
	singular: false,	// is singular property
	
	// methods
	getSelectedNodes: function(){
		// summary: returns a list (an array) of selected nodes
		var t = new dojo.NodeList();
		var e = dojo.dnd._empty;
		for(var i in this.selection){
			if(i in e){ continue; }
			t.push(dojo.byId(i));
		}
		return t;	// Array
	},
	selectNone: function(){
		// summary: unselects all items
		return this._removeSelection()._removeAnchor();	// self
	},
	selectAll: function(){
		// summary: selects all items
		this.forInItems(function(data, id){
			this._addItemClass(dojo.byId(id), "Selected");
			this.selection[id] = 1;
		}, this);
		return this._removeAnchor();	// self
	},
	deleteSelectedNodes: function(){
		// summary: deletes all selected items
		var e = dojo.dnd._empty;
		for(var i in this.selection){
			if(i in e){ continue; }
			var n = dojo.byId(i);
			this.delItem(i);
			dojo.destroy(n);
		}
		this.anchor = null;
		this.selection = {};
		return this;	// self
	},
	forInSelectedItems: function(/*Function*/ f, /*Object?*/ o){
		// summary: iterates over selected items,
		// see dojo.dnd.Container.forInItems() for details
		o = o || dojo.global;
		var s = this.selection, e = dojo.dnd._empty;
		for(var i in s){
			if(i in e){ continue; }
			f.call(o, this.getItem(i), i, this);
		}
	},
	sync: function(){
		// summary: synch up the node list with the data map
		
		dojo.dnd.Selector.superclass.sync.call(this);
		
		// fix the anchor
		if(this.anchor){
			if(!this.getItem(this.anchor.id)){
				this.anchor = null;
			}
		}
		
		// fix the selection
		var t = [], e = dojo.dnd._empty;
		for(var i in this.selection){
			if(i in e){ continue; }
			if(!this.getItem(i)){
				t.push(i);
			}
		}
		dojo.forEach(t, function(i){
			delete this.selection[i];
		}, this);
		
		return this;	// self
	},
	insertNodes: function(addSelected, data, before, anchor){
		// summary: inserts new data items (see Container's insertNodes method for details)
		// addSelected: Boolean: all new nodes will be added to selected items, if true, no selection change otherwise
		// data: Array: a list of data items, which should be processed by the creator function
		// before: Boolean: insert before the anchor, if true, and after the anchor otherwise
		// anchor: Node: the anchor node to be used as a point of insertion
		var oldCreator = this._normalizedCreator;
		this._normalizedCreator = function(item, hint){
			var t = oldCreator.call(this, item, hint);
			if(addSelected){
				if(!this.anchor){
					this.anchor = t.node;
					this._removeItemClass(t.node, "Selected");
					this._addItemClass(this.anchor, "Anchor");
				}else if(this.anchor != t.node){
					this._removeItemClass(t.node, "Anchor");
					this._addItemClass(t.node, "Selected");
				}
				this.selection[t.node.id] = 1;
			}else{
				this._removeItemClass(t.node, "Selected");
				this._removeItemClass(t.node, "Anchor");
			}
			return t;
		};
		dojo.dnd.Selector.superclass.insertNodes.call(this, data, before, anchor);
		this._normalizedCreator = oldCreator;
		return this;	// self
	},
	destroy: function(){
		// summary: prepares the object to be garbage-collected
		dojo.dnd.Selector.superclass.destroy.call(this);
		this.selection = this.anchor = null;
	},

	// markup methods
	markupFactory: function(params, node){
		params._skipStartup = true;
		return new dojo.dnd.Selector(node, params);
	},

	// mouse events
	onMouseDown: function(e){
		// summary: event processor for onmousedown
		// e: Event: mouse event
		if(this.autoSync){ this.sync(); }
		if(!this.current){ return; }
		if(!this.singular && !dojo.dnd.getCopyKeyState(e) && !e.shiftKey && (this.current.id in this.selection)){
			this.simpleSelection = true;
			if(e.button === dojo.dnd._lmb){
				// accept the left button and stop the event
				// for IE we don't stop event when multiple buttons are pressed
				dojo.stopEvent(e);
			}
			return;
		}
		if(!this.singular && e.shiftKey){
			if(!dojo.dnd.getCopyKeyState(e)){
				this._removeSelection();
			}
			var c = this.getAllNodes();
			if(c.length){
				if(!this.anchor){
					this.anchor = c[0];
					this._addItemClass(this.anchor, "Anchor");
				}
				this.selection[this.anchor.id] = 1;
				if(this.anchor != this.current){
					var i = 0;
					for(; i < c.length; ++i){
						var node = c[i];
						if(node == this.anchor || node == this.current){ break; }
					}
					for(++i; i < c.length; ++i){
						var node = c[i];
						if(node == this.anchor || node == this.current){ break; }
						this._addItemClass(node, "Selected");
						this.selection[node.id] = 1;
					}
					this._addItemClass(this.current, "Selected");
					this.selection[this.current.id] = 1;
				}
			}
		}else{
			if(this.singular){
				if(this.anchor == this.current){
					if(dojo.dnd.getCopyKeyState(e)){
						this.selectNone();
					}
				}else{
					this.selectNone();
					this.anchor = this.current;
					this._addItemClass(this.anchor, "Anchor");
					this.selection[this.current.id] = 1;
				}
			}else{
				if(dojo.dnd.getCopyKeyState(e)){
					if(this.anchor == this.current){
						delete this.selection[this.anchor.id];
						this._removeAnchor();
					}else{
						if(this.current.id in this.selection){
							this._removeItemClass(this.current, "Selected");
							delete this.selection[this.current.id];
						}else{
							if(this.anchor){
								this._removeItemClass(this.anchor, "Anchor");
								this._addItemClass(this.anchor, "Selected");
							}
							this.anchor = this.current;
							this._addItemClass(this.current, "Anchor");
							this.selection[this.current.id] = 1;
						}
					}
				}else{
					if(!(this.current.id in this.selection)){
						this.selectNone();
						this.anchor = this.current;
						this._addItemClass(this.current, "Anchor");
						this.selection[this.current.id] = 1;
					}
				}
			}
		}
		dojo.stopEvent(e);
	},
	onMouseUp: function(e){
		// summary: event processor for onmouseup
		// e: Event: mouse event
		if(!this.simpleSelection){ return; }
		this.simpleSelection = false;
		this.selectNone();
		if(this.current){
			this.anchor = this.current;
			this._addItemClass(this.anchor, "Anchor");
			this.selection[this.current.id] = 1;
		}
	},
	onMouseMove: function(e){
		// summary: event processor for onmousemove
		// e: Event: mouse event
		this.simpleSelection = false;
	},
	
	// utilities
	onOverEvent: function(){
		// summary: this function is called once, when mouse is over our container
		this.onmousemoveEvent = dojo.connect(this.node, "onmousemove", this, "onMouseMove");
	},
	onOutEvent: function(){
		// summary: this function is called once, when mouse is out of our container
		dojo.disconnect(this.onmousemoveEvent);
		delete this.onmousemoveEvent;
	},
	_removeSelection: function(){
		// summary: unselects all items
		var e = dojo.dnd._empty;
		for(var i in this.selection){
			if(i in e){ continue; }
			var node = dojo.byId(i);
			if(node){ this._removeItemClass(node, "Selected"); }
		}
		this.selection = {};
		return this;	// self
	},
	_removeAnchor: function(){
		if(this.anchor){
			this._removeItemClass(this.anchor, "Anchor");
			this.anchor = null;
		}
		return this;	// self
	}
});

}

if(!dojo._hasResource["dojo.dnd.autoscroll"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.dnd.autoscroll"] = true;
dojo.provide("dojo.dnd.autoscroll");

dojo.dnd.getViewport = function(){
	// summary: returns a viewport size (visible part of the window)

	// FIXME: need more docs!!
	var d = dojo.doc, dd = d.documentElement, w = window, b = dojo.body();
	if(dojo.isMozilla){
		return {w: dd.clientWidth, h: w.innerHeight};	// Object
	}else if(!dojo.isOpera && w.innerWidth){
		return {w: w.innerWidth, h: w.innerHeight};		// Object
	}else if (!dojo.isOpera && dd && dd.clientWidth){
		return {w: dd.clientWidth, h: dd.clientHeight};	// Object
	}else if (b.clientWidth){
		return {w: b.clientWidth, h: b.clientHeight};	// Object
	}
	return null;	// Object
};

dojo.dnd.V_TRIGGER_AUTOSCROLL = 32;
dojo.dnd.H_TRIGGER_AUTOSCROLL = 32;

dojo.dnd.V_AUTOSCROLL_VALUE = 16;
dojo.dnd.H_AUTOSCROLL_VALUE = 16;

dojo.dnd.autoScroll = function(e){
	// summary:
	//		a handler for onmousemove event, which scrolls the window, if
	//		necesary
	// e: Event:
	//		onmousemove event

	// FIXME: needs more docs!
	var v = dojo.dnd.getViewport(), dx = 0, dy = 0;
	if(e.clientX < dojo.dnd.H_TRIGGER_AUTOSCROLL){
		dx = -dojo.dnd.H_AUTOSCROLL_VALUE;
	}else if(e.clientX > v.w - dojo.dnd.H_TRIGGER_AUTOSCROLL){
		dx = dojo.dnd.H_AUTOSCROLL_VALUE;
	}
	if(e.clientY < dojo.dnd.V_TRIGGER_AUTOSCROLL){
		dy = -dojo.dnd.V_AUTOSCROLL_VALUE;
	}else if(e.clientY > v.h - dojo.dnd.V_TRIGGER_AUTOSCROLL){
		dy = dojo.dnd.V_AUTOSCROLL_VALUE;
	}
	window.scrollBy(dx, dy);
};

dojo.dnd._validNodes = {"div": 1, "p": 1, "td": 1};
dojo.dnd._validOverflow = {"auto": 1, "scroll": 1};

dojo.dnd.autoScrollNodes = function(e){
	// summary:
	//		a handler for onmousemove event, which scrolls the first avaialble
	//		Dom element, it falls back to dojo.dnd.autoScroll()
	// e: Event:
	//		onmousemove event

	// FIXME: needs more docs!
	for(var n = e.target; n;){
		if(n.nodeType == 1 && (n.tagName.toLowerCase() in dojo.dnd._validNodes)){
			var s = dojo.getComputedStyle(n);
			if(s.overflow.toLowerCase() in dojo.dnd._validOverflow){
				var b = dojo._getContentBox(n, s), t = dojo._abs(n, true);
				//
				var w = Math.min(dojo.dnd.H_TRIGGER_AUTOSCROLL, b.w / 2), 
					h = Math.min(dojo.dnd.V_TRIGGER_AUTOSCROLL, b.h / 2),
					rx = e.pageX - t.x, ry = e.pageY - t.y, dx = 0, dy = 0;
				if(dojo.isWebKit || dojo.isOpera){
					// FIXME: this code should not be here, it should be taken into account 
					// either by the event fixing code, or the dojo._abs()
					// FIXME: this code doesn't work on Opera 9.5 Beta
					rx += dojo.body().scrollLeft, ry += dojo.body().scrollTop;
				}
				if(rx > 0 && rx < b.w){
					if(rx < w){
						dx = -w;
					}else if(rx > b.w - w){
						dx = w;
					}
				}
				//
				if(ry > 0 && ry < b.h){
					if(ry < h){
						dy = -h;
					}else if(ry > b.h - h){
						dy = h;
					}
				}
				var oldLeft = n.scrollLeft, oldTop = n.scrollTop;
				n.scrollLeft = n.scrollLeft + dx;
				n.scrollTop  = n.scrollTop  + dy;
				if(oldLeft != n.scrollLeft || oldTop != n.scrollTop){ return; }
			}
		}
		try{
			n = n.parentNode;
		}catch(x){
			n = null;
		}
	}
	dojo.dnd.autoScroll(e);
};

}

if(!dojo._hasResource["dojo.dnd.Avatar"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.dnd.Avatar"] = true;
dojo.provide("dojo.dnd.Avatar");



dojo.declare("dojo.dnd.Avatar", null, {
	// summary: an object, which represents transferred DnD items visually
	// manager: Object: a DnD manager object

	constructor: function(manager){
		this.manager = manager;
		this.construct();
	},

	// methods
	construct: function(){
		// summary: a constructor function;
		//	it is separate so it can be (dynamically) overwritten in case of need
		this.isA11y = dojo.hasClass(dojo.body(),"dijit_a11y");
		var a = dojo.create("table", {
				"class": "dojoDndAvatar",
				style: {
					position: "absolute",
					zIndex:   "1999",
					margin:   "0px"
				}
			}),
			source = this.manager.source, node,
			b = dojo.create("tbody", null, a),
			tr = dojo.create("tr", null, b),
			td = dojo.create("td", null, tr),
			icon = this.isA11y ? dojo.create("span", {
						id : "a11yIcon",
						innerHTML : this.manager.copy ? '+' : "<"
					}, td) : null,
			span = dojo.create("span", {
				innerHTML: source.generateText ? this._generateText() : ""
			}, td),
			k = Math.min(5, this.manager.nodes.length), i = 0;
		// we have to set the opacity on IE only after the node is live
		dojo.attr(tr, {
			"class": "dojoDndAvatarHeader",
			style: {opacity: 0.9}
		});
		for(; i < k; ++i){
			if(source.creator){
				// create an avatar representation of the node
				node = source._normalizedCreator(source.getItem(this.manager.nodes[i].id).data, "avatar").node;
			}else{
				// or just clone the node and hope it works
				node = this.manager.nodes[i].cloneNode(true);
				if(node.tagName.toLowerCase() == "tr"){
					// insert extra table nodes
					var table = dojo.create("table"),
						tbody = dojo.create("tbody", null, table);
					tbody.appendChild(node);
					node = table;
				}
			}
			node.id = "";
			tr = dojo.create("tr", null, b);
			td = dojo.create("td", null, tr);
			td.appendChild(node);
			dojo.attr(tr, {
				"class": "dojoDndAvatarItem",
				style: {opacity: (9 - i) / 10}
			});
		}
		this.node = a;
	},
	destroy: function(){
		// summary: a desctructor for the avatar, called to remove all references so it can be garbage-collected
		dojo.destroy(this.node);
		this.node = false;
	},
	update: function(){
		// summary: updates the avatar to reflect the current DnD state
		dojo[(this.manager.canDropFlag ? "add" : "remove") + "Class"](this.node, "dojoDndAvatarCanDrop");
		if (this.isA11y){
			var icon = dojo.byId("a11yIcon");
			var text = '+';   // assume canDrop && copy
			if (this.manager.canDropFlag && !this.manager.copy) {
				text = '< '; // canDrop && move 
			}else if (!this.manager.canDropFlag && !this.manager.copy) {
				text = "o"; //!canDrop && move
			}else if(!this.manager.canDropFlag){
				text = 'x';  // !canDrop && copy
			}
			icon.innerHTML=text;
		}
		// replace text
		dojo.query(("tr.dojoDndAvatarHeader td span" +(this.isA11y ? " span" : "")), this.node).forEach(
			function(node){
				node.innerHTML = this._generateText();
			}, this);
	},
	_generateText: function(){
		// summary: generates a proper text to reflect copying or moving of items
		return this.manager.nodes.length.toString();
	}
});

}

if(!dojo._hasResource["dojo.dnd.Manager"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.dnd.Manager"] = true;
dojo.provide("dojo.dnd.Manager");





dojo.declare("dojo.dnd.Manager", null, {
	// summary: the manager of DnD operations (usually a singleton)
	constructor: function(){
		this.avatar  = null;
		this.source = null;
		this.nodes = [];
		this.copy  = true;
		this.target = null;
		this.canDropFlag = false;
		this.events = [];
	},

	// avatar's offset from the mouse
	OFFSET_X: 16,
	OFFSET_Y: 16,
	
	// methods
	overSource: function(source){
		// summary: called when a source detected a mouse-over conditiion
		// source: Object: the reporter
		if(this.avatar){
			this.target = (source && source.targetState != "Disabled") ? source : null;
			this.canDropFlag = Boolean(this.target);
			this.avatar.update();
		}
		dojo.publish("/dnd/source/over", [source]);
	},
	outSource: function(source){
		// summary: called when a source detected a mouse-out conditiion
		// source: Object: the reporter
		if(this.avatar){
			if(this.target == source){
				this.target = null;
				this.canDropFlag = false;
				this.avatar.update();
				dojo.publish("/dnd/source/over", [null]);
			}
		}else{
			dojo.publish("/dnd/source/over", [null]);
		}
	},
	startDrag: function(source, nodes, copy){
		// summary: called to initiate the DnD operation
		// source: Object: the source which provides items
		// nodes: Array: the list of transferred items
		// copy: Boolean: copy items, if true, move items otherwise
		this.source = source;
		this.nodes  = nodes;
		this.copy   = Boolean(copy); // normalizing to true boolean
		this.avatar = this.makeAvatar();
		dojo.body().appendChild(this.avatar.node);
		dojo.publish("/dnd/start", [source, nodes, this.copy]);
		this.events = [
			dojo.connect(dojo.doc, "onmousemove", this, "onMouseMove"),
			dojo.connect(dojo.doc, "onmouseup",   this, "onMouseUp"),
			dojo.connect(dojo.doc, "onkeydown",   this, "onKeyDown"),
			dojo.connect(dojo.doc, "onkeyup",     this, "onKeyUp"),
			// cancel text selection and text dragging
			dojo.connect(dojo.doc, "ondragstart",   dojo.stopEvent),
			dojo.connect(dojo.body(), "onselectstart", dojo.stopEvent)
		];
		var c = "dojoDnd" + (copy ? "Copy" : "Move");
		dojo.addClass(dojo.body(), c); 
	},
	canDrop: function(flag){
		// summary: called to notify if the current target can accept items
		var canDropFlag = Boolean(this.target && flag);
		if(this.canDropFlag != canDropFlag){
			this.canDropFlag = canDropFlag;
			this.avatar.update();
		}
	},
	stopDrag: function(){
		// summary: stop the DnD in progress
		dojo.removeClass(dojo.body(), "dojoDndCopy");
		dojo.removeClass(dojo.body(), "dojoDndMove");
		dojo.forEach(this.events, dojo.disconnect);
		this.events = [];
		this.avatar.destroy();
		this.avatar = null;
		this.source = this.target = null;
		this.nodes = [];
	},
	makeAvatar: function(){
		// summary: makes the avatar, it is separate to be overwritten dynamically, if needed
		return new dojo.dnd.Avatar(this);
	},
	updateAvatar: function(){
		// summary: updates the avatar, it is separate to be overwritten dynamically, if needed
		this.avatar.update();
	},
	
	// mouse event processors
	onMouseMove: function(e){
		// summary: event processor for onmousemove
		// e: Event: mouse event
		var a = this.avatar;
		if(a){
			dojo.dnd.autoScrollNodes(e);
			//dojo.dnd.autoScroll(e);
			var s = a.node.style;
			s.left = (e.pageX + this.OFFSET_X) + "px";
			s.top  = (e.pageY + this.OFFSET_Y) + "px";
			var copy = Boolean(this.source.copyState(dojo.dnd.getCopyKeyState(e)));
			if(this.copy != copy){ 
				this._setCopyStatus(copy);
			}
		}
	},
	onMouseUp: function(e){
		// summary: event processor for onmouseup
		// e: Event: mouse event
		if(this.avatar){
			if(this.target && this.canDropFlag){
				var copy = Boolean(this.source.copyState(dojo.dnd.getCopyKeyState(e))),
				params = [this.source, this.nodes, copy, this.target];
				dojo.publish("/dnd/drop/before", params);
				dojo.publish("/dnd/drop", params);
			}else{
				dojo.publish("/dnd/cancel");
			}
			this.stopDrag();
		}
	},
	
	// keyboard event processors
	onKeyDown: function(e){
		// summary: event processor for onkeydown:
		//	watching for CTRL for copy/move status, watching for ESCAPE to cancel the drag
		// e: Event: keyboard event
		if(this.avatar){
			switch(e.keyCode){
				case dojo.keys.CTRL:
					var copy = Boolean(this.source.copyState(true));
					if(this.copy != copy){ 
						this._setCopyStatus(copy);
					}
					break;
				case dojo.keys.ESCAPE:
					dojo.publish("/dnd/cancel");
					this.stopDrag();
					break;
			}
		}
	},
	onKeyUp: function(e){
		// summary: event processor for onkeyup, watching for CTRL for copy/move status
		// e: Event: keyboard event
		if(this.avatar && e.keyCode == dojo.keys.CTRL){
			var copy = Boolean(this.source.copyState(false));
			if(this.copy != copy){ 
				this._setCopyStatus(copy);
			}
		}
	},
	
	// utilities
	_setCopyStatus: function(copy){
		// summary: changes the copy status
		// copy: Boolean: the copy status
		this.copy = copy;
		this.source._markDndStatus(this.copy);
		this.updateAvatar();
		dojo.removeClass(dojo.body(), "dojoDnd" + (this.copy ? "Move" : "Copy"));
		dojo.addClass(dojo.body(), "dojoDnd" + (this.copy ? "Copy" : "Move"));
	}
});

// summary: the manager singleton variable, can be overwritten, if needed
dojo.dnd._manager = null;

dojo.dnd.manager = function(){
	// summary: returns the current DnD manager, creates one if it is not created yet
	if(!dojo.dnd._manager){
		dojo.dnd._manager = new dojo.dnd.Manager();
	}
	return dojo.dnd._manager;	// Object
};

}

if(!dojo._hasResource["dojo.dnd.Source"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.dnd.Source"] = true;
dojo.provide("dojo.dnd.Source");




/*
	Container property:
		"Horizontal"- if this is the horizontal container
	Source states:
		""			- normal state
		"Moved"		- this source is being moved
		"Copied"	- this source is being copied
	Target states:
		""			- normal state
		"Disabled"	- the target cannot accept an avatar
	Target anchor state:
		""			- item is not selected
		"Before"	- insert point is before the anchor
		"After"		- insert point is after the anchor
*/

/*=====
dojo.dnd.__SourceArgs = function(){
	//	summary:
	//		a dict of parameters for DnD Source configuration. Note that any
	//		property on Source elements may be configured, but this is the
	//		short-list
	//	isSource: Boolean?
	//		can be used as a DnD source. Defaults to true.
	//	accept: Array?
	//		list of accepted types (text strings) for a target; defaults to
	//		["text"]
	//	autoSync: Boolean
	//		if true refreshes the node list on every operation; false by default
	//	copyOnly: Boolean?
	//		copy items, if true, use a state of Ctrl key otherwise,
	//		see selfCopy and selfAccept for more details
	//	delay: Number
	//		the move delay in pixels before detecting a drag; 0 by default
	//	horizontal: Boolean?
	//		a horizontal container, if true, vertical otherwise or when omitted
	//	selfCopy: Boolean?
	//		copy items by default when dropping on itself,
	//		false by default, works only if copyOnly is true
	//	selfAccept: Boolean?
	//		accept its own items when copyOnly is true,
	//		true by default, works only if copyOnly is true
	//	withHandles: Boolean?
	//		allows dragging only by handles, false by default
	//  generateText: Boolean?
	//		generate text node for drag and drop, true by default
	this.isSource = isSource;
	this.accept = accept;
	this.autoSync = autoSync;
	this.copyOnly = copyOnly;
	this.delay = delay;
	this.horizontal = horizontal;
	this.selfCopy = selfCopy;
	this.selfAccept = selfAccept;
	this.withHandles = withHandles;
	this.genertateText = true;
}
=====*/

dojo.declare("dojo.dnd.Source", dojo.dnd.Selector, {
	// summary: a Source object, which can be used as a DnD source, or a DnD target
	
	// object attributes (for markup)
	isSource: true,
	horizontal: false,
	copyOnly: false,
	selfCopy: false,
	selfAccept: true,
	skipForm: false,
	withHandles: false,
	autoSync: false,
	delay: 0, // pixels
	accept: ["text"],
	generateText: true,
	
	constructor: function(/*DOMNode|String*/node, /*dojo.dnd.__SourceArgs?*/params){
		// summary: 
		//		a constructor of the Source
		// node:
		//		node or node's id to build the source on
		// params: 
		//		any property of this class may be configured via the params
		//		object which is mixed-in to the `dojo.dnd.Source` instance
		dojo.mixin(this, dojo.mixin({}, params));
		var type = this.accept;
		if(type.length){
			this.accept = {};
			for(var i = 0; i < type.length; ++i){
				this.accept[type[i]] = 1;
			}
		}
		// class-specific variables
		this.isDragging = false;
		this.mouseDown = false;
		this.targetAnchor = null;
		this.targetBox = null;
		this.before = true;
		this._lastX = 0;
		this._lastY = 0;
		// states
		this.sourceState  = "";
		if(this.isSource){
			dojo.addClass(this.node, "dojoDndSource");
		}
		this.targetState  = "";
		if(this.accept){
			dojo.addClass(this.node, "dojoDndTarget");
		}
		if(this.horizontal){
			dojo.addClass(this.node, "dojoDndHorizontal");
		}
		// set up events
		this.topics = [
			dojo.subscribe("/dnd/source/over", this, "onDndSourceOver"),
			dojo.subscribe("/dnd/start",  this, "onDndStart"),
			dojo.subscribe("/dnd/drop",   this, "onDndDrop"),
			dojo.subscribe("/dnd/cancel", this, "onDndCancel")
		];
	},
	
	// methods
	checkAcceptance: function(source, nodes){
		// summary: checks, if the target can accept nodes from this source
		// source: Object: the source which provides items
		// nodes: Array: the list of transferred items
		if(this == source){
			return !this.copyOnly || this.selfAccept;
		}
		for(var i = 0; i < nodes.length; ++i){
			var type = source.getItem(nodes[i].id).type;
			// type instanceof Array
			var flag = false;
			for(var j = 0; j < type.length; ++j){
				if(type[j] in this.accept){
					flag = true;
					break;
				}
			}
			if(!flag){
				return false;	// Boolean
			}
		}
		return true;	// Boolean
	},
	copyState: function(keyPressed, self){
		// summary: Returns true, if we need to copy items, false to move.
		//		It is separated to be overwritten dynamically, if needed.
		// keyPressed: Boolean: the "copy" was pressed
		// self: Boolean?: optional flag, which means that we are about to drop on itself
		
		if(keyPressed){ return true; }
		if(arguments.length < 2){
			self = this == dojo.dnd.manager().target;
		}
		if(self){
			if(this.copyOnly){
				return this.selfCopy;
			}
		}else{
			return this.copyOnly;
		}
		return false;	// Boolean
	},
	destroy: function(){
		// summary: prepares the object to be garbage-collected
		dojo.dnd.Source.superclass.destroy.call(this);
		dojo.forEach(this.topics, dojo.unsubscribe);
		this.targetAnchor = null;
	},

	// markup methods
	markupFactory: function(params, node){
		params._skipStartup = true;
		return new dojo.dnd.Source(node, params);
	},

	// mouse event processors
	onMouseMove: function(e){
		// summary: event processor for onmousemove
		// e: Event: mouse event
		if(this.isDragging && this.targetState == "Disabled"){ return; }
		dojo.dnd.Source.superclass.onMouseMove.call(this, e);
		var m = dojo.dnd.manager();
		if(this.isDragging){
			// calculate before/after
			var before = false;
			if(this.current){
				if(!this.targetBox || this.targetAnchor != this.current){
					this.targetBox = {
						xy: dojo.coords(this.current, true),
						w: this.current.offsetWidth,
						h: this.current.offsetHeight
					};
				}
				if(this.horizontal){
					before = (e.pageX - this.targetBox.xy.x) < (this.targetBox.w / 2);
				}else{
					before = (e.pageY - this.targetBox.xy.y) < (this.targetBox.h / 2);
				}
			}
			if(this.current != this.targetAnchor || before != this.before){
				this._markTargetAnchor(before);
				m.canDrop(!this.current || m.source != this || !(this.current.id in this.selection));
			}
		}else{
			if(this.mouseDown && this.isSource &&
					(Math.abs(e.pageX - this._lastX) > this.delay || Math.abs(e.pageY - this._lastY) > this.delay)){
				var nodes = this.getSelectedNodes();
				if(nodes.length){
					m.startDrag(this, nodes, this.copyState(dojo.dnd.getCopyKeyState(e), true));
				}
			}
		}
	},
	onMouseDown: function(e){
		// summary: event processor for onmousedown
		// e: Event: mouse event
		if(!this.mouseDown && this._legalMouseDown(e) && (!this.skipForm || !dojo.dnd.isFormElement(e))){
			this.mouseDown = true;
			this._lastX = e.pageX;
			this._lastY = e.pageY;
			dojo.dnd.Source.superclass.onMouseDown.call(this, e);
		}
	},
	onMouseUp: function(e){
		// summary: event processor for onmouseup
		// e: Event: mouse event
		if(this.mouseDown){
			this.mouseDown = false;
			dojo.dnd.Source.superclass.onMouseUp.call(this, e);
		}
	},
	
	// topic event processors
	onDndSourceOver: function(source){
		// summary: topic event processor for /dnd/source/over, called when detected a current source
		// source: Object: the source which has the mouse over it
		if(this != source){
			this.mouseDown = false;
			if(this.targetAnchor){
				this._unmarkTargetAnchor();
			}
		}else if(this.isDragging){
			var m = dojo.dnd.manager();
			m.canDrop(this.targetState != "Disabled" && (!this.current || m.source != this || !(this.current.id in this.selection)));
		}
	},
	onDndStart: function(source, nodes, copy){
		// summary: topic event processor for /dnd/start, called to initiate the DnD operation
		// source: Object: the source which provides items
		// nodes: Array: the list of transferred items
		// copy: Boolean: copy items, if true, move items otherwise
		if(this.autoSync){ this.sync(); }
		if(this.isSource){
			this._changeState("Source", this == source ? (copy ? "Copied" : "Moved") : "");
		}
		var accepted = this.accept && this.checkAcceptance(source, nodes);
		this._changeState("Target", accepted ? "" : "Disabled");
		if(this == source){
			dojo.dnd.manager().overSource(this);
		}
		this.isDragging = true;
	},
	onDndDrop: function(source, nodes, copy, target){
		// summary: topic event processor for /dnd/drop, called to finish the DnD operation
		// source: Object: the source which provides items
		// nodes: Array: the list of transferred items
		// copy: Boolean: copy items, if true, move items otherwise
		// target: Object: the target which accepts items
		if(this == target){
			// this one is for us => move nodes!
			this.onDrop(source, nodes, copy);
		}
		this.onDndCancel();
	},
	onDndCancel: function(){
		// summary: topic event processor for /dnd/cancel, called to cancel the DnD operation
		if(this.targetAnchor){
			this._unmarkTargetAnchor();
			this.targetAnchor = null;
		}
		this.before = true;
		this.isDragging = false;
		this.mouseDown = false;
		this._changeState("Source", "");
		this._changeState("Target", "");
	},
	
	// local events
	onDrop: function(source, nodes, copy){
		// summary: called only on the current target, when drop is performed
		// source: Object: the source which provides items
		// nodes: Array: the list of transferred items
		// copy: Boolean: copy items, if true, move items otherwise
		
		if(this != source){
			this.onDropExternal(source, nodes, copy);
		}else{
			this.onDropInternal(nodes, copy);
		}
	},
	onDropExternal: function(source, nodes, copy){
		// summary: called only on the current target, when drop is performed
		//	from an external source
		// source: Object: the source which provides items
		// nodes: Array: the list of transferred items
		// copy: Boolean: copy items, if true, move items otherwise
		
		var oldCreator = this._normalizedCreator;
		// transferring nodes from the source to the target
		if(this.creator){
			// use defined creator
			this._normalizedCreator = function(node, hint){
				return oldCreator.call(this, source.getItem(node.id).data, hint);
			};
		}else{
			// we have no creator defined => move/clone nodes
			if(copy){
				// clone nodes
				this._normalizedCreator = function(node, hint){
					var t = source.getItem(node.id);
					var n = node.cloneNode(true);
					n.id = dojo.dnd.getUniqueId();
					return {node: n, data: t.data, type: t.type};
				};
			}else{
				// move nodes
				this._normalizedCreator = function(node, hint){
					var t = source.getItem(node.id);
					source.delItem(node.id);
					return {node: node, data: t.data, type: t.type};
				};
			}
		}
		this.selectNone();
		if(!copy && !this.creator){
			source.selectNone();
		}
		this.insertNodes(true, nodes, this.before, this.current);
		if(!copy && this.creator){
			source.deleteSelectedNodes();
		}
		this._normalizedCreator = oldCreator;
	},
	onDropInternal: function(nodes, copy){
		// summary: called only on the current target, when drop is performed
		//	from the same target/source
		// nodes: Array: the list of transferred items
		// copy: Boolean: copy items, if true, move items otherwise
		
		var oldCreator = this._normalizedCreator;
		// transferring nodes within the single source
		if(this.current && this.current.id in this.selection){
			// do nothing
			return;
		}
		if(copy){
			if(this.creator){
				// create new copies of data items
				this._normalizedCreator = function(node, hint){
					return oldCreator.call(this, this.getItem(node.id).data, hint);
				};
			}else{
				// clone nodes
				this._normalizedCreator = function(node, hint){
					var t = this.getItem(node.id);
					var n = node.cloneNode(true);
					n.id = dojo.dnd.getUniqueId();
					return {node: n, data: t.data, type: t.type};
				};
			}
		}else{
			// move nodes
			if(!this.current){
				// do nothing
				return;
			}
			this._normalizedCreator = function(node, hint){
				var t = this.getItem(node.id);
				return {node: node, data: t.data, type: t.type};
			};
		}
		this._removeSelection();
		this.insertNodes(true, nodes, this.before, this.current);
		this._normalizedCreator = oldCreator;
	},
	onDraggingOver: function(){
		// summary: called during the active DnD operation, when items
		// are dragged over this target, and it is not disabled
	},
	onDraggingOut: function(){
		// summary: called during the active DnD operation, when items
		// are dragged away from this target, and it is not disabled
	},
	
	// utilities
	onOverEvent: function(){
		// summary: this function is called once, when mouse is over our container
		dojo.dnd.Source.superclass.onOverEvent.call(this);
		dojo.dnd.manager().overSource(this);
		if(this.isDragging && this.targetState != "Disabled"){
			this.onDraggingOver();
		}
	},
	onOutEvent: function(){
		// summary: this function is called once, when mouse is out of our container
		dojo.dnd.Source.superclass.onOutEvent.call(this);
		dojo.dnd.manager().outSource(this);
		if(this.isDragging && this.targetState != "Disabled"){
			this.onDraggingOut();
		}
	},
	_markTargetAnchor: function(before){
		// summary: assigns a class to the current target anchor based on "before" status
		// before: Boolean: insert before, if true, after otherwise
		if(this.current == this.targetAnchor && this.before == before){ return; }
		if(this.targetAnchor){
			this._removeItemClass(this.targetAnchor, this.before ? "Before" : "After");
		}
		this.targetAnchor = this.current;
		this.targetBox = null;
		this.before = before;
		if(this.targetAnchor){
			this._addItemClass(this.targetAnchor, this.before ? "Before" : "After");
		}
	},
	_unmarkTargetAnchor: function(){
		// summary: removes a class of the current target anchor based on "before" status
		if(!this.targetAnchor){ return; }
		this._removeItemClass(this.targetAnchor, this.before ? "Before" : "After");
		this.targetAnchor = null;
		this.targetBox = null;
		this.before = true;
	},
	_markDndStatus: function(copy){
		// summary: changes source's state based on "copy" status
		this._changeState("Source", copy ? "Copied" : "Moved");
	},
	_legalMouseDown: function(e){
		// summary: checks if user clicked on "approved" items
		// e: Event: mouse event
		
		// accept only the left mouse button
		if(!dojo.dnd._isLmbPressed(e)){ return false; }
		
		if(!this.withHandles){ return true; }
		
		// check for handles
		for(var node = e.target; node && node !== this.node; node = node.parentNode){
			if(dojo.hasClass(node, "dojoDndHandle")){ return true; }
			if(dojo.hasClass(node, "dojoDndItem")){ break; }
		}
		return false;	// Boolean
	}
});

dojo.declare("dojo.dnd.Target", dojo.dnd.Source, {
	// summary: a Target object, which can be used as a DnD target
	
	constructor: function(node, params){
		// summary: a constructor of the Target --- see the Source constructor for details
		this.isSource = false;
		dojo.removeClass(this.node, "dojoDndSource");
	},

	// markup methods
	markupFactory: function(params, node){
		params._skipStartup = true;
		return new dojo.dnd.Target(node, params);
	}
});

dojo.declare("dojo.dnd.AutoSource", dojo.dnd.Source, {
	// summary: a source, which syncs its DnD nodes by default
	
	constructor: function(node, params){
		// summary: a constructor of the AutoSource --- see the Source constructor for details
		this.autoSync = true;
	},

	// markup methods
	markupFactory: function(params, node){
		params._skipStartup = true;
		return new dojo.dnd.AutoSource(node, params);
	}
});

}

if(!dojo._hasResource["com.ibm.dnd.CustomManagerSource"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.dnd.CustomManagerSource"] = true;
dojo.provide("com.ibm.dnd.CustomManagerSource");



dojo.declare("com.ibm.dnd.CustomManagerMixin",
	null,
	{
		// summary: An extension of the dojo.dnd.Source base module which provides 
		//		automatic declarative support for overriding properties on the dnd
		//		manager dynamically when a drag operation originates from this source.
		//		All properties that are overriden are reset back to their original
		//		values once the drag operation ends, regardless of the target or
		//		the outcome.  Customizing the dnd manager from a dnd Source is easily
		//		done by extending this module and overriding the managerOverrides
		//		map in the extension.
		
		// managerOverrides: Object
		//		Map of properties to override in the dojo.dnd.Manager instance returned
		//		by dojo.dnd.manager() when onMouseDown occurs in this dnd Source.
		//		The properties defined here will override the same properties in the
		//		dnd manager, and then reset back to what they were before after the
		//		drag operation ends.
		managerOverrides: {},
		
		_partialMixin: function(tgt, src, map) {
			// summary: Performs a partial, simple mixin from the src to the tgt as defined
			// 		by the map.  For each property defined in map, it sets the value of 
			// 		that property in tgt to the value of that same property in src.
			for(var p in map) {
				tgt[p] = src[p];
			}
			return tgt;
		},
		
		_changeManager: function() {
			// only fix once
			if(!this._mgr) {
				this.mgrProps = {};
				this._mgr = dojo.dnd.manager();
				this._partialMixin(this.mgrProps, this._mgr, this.managerOverrides);
				dojo.mixin(this._mgr, this.managerOverrides);
				this._mgrFixConn = dojo.connect(dojo.doc, "onmouseup", this, "_fixManager");
			}
		},
		_fixManager: function() {
			if(this._mgrFixConn) {
				dojo.disconnect(this._mgrFixConn);
				this._mgrFixConn = null;
			}
			if(this._mgr) {
				dojo.mixin(this._mgr, this.mgrProps);
				this.mgrProps = {};
			}
			// reset
			this._mgr = null;
		},
		onMouseDown: function(e){
			// summary: Plugin to change the dojo.dnd manager instance using the dynamic
			//		hot replace/fix paradigm.
			this._changeManager();
			this.inherited(arguments);
		},
		destroy: function() {
			// safety if for some reason we get destroyed before fixing the manager
			if(this._mgrFixConn) dojo.disconnect(this._mgrFixConn);
			this._mgrFixConn = null;
			this.inherited(arguments);
		}
	}
);

dojo.declare("com.ibm.dnd.CustomManagerSource",
	[dojo.dnd.Source, com.ibm.dnd.CustomManagerMixin],
	{
		
		
	}
);

dojo.declare("com.ibm.dnd.CustomManagerAutoSource",
	[dojo.dnd.AutoSource, com.ibm.dnd.CustomManagerMixin],
	{
		
		
	}
);

}

if(!dojo._hasResource["com.ibm.dnd.PageAvatar"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.dnd.PageAvatar"] = true;
dojo.provide("com.ibm.dnd.PageAvatar");

dojo.declare("com.ibm.dnd.PageAvatar", dojo.dnd.Avatar, {
	construct: function(){
		// summary: constructs the avatar for page tabs, 
		//          opacity for the avatar is applied by the 
		//          class assigned during creator
		var div = dojo.doc.createElement("div");
		div.style.position = "absolute";
		div.style.zIndex = 1999;
		div.style.margin = "0px";
		var source = this.manager.source, node;
		// create an avatar representation of the node
		// Portal only allows 1 page tab to be dragged, 
		// so it is known to use the first item in the array
		node = source._normalizedCreator(source.getItem(this.manager.nodes[0].id).data, "avatar").node;
		node.id = "";
		div.appendChild(node);
		this.node = div;
	}
});

}

if(!dojo._hasResource["com.ibm.dnd.ModeledSource"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.dnd.ModeledSource"] = true;
dojo.provide("com.ibm.dnd.ModeledSource");

/*
 * A ModeledSource is a dnd Source which provides dnd operational support to a modeled widget.
 * Can be extended to provide different drop actions, as well as drop zones, depending on the
 * type of data being dragged around.  
 * Examples:
 * 	1) Dragging items of the same type around simply creates drop zones around other objects 
 * 		in a heirarchy or list.  Dropping them reorders those items in the modeled heirarchy.
 *  2) Dragging items of different types onto other items creates drop zones on top of the
 * 		items themselves, representing actions where a certain type of data is applied to a
 * 		different type of data.
 */




dojo.declare("com.ibm.dnd.ModeledSource",
	com.ibm.dnd.CustomManagerSource,
	{
		managerOverrides: {
			OFFSET_X: 1,
			OFFSET_Y: 1,
			makeAvatar: function(){
				return new com.ibm.dnd.PageAvatar(this);
			}
		},
		model: null,
		item: null,
		isBidi: false,
		constructor: function(/*DOMNode|String*/node, /*dojo.dnd.__SourceArgs?*/params) {
			if(this.withHandles) {
				dojo.addClass(node, "dndHasHandles");
			}
			if(typeof(ibmPortalConfig) != "undefined") this.isBidi = ibmPortalConfig.isRTL;
			else if(typeof(ibmConfig) != "undefined") this.isBidi = ibmConfig.isBidi;
		},
		onDrop: function(source, nodes, copy) {
			// summary: Called when a drop action occurs in this container
			var targetWidget = dijit.getEnclosingWidget(this.current),
			nextSibling = null,
			newParentItem = null;
			
			if(dojo.hasClass(this.current, "dojoDndItemChild")){
				newParentItem = targetWidget.item;
			}else{
				newParentItem = targetWidget.getParent().item;

				if(this.current) {
					var afterClass = (this.isBidi && this.horizontal) ? "dojoDndItemBefore" : "dojoDndItemAfter";
					
					if(dojo.hasClass(this.current, afterClass)) {
						targetWidget = targetWidget.getNextSibling();
						while(targetWidget && dojo.hasClass(targetWidget.domNode, "dojoDndItemAnchor")) {
							targetWidget = targetWidget.getNextSibling();
						}
					}
					if(targetWidget) nextSibling = targetWidget.item;
				}
			}
			
			setTimeout(dojo.hitch(this, function() {
				dojo.forEach(nodes, function(node){
					var childWidget = dijit.getEnclosingWidget(node),
						childItem = childWidget.item,
						prevParentItem = childWidget.getParent().item;	
					this.model.pasteItem(childItem, prevParentItem, newParentItem, copy, nextSibling);
				}, this);
			}), 50);
		},
		// mouse event processors
		onMouseMove: function(e){
			// summary: event processor for onmousemove
			// e: Event: mouse event
			if(this.isDragging && this.targetState == "Disabled"){ return; }
			dojo.dnd.Source.superclass.onMouseMove.call(this, e);
			var m = dojo.dnd.manager();
			if(this.isDragging){
				dojo.forEach(this.draggingItems, function(item){
					if(item.popup.isShowingNow){
						dijit.popup.close(item.popup);
						this._removeItemClass(this.current, "Over");
						dojo.removeClass(this.current, "dijitMenuItemHover");
					}
				}, this);
				
				// calculate before/after
				var before = false;
				if(this.current){
					
					if(!this.targetBox || this.targetAnchor != this.current){
						this.targetBox = {
							xy: dojo.coords(this.current, true),
							w: this.current.offsetWidth,
							h: this.current.offsetHeight
						};
					}

					if(this.horizontal){
						//before = (e.pageX - this.targetBox.xy.x) < (this.targetBox.w / 2);
						if((e.pageX - this.targetBox.xy.x) < (this.targetBox.w * 0.25)){
							before = "Before";
						}else if((e.pageX - this.targetBox.xy.x) > (this.targetBox.w * 0.75)){
							before = "After";
						}else{
							before = "Child";
						}
						
					}else{
						//before = (e.pageY - this.targetBox.xy.y) < (this.targetBox.h / 2);
						if((e.pageY - this.targetBox.xy.y) < (this.targetBox.h * 0.25)){
							before = "Before";
						}else if((e.pageY - this.targetBox.xy.y) > (this.targetBox.h * 0.75)){
							before = "After";
						}else{
							before = "Child";
						}
						
					}
				}
				if(this.current != this.targetAnchor || before != this.before){
					this._markTargetAnchor(before);
					m.canDrop(!this.current || m.source != this || !(this.current.id in this.selection));
				}
			}else{
				if(this.mouseDown && this.isSource &&
						(Math.abs(e.pageX - this._lastX) > this.delay || Math.abs(e.pageY - this._lastY) > this.delay)){
					var nodes = this.getSelectedNodes();
					if(nodes.length){
						m.startDrag(this, nodes, this.copyState(dojo.dnd.getCopyKeyState(e), true));
					}
				}
			}
		},
		_markTargetAnchor: function(before){
			// summary: assigns a class to the current target anchor based on "before" status
			// before: Boolean: insert before, if true, after otherwise
			if(this.current == this.targetAnchor && this.before == before){ return; }
			if(this.targetAnchor){
				this._removeItemClass(this.targetAnchor, this.before);
			}
			this.targetAnchor = this.current;
			this.targetBox = null;
			this.before = before;
			if(this.targetAnchor){
				this._addItemClass(this.targetAnchor, this.before);
			}
		},
		_unmarkTargetAnchor: function(){
			// summary: removes a class of the current target anchor based on "before" status
			if(!this.targetAnchor){ return; }
			this._removeItemClass(this.targetAnchor, this.before);
			this.targetAnchor = null;
			this.targetBox = null;
			this.before = true;
		},
		onDndStart: function(source, nodes, copy){
			this.draggingItems = new Array();
			dojo.forEach(nodes, function(node){
				var widget = dijit.getEnclosingWidget(node);
				if(widget && widget.popup){
					this.draggingItems.push(widget);
					this._removeItemClass(widget.popup, "Over");
					dijit.popup.close(widget.popup);
				}
			}, this);
			
			this.inherited(arguments);
			dojo.addClass(this.node, "isDragging");
		},
		onDndCancel: function(){
			this.inherited(arguments);
			dojo.removeClass(this.node, "isDragging");
		},
		destroy: function() {
			this.inherited(arguments);
			this.model = this.node = this.current = this.item = null;
		}
	}
);

}

if(!dojo._hasResource["com.ibm.widgets.TreeModeled"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.widgets.TreeModeled"] = true;
dojo.provide( "com.ibm.widgets.TreeModeled" );

dojo.require( "com.ibm.dnd.ModeledSource" );
 
/*
 * This module provides a simple API for creating a widget that is built from a data set through
 * some API.  Examples include but are not limited to the tree model API used by dijit.Tree and
 * the dojo.data API.  This module can be mixed in to other widgets that use data to build their
 * representations.
 */

dojo.declare( "com.ibm.widgets._DataBacked",
			null,
			{
				// _loaded: Boolean flag indicates whether or not this data backed widget has loaded
				//		its data yet
				_loaded: false,
				
				// _loading: Boolean flag indicates whether or not this data backed widget is currently
				//		loading its data
				_loading: false,
				
				load: function() {
					// summary: Loads the data used to build the implementing widget.  Subclasses should
					//		ensure that the _onLoad and _onLoading functions are called so that listeners
					//		to the onLoad and onLoading functions can receive proper notifications.
				},
				
				reload: function() {
					// summary: Reload a widget's data set in order to (optionally) rebuild
					//		the widget's representation.  Not all subclasses may support this.
				},
				_onLoad: function() {
					// implementations should call this internal function not the public one
					this._loaded = true;
					this._loading = false;
					this.onLoad();
				},
				_onLoading: function() {
					// implementations should call this internal function not the public one
					this._loading = true;
					this.onLoading();
				},
				
				onLoad: function() {
					// summary: Extension point called when data loading is finished regardless
					// 		of success or error.
				},
				onLoading: function() {
					// summary: Extension point called when data loading begins.
					
				}
			}
);


dojo.declare( "com.ibm.widgets.TreeModeled",
			com.ibm.widgets._DataBacked,
			{
				// summary:
				//		Mixin used for widgets that are built using a data model to represent
				//		data in some visual way.  Listens to model notifications of change events
				//		in order to update the representation of the model data in the widget.
				//		To use this mixin, call initializeModelWidget() in postCreate()
				//		and startupModelWidget() in startup().  They must also mixin the 
				// 		dijit._Container mixin or subclass an widget that already mixes it in.
				
				// model: Object which is an implementation	of the com.ibm.data.DataTreeModel
				// 		APIs.
				model: null,
				
				// item: Object the root item of this widget whose children will 
				//		populate the tabs in this widget.  Must be provided to root
				//		this widget at some point in the model.
				item: null,
				
				// items: Map of the widgets representing the children items of item retrieved 
				// 		from the model.  Keys are item ids and values are the widgets representing
				//		the items.
				items: null,
				
				// levels: Number of levels to recurse down the model when creating widget
				//		representations of the model.  Default is Infinity, indicating 
				// 		no maximum depth, which will continue to create representations of 
				// 		descendants all the	way down the tree model.  Implementations should
				//		handle this accordingly when creating new children.
				levels: Infinity,
				
				// level: Number the level of the current modeled widget in a heirarchy of modeled
				//		widgets.
				level: 0,
				
				// dndEnabled: Boolean indicates whether or not this widget should allow dnd operations
				dndEnabled: false,
				
				// dndClass: String class used to create a DND source object for this modeled widget
				dndClass: "com.ibm.dnd.ModeledSource",
				
				// dndAccept: Array of dnd types that this widget accepts
				dndAccept: null,
				
				// dndType: Array indicating the dndType(s) of items represented in this
				//		modeled widget.
				dndType: null,
				
				// dndCreator: Function dnd creator function
				dndCreator: null,
				
				// dndSingular: Boolean to determine if multiple items can be dragged
				//		simultaneously or not
				dndSingular: true,
				
				// dndDelay: Number of pixels to use as a delay before triggering a dnd operation
				dndDelay: 0,
				
				// dndHorizontal: Boolean indicating if this model widget should use horizontal dnd
				//		operations.  Default is false.
				dndHorizontal: false,
				
				// loadingIndicatorWidget: String name of widget class used to represent the loading state of this 
				// 		modeled widget.  By default, it is displayed as a child of this widget while children 
				// 		are being loaded, and is then removed after loading has completed.
				loadingIndicatorWidget: "",
				
				// showInlineEditor: Boolean indicating whether or not to show an inline editor widget 
				// 		somewhere in this modeled widget.  Implementations are free to handle this
				// 		however they please.  One example use case is to provide a means of creating 
				// 		new data in a data backed widget through an inline editor.  Inline editor
				//		onchange events are propagated to the onInlineEditorChange function with the
				//		parentItem and the new value passed as arguments.
				showInlineEditor: false,
				
				// inlineEditorWidget: String name of widget class to use to instantiate the inline
				//		editor of this data backed widget.  Must implement onChange, onCancel, and onEdit
				// 		events for the inline editor.  The com.ibm.widgets.InlineEditorWrapper mixin
				//		provides prebuilt logic for these handlers and can be mixed into other widgets
				//		that will contain the editor.
				inlineEditorWidget: "",
				
				// inlineEditorTitle: String title to display on hover over the inline editor
				//		while in edit mode
				inlineEditorTitle: "",
				
				// inlineEditorLabel: String default label to display in inline editor
				// 		when not in edit mode 
				inlineEditorLabel: "",
				
				// inlineEditorLabel: String default value to display in inline editor when going into
				// 		edit mode
				inlineEditorDefaultValue: "",
				
				// embeddedEditorWidget: Widget class used to instantiate the embedded inline editor
				//		used inside this modeled widget
				embeddedEditorWidget: "dijit.form.TextBox",
				
				// embeddedEditorParams: Object set of parameters used when instantiating the embedded
				//		inline editor widget, like {required: true} or {constraints: {}}
				embeddedEditorParams: {},
				
				embeddedEditorPopup: "com.ibm.widgets.InlineEditorPopup",
				embeddedEditorPopupParams: {},
								
				constructor: function() {
					this.embeddedEditorParams = {};
					this.embeddedEditorPopupParams = {};
					this.items = {};
				},
				
				initializeModelWidget: function() {
					this.connect(this.model, "onTreeChange", "onModelTreeChange");
					this.connect(this.model, "onChange", "onModelChange");
					this.connect(this.model, "onChildrenChange", "onModelChildrenChange");
					
					if(!this.preloaded) {
						var loaderCls = dojo.getObject(this.loadingIndicatorWidget);
						if(loaderCls) {
							this.loadingIndicator = new loaderCls();
						}
					}
					
					if(this.showInlineEditor) {
						this.connect(this, "onLoad", "setupInlineEditor");
					}
					
					if(!dojo.isArray(this.dndAccept)) this.dndAccept = [this.dndAccept];
					this._dndParams = {
						model: this.model,
						item: this.item,
						skipForm: true,
						accept: this.dndAccept || [],
						singular: this.dndSingular,
						creator: this.dndCreator,
						delay: this.dndDelay,
						horizontal: this.dndHorizontal,
						dropParent: this.containerNode
					};
					
					if(this.dndEnabled && !this.preloaded) {
						this.setupDnd();	// not set up when preloaded, called after preload processing
					}
					
					this._draggingNodes = [];
				},
				
				startupModelWidget: function() {
					if(!this.preloaded && this.loadingIndicator) this.addChild(this.loadingIndicator);
				},
				
				setupInlineEditor: function() {
					if(!this.inlineEditor) {
						var editorCls = dojo.getObject(this.inlineEditorWidget);
						if(editorCls) {
							this.inlineEditor = new editorCls({
								label: this.inlineEditorLabel,
								title: this.inlineEditorTitle,
								defaultValue: this.inlineEditorDefaultValue,
								embeddedEditorWidget: this.embeddedEditorWidget,
								embeddedEditorParams: this.embeddedEditorParams,
								popupWidget: this.embeddedEditorPopup,
								popupParams: this.embeddedEditorPopupParams
							});
							
							this.connect(this.inlineEditor, "onChange", "_onInlineEditorChange");
							this.connect(this.inlineEditor, "onCancel", "onInlineEditorCancel");
							this.connect(this.inlineEditor, "onEdit", "onInlineEdit");
							this.addChild(this.inlineEditor);
						}
					}
				},
				
				setupDnd: function() {
					// summary: Called during postCreate to setup dnd operations for this widget.
					//		Subclasses may override for customized behavior.
					if(!this.dndSource) {
						this.dndEnabled = true;
						var cls = dojo.getObject(this.dndClass);
						this.dndSource = new cls(this.domNode, this._dndParams);
						this._dndConnects = [];
						this._dndConnects.push(this.connect(this.dndSource, "onDraggingOver", "onDraggingOver"));
						this._dndConnects.push(this.connect(this.dndSource, "onDraggingOut", "onDraggingOut"));
						this._dndConnects.push(this.connect(this.dndSource, "onDndStart", "onDndStart"));
						this._dndConnects.push(this.connect(this.dndSource, "onDndCancel", "onDndCancel"));
					}
					dojo.forEach(this.getChildren(), function(child){
						child.attr("dndStatus", true);
					}, this);
				},
				disableDnd: function() {
					this._disableLocalDnd();
					dojo.forEach(this.getChildren(), function(child){
						child.attr("dndStatus", false);
					}, this);
				},
				_disableLocalDnd: function() {
					if(this.dndSource) {
						this.dndEnabled = false;
						dojo.forEach(this._dndConnects, this.disconnect, this);
						this._dndConnects = [];
						this.dndSource.destroy();
						this.dndSource = null;
					}
				},
				destroy: function() {
					this._disableLocalDnd();
					this.inherited(arguments);
				},
				getInheritableParameters: function(item) {
					// summary: Returns an object map of parameters to use when constructing the
					//		widget representation of the next level of the model.  Subclasses
					//		can extend this and provide additional properties or override ones
					//		set here.  Much of this is boilerplate, so it's often easiest to
					//		call this.inherited(arguments) and then modify the result before
					//		returning.
					// item: Current item to use as the root of the next level in the model.
					return {
						item: item,
						model: this.model, 
						level: this.level + 1,
						levels: this.levels,
						showInlineEditor: this.showInlineEditor,
						inlineEditorLabel: this.inlineEditorLabel,
						inlineEditorTitle: this.inlineEditorTitle,
						inlineEditorDefaultValue: this.inlineEditorDefaultValue,
						embeddedEditorWidget: this.embeddedEditorWidget,
						embeddedEditorParams: dojo.mixin({}, this.embeddedEditorParams),
						embeddedEditorPopup: this.embeddedEditorPopup,
						embeddedEditorPopupParams: dojo.mixin({}, this.embeddedEditorPopupParams),
						dndCreator: this.dndCreator,
						dndEnabled: this.dndEnabled,
						dndAccept: this.dndAccept,
						dndSingular: this.dndSingular,
						dndDelay: this.dndDelay,
						dndType: this.dndType,
						onModelItemClick: this.onModelItemClick,
						setupInlineEditor: this.setupInlineEditor,
						seedPreloadedData: this.seedPreloadedData
					};
				},
				createItemRep: function(item) {
					// summary: Subclasses should implement this function to create a widget representation of
					//		a data item in the model which is a child of the item backing this widget.  Each
					//		representation created here should mixin dijit._Contained as they will be children
					//		of this widget.  They also must support the dndHandle attribute getter/setter to set 
					// 		and get a boolean value indicating whether or not a	dnd handle should be used on the item.
					// item: Object item in the model backing this widget
				},
				handlePreloaded: function() {
					// summary: Plugin point for overrides that handle instantiation of this widget where data
					//		has been provided in the contents of the of the widget itself.
					this.domNode.removeAttribute("item");
					dojo.forEach(this.getChildren(), function(wij){
						this.items[this.model.getIdentity(wij.item)] = wij;
						this._flagChildForDnd(wij);
						this._flagChildHasChildren(wij);
						wij.domNode.removeAttribute("item");
					}, this);
				},
				seedPreloadedData: function() {
					// summary: Called when a widget is instantiated with preloaded data.  Override this to
					//		parse the data and do any processing such as seeding the model or store with the
					//		data found in the widget source point.
				},
				load: function() {
					// summary: Loads the children of this widget's item property from the model, and 
					// 		creates widgets	to represent each child item.  Can be overriden by subclasses 
					// 		to provide customized behavior.
					// returns: Boolean indicating whether or not this widget had any children to load.
					//		In either case, the onLoad and onLoading events are still fired.
					if(this._loaded || this._loading || !this.item) return false;	// already loaded, in process, or n/a
					if(this.preloaded) {
						this.seedPreloadedData();
						this.handlePreloaded();
						if(this.showInlineEditor){
							this.setupInlineEditor();
						}
						if(this.dndEnabled) {
							this.setupDnd();	// not set up when preloaded
						}
						return false;
					}
					if(!this.model.mayHaveChildren(this.item)) {
						if(this.loadingIndicator) this.removeChild(this.loadingIndicator);
						this._onLoading();
						this._onLoad();
						return false;
					}
					this._onLoading();
					this.model.getChildren(this.item, 
						dojo.hitch(this, function(items) {
							if(this.loadingIndicator) this.removeChild(this.loadingIndicator);
							
							if(!this.showInlineEditor && this.inlineEditor != null){
									this.inlineEditor.destroy();
									this.inlineEditor = null;
							}else if(this.showInlineEditor && this.inlineEditor == null){
									this.setupInlineEditor();
							}
							
							var insIndex = 0;
							if(this.inlineEditor) insIndex = this.getIndexOfChild(this.inlineEditor);
							
							dojo.forEach(items, function(item){
								var childWidget = this._setupNewChild(item);
								this.items[this.model.getIdentity(item)] = childWidget;
								if(insIndex != null) this.addChild(childWidget, insIndex++);
								else this.addChild(childWidget);
							}, this);
							
							if(this.dndSource) this.dndSource.sync();
							this._onLoad();
						}),
						dojo.hitch(this, function(error) {
							if(this.loadingIndicator) this.removeChild(this.loadingIndicator);
							this._onLoad();
							this.onError(error);
						})
					);
					return true;
				},
				reload: function() {
					// summary: Reloads this widget's children by destroying the existing children
					//		that are backed by model items and then calling load again.
					if(this._loading) return false;
					this._loaded = false;
					var items = this.items;
					for(var id in items) {
						this.removeChild(items[id]);
						//items[id].destroyRecursive();
						delete items[id];
					}
					if(this.dndSource) this.dndSource.sync();
					if(this.loadingIndicator) this.addChild(this.loadingIndicator);
					this.preloaded = false;
					if(this.model.resolver) this.model.resolver.getValue(this.item, "children").reload();
					return this.load();
				},
				_flagChildForDnd: function(childWidget) {
					//if(this.dndEnabled) {
						dojo.addClass(childWidget.domNode, "dojoDndItem");
						childWidget.domNode.setAttribute("dndType", this.dndType);
						childWidget.domNode.setAttribute("dndData", this.model.getLabel(childWidget.item));
						childWidget.attr("dndHandle", this._dndParams.withHandles);
					//}
				},
				_flagChildHasChildren: function(childWidget) {
					if(!this.model.mayHaveChildren(childWidget.item) || this.levels == 0 || this.level >= this.levels) {
						childWidget.attr("hasChildren", false);
					} else {
						childWidget.attr("hasChildren", true);
					}
				},
				_setupNewChild: function(item) {
					var childWidget = this.createItemRep(item);
					childWidget.item = item;
					this._flagChildForDnd(childWidget);
					this._flagChildHasChildren(childWidget);
					return childWidget;
				},
				onError: function(error) {
					// summary: Called when there is an error loading this widget.
					// error: Error data indicating what failed during the process of retrieving the children
					//		of this widget's item from the model.
					console.error(error);
				},
				onItemCreate: function(childWidget, item) {
					// summary: Can be fired for child items when they are created perhaps after the widget creates 
					// 		some representation of the item before it was created on the server.
				},
				onModelRemoveChild: function(/*Item*/ childItem) {
					var childWidgets = this.getChildren();
					for(var i=0, wij; wij=childWidgets[i], i<childWidgets.length; i++) {
						if(wij.item == childItem) {
							delete this.items[this.model.getIdentity(childItem)];
							this.removeChild(wij);
							wij.destroyRecursive();
							for(var x in wij) {
								try {
									delete wij[x];
								}
								catch(e){
									wij[x] = null;
								}
							}
							if(this.dndSource) this.dndSource.sync();
							return;
						}
					}
				},
				onModelInsertChild: function(/*Item*/ childItem, /*Item*/ nextSiblingItem) {
					var childWidget = this._setupNewChild(childItem);
					var childWidgets = this.getChildren();
					var insIdx = null;
					if(nextSiblingItem) {
						for(var i=0, wij; wij=childWidgets[i], i<childWidgets.length; i++) {
							if(wij.item == nextSiblingItem) {
								insIdx = i;
								break;
							}
						}
					}
					else {
						insIdx = this.getIndexOfChild(this.inlineEditor)
					}
					this.animateInChild(childWidget, insIdx);
					if(!this.model.isCreated(childItem)) {
						if(this._editorChangedWithFocus) {
							setTimeout(function(){
								dijit.focus(childWidget.focusNode ? childWidget.focusNode : childWidget.domNode);
							},0);
						}
						this._editorChangedWithFocus = false;
						childWidget.attr("disabled", true);
						this.model.addOnCreate(childItem, dojo.hitch(this, function(){
							this.items[this.model.getIdentity(childItem)] = childWidget;
							childWidget.attr("disabled", false);
							this.onItemCreate(childWidget, childItem);
						}));
					}
					else {
						this.items[this.model.getIdentity(childItem)] = childWidget;
					}
					if(this.dndSource) this.dndSource.sync();
				},
				onModelReorderChild: function(/*Item*/childItem, /*Item*/nextSiblingItem) {
					var childWidgets = this.getChildren();
					var childWidget = null;
					for(var i=0, wij; wij=childWidgets[i], i<childWidgets.length; i++) {
						if(wij.item == childItem) {
							childWidget = wij;
							this.removeChild(childWidget);
							// remove the item from the childWidgets node-list too, since we process
							// using the childWidgets below
							childWidgets.splice(i, 1);
							break;
						}
					}
					
					var insIdx = null;
					if(nextSiblingItem) {
						for(var i=0, wij; wij=childWidgets[i], i<childWidgets.length; i++) {
							if(wij.item == nextSiblingItem) {
								insIdx = i;
								break;
							}
						}
					}
					else {
						insIdx = this.getIndexOfChild(this.inlineEditor);
					}
					this.animateInChild(childWidget, insIdx);
					if(this.dndSource) this.dndSource.sync();
				},
				onModelTreeChange: function(/*Item*/ childItem, /*Item*/ oldParentItem, /*Item*/ newParentItem, /*Item*/ nextSiblingItem) {
					// summary: Listens to changes in the tree model where a particular childItem is added, removed, or moved
					//		under a parent item in the tree.  Here are the semantics:
					//		1) If oldParentItem is non-null, the childItem used to be a child of the oldParentItem (and still
					//			may, depending upon the other conditions.  If it is null, then the childItem is being inserted
					//			into the tree under the newParentItem as a new created tree node.
					//		2) If newParentItem is non-null, the childItem is now a child of the newParentItem.  If newParentItem
					//			is null, then the item is being deleted from the tree altogether from under the oldParentItem.
					//			If newParentItem is equal to oldParentItem, then the childItem is being reordered among the list
					//			of children of its parent.
					//		3) If nextSiblingItem is non-null, then the item is being moved or inserted into the tree and the 
					//			nextSiblingItem is the next sibling of the childItem under its parent.
					// childItem: Item being operated on in the model.
					// oldParentItem: Item previous parent of the childItem
					// newParentItem: Item new parent of the childItem
					// nextSiblingItem: Item next sibling of the childItem
					var f = null;
					if(this.item == oldParentItem) {
						f = "onModelRemoveChild";
					}
					if(this.item == newParentItem) {
						f = f ? "onModelReorderChild" : "onModelInsertChild";
					}
					if(f) {
						this[f](childItem, nextSiblingItem);
						return true;
					}
					return false;
				},
				onModelChange: function(/*dojo.data.Item*/ item) {
					if(this.items[this.model.getIdentity(item)]) {
						// TODO: process the change
					}
					return false;
				},
				onModelChildrenChange: function(parentItem, children) {
					if(this.item != parentItem) {
						var parentId = this.model.getIdentity(parentItem), child = this.items[parentId];
						if(child) {
							this.handleChildChildrenChange(child, children || []);
						}
						return false;
					}
					// only handle the no-children case... all other updates to children are 
					// handled by the other callbacks
					if(this.anchor) {
						this.anchor.attr("hasChildren", children && children.length > 0);
					}
				},
				handleChildChildrenChange: function(child, children) {
					// summary: Called when a child that has no children gets children or when a child that has children
					//		loses all its children.
				},
				onModelItemClick: function(widget, item) {
					// summary: Extension point for getting notifications when users click
					//		a widget representing an item in this model.  By default, this
					//		is propogated to all cascading modeled widgets created by the
					//		model so that all descendants fire the same function.
					//		Implementations should ensure that any onclick event on a child 
					// 		widget representing	modeled data calls results in a call to this 
					// 		function with the appropriate arguments. 
				},
				onDraggingOver: function() {
					if(this.inlineEditor && this.dndSource.getAllNodes().length == 0) {
						// empty container... style the inlineEditor
						this.dndSource._addItemClass(this.inlineEditor.domNode, "Before");
					}
				},
				onDraggingOut: function() {
					if(this.inlineEditor && this.dndSource.getAllNodes().length == 0) {
						// empty container... style the inlineEditor
						this.dndSource._removeItemClass(this.inlineEditor.domNode, "Before");
					}
				},
				onDndStart: function(source, nodes, copy) {
					if(this.dndSource == source) {
						dojo.forEach(nodes, function(node){
							this._animateOut(node);
						}, this);
						this._draggingNodes = nodes;
					}
				},
				onDndCancel: function() {
					if(this.inlineEditor) this.dndSource._removeItemClass(this.inlineEditor.domNode, "Before");
					dojo.forEach(this._draggingNodes, function(node){
						this._animateIn(node);
					}, this);
					this._draggingNodes = [];
				},
				_animateIn: function(node) {
					if(node._animation) node._animation.stop(true);
					dojo.style(node, "display", "");
					var anim = dojo.fadeIn({
						node: node,
						duration: 500
					});
					if(dojo.isIE) {
						var filter = node.style.filter;
						anim.onEnd = function() {
							node._animation = null;
							node.style.filter = filter;
						}
					}
					node._animation = anim;
					anim.play();
					return anim;
				},
				_animateOut: function(node) {
					if(node._animation) node._animation.stop(true);
					var anim = dojo.fadeOut({
						node: node,
						duration: 500,
						onEnd: function() {
							node._animation = null;
							dojo.style(node, "display", "none");
						}
					});
					node._animation = anim;
					anim.play();
					return anim;
				},
				animateInChild: function(/*Widget*/ widget, /*int?*/ insertIndex) {
					// summary: Adds a child to this modeled widget but allows animation
					//		effects to display the new child.
					// returns: Animation object which has already been started on return.
					//		Returns null if no animation was used.
					var filter = null;
					if(dojo.isIE) {
						filter = widget.domNode.style.filter;
					}
					dojo.style(widget.domNode, "opacity", "0");
					(insertIndex >= 0) ? this.addChild(widget, insertIndex) : this.addChild(widget);
					var anim = this._animateIn(widget.domNode);
					// hack for IE to get filter exactly back to original before animation
					if(dojo.isIE) var conn = dojo.connect(anim, "onEnd", function(){
						widget.domNode.style.filter = filter;
						dojo.disconnect(conn);
					});
					return anim;
				},
				animateOutChild: function(/*Widget*/ widget) {
					// summary: Hides a child from this modeled widget but allows animation
					//		effects when hiding the child.  At the end of the animation,
					//		this removes the child.
					// returns: Animation object which has already been started on return.
					//		Returns null if no animation was used.
					var anim = this._animateOut(widget.domNode);
					dojo.connect(anim, "onEnd", this, function(){
						this.removeChild(widget);
					});
					return anim;
				},
				moveChild: function(/*Widget*/ widget, /*int?*/ newIndex) {
					this.removeChild(widget);
					this.animateInChild(widget, newIndex);
				},
				_onInlineEditorChange: function(value, focus) {
					this._editorChangedWithFocus = focus;
					this.onInlineEditorChange(value, this.item);
				},
				onInlineEditorChange: function(value, parentItem) {
					// summary: Override or connect to this function to get notifications of changes to
					//		this menu's inline editor (if one exists).  The default implementation calls 
					// 		the model's newItem function passing in an object of the form {title: newValue}
					//		as the first argument and the item of this widget as the parent in the second
					//		argument.
					// value: Object map of key-value pairs from the inline editor's composite value.
					// parentItem: Item which is root of the widget whose editor fired its onChange event.
					this.model.newItem(value, parentItem);
				},
				onInlineEditorCancel: function() {
					// summary: Override or connect to this function to get notified when the user cancels
					//		an edit operation in the inline editor.
				},
				onInlineEdit: function() {
					// summary: Override or connect to this function to get notified when the user starts
					//		an edit operation in the inline editor usually by clicking or entering the inline
					//		editor.
				}
			}
);

}

if(!dojo._hasResource["com.ibm.widgets.SelectionModeled"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.widgets.SelectionModeled"] = true;
dojo.provide("com.ibm.widgets.SelectionModeled");





dojo.declare( "com.ibm.widgets.SelectionModeled",
			com.ibm.widgets.TreeModeled,
			{
				// summary:
				//		Mixin for building widgets from a selection model, which is a list structure
				//		that represents a current selection in a model starting at the root and walking
				//		down a tree to the currently selected node.
				
				// level: Number the level of the current modeled widget in a heirarchy of modeled
				//		widgets.  This represents the level in the tree from the root where this
				//		widget is rooted.  From the selection model's point of view, it is the index
				//		into the reverse selection path (since that goes up the tree instead).
				level: 0,
				
				// selectionModel: An instance of the com.ibm.data.SelectionModel class representing
				//		a selection model.
				selectionModel: null,
				
				// selectedClass: String name of the CSS class to apply to a node that is in the
				//		selection path.
				selectedClass: "",
				
				// selectedChild: Child widget which is currently marked as selected, indicating that
				//		it is part of the selection model.
				selectedChild: null,
				
				// tiedToSelection: Boolean flag indicating if this widget is tied to the selection
				//		model at this level.  If this is true, then if the selection path changes
				//		at this level, this widget will reload itself completely to root itself
				//		at the new item in the selection path at this level.
				tiedToSelection: false,
				
				constructor: function(){
					this.bundle = dojo.i18n.getLocalization("com.ibm.bundles", "Theme");
					this.currentlySelected = this.bundle["currently_selected"];
				},
				postMixInProperties: function() {
					this.inherited(arguments);
					if(this.tiedToSelection) this.item = this.selectionModel.atLevel(this.level, true);
				},
				initializeModelWidget: function() {
					this.inherited(arguments);
					this.connect(this.selectionModel, "onSelectionPathChange", "_updateSelection");
				},
				_markSel: function(childWidget, value) {
					if(value) {
						if(this.selectedChild) this.markSelected(this.selectedChild, false);
						this.selectedChild = childWidget;
					}
					this.markSelected(childWidget, value);
				},
				markSelected: function(childWidget, value) { 
					// summary: Marks the childWidget as selected or unselected depending on the value.
					//		By default, adds/removes the selectedClass to the childWidget's domNode.
					dojo[value ? "addClass" : "removeClass"](childWidget.domNode, this.selectedClass);
					if(childWidget.labelNode){
						if(value){  
							// add a strong tag to a selected child widget
							var label = childWidget.labelNode.innerHTML,
								selectedLabel = "";
							dojo.empty(childWidget.labelNode);
							
							if(this.selectionModel.selectionPath[0] == childWidget.item){

								var hiddenText = dojo.create("span", {innerHTML: this.currentlySelected, className: "ibmPortalHiddenText"});
								var hiddenSpan = dojo.create("span");
								hiddenSpan.appendChild(hiddenText);
								selectedLabel = dojo.create("strong",{innerHTML:label+hiddenSpan.innerHTML});
							}else{
								selectedLabel = dojo.create("strong",{innerHTML:label});
							}
							
							childWidget.labelNode.appendChild(selectedLabel);
						} else { 
							// remove a strong tag from a unselected child widget
							var label = dojo.query("strong",childWidget.labelNode); 
							if(label[0]) childWidget.labelNode.innerHTML = label[0].innerHTML; 
						}
					}
				},
				_updateSelection: function() {
					var curLevelItem = this.selectionModel.atLevel(this.level, true),
						lastLevelItem = this.selectionModel.atLevel(this.level + 1, true);
					if(curLevelItem != null){
						if(this.tiedToSelection && this.model.getIdentity(this.item) != this.model.getIdentity(curLevelItem) ) {
							this.item = curLevelItem;
							this.reload();
						}
						else {
							var curLevelId = curLevelItem ? this.model.getIdentity(curLevelItem) : null,
								levelId = lastLevelItem ? this.model.getIdentity(lastLevelItem) : null;
							
							if(curLevelItem && curLevelId != levelId && this.items[curLevelId]) {
								this._markSel(this.items[curLevelId], false);
							}
							if(levelId && this.items[levelId]) {
								this._markSel(this.items[levelId], true);
							}
						}
					}
				},
				_setupNewChild: function(item) {
					var childWidget = this.inherited(arguments);
					if(this.selectionModel.atLevel(this.level + 1, true) == item) {
						this._markSel(childWidget, true);
					}
					return childWidget;
				},
				getInheritableParameters: function(item) {
					return dojo.mixin(this.inherited(arguments), {
						selectionModel: this.selectionModel,
						selectedClass: this.selectedClass
					});
				},
				onModelItemClick: function(widget, item) {
					// summary: Extension point for getting notifications when users click
					//		a widget representing an item in this model.  By default, this
					//		is propogated to all cascading modeled widgets created by the
					//		model so that all descendants fire the same function.
					//		Implementations should ensure that any onclick event on a child 
					// 		widget representing	modeled data calls results in a call to this 
					// 		function with the appropriate arguments. 
					//		For SelectionModeled widgets, this changes the current selection
					//		to the widget's item that was clicked.
					if(widget.disabled) return false;
					var id = this.model.getIdentity(item);
						thisSel = this.selectionModel.atLevel(this.level, true),
						thisSelId = thisSel ? this.model.getIdentity(thisSel) : null;
					if(thisSelId != id) {
						// didn't click the current selection
						this.selectionModel.changeSelection(item);
						return true;
					}
					return false;
				}
			}
);

}

if(!dojo._hasResource["com.ibm.widgets.DataMenu"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.widgets.DataMenu"] = true;
dojo.provide("com.ibm.widgets.DataMenu");

dojo.require( "dijit.Menu" );
dojo.require( "dijit.InlineEditBox" );
dojo.require( "com.ibm.widgets.TimedMenu" );
dojo.require( "com.ibm.widgets.SelectionModeled" );
dojo.require( "com.ibm.widgets.InlineEditorWrapper" );



dojo.declare( "com.ibm.widgets.DataMenu",
			[dijit.Menu, com.ibm.widgets.TimedMenu, com.ibm.widgets.SelectionModeled],
			{			
				"class": "lotusActionMenu",
				
				// loadingIndicatorWidget: String name of widget class used to represent the loading state of this 
				// 		modeled widget.  By default, it is displayed as a child of this widget while children 
				// 		are being loaded, and is then removed after loading has completed.
				loadingIndicatorWidget: "com.ibm.widgets.LoadingMenuItem",
				
				// inlineEditorWidget: String name of widget class to use to instantiate the inline
				//		editor of this data backed widget.
				inlineEditorWidget: "com.ibm.widgets.EditorMenuItem",
				
				// closeDelay: Number of milliseconds to wait before closing a menu when it 
				// 		loses focus or receives an unhover event
				closeDelay: 500,
				
				// level: Number indicating the number of ancestor menus in the model chain above
				//		this menu.  Default is 0, indicating that this is a top level menu.
				level: 0,
				
				postCreate: function() {
					this.inherited(arguments);
					var ltr = this.isLeftToRight(),
						k = dojo.keys;
					this._exitKey = ltr ? k.LEFT_ARROW : k.RIGHT_ARROW;
					this._openKey = ltr ? k.RIGHT_ARROW : k.LEFT_ARROW;
					if(this.embeddedEditorParams.tooltipPosition) {
						this.embeddedEditorParams.tooltipPosition = ["after", "before", "below"];
					}
					this.initializeModelWidget();
					this._dndParams.withHandles = true;
					dojo.addClass(this.domNode, this["class"]);
					dojo.addClass(this.domNode, "modeledDataMenu");
					this.connect(this, "onMouseEnter", "_onHover");
					this.connect(this, "onMouseLeave", "_onUnhover");
					
					this.domNode.setAttribute("cellSpacing", "0px");
					dojo.style(this.domNode, {
						borderCollapse: "separate",
						borderSpacing: "0px"
					});
				},
				
				startup: function() {
					this.inherited(arguments);
					this.startupModelWidget();
				},
				
				setupInlineEditor: function() {
					return;
				},
				
				setupDnd: function() {
					this._dndParams.withHandles = true;
					this.inherited(arguments);
				},
				getInheritableParameters: function(item) {
					return dojo.mixin(this.inherited(arguments), {
						parentMenu: this,
						closeDelay: this.closeDelay,
						popupDelay: this.popupDelay,
						"class": this["class"]
					});
				},
				_getPopup: function(item) {
					if(this.level < this.levels) {
						return new this.constructor(this.getInheritableParameters(item));
					}
					return null;
				},
				createItemRep: function(item) {
					var args = {
						iconClass: "dragHandleIcon", 
						label: com.ibm.domUtilities.encodeXML(this.model.getLabel(item)), 
						item: item
					};
					var cls = com.ibm.widgets.DataPopupMenuItem;
					
					if(this.model.mayHaveChildren(item) || this.showInlineEditor) {
						var popup = this._getPopup(item);
						if(popup) {
							args.popup = popup;
						}
					}
					
					var childWidget = new cls(args);
					return childWidget;
				},
				handleChildChildrenChange: function(child, children) {
					// summary: Called when a child that has no children gets children or when a child that has children
					//		loses all its children.
					if(children.length == 0) {
						// child lost all children, destroy its popup
						child.destroyPopup();
						child.attr("hasChildren", false);
					}
					else if(!child.popup){
						// child without children got new children, create its popup
						var popup = this._getPopup(child.item);
						if(popup) {
							child.setPopup(popup);
							child.attr("hasChildren", true);
							popup.load();
							this.onItemHover(child);
						}
					}
				},
				getTopAnchor: function() {
					if(this.anchor) { 
						var parent = this.anchor.getParent();
						return parent && parent.getTopAnchor ? parent.getTopAnchor() : this.anchor;
					}
					else return null;
				},
				_moveToPopup: function(/*Event*/ evt){
					if(this.focusedChild && this.focusedChild.popup && !this.focusedChild.disabled) {
						this._openPopup();
					}
					else {
						var topAnchor = this.getTopAnchor();
						if(topAnchor) {
							topAnchor.getParent().focusNext();
						}
					}
				},
				_onChildBlur: function(item) {
					// nobody else is checking this, and apparently when widgets are destroyed
					// and the dom destroyed too, this fails trying to blur a non-existing node
					if(!item || !item.domNode) return;
					return this.inherited(arguments);
				},
				onItemHover: function(/*Widget*/ item){
					// summary: Called when cursor is over a MenuItem
					if(!this.inlineEditor || !this.inlineEditor.isEditing()) {
						this.isActive = true;
						return this.inherited(arguments);
					}
				},
				onItemClick: function(/*Widget*/ child, /*Event*/ evt){
					// summary: user defined function to handle clicks on an item
					if(child.attr("disabled")) return false; 
					this.onExecute();
					child.onClick(evt);
					if(child.item) this.onModelItemClick(child, child.item);
				},
				_onKeyPress: function(/*Event*/ evt){
					if(this.inlineEditor 
							&& this.inlineEditor.isEditing() 
							&& dojo.isDescendant(evt.target, this.inlineEditor.domNode)) {
						return;
					}
					 
					if(evt.ctrlKey || evt.altKey) return;
					switch(evt.charOrCode) {
						case this._exitKey:
							if(this.parentMenu) {
								this.onCancel(false);
							}
							else {
								var topAnchor = this.getTopAnchor();
								if(topAnchor) {
									topAnchor.getParent().focusPrev();
								}
							}
							dojo.stopEvent(evt);
							break;
						case this._openKey:
						 	this._moveToPopup(evt);
						 	dojo.stopEvent(evt);
						 	break;
					}
				},
				canClose: function() {
					// summary: Indicates whether or not this menu can close right now.  Is
					//		used to keep menus from closing when they are editing or in other
					//		conditions.
					return !this.inlineEditor || (this.inlineEditor && !this.inlineEditor.isEditing());
				}
			}
);

dojo.declare( "com.ibm.widgets._DataMenuItem", 
			null, 
			{
				templateString: 
				 '<tr class="dijitReset dijitMenuItem" dojoAttachPoint="focusNode" waiRole="menuitem" tabIndex="-1"'
				+'dojoAttachEvent="onmouseenter:_onHover,onmouseleave:_onUnhover,ondijitclick:_onClick">'
				+'<td dojoAttachPoint="dndHandleNode" class="dijitReset dragHandle" waiRole="presentation">'
					+'<img dojoAttachPoint="iconNode" src="${_blankGif}" alt="" />'
					+'<span class="dragHandleA11y">|</span>'
				+'</td>'
				+'<td class="dijitReset dijitMenuItemLabel" dojoAttachPoint="containerNode"></td>'
				+'<td class="dijitReset dijitMenuArrowCell" waiRole="presentation">'
					+'<div class="modelHasChildrenIcon" dojoAttachPoint="arrowWrapper">'
						+'<div class="dijitMenuExpand"></div>'
						+'<span class="dijitMenuExpandA11y">+</span>'
					+'</div>'
				+'</td>'
				+'</tr>',
				
				_setDndHandleAttr: function(value) {
					this.dndHandle = value;
					dojo[value ? "addClass" : "removeClass"](this.dndHandleNode, "dojoDndHandle");
				},
				_setHasChildrenAttr: function(value) {
					this.hasChildren = value;
					dojo[value ? "addClass" : "removeClass"](this.domNode, "modelHasChildren");
				},
				_setDndStatusAttr: function(value) {
					this.dndStatus = value;
					if(this.popup) {
						this.popup[value ? "setupDnd" : "disableDnd"]();
					}
				},
				focus: function() {
					var parent = this.getParent();
					if(!parent.dndSource || !parent.dndSource.isDragging) {
						this.inherited(arguments);
					}
				}
			}
);

dojo.declare( "com.ibm.widgets.DataMenuItem",
			[dijit.MenuItem, com.ibm.widgets._DataMenuItem], 
			{
				
			}
);

dojo.declare( "com.ibm.widgets.DataPopupMenuItem",
			[dijit.MenuItem, com.ibm.widgets._DataMenuItem],
			{
				constructor: function() {
					this._popupConnects = null;
				},
				startup: function() {
					this.inherited(arguments);
					if(this.popup) {
						this.setPopup(this.popup);
					}
				},
				setPopup: function(popup) {
					this.popup = popup;
					this.popup.anchor = this;
					this._popupConnects = [
						this.connect(this.focusNode, "onfocus", "loadPopup"),
						this.connect(this.popup, "onLoading", "onLoading"),
						this.connect(this.popup, "onLoad", "onLoad")
					];
					this.popup.startup();
					if(this.arrowWrapper) {
						dojo.style(this.arrowWrapper, "visibility", "");
					}
					dijit.setWaiState(this.focusNode, "haspopup", "true");
				},
				destroyPopup: function() {
					if(this.popup) {
						dojo.forEach(this._popupConnects, this.disconnect, this);
						this._popupConnects = null;
						this.popup.destroyRecursive();
						delete this.popup;
						dijit.setWaiState(this.focusNode, "haspopup", "false");
					}
				},
				loadPopup: function() {
					if(this.popup) this.popup.load();
				},
				onLoad: function() {
					// fired when loading this menu item's popup is complete
				},
				onLoading: function() {
					// fired when loading this menu item's popup has started
				},
				_onHover: function() {
					this.loadPopup();
					this.inherited(arguments);
				},
				destroyDescendants: function() {
					this.destroyPopup();
					this.inherited(arguments);
				}
			}
);

dojo.declare( "com.ibm.widgets.LoadingMenuItem",
			dijit.MenuItem,
			{
				label: "Loading...",
				iconClass: "ibmLoading",
				
				postMixInProperties: function() {
					this.shelfBundle = dojo.i18n.getLocalization("com.ibm.bundles", "Shelf");
					this.label=this.shelfBundle["shelf_loading"];
				}
			}
);

dojo.declare( "com.ibm.widgets.EditorMenuItem",
			[dijit.MenuItem, com.ibm.widgets.InlineEditorWrapper],
			{
				templateString:
					 '<tr class="dijitReset dijitMenuItem inlineEditor lotusMenuSeparator" dojoAttachPoint="focusNode" waiRole="menuitem" tabIndex="-1"'
					+'dojoAttachEvent="onmouseenter:_onHover,onmouseleave:_onUnhover,onkeypress:_onKeyPress">'
					+'<td class="dijitReset" waiRole="presentation"><div class="dijitMenuItemIcon" dojoAttachPoint="iconNode"></div></td>'
					+'<td class="dijitReset dijitMenuItemLabel" dojoAttachPoint="containerNode"><span dojoAttachPoint="editor">${label}</span></td>'
					+'<td class="dijitReset dijitMenuArrowCell" waiRole="presentation"></td>'
					+'</tr>',
					
				attributeMap: dojo.mixin(dojo.clone(dijit.MenuItem.prototype.attributeMap), {
					label: {node: "editor", type: "innerHTML"}
				}),
				postCreate: function() {
					this.inherited(arguments);
					dojo.setSelectable(this.domNode, true);
				},
				focus: function() {
					var parent = this.getParent();
					if(!parent.dndSource || !parent.dndSource.isDragging) {
						this.inherited(arguments);
					}
				},
				_onKeyPress: function(evt) {
					if(!evt.ctrlKey && !evt.altKey && evt.charOrCode == dojo.keys.ENTER
						&& !this.isEditing()) {
						this.editor.edit();
						dojo.stopEvent(evt);
						return false;
					}
				}
			}
);

}

if(!dojo._hasResource["com.ibm.widgets.DataTabBar"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.widgets.DataTabBar"] = true;
dojo.provide( "com.ibm.widgets.DataTabBar" );

dojo.require( "com.ibm.widgets.TabBar" );
dojo.require( "com.ibm.widgets.DataMenu" );
dojo.require( "com.ibm.widgets.SelectionModeled" );




dojo.declare( "com.ibm.widgets.DataTabBar",
			[com.ibm.widgets.TabBar, com.ibm.widgets.SelectionModeled],
			{				
				// tagWidget: String the name of the widget class to instantiate for each
				//		tab in this tab bar.
				tabWidget: "com.ibm.widgets.DataTab",
				
				// menuWidget: String the name of the widget class to instantiate for each
				//		menu associated with the tabs.
				menuWidget: "com.ibm.widgets.DataMenu",
				
				// closeDelay: Number of milliseconds to wait before closing a menu when a tab
				//		and any of its menus are no longer hovered over
				closeDelay: 500,
				
				// openDelay: Number of milliseconds to wait before opening a menu when a tab
				//		is hovered over
				openDelay: 0,
				
				// dndHorizontal: Boolean indicating if this model widget should use horizontal dnd
				//		operations.  True for this widget.
				dndHorizontal: true,
				
				// loadingIndicatorWidget: String name of widget class used to represent the loading state of this 
				// 		modeled widget.  By default, it is displayed as a child of this widget while children 
				// 		are being loaded, and is then removed after loading has completed.
				loadingIndicatorWidget: "com.ibm.widgets.LoadingTab",
				
				// inlineEditorWidget: String name of widget class to use to instantiate the inline
				//		editor of this data backed widget.
				inlineEditorWidget: "com.ibm.widgets.ShowEditorTab",
				
				// showNestedInlineEditor: Boolean indicating whether or not to show the inline editor on 
				//		nested menus, cascading down the tree.  False does not show the inline editor for any
				//		while true shows it for all descendants.
				showNestedInlineEditor: false,
								
				postCreate: function() {
					this.inherited(arguments);
					this.initializeModelWidget();
					this._dndParams.withHandles = true;
					dojo.addClass(this.domNode, "modeledTabs");
					if(this.tabStrip) dojo.addClass(this.tabList, this["class"] + "Strip");
				},
				
				startup: function() {
					this.inherited(arguments);
					this.startupModelWidget();
					this.load();
				},
				
				getInheritableParameters: function(item) {
					return dojo.mixin(this.inherited(arguments), {
						closeDelay: this.closeDelay,
						popupDelay: this.popupDelay,
						showInlineEditor: this.showNestedInlineEditor
					});
				},
				handlePreloaded: function() {
					// summary: Plugin point for overrides that handle instantiation of this widget where data
					//		has been provided in the contents of the of the widget itself.
					dojo.forEach(this.getChildren(), function(wij){
						if(this.model.mayHaveChildren(wij.item) || this.showNestedInlineEditor) {
							var popup = this._getPopup(wij.item);
							if(popup) {
								wij.setPopup(popup);
								popup.startup();
							}
						}
					}, this);
					return this.inherited(arguments);
				},
				_getPopup: function(item) {
					if(this.level < this.levels) {
						var menuConstructor = dojo.getObject(this.menuWidget);
						return new menuConstructor(this.getInheritableParameters(item));
					}
					return null;
				},
				createItemRep: function(item) {
					var tabConstructor = dojo.getObject(this.tabWidget);
									
					var args = {
						label: com.ibm.domUtilities.encodeXML(this.model.getLabel(item)),
						iconClass: "dragHandleIcon",
						model: this.model,
						item: item
					};
					if(this.tabClass) {
						args["class"]= this.tabClass;
					}
					if(this.model.mayHaveChildren(item) || this.showNestedInlineEditor) {
						var popup = this._getPopup(item);
						if(popup) args.popup = popup;
					}
					
					var childWidget = new tabConstructor(args);
					childWidget.startup();
					
					// don't load the popup immediately
					// if(childWidget.popup) childWidget.popup.load(); 
					return childWidget; 
				},
				handleChildChildrenChange: function(child, children) {
					// summary: Called when a child that has no children gets children or when a child that has children
					//		loses all its children.
					if(!this.showNestedInlineEditor) {
						if(children.length == 0) {
							// child lost all children, destroy its popup
							child.destroyPopup();
							child.attr("hasChildren", false);
						}
						else if(!child.popup){
							// child without children got new children, create its popup
							var popup = this._getPopup(child.item);
							if(popup) {
								child.setPopup(popup);
								child.attr("hasChildren", true);
								popup.load();
								this.onItemHover(child);
							}
						}
					}
				},
				onItemFocus: function(child) {
					if(child.popup) child.popup.load();
					this.inherited(arguments);
				},
				onItemHover: function(child, evt) {
					if(child.popup) child.popup.load();
					this.inherited(arguments);
				},
				onItemClick: function(child, evt) {
					if(child.attr("disabled")) return false; 
					child.onClick(evt);
					if(child.item) this.onModelItemClick(child, child.item);
				}
			}
);

dojo.declare("com.ibm.widgets.DataTab",
			com.ibm.widgets.Tab,
			{
				_setHasChildrenAttr: function(value) {
					this.hasChildren = value;
					
					if(value){
						var _navModel = com.ibm.mm.builder.utils.navigationUtil.getNavigationModel();
						var childrenIter = _navModel.getChildren(this.item);
						var allChildrenAreHidden = true;
						while (childrenIter.hasNext()) {
							var child = childrenIter.next();
							allChildrenAreHidden = allChildrenAreHidden && child.isHidden();
							if(!allChildrenAreHidden) break;
						}
						value = !allChildrenAreHidden;
					}
					
					dojo[value ? "addClass" : "removeClass"](this.domNode, "modelHasChildren");
				},
				
				_setDndStatusAttr: function(value) {
					this.dndStatus = value;
					if(this.popup) {
						this.popup[value ? "setupDnd" : "disableDnd"]();
					}
				},
				item: null	// type is string so we can process parsed attributes as strings
			}
);

dojo.declare( "com.ibm.widgets.LoadingTab",
			com.ibm.widgets._TabBase,
			{
				templateString:"<li class=\"${class}\" waiRole=\"presentation\" dojoAttachPoint=\"containerNode\" dojoAttachEvent=\"onclick:onClick,onmouseenter:_onHover,onmouseleave:_onUnhover\"\n\t><div\n\t\t><img alt=\"\" dojoAttachPoint=\"iconNode\" src=\"${_blankGif}\" class=\"${iconClass}\"\n\t\t/><a dojoAttachPoint=\"labelNode,focusNode\" href=\"javascript:;\" class=\"tabLabel\" waiRole=\"tab\" onclick=\"javascript:return false;\">${label}</a\n\t></div\n></li>\n",
				
				"class": "loadingTab lotusTab",
				
				iconClass: "ibmLoading",
				
				label: "Loading...",
				
				postMixInProperties: function() {
					this.shelfBundle = dojo.i18n.getLocalization("com.ibm.bundles", "Shelf");
					this.label=this.shelfBundle["shelf_loading"];
				},
				
				attributeMap: dojo.mixin(dojo.clone(dijit._Widget.prototype.attributeMap), {
					label: {node: "labelNode", type: "innerHTML"},
					iconClass: {node: "iconNode", type: "class" }
				}),
				
				isFocusable: function() {
					// loading tabs are not focusable because they provide no actionable
					// content and are simply indicators of an unready or pending status
					return false;
				}
			}
);

}

if(!dojo._hasResource["com.ibm.widgets.NavigationWidget"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.widgets.NavigationWidget"] = true;
dojo.provide( "com.ibm.widgets.NavigationWidget" );

dojo.require( "com.ibm.widgets.DataTabBar" );
dojo.require( "com.ibm.widgets.DataMenu" );



dojo.declare( "com.ibm.widgets.NavigationWidget",
		com.ibm.widgets.DataTabBar,
		{
			
			menuWidget: "com.ibm.widgets.NavigationMenu",
			
			"class": "lotusTabContainer",
			
			tabListClass: "lotusTabs",
			
			tabClass: "lotusTab",
			
			// selectedClass: String the class added to the tab widget which is the
			//		currently selected tab.
			selectedClass: "lotusSelected",
			
			// menuBaseClass: String class to set as the base class of submenus.
			menuBaseClass: "lotusActionMenu",
			
			nestedInlineEditorLabel: "",
			
			// emptyContentsInlineEditorLabel: String used to display the label on inline editor
			//		widgets in the popup menu widgets beneath this level in the model 
			// 		if there are no children at those nodes in the model.
			emptyContentsInlineEditorLabel: "",
			
			constructor: function() {
				this.bundle = dojo.i18n.getLocalization("com.ibm.bundles", "NavWidget");
				this.inlineEditorLabel = this.bundle["nav_new_page_label"];
				this.inlineEditorDefaultValue = this.bundle["nav_new_page_default_value"];
				this.nestedInlineEditorLabel = this.bundle["nav_new_page_nested_label"];
				this.emptyContentsInlineEditorLabel = this.bundle["nav_new_page_empty_nested_label"];
				this.inlineEditorTitle = this.bundle["nav_new_page_title"];
			},
			
			postMixInProperties: function() {
				this.inherited(arguments);
				if(!this.embeddedEditorParams.invalidMessage) this.embeddedEditorParams.invalidMessage = this.bundle["nav_new_page_invalid_message"];
				if(!this.embeddedEditorParams.promptMessage) this.embeddedEditorParams.promptMessage = this.bundle["nav_new_page_prompt_message"];
			},
			
			postCreate: function() {
				this.inherited(arguments);
				dijit.setWaiRole(this.containerNode, "menubar");
				if (dojo.isOpera)
				{
					this.connect(this, "onLoad", function(){
						dojo.query(".ibmPortalList").addContent(" ");
					});
				}
			},	
			
			getInheritableParameters: function(item) {
				return dojo.mixin(this.inherited(arguments), {
					inlineEditorLabel: this.nestedInlineEditorLabel,
					emptyContentsInlineEditorLabel: this.emptyContentsInlineEditorLabel,
					"class": this.menuBaseClass
					/*
					,animateOpen: function() {
						var box = dojo.marginBox(this.domNode);
						var origH = this.domNode.parentNode.style.height,
							origW = this.domNode.parentNode.style.width 
							origD = this.domNode.style.display;
						dojo.style(this.domNode, "display", "none");
						dojo.style(this.domNode.parentNode, {
							"width": box.w + "px"
						});
						
						dojo.addClass(this.domNode.parentNode, "bordered");
						
						var dur = 200, anim = null;
						dojo.animateProperty({
							node: this.domNode.parentNode, 
							duration: 150, 
							properties: {
								height: { start:'0', end: box.h, unit:"px" }
							}
						});

						anim.onEnd = dojo.hitch(this, function() {
							dojo.style(this.domNode.parentNode, "height", origH);
							dojo.removeClass(this.domNode.parentNode, "bordered");
							dojo.style(this.domNode, "display", origD);
						});
						anim.play();
					}
					*/
				});
			}
		}
);

dojo.declare( "com.ibm.widgets.NavigationMenu",
		com.ibm.widgets.DataMenu,
		{	
			// emptyContentsInlineEditorLabel: String used to display the label on inline editor
			//		widgets in this widget if there are no children at this node in the model.
			emptyContentsInlineEditorLabel: "",
			
			"class": "lotusActionMenu",
			
			constructor: function() {
				this.bundle = dojo.i18n.getLocalization("com.ibm.bundles", "NavWidget");
				this.inlineEditorLabel = this.bundle["nav_new_page_label"];
				this.inlineEditorDefaultValue = this.bundle["nav_new_page_default_value"];
				this.nestedInlineEditorLabel = this.bundle["nav_new_page_nested_label"];
				this.emptyContentsInlineEditorLabel = this.bundle["nav_new_page_empty_nested_label"];
				this.inlineEditorTitle = this.bundle["nav_new_page_title"];
			},
			
			postMixInProperties: function() {
				this.inherited(arguments);
				if(!this.embeddedEditorParams.invalidMessage) this.embeddedEditorParams.invalidMessage = this.bundle["nav_new_page_invalid_message"];
				if(!this.embeddedEditorParams.promptMessage) this.embeddedEditorParams.promptMessage = this.bundle["nav_new_page_prompt_message"];
			},
			
			postCreate: function() {
				this.inherited(arguments);
				dijit.setWaiRole(this.containerNode, "navigation");
				if(this.showInlineEditor && this.level == 1) {
					this.connect(this, "onLoad", function() {
						if(this.inlineEditor) {
							if(this.getChildren().length < 2) {
								this.inlineEditor.editor.attr("value", this.emptyContentsInlineEditorLabel);
							}
						}
					});
					this.connect(this, "onModelRemoveChild", function(parentItem, childItem) {
						if(this.item == parentItem && this.getChildren().length < 2) {
							this.inlineEditor.editor.attr("value", this.emptyContentsInlineEditorLabel);
						}
					});
					this.connect(this, "onModelInsertChild", function(parentItem, childItem, nextSibling) {
						if(this.item == parentItem) {
							this.inlineEditor.editor.attr("value", this.inlineEditorLabel);
						}
					});
				}
			},
			getInheritableParameters: function(item) {
				return dojo.mixin(this.inherited(arguments), {
					emptyContentsInlineEditorLabel: this.emptyContentsInlineEditorLabel
					/*
					,animateOpen: function() {
						var box = dojo.marginBox(this.domNode);
						var origH = this.domNode.parentNode.style.height,
							origW = this.domNode.parentNode.style.width 
							origD = this.domNode.style.display;
						dojo.style(this.domNode, "display", "none");
						dojo.style(this.domNode.parentNode, {
							"height": box.h + "px"
						});
						
						dojo.addClass(this.domNode.parentNode, "bordered");
						
						var dur = 200, anim = null;
						anim = dojo.animateProperty({
							node: this.domNode.parentNode, 
							duration: 150, 
							properties: {
								width: { start:'0', end: box.w, unit:"px" }
							}
						})

						anim.onEnd = dojo.hitch(this, function() {
							dojo.style(this.domNode.parentNode, "width", origW);
							dojo.removeClass(this.domNode.parentNode, "bordered");
							dojo.style(this.domNode, "display", origD);
						});
						anim.play();
					}
					*/
				});
			}
		}
);

}

if(!dojo._hasResource["com.ibm.widgets.Breadcrumbs"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.widgets.Breadcrumbs"] = true;
dojo.provide("com.ibm.widgets.Breadcrumbs");







dojo.declare("com.ibm.widgets.Breadcrumbs",
			[dijit._Widget, dijit._Templated],
			{
				model: null,				// a selection model on which to base the breadcrumb trail
				treeModel: null,			// the tree model backing the selection model 
				item: null,					// the currently selected item with in the model
				parent: null,				// the parent of item
				siblings: {},				// an associative array of item => DOM node pairs
				startLevel: null,			// the number of the level to start rendering the breadcrumbs at
				levels: Number.MAX_VALUE,	// the number of levels to render in the trail, Number.MAX_VALUE is used to represent all levels
				renderSiblings: true,		// true if siblings of the current selection should be rendered in the trail
				newSiblingText: "",			// text to display in the link to create a new sibling item
				newSiblingDefaultValue: "",
				embeddedEditorWidget: "dijit.form.TextBox",
				allowNew: true,				// true if a link should be rendered allowing the user to create a new sibling item
				newEditor: null,			// a dijit.form.ValidationTextBox to create new pages
				embeddedEditorParams: {},	// parameters for the dijit.form.ValidationTextBox
				introText: "",				// text to display before the trail begins
				listDOM: "ul",				// the type of DOM node that holds the trail links
				itemDOM: "li",				// the type of DOM node to act as a trail node
				containerClass: "",			// the class to put on the outer container div to the trail
				listClass: "",				// the CSS class to put on the container of the trail links
				ancestorClass: "",			// the CSS class to put on any ancestor nodes in the trail
				siblingClass: "",			// the CSS class to put on any sibling nodes in the trail
				newClass: "",				// the CSS class to put on the link to create a new item
				ancestorSeparator: " > ",	// the text separation to put between ancestor nodes
				siblingSeparator: " | ",	// the text separation to put between sibling nodes
				templateString: '<div dojoAttachPoint="focusNode" class="${containerClass}"><span dojoAttachPoint="introTextNode"></span><${listDOM} dojoAttachPoint="trail" class="${listClass}"></${listDOM}></div>',
					
				constructor: function() {
					this.bundle = dojo.i18n.getLocalization("com.ibm.bundles", "NavWidget");
					this.theme = dojo.i18n.getLocalization("com.ibm.bundles", "Theme");
					this.introText = this.bundle["breadcrumb_intro"];
					this.newSiblingText = this.bundle["breadcrumb_new_page_label"];			
					this.newSiblingDefaultValue = this.bundle["nav_new_page_default_value"];
					this.currentlySelected = this.theme["currently_selected"];
				},
				
				postMixInProperties: function() {
					this.inherited(arguments);
					if(!this.embeddedEditorParams.invalidMessage) this.embeddedEditorParams.invalidMessage = this.bundle["nav_new_page_invalid_message"];
					if(!this.embeddedEditorParams.promptMessage) this.embeddedEditorParams.promptMessage = this.bundle["nav_new_page_prompt_message"];
				},
				
				postCreate: function(){
					// summary: populate some of the class variables and set up listeners
					//this.parent = this.model.getParent(this.item);
					// set up listeners on the model for when an item is removed/inserted/moved
					this.treeModel = this.model.treeModel;
					this.connect(this.model, "onSelectionPathChange", "redraw");
					this.connect(this.treeModel, "onTreeChange", "onModelTreeChange");
				},
				
				startup: function() {
					this.inherited(arguments);
					// populate the breadcrumbtail
					this.draw();
				},
					
				draw: function(){
					// summary: populates the breadcrumb trail with ancestors and siblings (if specified) to the current item
					var path = this.model.getPath();
					this.parent = path[1];
					if(path.length - this.startLevel <= 1){
						this.introTextNode.innerHTML = "";
						return;
					}
					this.introTextNode.innerHTML = this.introText;
					for(var i = 1; i < path.length && i <= this.levels && i < (path.length - this.startLevel); i++) {
						this.createDomLink(path[i], this.ancestorClass, this.ancestorSeparator, this.trail.firstChild);
					}
					// retrieve and add the siblings to the current item
					if(this.renderSiblings){	
						this.siblings = [];
						this.shelfBundle = dojo.i18n.getLocalization("com.ibm.bundles", "Shelf");
						var loading = document.createTextNode(this.shelfBundle["shelf_loading"]);
						this.trail.appendChild(loading);
						this.treeModel.getChildren(path[1], dojo.hitch(this, function(siblings){
							this.trail.removeChild(loading);
							// render the current item
							this.createDomText(path[0], this.siblingClass, this.siblingSeparator, null);
							// render the siblings
							var curPageId = this.treeModel.getIdentity(path[0]);
							dojo.forEach(siblings, function(sibling) {  
								if(curPageId != this.treeModel.getIdentity(sibling)) 
									this.siblings.push({item: sibling, node: this.createDomLink(sibling, this.siblingClass, this.siblingSeparator, null)});
							}, this)
							this.createEditBox();
						}));
					} else { // do not add siblings
						this.createDomText(path[0], this.siblingClass, this.siblingSeparator, null);
						this.createEditBox();
					}
				},
				
				redraw: function(/*Boolean*/ selectionChanged) {
					this.trail.innerHTML = "";
					this.draw();
				},
				
				onModelTreeChange: function(/*Item*/ childItem, /*Item*/ oldParentItem, /*Item*/ newParentItem, /*Item*/ nextSiblingItem) {
					// summary: Listens to changes in the tree model where items are inserted, deleted, or moved within the tree.
					// 		This only cares about insertions and deletions under the current selection's parent node.
					var currentlySelectedItem = this.model.getPath()[0];
					if(oldParentItem != newParentItem && childItem != currentlySelectedItem) {
						if(this.parent == oldParentItem) {
							this.onModelRemoveChild(childItem);
						}
						else if(this.parent == newParentItem) {
							var isNew = (!oldParentItem)?true:false;
							this.onModelInsertChild(childItem, isNew);
						}
					}
				},
				
				onModelRemoveChild: function(/*Item*/childItem){
					// summary: Responds to events which cause a node to be removed from the current selection's parent node
					// 		in the model either by moving or deletion of an item.
					// childItem: the item that was deleted
					var path = this.model.getPath();
					if(path.length - this.startLevel <= 1) return;
					for(var i = 0; i < this.siblings.length; i++) {
						if(childItem == this.siblings[i].item) {
							this.trail.removeChild(this.siblings[i].node);
							delete this.siblings[i].item;
							delete this.siblings[i].node;
							this.siblings.splice(i, 1);						
							return;
						}
					}
				},
				
				onModelInsertChild: function(/*Item*/childItem,/*bool*/isNew){
					// summary: Responds to events which cause a node to be inserted under the current selection's parent
					// 		node in the model either by moving or creation of a new item. 
					// childItem: the new/moved item
					// isNew: true if the child is new, as opposed to having been moved from a different parent
					var path = this.model.getPath();
					if(path.length - this.startLevel <= 1) return;
					if(this.renderSiblings){ 
						// this.item has a new sibling
						// find the new item editor link and insert the new sibling item BEFORE this node
						var editor = this.newEditor;
						var insertBefore = (editor)?editor.domNode:null;
						var node = this.createDomLink(childItem,this.siblingClass,this.siblingSeparator,insertBefore);
						if(isNew) dojo.addClass(node,"disabled");
						this.siblings.push({item: childItem, node: node});
						
						if(!childItem.created) {
							setTimeout(function(){
								dijit.focus(node);
							},0);
							var conn = dojo.connect(childItem, "onCreate", this, function(){
								node.firstChild.href = top.location.href + "?uri=" + this.treeModel.getIdentity(childItem);
								dojo.removeClass(node,"disabled");
								dojo.disconnect(conn);
							});
						}
					}
				},
				
				createDomLink: function(item, className, separator, node){
					// summary: creates a DOM node in the breadcrumb trail with a link as inner html
					// item: the item for which to create the DOM node
					// className: the CSS class to put on the new DOM node
					// separator: a text separator to append after the item link
					// node: a DOM item before which to place the new DOM link, null to place it at the end of the list
					var domItem = document.createElement(this.itemDOM);
					dojo.addClass(domItem, className);
					var link = document.createElement("a");
					domItem.appendChild(link);
					domItem.appendChild(document.createTextNode(separator));
					link.appendChild(document.createTextNode(this.treeModel.getLabel(item)));
					var url = top.location.href;
					// check to see if url has reference anchors or parameters, and if so, then discard them
					if(url.indexOf('#') > -1)
						url = url.substring(0, url.indexOf('#'));
					if(url.indexOf('?') > -1)
						url = url.substring(0, url.indexOf('?'));
					link.href = url + "?uri=" + this.treeModel.getIdentity(item);
					this.trail.insertBefore(domItem, node);
					return domItem;
				},
				
				createDomText: function(item, className, separator, node){
					// summary: creates a DOM node in the breadcrumb trail with plain text inner html
					// item: the item for which to create the DOM node
					// className: the CSS class to put on the new DOM node
					// separator: a text separator to append after the item text
					// node: a DOM item before which to place the new DOM text, null to place it at the end of the list
					var domItem = document.createElement(this.itemDOM);
					dojo.addClass(domItem, className);
					var hiddenText = dojo.create("span", {innerHTML: this.currentlySelected, className: "ibmPortalHiddenText"});
					var hiddenSpan = dojo.create("span");
					hiddenSpan.appendChild(hiddenText);
					domItem.appendChild(document.createTextNode(this.treeModel.getLabel(item)));
					domItem.appendChild(hiddenText);
					domItem.appendChild(document.createTextNode(separator));
					this.trail.insertBefore(domItem, node);
					return domItem;
				},
				
				createEditBox: function(){
					// summary: creates a link to create a new sibling item iff this.allowNew is true
					if(this.allowNew){
						this.newEditor = new com.ibm.widgets.BreadcrumbsEditor({
							embeddedEditorWidget: this.embeddedEditorWidget,
							embeddedEditorParams: this.embeddedEditorParams,
							"class": this.newClass,
							label: this.newSiblingText,
							defaultValue: this.newSiblingDefaultValue
						});
						
						this.newEditor.editor.width = "10em";
						this.newEditor.editor.lineHeight = "1.5em";
						
						//this.newEditor = new dijit.InlineEditBox({value:this.newSiblingText,width:"10em",lineheight:"1.5em",editor:"dijit.form.ValidationTextBox",editorParams:this.embeddedEditorParams},link);
						this.connect(this.newEditor, "onChange", "createNewSiblingItem");
						this.trail.appendChild(this.newEditor.domNode);
					}
				},
				
				onClickItem: function(item){
					// summary: redirects the browser to the url associated with item
					// item: the item with the link to redirect to
					if(!item.created) return false;
					top.location.href = top.location.href + "?uri=" + this.treeModel.getIdentity(item);
				},
				
				createNewSiblingItem: function(/*Object*/value, focus){
					// summary: triggered by the onChange event from the dijit.InlineEditBox used for creating new items
					// value: Object key-value map of attributes to set on the new item
					var newItem = null;
					var onComplete = function() {
						newItem.onCreate();
					}
					newItem = this.treeModel.newItem(dojo.mixin(value, {onComplete: onComplete, scope: this}),this.parent); // create the new item as a sibling to this.item
					newItem._onCreate = function(){ /*do nothing*/ };  // make sure _onCreate is a non null function
				}
				
			}
);

dojo.declare("com.ibm.widgets.BreadcrumbsEditor",
	[dijit._Widget, dijit._Templated, com.ibm.widgets.InlineEditorWrapper],
	{
		templateString: '<span class="inlineEditor ${class}" waiRole="presentation"><a dojoAttachPoint="editor,focusNode" class="newPageLink" href="javascript:;">${label}</a></span>'
		
	}
);

}

if(!dojo._hasResource["com.ibm.dnd.PageCreator"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.dnd.PageCreator"] = true;
dojo.provide("com.ibm.dnd.PageCreator");

dojo.declare("com.ibm.dnd.PageCreator",
	null,
	{		
		creator: function(item, hint){
		//summary: creates the node to be used during
	    //         construction of the avatar
			var node = document.createElement("div");
			if(hint=="avatar"){
				node.className = "ibmPortalDndPageAvatar";
				var title = document.createTextNode(item);
				node.appendChild(title);
			}
			return {node: node, data: item, type: ["cmNode"]};
		}
	});

com.ibm.dnd.PAGE_CREATOR = new com.ibm.dnd.PageCreator();

}

if(!dojo._hasResource["com.ibm.widgets.InlineShelf"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.widgets.InlineShelf"] = true;
 // This is a dropdown inline shelf

dojo.provide("com.ibm.widgets.InlineShelf");



dojo.declare("com.ibm.widgets.InlineShelf",
	[dijit._Widget, dijit._Templated],
	{
		content: null,				// HTML content to display in the shelf
		link: null,					// an id or DOM element to which the shelf's toggle function should be attached
		shelfClass: "",				// css classes to put on the shelf
		displayState: "closed",		// state of the shelf, ie "open", "closed"
		everOpened: false,			// true when the shelf has been opened before
		wipeOut: null,				// animation to slide the shelf out of view
		wipeIn: null,				// animation to slide the shelf into view
		wipeTime: 300,				// the time the shelf takes to slide in/out in milliseconds
		templateString: '<div dojoAttachPoint="focusNode" style="display: none;" class="${shelfClass}"></div>',
		
		startup: function(){
			// create the hide/show animations
			this.wipeOut = dojo.fx.wipeOut({node:this.domNode, duration:this.wipeTime});
			this.wipeIn = dojo.fx.wipeIn({node:this.domNode, duration:this.wipeTime});
			
			// add the content
			if(this.content) this.domNode.appendChild(this.content);
			this.onCreate();
		},
		
		connectButton: function(){
			// set the onclick handler for the toggle link
			if (dojo.isString(this.link)) this.link = dojo.byId(this.link);
			if(this.link && !this.buttonConnection) {
				this.buttonConnection = dojo.connect(this.link, "onclick", this, this.toggleDisplay);
				dojo.removeClass(this.link,"lotusBtnDisabled");
			}
		},
		
		disconnectButton: function(){
			// set the onclick handler for the toggle link
			if(this.buttonConnection) {
				dojo.disconnect(this.buttonConnection);
				this.buttonConnection = null;
			}
			if(this.link) dojo.addClass(this.link, "lotusBtnDisabled");
		},
		
		toggleDisplay: function(){
			// summary: changes the state of the display
			if(this.displayState == "open") {
				this.onClose();
				if(dojo.isIE == 6) dojo.style(this.domNode,"display","none");
				else this.wipeOut.play();
				this.displayState = "closed";
			} else if (this.displayState == "closed"){
				this.onOpen();
				if(!this.everOpened) { this.startup(); }
				if(dojo.isIE == 6) dojo.style(this.domNode,"display","");
				else this.wipeIn.play();
				if(!this.everOpened) { this.onFirstOpen(); this.everOpened = true; }
				this.displayState = "open";
			}
		},
		
		onCreate: function(){
			// summary: stub event for when the shelf is instantiated
		},
		
		onOpen: function(){
			// summary: stub event for when the shelf is displayed
		},
		
		onFirstOpen: function(){
			// summary: stub event for when the shelf is opened for the first time
		},
		
		onClose: function(){
			// summary: stub event for when the shelf is hidden
		}
});

}

if(!dojo._hasResource["com.ibm.UnloadGuard"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.UnloadGuard"] = true;
dojo.provide("com.ibm.UnloadGuard");

(function(){
	
	// This utility is used for guarding against unload events when certain events
	// are still pending.  It provides topics for adding and removing pending events
	// through the dojo.publish/subscribe model.
	
	// If events are still pending when the window tries to unload, a confirmation dialog
	// will be displayed to the user with one of the outstanding pending messages, allowing the user
	// to cancel the unload event and stay on the page if the user so chooses.  There is no
	// way to determine which message amongst the list of pending events is displayed to the user as
	// the only guarantee is that one of them will be displayed.
	
	// Other things can subscribe to these topics also in order to perform other functions.
	// An example could be a widget that shows some visual indicator while certain events are
	// still pending and hides itself when they complete.
	
	// Below is a list of topics used by this module.  The arguments that this utility is interested
	// in are also documented, however, any additional arguments can be used by other modules
	// that are also interested in these topics.  However, this utility will only use the arguments
	// specified below.  Other things can subscribe to these topics also in order to perform other 
	// functions.  An example could be a widget that shows some visual indicator while certain events 
	// are still pending and hides itself when they complete.
	//
	// Topics:
	//		"/window/unload/addPending" - Publish to this with one argument which is the message 
	//			to display to the user if the window is unloaded before the event is completed.
	//		
	//		"/window/unload/removePending" - Publish to this with one argument which is a previously
	//			added message in order to remove this message from the list of pending events.
	//				
	//		"/window/unload/nonePending" - Do not publish to this topic.  It is published to by this
	//			module whenever there are no more pending events after a previous one was removed.
	//			It is meant to be subscribed to.
	
	var pending = {};
	
	var isPending = function() {
		for(var x in pending) {
			if(pending[x] && pending[x].length > 0) return x;
		}
		return false;
	}
	
	var addPending = function(message) {
		if(!pending[message]) pending[message] = [];
		pending[message].push(true);
	}
	
	var removePending = function(message) {
		if(pending[message]) {
			pending[message].pop();
		}
		if(!isPending()) {
			dojo.publish("/window/unload/nonePending");
		}
	}
	

	dojo.subscribe("/window/unload/addPending", null, addPending);
	dojo.subscribe("/window/unload/removePending", null, removePending);

	window.onbeforeunload = function() {
		var msg = isPending();
		if(msg !== false) return msg;
	}
})();

}

if(!dojo._hasResource["dojo.DeferredList"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.DeferredList"] = true;
dojo.provide("dojo.DeferredList");
dojo.declare("dojo.DeferredList", dojo.Deferred, {
	constructor: function(/*Array*/ list, /*Boolean?*/ fireOnOneCallback, /*Boolean?*/ fireOnOneErrback, /*Boolean?*/ consumeErrors, /*Function?*/ canceller){
		// summary:
		//		Provides event handling for a group of Deferred objects.
		// description:
		//		DeferredList takes an array of existing deferreds and returns a new deferred of its own
		//		this new deferred will typically have its callback fired when all of the deferreds in
		//		the given list have fired their own deferreds.  The parameters `fireOnOneCallback` and
		//		fireOnOneErrback, will fire before all the deferreds as appropriate
		//
		//	list:
		//		The list of deferreds to be synchronizied with this DeferredList
		//	fireOnOneCallback:
		//		Will cause the DeferredLists callback to be fired as soon as any
		//		of the deferreds in its list have been fired instead of waiting until
		//		the entire list has finished
		//	fireonOneErrback:
		//		Will cause the errback to fire upon any of the deferreds errback
		//	canceller:
		//		A deferred canceller function, see dojo.Deferred
		this.list = list;
		this.resultList = new Array(this.list.length);

		// Deferred init
		this.chain = [];
		this.id = this._nextId();
		this.fired = -1;
		this.paused = 0;
		this.results = [null, null];
		this.canceller = canceller;
		this.silentlyCancelled = false;

		if(this.list.length === 0 && !fireOnOneCallback){
			this.callback(this.resultList);
		}

		this.finishedCount = 0;
		this.fireOnOneCallback = fireOnOneCallback;
		this.fireOnOneErrback = fireOnOneErrback;
		this.consumeErrors = consumeErrors;

		dojo.forEach(this.list, function(d, index){
			d.addCallback(this, function(r){ this._cbDeferred(index, true, r); return r; });
			d.addErrback(this, function(r){ this._cbDeferred(index, false, r); return r; });
		}, this);
	},

	_cbDeferred: function(index, succeeded, result){
		// summary:
		//	The DeferredLists' callback handler

		this.resultList[index] = [succeeded, result]; this.finishedCount += 1;
		if(this.fired !== 0){
			if(succeeded && this.fireOnOneCallback){
				this.callback([index, result]);
			}else if(!succeeded && this.fireOnOneErrback){
				this.errback(result);
			}else if(this.finishedCount == this.list.length){
				this.callback(this.resultList);
			}
		}
		if(!succeeded && this.consumeErrors){
			result = null;
		}
		return result;
	},

	gatherResults: function(deferredList){
		// summary:	
		//	Gathers the results of the deferreds for packaging
		//	as the parameters to the Deferred Lists' callback

		var d = new dojo.DeferredList(deferredList, false, true, false);
		d.addCallback(function(results){
			var ret = [];
			dojo.forEach(results, function(result){
				ret.push(result[1]);
			});
			return ret;
		});
		return d;
	}
});

}

if(!dojo._hasResource["com.ibm.customize.TabbedController"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.customize.TabbedController"] = true;
 // This is tabbed container with controller children
dojo.provide("com.ibm.customize.TabbedController");







dojo.declare("com.ibm.customize.TabbedController",
	[com.ibm.widgets.InlineShelf],
	{
		children: [],					// array of children to display in the tabs, each array item is an object {tabName:"",controller:object that implements the Customize Controller API}
		pendingChildren: 0,				// the number of children with pending changes used to determine whether or not the save link should be enabled
		imagePath: '.',					// path to the css images
		hiddenClass: "lotusHidden",		// the css class name to hide content panes
		selectedClass: "lotusSelected",	// the css class to select tabs
		transitions:true, 				// true if com.ibm.portal.fx.Transitions should be used when saving children
		templateString: '<div class="lotusui ibmPortalCustomizeShelf lotusPalette" style="display: none;">' +
							'<div class="lotusPaletteHeader">' +
								'<ul dojoAttachPoint="tabs" class="lotusTabs"></ul>' +
							'</div>' +
							'<div dojoAttachPoint="containerDivs"></div>' +
						'</div>',
		refreshRetryInterval: 300,		// if a refresh request is delayed because a save is pending, this is the amount of time to wait before retrying the refresh				
		
		constructor: function() {
			this.bundle = dojo.i18n.getLocalization("com.ibm.bundles", "Shelf");
			this.okText = this.bundle["shelf_saveChanges"];
			this.cancelText = this.bundle["add_content_cancel"];
		},
		
		onFirstOpen: function(){
			this.fillTabs();
		},
		
		fillTabs: function(){
			// create the tabs and container divs for each child
			var clickFirstTab, first = true;
			dojo.forEach(
				this.children,
			    dojo.hitch(this, function(child){
					// create a node for the child to create its container
					var div = dojo.create("div",{className:this.hiddenClass});
					this.containerDivs.appendChild(div);
					div.appendChild(child.controller.domNode);
					child.containerDiv = div;
					// create a tab div to access the container
					var tab = dojo.create("li");
					var tabName = dojo.create("a",{innerHTML:child.controller.tabLabel,href:"javascript:void(0)"});
					tab.appendChild(tabName);
					this.tabs.appendChild(tab);
					child.tab = tab;
					// create an onclick handler for each tab that opens its container
					tabName.onclick = dojo.hitch(this,this.showTab,child);
					// connect to the child's dirty attribute
					this.connect(child.controller, "makeDirty", "modifyPending");
					// if it's the first child, select its tab
					if(first) {
						first = false;
						clickFirstTab = tabName.onclick;
					}
			}));
			clickFirstTab(); 
			this.onStartup();
		},
		
		undoChildren: function(){
			// summary: undoes all pending changes in the children
			dojo.forEach( this.children, dojo.hitch(this, function(child){ 
				child.controller.undo();	
			}));
		},
		
		saveChildren: function(){
			// summary: saves all pending changes in the children and refreshes the page if necessary
			// check if there are any changes in the controllers
			if(!this.pendingChildren) return;
			var closeOverlay = this.transitions ? this.children[0].controller.showWaitMsgInDialog(this.bundle["shelf_saving"]) : function(){};
			this.beforeSave().addCallback(dojo.hitch(this, "_proceedSave", closeOverlay));
		},
		
		_proceedSave: function(closeOverlay) {
			// count function keeps track of how many children are done submitting
			// when count is 0, all children have finished submitting
			var refresh = false;
			var count = this.children.length;
			var counter = dojo.hitch(this,function(){
				if(--count == 0) {
					if(this.transitions) closeOverlay();
					if(refresh) this.refreshPage();
				}
			});
			var handleError = dojo.hitch(this,function(errors){
				counter();
				var message = errors[0].message;
				var details = errors[0].responseText;
				if(message.match(/\D401/)){ // Portal session not authenticated
					details = message;
					message = this.bundle["shelf_session_timeout"];
				}
				var statusMessage = new com.ibm.widgets.StatusMessage( "error", message, details );
				dojo.publish("/portal/status",[{message: statusMessage, uid: 'ibmPortalStatusBox'}]);
			});
			// call beforeSubmit on each child
			var dfdl = new dojo.DeferredList(dojo.map( this.children, function(child){
				return child.controller.beforeSubmit();
			}, this));
			dfdl.addCallback(dojo.hitch(this, function(){
				// call submit on each child
				dojo.forEach( this.children, function(child){ 
					if(child.controller.refresh && child.controller.dirty) refresh = true; 
					child.controller.submit({onComplete:counter,onError:handleError});	
				}, this);
			}));
		},
		
		portalBeforeSave: function(callback){
			if(!this.pendingChildren) { callback(); return; } 
			this.closeOverlay = this.transitions ? this.children[0].controller.showWaitMsgInDialog(this.bundle["shelf_saving"]) : function(){};
			var dfdl = new dojo.DeferredList(dojo.map( this.children, function(child){
				return child.controller.beforeSubmit();
			}, this));
			dfdl.addCallback(dojo.hitch(this, callback));
		},
		
		portalSave: function(callback){
			if(!this.pendingChildren) return;
			var refresh = false;
			var count = this.children.length;
			var counter = dojo.hitch(this,function(){
				if(--count == 0) {
					callback();
					if(this.transitions) this.closeOverlay();
					if(refresh) this.refreshPage();
				}
			});
			var handleError = dojo.hitch(this,function(errors){
				counter();
				var message = errors[0].message;
				var details = errors[0].responseText;
				if(message.match(/\D401/)){ // Portal session not authenticated
					details = message;
					message = this.bundle["shelf_session_timeout"];
				}
				var statusMessage = new com.ibm.widgets.StatusMessage( "error", message, details );
				dojo.publish("/portal/status",[{message: statusMessage, uid: 'ibmPortalStatusBox'}]);
			});
			dojo.forEach( this.children, function(child){ 
				if(child.controller.refresh && child.controller.dirty) refresh = true; 
				child.controller.submit({onComplete:counter,onError:handleError});	
			}, this);
		},
		
		refreshPage: function () {
			// summary: Reloads the page to show any changes that require the page to be completely reloaded to render. If a save is currently in progress,
			//		the reload request will be queued until the save operation completes. 
			if (ibmPortalConfig.savePageManager && !ibmPortalConfig.savePageManager.isDirty()) {
				com.ibm.utilities.refreshPage();
			} else {
				//A refresh has been requested, but we need to wait until the save is completed before honoring it.
				setTimeout( dojo.hitch( this, this.refreshPage ), this.refreshRetryInterval );
			}
		},
		
		modifyPending: function(/*bool*/change){
			// summary: changes the value of the pendingChildren variable
			if(change) this.pendingChildren++
			else this.pendingChildren--;
			if(change) this.makeDirty();
		},
		
		makeDirty: function(){},  // used for Save Page Manager to connect to
		
		showTab: function(/*Object*/selectedChild){
			// summary: displays the content pane for the given controller
			// selectedChild: the child to show
			
			if(!selectedChild.controller.started){
				// if the child isn't started yet, start it up
				selectedChild.controller.startup(this);
			}
			// clear all the tabs and container divs
			dojo.forEach(
				this.children,
			    dojo.hitch(this, function(child){
					dojo.removeClass(child.tab,this.selectedClass);
					dojo.addClass(child.containerDiv,this.hiddenClass);
			}));
			// select and show the given child
			dojo.addClass(selectedChild.tab,this.selectedClass);
			dojo.removeClass(selectedChild.containerDiv,this.hiddenClass);
			this.onShowTab(selectedChild);
			return false; /* to prevent onBeforeUnload event from triggering in IE */
		},
		
		onStartup: function(){
			// summary: stub event to be called when the TabbedController is started up
		},
		
		onShowTab: function(/*Object*/selectedChild){
			// summary: stub event to be called whenever a tab is shown
		},
		
		beforeSave: function(){
			// summary: stub event to be called when saveChildren is called.  Returns a Deferred
			//		which is fired when save processing can be continued.
			var dfd = new dojo.Deferred();
			dfd.callback();
			return dfd;
		}
});

}

if(!dojo._hasResource["com.ibm.customize.ResultsList"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.customize.ResultsList"] = true;
// This controls the list of results in the customization shelf.  It handles searching datastores and paging.  It usually works with a com.ibm.customize.Container as its parent.

dojo.provide("com.ibm.customize.ResultsList");





dojo.declare("com.ibm.customize.ResultsList",
	[dijit._Widget, dijit._Templated],
	{
		source: null,						// the source which is currently selected for searching
		parent: null, 						// the parent container for this widget
		searchTerms: [], 					// an array of search terms for fetch 
		currRequest: null,					// the current fetch request
		size: 9,							// the number of results displayed at once
		start: 0,							// the index of the first result displayed in the section
		totalItemCount: 0,					// the total number of items matched by the last search query
		templateString: '<div dojoAttachPoint="focusNode">' +
							'<div class="lotusPaletteWidgetContainer" role="grid" dojoAttachPoint="table"></div>' +
							'<div class="lotusPaging">' +
								'<div class="lotusLeft" dojoAttachPoint="pagingStatus"></div>' +
								'<ul class="lotusRight lotusInlinelist">' +
									'<li class="lotusFirst" dojoAttachPoint="prevLink"></li>' +
									'<li dojoAttachPoint="nextLink"></li>' +
								'</ul>' +
								'<div dojoAttachPoint="jumpToLink" class="lotusText"></div>' +
							'<div>' +
						'</div>',
		
		constructor: function() {
			this.shelfBundle = dojo.i18n.getLocalization("com.ibm.bundles", "Shelf");
		},
		
		postCreate: function(){ 
			// summary: subscribes to events for when the search terms changes, the source changes, the user wants to add a saved search, or the size of the browser window adjusts
			dojo.subscribe("/epc/customize/search"+this.parent.id, this, this.changeSearchTerms);
			dojo.subscribe("/epc/customize/changeSource"+this.parent.id, this, this.changeSource);
		},
		
		/**********************************/
		/*            SEARCH              */
		/**********************************/
		
		changeSearchTerms: function(/*String[]*/ searchTerms){
			// summary: does a new search when the filters change
			// searchTerms: an array of strings which are filters
			this.searchTerms = searchTerms;
			this.start = 0;
			this._search();
		},
		
		changeSource: function(/*Object*/ source){
			// summary: does a fresh search with no filters when the hub changes
			// source: the new source to search
			if(this.currRequest) this.currRequest.abort();  // make sure any unfinished request is aborted
			this.source = source;
			this.searchTerms = [];
			this.start = 0;
			if(source.hub.noIcons) dojo.addClass(this.domNode.parentNode,"lotusPlain");
			else dojo.removeClass(this.domNode.parentNode,"lotusPlain");
			this._search();
		},
		
		_search: function(){
			// summary: does a fetch operation on the hub and fills the table with the results
			if(this.source.hub == null){
				// alert the user if the hub is null and clear out old info on the paging bar
				this.addMessage("Error",dojo.string.substitute(this.shelfBundle["shelf_badDatastoreError"], [this.source.label]));
				return;
			} else this.setLoading();
			
			// See dojo.data.api.Read.fetch()
			this.currRequest = this.source.hub.fetch({
				queryOptions: { ignoreCase: true },
				query: { keywords: this.searchTerms }, // query is the array of filters that the hub handles in its own way
				count: this.size,
				start: this.start,  
				
				onComplete: dojo.hitch(this, function(/*DatastoreItem[]*/items) {
					// summary: uses the items returned from the search to adjust what is displayed on the paging bars, and fill the table with results
					if(this.parent.filterAdd){
						// filter out any items that should not be displayed
						filterFcn = dojo.hitch(this,function(item){ return this.parent.filterAdd(this.source.hub.mapItem(item)); })
						items = dojo.filter(items,filterFcn);
					}
					if(items.length == 0) this.addMessage("Warning",this.shelfBundle["shelf_noResults"]);
					else this.fill(items);
				}),
				
				onError: dojo.hitch(this, function(/*String*/error, /*Object*/request) {
					// summary: displays an error message in the table and clears out old info on the paging bar
					this.clear();
					this.addMessage("Error", dojo.string.substitute(this.shelfBundle["shelf_feedError"], [this.source.label]));
				}),
				
				onBegin: dojo.hitch(this, function(totalNumber) {
					// summary: records the number of results returns in the current query
					this.totalItemCount = totalNumber;
				})
			});
		},
		
		/***********************************/
		/*              TABLE              */
		/***********************************/
		
		setLoading: function() {
			// summary: adds a loading indicator, for use before search results are appended
			this.clear();
			this.table.appendChild(document.createTextNode(this.shelfBundle["shelf_loading"]));
		},
		
		addMessage: function(/*String*/type,/*String*/msg){
			// summary: clears out the table and then builds it back up enough to enter a single message into the table
			// msg: the message to enter in the table
			this.clear();
			// create the cell
			var message = this.parent.createLotusMsgNode(msg,type);
			this.table.appendChild(message);
			// reset search numbers to 0 and adjust the info on the paging bar
			this.start = 0;
			this.totalItemCount = 0;
		},
		
		clear: function(){
			// summary: clears out the table
			var items = dojo.query(".lotusPaletteWidget",this.table);
			dojo.forEach(items, dojo.hitch(this, function(item){
				dijit.byId(item.id).destroy();
			}));
			this.table.innerHTML = "";
			this.pagingStatus.innerHTML = "";
			this.jumpToLink.innerHTML = "";
			this.prevLink.innerHTML = "";
			this.nextLink.innerHTML = "";
		},
		
		fill: function(/*DatastoreItem[]*/contents){
			// summary: fills the table with rows of catalog item results
			// contents: array holding DatastoreItems to be entered in the table
			this.clear();
			dojo.forEach(contents, dojo.hitch(this, function(item) {
				var newCell = this.parent.newCell(this.source,item)
				this.table.appendChild(newCell);
			}));	
			this.adjustPagingBar();
		},
		
		/************************************/
		/*              PAGING              */
		/************************************/
		
		prev: function(){
			// summary: triggers when the user clicks the Previous link,
			this.start = this.start - this.size;
			this._search();
		},
		
		next: function(){
			// summary: triggers when the user clicks the Next link
			this.start = this.start + this.size;
			this._search();
		},
		
		jumpTo: function(/*Event*/e){
			// summary: triggers when a user jumps to a new page
			// event: the onkeydown event
			e = dojo.fixEvent(e, e.target);
			var key = e.keyCode;
		
			if(key == dojo.keys.ENTER){
				var input = this.jumpToInput.value;
				// if number is not an integer, return
				if(input.toString().search(/^[0-9]+$/) != 0)  return;
				// if number is less than 1, set it to 1
				if(input < 1) input = 1;
				
				// calculate the new starting index for result items and make sure it's within range
				var userInputStart = (input - 1) * this.size;
				var maxStart = (Math.ceil(this.totalItemCount/this.size) - 1) * this.size;
				this.start = (userInputStart < maxStart)?userInputStart:maxStart;
				// search with the new starting index
				this._search();
			}
		},
		
		adjustPagingBar: function(){
			// summary: triggers when a search is performed to make sure the numbers and contents of the bar match up
			var firstItem = (this.totalItemCount == 0)?0:this.start + 1;
			var lastItem = this.start + this.size;
			lastItem = (this.totalItemCount > lastItem)?lastItem:this.totalItemCount;
			
			// displays "Page X of Y" in the paging bar
			var currentPage = Math.ceil(firstItem/this.size);
			var totalPageCount = Math.ceil(this.totalItemCount/this.size);
			this.pagingStatus.innerHTML = dojo.string.substitute(this.shelfBundle["shelf_page"], [currentPage, totalPageCount]);
			
			// create Previous and Next links , and Jump to page ___  if appropriate
			this.createPrevNode(firstItem);
			this.createNextNode(lastItem);
			if(this.totalItemCount > this.size) this.createJumpTo(firstItem);
		},
		
		createPrevNode: function(/*Int*/firstItem){
			// summary: determines if a Previous link should be rendered and creates it if appropriate
			if(firstItem > 1){  // create a link
				var prev = dojo.create("a", {href:"javascript:void(0)",innerHTML:this.shelfBundle["shelf_previous"]});
				prev.onclick = dojo.hitch(this, function(){ this.prev(); return false; /* to prevent onBeforeUnload event from triggering in IE */ });
				this.prevLink.appendChild(prev);
			}
			else  // create unclickable text
				this.prevLink.appendChild(document.createTextNode(this.shelfBundle["shelf_previous"]));
		},
		
		createNextNode: function(/*Int*/lastItem){
			// summary: determines if a Next link should be rendered and creates it if appropriate
			if(this.totalItemCount > lastItem){  // create a link
				var next = dojo.create("a", {href:"javascript:void(0)",innerHTML:this.shelfBundle["shelf_next"]});
				next.onclick = dojo.hitch(this, function(){ this.next(); return false; /* to prevent onBeforeUnload event from triggering in IE */ });
				this.nextLink.appendChild(next);
			}
			else // create unclickable text
				this.nextLink.appendChild(document.createTextNode(this.shelfBundle["shelf_next"]));
		},
		
		createJumpTo: function(firstItem){
			// summary: if there is  more than one page available, this creates a "Jump to page ___" input
			this.jumpToInput = dojo.create("input",{type:"text",value:Math.ceil(firstItem/this.size),className:"lotusText"});
			dojo.connect(this.jumpToInput, "onkeydown", this, this.jumpTo);
			this.jumpToLink.appendChild(document.createTextNode(this.shelfBundle["shelf_jumpTo"]));
			this.jumpToLink.appendChild(this.jumpToInput);
		}
});

}

if(!dojo._hasResource["com.ibm.customize.SearchBar"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.customize.SearchBar"] = true;
// This is an input box which publishes all the words of the input's value as an array to a given event

dojo.provide("com.ibm.customize.SearchBar");





dojo.declare("com.ibm.customize.SearchBar",
	[dijit._Widget, dijit._Templated],
	{
		imagePath: ".",
		searchId: "",
		searchFieldText: "",
		searching: true,
		publishKeyword: "/epc/customize/search",	// the keyword to publish when a string is submitted
		templateString: '<div dojoAttachPoint="focusNode" class="lotusChunk lotusSearch">' +
							'<form role="search" action="" onsubmit="return false">' +
								'<label for="${searchBoxId}" class="ibmPortalHiddenText" dojoAttachPoint="searchFieldLabel">${searchFieldText}</label>' +
								'<input id="${searchBoxId}" dojoAttachEvent="onkeydown:newSearch" class="lotusText" type="text" value="${searchFieldText}" onfocus="this.value=\'\';" dojoAttachPoint="searchField"/>' +
								'<span class="lotusBtnImg">' +
									'<input dojoAttachEvent="onclick:searchButton" title="${submitSearchText}" class="lotusSearchButton" type="image" alt="" src="${imagePath}/blank.gif"/>' +
									'<span class="lotusAltText">Search</span>' +
								'</span>' +
							'</form>' +
						'</div>',
		
		constructor: function() {
			this.bundle = dojo.i18n.getLocalization("com.ibm.bundles", "Shelf");
			this.submitSearchText = this.bundle["shelf_submitSearch"];
		},
		
		postMixInProperties: function(){
			this.searchBoxId = this.searchId + "_search";
		},
		
		postCreate: function(){
			// summary: subscribe to the event that changes the default text in the search box
			dojo.subscribe("/epc/customize/changeSource"+this.searchId, this, this.changeInputValue);
		},
		
		enableSearch: function(){
			if(!this.searching){
				this.searching = true;
				dojo.style(this.searchField, "backgroundColor", "#FFFFFF");
				dojo.style(this.searchField, "borderColor", "#FFFFFF");
				this.searchField.removeAttribute("disabled");
			}
		},
		
		disableSearch: function(){
			if(this.searching){
				this.searching = false;
				dojo.style(this.searchField, "backgroundColor", "#CCCCCC");
				dojo.style(this.searchField, "borderColor", "#CCCCCC");
				dojo.attr(this.searchField, "disabled", true);
			}
		},
		
		changeInputValue: function(/*Object*/source){
			// summary: changes the text in the field
			if(source.hub.searchable) this.enableSearch();
			else this.disableSearch();
			if(source.searchStr) this.searchFieldText = source.hub.searchable ? source.searchStr : "";
			else this.searchFieldText = source.hub.searchable ? dojo.string.substitute(this.bundle["shelf_search"], [source.label]) : "";
			this.searchField.value = this.searchFieldLabel.innerHTML = this.searchFieldText;
		},
		
		newSearch: function(/*Event*/e){
			// summary: triggers when a user is typing 
			// Publishes an event when the user presses the enter key
			e = dojo.fixEvent(e, e.target);
			var key = e.keyCode;
		
			if(dojo.isIE && key == dojo.keys.ENTER)
				this.searchButton();
		},
		
		searchButton: function(){
			// summary: creates an array of the space separated search terms and publishes them to an event
			if(this.searching){
				var searchWords = (this.searchField.value == this.searchFieldText) ? "" : this.searchField.value;  // no search criteria if field = "Search xxxx"
				var searchArray = searchWords.split(" ");
				// publish the event to a specific id so not all instances of the receiving class respond
				dojo.publish(this.publishKeyword+this.searchId, [searchArray]);
			}
		}
});

}

if(!dojo._hasResource["dojo.fx.easing"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.fx.easing"] = true;
dojo.provide("dojo.fx.easing");

dojo.fx.easing = {
	// summary: Collection of easing functions to use beyond the default dojo._defaultEasing
	// 
	// description:
	//	Easing functions are used to manipulate the iteration through
	//	an _Animation's _Line. _Line being the properties of an Animation,
	//	and the easing function progresses through that Line determing
	//	how quickly (or slowly) it should go. Or more accurately: modify
	//	the value of the _Line based on the percentage of animation completed.
	//	
	//	All functions follow a simple naming convention of "ease type" + "when".
	//	If the name of the function ends in Out, the easing described appears
	//	towards the end of the animation. "In" means during the beginning,
	//	and InOut means both ranges of the Animation will applied, both beginning
	//	and end. 
	//
	//	example:
	//	|	
	//	|	var anim = dojo.fadeOut({
	//	|		node: 'node',	
	//	|		duration: 2000,
	//	|		easing: dojo.fx.easing.quadIn
	//	|	}).play();
	//
	
	linear: function(/* Decimal? */n){
		// summary: A linear easing function
		return n;
	},

	quadIn: function(/* Decimal? */n){
		return Math.pow(n, 2);
	},

	quadOut: function(/* Decimal? */n){
		return n * (n - 2) * -1;
	},

	quadInOut: function(/* Decimal? */n){
		n = n * 2;
		if(n < 1){ return Math.pow(n, 2) / 2; }
		return -1 * ((--n) * (n - 2) - 1) / 2;
	},

	cubicIn: function(/* Decimal? */n){
		return Math.pow(n, 3);
	},

	cubicOut: function(/* Decimal? */n){
		return Math.pow(n - 1, 3) + 1;
	},

	cubicInOut: function(/* Decimal? */n){
		n = n * 2;
		if(n < 1){ return Math.pow(n, 3) / 2; }
		n -= 2;
		return (Math.pow(n, 3) + 2) / 2;
	},

	quartIn: function(/* Decimal? */n){
		return Math.pow(n, 4);
	},

	quartOut: function(/* Decimal? */n){
		return -1 * (Math.pow(n - 1, 4) - 1);
	},

	quartInOut: function(/* Decimal? */n){
		n = n * 2;
		if(n < 1){ return Math.pow(n, 4) / 2; }
		n -= 2;
		return -1 / 2 * (Math.pow(n, 4) - 2);
	},

	quintIn: function(/* Decimal? */n){
		return Math.pow(n, 5);
	},

	quintOut: function(/* Decimal? */n){
		return Math.pow(n - 1, 5) + 1;
	},

	quintInOut: function(/* Decimal? */n){
		n = n * 2;
		if(n < 1){ return Math.pow(n, 5) / 2; };
		n -= 2;
		return (Math.pow(n, 5) + 2) / 2;
	},

	sineIn: function(/* Decimal? */n){
		return -1 * Math.cos(n * (Math.PI / 2)) + 1;
	},

	sineOut: function(/* Decimal? */n){
		return Math.sin(n * (Math.PI / 2));
	},

	sineInOut: function(/* Decimal? */n){
		return -1 * (Math.cos(Math.PI * n) - 1) / 2;
	},

	expoIn: function(/* Decimal? */n){
		return (n == 0) ? 0 : Math.pow(2, 10 * (n - 1));
	},

	expoOut: function(/* Decimal? */n){
		return (n == 1) ? 1 : (-1 * Math.pow(2, -10 * n) + 1);
	},

	expoInOut: function(/* Decimal? */n){
		if(n == 0){ return 0; }
		if(n == 1){ return 1; }
		n = n * 2;
		if(n < 1){ return Math.pow(2, 10 * (n - 1)) / 2; }
		--n;
		return (-1 * Math.pow(2, -10 * n) + 2) / 2;
	},

	circIn: function(/* Decimal? */n){
		return -1 * (Math.sqrt(1 - Math.pow(n, 2)) - 1);
	},

	circOut: function(/* Decimal? */n){
		n = n - 1;
		return Math.sqrt(1 - Math.pow(n, 2));
	},

	circInOut: function(/* Decimal? */n){
		n = n * 2;
		if(n < 1){ return -1 / 2 * (Math.sqrt(1 - Math.pow(n, 2)) - 1); }
		n -= 2;
		return 1 / 2 * (Math.sqrt(1 - Math.pow(n, 2)) + 1);
	},

	backIn: function(/* Decimal? */n){
		// summary: An easing function that starts away from the target, and 
		//		quickly accelerates towards the end value
		var s = 1.70158;
		return Math.pow(n, 2) * ((s + 1) * n - s);
	},

	backOut: function(/* Decimal? */n){
		// summary: An easing function that pops past the range briefly, and 
		// 	slowly comes back. 
		n = n - 1;
		var s = 1.70158;
		return Math.pow(n, 2) * ((s + 1) * n + s) + 1;
	},

	backInOut: function(/* Decimal? */n){
		// summary: An easing function combining the effects of backIn and backOut
		var s = 1.70158 * 1.525;
		n = n * 2;
		if(n < 1){ return (Math.pow(n, 2) * ((s + 1) * n - s)) / 2; }
		n-=2;
		return (Math.pow(n, 2) * ((s + 1) * n + s) + 2) / 2;
	},

	elasticIn: function(/* Decimal? */n){
		// summary: An easing function the elastically snaps from the start value
		if(n == 0 || n == 1){ return n; }
		var p = .3;
		var s = p / 4;
		n = n - 1;
		return -1 * Math.pow(2, 10 * n) * Math.sin((n - s) * (2 * Math.PI) / p);
	},

	elasticOut: function(/* Decimal? */n){
		// summary: An easing function that elasticly snaps around the target value, near the end of the Animation
		if(n==0 || n == 1){ return n; }
		var p = .3;
		var s = p / 4;
		return Math.pow(2, -10 * n) * Math.sin((n - s) * (2 * Math.PI) / p) + 1;
	},

	elasticInOut: function(/* Decimal? */n){
		// summary: An easing function that elasticly snaps around the value, near the beginning and end of the Animation		
		if(n == 0) return 0;
		n = n * 2;
		if(n == 2) return 1;
		var p = .3 * 1.5;
		var s = p / 4;
		if(n < 1){
			n -= 1;
			return -.5 * (Math.pow(2, 10 * n) * Math.sin((n - s) * (2 * Math.PI) / p));
		}
		n -= 1;
		return .5 * (Math.pow(2, -10 * n) * Math.sin((n - s) * (2 * Math.PI) / p)) + 1;
	},

	bounceIn: function(/* Decimal? */n){
		// summary: An easing function that "bounces" near the beginning of an Animation
		return (1 - dojo.fx.easing.bounceOut(1 - n)); // Decimal
	},

	bounceOut: function(/* Decimal? */n){
		// summary: An easing function that "bounces" near the end of an Animation
		var s = 7.5625;
		var p = 2.75;
		var l; 
		if(n < (1 / p)){
			l = s * Math.pow(n, 2);
		}else if(n < (2 / p)){
			n -= (1.5 / p);
			l = s * Math.pow(n, 2) + .75;
		}else if(n < (2.5 / p)){
			n -= (2.25 / p);
			l = s * Math.pow(n, 2) + .9375;
		}else{
			n -= (2.625 / p);
			l = s * Math.pow(n, 2) + .984375;
		}
		return l;
	},

	bounceInOut: function(/* Decimal? */n){
		// summary: An easing function that "bounces" at the beginning and end of the Animation
		if(n < 0.5){ return dojo.fx.easing.bounceIn(n * 2) / 2; }
		return (dojo.fx.easing.bounceOut(n * 2 - 1) / 2) + 0.5; // Decimal
	}
};

}

if(!dojo._hasResource["dojox.fx.easing"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojox.fx.easing"] = true;
dojo.provide("dojox.fx.easing");
dojo.deprecated("dojox.fx.easing","Upgraded to Core, use dojo.fx.easing instead","2.0");

/*=====
	dojox.fx.easing = {
		// summary:
		//		An Alias to `dojo.fx.easing`. Moved to Core in Dojo 1.2.
	});
=====*/
dojox.fx.easing = dojo.fx.easing;

}

if(!dojo._hasResource["com.ibm.customize.Menu"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.customize.Menu"] = true;
// This is a menu.  It takes a list of sources that each have label attributes to use as display titles.  It publishes an event on a source each time one is clicked.
dojo.provide("com.ibm.customize.Menu");








dojo.declare("com.ibm.customize.Menu",
	[dijit._Widget, dijit._Templated],
	{
		sources: [],									// an array of objects containing labels and datastore hubs for each menu choice
		choices: {},									// a map of label : DOMNode pairs for each choice in the menu
		searchId: "",									// the id of the Container to search within
		menuTitle: "Menu",								// title for the menu
		current: null,									// the menu choice currently selected
		selectedText: "currently selected category",
		unselectedText: "press enter to browse this category",
		publishKeyword: "/epc/customize/changeSource",	// the keyword to publish to add a filter
		templateString: '<div dojoAttachPoint="focusNode"><h3>${menuTitle}</h3><div role="menu" dojoAttachPoint="menuContainer" class="lotusMenu"><ul dojoAttachPoint="list"></ul></div></div>',
		
		constructor: function() {
			this.bundle = dojo.i18n.getLocalization("com.ibm.bundles", "Shelf");
			this.menuTitle = this.bundle["shelf_menu"];
			this.selectedText = this.bundle["menu_selected_text"] || this.selectedText;
			this.unselectedText = this.bundle["menu_unselected_text"] || this.unselectedText;
		},
	
		postCreate: function(){
			// summary: populates the menu with the given choices , makes sure the first item on the list is selected
			
			//subscribe to when a new source is changed so the highlighting in the menu will match
			dojo.subscribe(this.publishKeyword+this.searchId, this, this.changeHighlighting);
			
			if(this.sources.length > 0) {
				// add the choices to the menu with the first choice selected
				dojo.forEach(this.sources, dojo.hitch(this, function(choice){ this.addLi(choice); }));
				this.select(this.sources[0]);
			}
		},
		
		addLi: function(/*Object*/choice){
			// summary: adds a new element to the list of choices in the menu
			// choice: a member of the choices array to add to the menu
			var li = dojo.create("li");
			var newLink = dojo.create("a",{href:"javascript:void(0)",innerHTML:choice.label});
			newLink.onclick = function(){ return false; /* to prevent onBeforeUnload event from triggering in IE */ };
			li.appendChild(newLink);
			var selectedSpan = dojo.create("span",{innerHTML:this.unselectedText,className:"",className:"ibmPortalHiddenText"});
			newLink.appendChild(selectedSpan);
			// when the menu item is clicked, call the select function on it
			dojo.connect(li, 'onclick', this, function(){ this.select(choice); });
			// add the new item to DOM and the map of choices
			this.list.appendChild(li);
			this.choices[choice.label] = {li:li,span:selectedSpan};
		},
		
		select: function(/*Object*/source){
			// summary: triggered by a menu click,
			// source: the menu choice that was clicked
			
			// publish the event to a specific id so not all instances of the receiving class respond
			dojo.publish(this.publishKeyword+this.searchId, [source]);
		},
		
		changeHighlighting: function(/*String*/source){
			// summary: switches which menu choice is selected
			// source: the menu choice that was chosen
			if(this.current) {
				dojo.removeClass(this.choices[this.current].li, "lotusSelected");
				this.choices[this.current].span.innerHTML = this.unselectedText;
			}
			dojo.addClass(this.choices[source.label].li, "lotusSelected");
			this.choices[source.label].span.innerHTML = this.selectedText;
			this.current = source.label;
		}
});

}

if(!dojo._hasResource["dojo.dnd.Mover"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.dnd.Mover"] = true;
dojo.provide("dojo.dnd.Mover");




dojo.declare("dojo.dnd.Mover", null, {
	constructor: function(node, e, host){
		// summary: an object, which makes a node follow the mouse, 
		//	used as a default mover, and as a base class for custom movers
		// node: Node: a node (or node's id) to be moved
		// e: Event: a mouse event, which started the move;
		//	only pageX and pageY properties are used
		// host: Object?: object which implements the functionality of the move,
		//	 and defines proper events (onMoveStart and onMoveStop)
		this.node = dojo.byId(node);
		this.marginBox = {l: e.pageX, t: e.pageY};
		this.mouseButton = e.button;
		var h = this.host = host, d = node.ownerDocument, 
			firstEvent = dojo.connect(d, "onmousemove", this, "onFirstMove");
		this.events = [
			dojo.connect(d, "onmousemove", this, "onMouseMove"),
			dojo.connect(d, "onmouseup",   this, "onMouseUp"),
			// cancel text selection and text dragging
			dojo.connect(d, "ondragstart",   dojo.stopEvent),
			dojo.connect(d.body, "onselectstart", dojo.stopEvent),
			firstEvent
		];
		// notify that the move has started
		if(h && h.onMoveStart){
			h.onMoveStart(this);
		}
	},
	// mouse event processors
	onMouseMove: function(e){
		// summary: event processor for onmousemove
		// e: Event: mouse event
		dojo.dnd.autoScroll(e);
		var m = this.marginBox;
		this.host.onMove(this, {l: m.l + e.pageX, t: m.t + e.pageY});
		dojo.stopEvent(e);
	},
	onMouseUp: function(e){
		if(dojo.isWebKit && dojo.dnd._isMac && this.mouseButton == 2 ? 
				e.button == 0 : this.mouseButton == e.button){
			this.destroy();
		}
		dojo.stopEvent(e);
	},
	// utilities
	onFirstMove: function(){
		// summary: makes the node absolute; it is meant to be called only once. 
		// 	relative and absolutely positioned nodes are assumed to use pixel units
		var s = this.node.style, l, t, h = this.host;
		switch(s.position){
			case "relative":
			case "absolute":
				// assume that left and top values are in pixels already
				l = Math.round(parseFloat(s.left));
				t = Math.round(parseFloat(s.top));
				break;
			default:
				s.position = "absolute";	// enforcing the absolute mode
				var m = dojo.marginBox(this.node);
				// event.pageX/pageY (which we used to generate the initial
				// margin box) includes padding and margin set on the body.
				// However, setting the node's position to absolute and then
				// doing dojo.marginBox on it *doesn't* take that additional
				// space into account - so we need to subtract the combined
				// padding and margin.  We use getComputedStyle and
				// _getMarginBox/_getContentBox to avoid the extra lookup of
				// the computed style. 
				var b = dojo.doc.body;
				var bs = dojo.getComputedStyle(b);
				var bm = dojo._getMarginBox(b, bs);
				var bc = dojo._getContentBox(b, bs);
				l = m.l - (bc.l - bm.l);
				t = m.t - (bc.t - bm.t);
				break;
		}
		this.marginBox.l = l - this.marginBox.l;
		this.marginBox.t = t - this.marginBox.t;
		if(h && h.onFirstMove){
			h.onFirstMove(this);
		}
		dojo.disconnect(this.events.pop());
	},
	destroy: function(){
		// summary: stops the move, deletes all references, so the object can be garbage-collected
		dojo.forEach(this.events, dojo.disconnect);
		// undo global settings
		var h = this.host;
		if(h && h.onMoveStop){
			h.onMoveStop(this);
		}
		// destroy objects
		this.events = this.node = this.host = null;
	}
});

}

if(!dojo._hasResource["dojo.dnd.Moveable"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.dnd.Moveable"] = true;
dojo.provide("dojo.dnd.Moveable");



dojo.declare("dojo.dnd.Moveable", null, {
	// object attributes (for markup)
	handle: "",
	delay: 0,
	skip: false,
	
	constructor: function(node, params){
		// summary: an object, which makes a node moveable
		// node: Node: a node (or node's id) to be moved
		// params: Object: an optional object with additional parameters;
		//	following parameters are recognized:
		//		handle: Node: a node (or node's id), which is used as a mouse handle
		//			if omitted, the node itself is used as a handle
		//		delay: Number: delay move by this number of pixels
		//		skip: Boolean: skip move of form elements
		//		mover: Object: a constructor of custom Mover
		this.node = dojo.byId(node);
		if(!params){ params = {}; }
		this.handle = params.handle ? dojo.byId(params.handle) : null;
		if(!this.handle){ this.handle = this.node; }
		this.delay = params.delay > 0 ? params.delay : 0;
		this.skip  = params.skip;
		this.mover = params.mover ? params.mover : dojo.dnd.Mover;
		this.events = [
			dojo.connect(this.handle, "onmousedown", this, "onMouseDown"),
			// cancel text selection and text dragging
			dojo.connect(this.handle, "ondragstart",   this, "onSelectStart"),
			dojo.connect(this.handle, "onselectstart", this, "onSelectStart")
		];
	},

	// markup methods
	markupFactory: function(params, node){
		return new dojo.dnd.Moveable(node, params);
	},

	// methods
	destroy: function(){
		// summary: stops watching for possible move, deletes all references, so the object can be garbage-collected
		dojo.forEach(this.events, dojo.disconnect);
		this.events = this.node = this.handle = null;
	},
	
	// mouse event processors
	onMouseDown: function(e){
		// summary: event processor for onmousedown, creates a Mover for the node
		// e: Event: mouse event
		if(this.skip && dojo.dnd.isFormElement(e)){ return; }
		if(this.delay){
			this.events.push(
				dojo.connect(this.handle, "onmousemove", this, "onMouseMove"),
				dojo.connect(this.handle, "onmouseup", this, "onMouseUp")
			);
			this._lastX = e.pageX;
			this._lastY = e.pageY;
		}else{
			this.onDragDetected(e);
		}
		dojo.stopEvent(e);
	},
	onMouseMove: function(e){
		// summary: event processor for onmousemove, used only for delayed drags
		// e: Event: mouse event
		if(Math.abs(e.pageX - this._lastX) > this.delay || Math.abs(e.pageY - this._lastY) > this.delay){
			this.onMouseUp(e);
			this.onDragDetected(e);
		}
		dojo.stopEvent(e);
	},
	onMouseUp: function(e){
		// summary: event processor for onmouseup, used only for delayed drags
		// e: Event: mouse event
		for(var i = 0; i < 2; ++i){
			dojo.disconnect(this.events.pop());
		}
		dojo.stopEvent(e);
	},
	onSelectStart: function(e){
		// summary: event processor for onselectevent and ondragevent
		// e: Event: mouse event
		if(!this.skip || !dojo.dnd.isFormElement(e)){
			dojo.stopEvent(e);
		}
	},
	
	// local events
	onDragDetected: function(/* Event */ e){
		// summary: called when the drag is detected,
		// responsible for creation of the mover
		new this.mover(this.node, e, this);
	},
	onMoveStart: function(/* dojo.dnd.Mover */ mover){
		// summary: called before every move operation
		dojo.publish("/dnd/move/start", [mover]);
		dojo.addClass(dojo.body(), "dojoMove"); 
		dojo.addClass(this.node, "dojoMoveItem"); 
	},
	onMoveStop: function(/* dojo.dnd.Mover */ mover){
		// summary: called after every move operation
		dojo.publish("/dnd/move/stop", [mover]);
		dojo.removeClass(dojo.body(), "dojoMove");
		dojo.removeClass(this.node, "dojoMoveItem");
	},
	onFirstMove: function(/* dojo.dnd.Mover */ mover){
		// summary: called during the very first move notification,
		//	can be used to initialize coordinates, can be overwritten.
		
		// default implementation does nothing
	},
	onMove: function(/* dojo.dnd.Mover */ mover, /* Object */ leftTop){
		// summary: called during every move notification,
		//	should actually move the node, can be overwritten.
		this.onMoving(mover, leftTop);
		var s = mover.node.style;
		s.left = leftTop.l + "px";
		s.top  = leftTop.t + "px";
		this.onMoved(mover, leftTop);
	},
	onMoving: function(/* dojo.dnd.Mover */ mover, /* Object */ leftTop){
		// summary: called before every incremental move,
		//	can be overwritten.
		
		// default implementation does nothing
	},
	onMoved: function(/* dojo.dnd.Mover */ mover, /* Object */ leftTop){
		// summary: called after every incremental move,
		//	can be overwritten.
		
		// default implementation does nothing
	}
});

}

if(!dojo._hasResource["dojo.dnd.move"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.dnd.move"] = true;
dojo.provide("dojo.dnd.move");




dojo.declare("dojo.dnd.move.constrainedMoveable", dojo.dnd.Moveable, {
	// object attributes (for markup)
	constraints: function(){},
	within: false,
	
	// markup methods
	markupFactory: function(params, node){
		return new dojo.dnd.move.constrainedMoveable(node, params);
	},

	constructor: function(node, params){
		// summary: an object, which makes a node moveable
		// node: Node: a node (or node's id) to be moved
		// params: Object: an optional object with additional parameters;
		//	following parameters are recognized:
		//		constraints: Function: a function, which calculates a constraint box,
		//			it is called in a context of the moveable object.
		//		within: Boolean: restrict move within boundaries.
		//	the rest is passed to the base class
		if(!params){ params = {}; }
		this.constraints = params.constraints;
		this.within = params.within;
	},
	onFirstMove: function(/* dojo.dnd.Mover */ mover){
		// summary: called during the very first move notification,
		//	can be used to initialize coordinates, can be overwritten.
		var c = this.constraintBox = this.constraints.call(this, mover);
		c.r = c.l + c.w;
		c.b = c.t + c.h;
		if(this.within){
			var mb = dojo.marginBox(mover.node);
			c.r -= mb.w;
			c.b -= mb.h;
		}
	},
	onMove: function(/* dojo.dnd.Mover */ mover, /* Object */ leftTop){
		// summary: called during every move notification,
		//	should actually move the node, can be overwritten.
		var c = this.constraintBox, s = mover.node.style;
		s.left = (leftTop.l < c.l ? c.l : c.r < leftTop.l ? c.r : leftTop.l) + "px";
		s.top  = (leftTop.t < c.t ? c.t : c.b < leftTop.t ? c.b : leftTop.t) + "px";
	}
});

dojo.declare("dojo.dnd.move.boxConstrainedMoveable", dojo.dnd.move.constrainedMoveable, {
	// object attributes (for markup)
	box: {},
	
	// markup methods
	markupFactory: function(params, node){
		return new dojo.dnd.move.boxConstrainedMoveable(node, params);
	},

	constructor: function(node, params){
		// summary: an object, which makes a node moveable
		// node: Node: a node (or node's id) to be moved
		// params: Object: an optional object with additional parameters;
		//	following parameters are recognized:
		//		box: Object: a constraint box
		//	the rest is passed to the base class
		var box = params && params.box;
		this.constraints = function(){ return box; };
	}
});

dojo.declare("dojo.dnd.move.parentConstrainedMoveable", dojo.dnd.move.constrainedMoveable, {
	// object attributes (for markup)
	area: "content",

	// markup methods
	markupFactory: function(params, node){
		return new dojo.dnd.move.parentConstrainedMoveable(node, params);
	},

	constructor: function(node, params){
		// summary: an object, which makes a node moveable
		// node: Node: a node (or node's id) to be moved
		// params: Object: an optional object with additional parameters;
		//	following parameters are recognized:
		//		area: String: a parent's area to restrict the move,
		//			can be "margin", "border", "padding", or "content".
		//	the rest is passed to the base class
		var area = params && params.area;
		this.constraints = function(){
			var n = this.node.parentNode, 
				s = dojo.getComputedStyle(n), 
				mb = dojo._getMarginBox(n, s);
			if(area == "margin"){
				return mb;	// Object
			}
			var t = dojo._getMarginExtents(n, s);
			mb.l += t.l, mb.t += t.t, mb.w -= t.w, mb.h -= t.h;
			if(area == "border"){
				return mb;	// Object
			}
			t = dojo._getBorderExtents(n, s);
			mb.l += t.l, mb.t += t.t, mb.w -= t.w, mb.h -= t.h;
			if(area == "padding"){
				return mb;	// Object
			}
			t = dojo._getPadExtents(n, s);
			mb.l += t.l, mb.t += t.t, mb.w -= t.w, mb.h -= t.h;
			return mb;	// Object
		};
	}
});

// WARNING: below are obsolete objects, instead of custom movers use custom moveables (above)

dojo.dnd.move.constrainedMover = function(fun, within){
	// summary: returns a constrained version of dojo.dnd.Mover
	// description: this function produces n object, which will put a constraint on 
	//	the margin box of dragged object in absolute coordinates
	// fun: Function: called on drag, and returns a constraint box
	// within: Boolean: if true, constraints the whole dragged object withtin the rectangle, 
	//	otherwise the constraint is applied to the left-top corner
	dojo.deprecated("dojo.dnd.move.constrainedMover, use dojo.dnd.move.constrainedMoveable instead");
	var mover = function(node, e, notifier){
		dojo.dnd.Mover.call(this, node, e, notifier);
	};
	dojo.extend(mover, dojo.dnd.Mover.prototype);
	dojo.extend(mover, {
		onMouseMove: function(e){
			// summary: event processor for onmousemove
			// e: Event: mouse event
			dojo.dnd.autoScroll(e);
			var m = this.marginBox, c = this.constraintBox,
				l = m.l + e.pageX, t = m.t + e.pageY;
			l = l < c.l ? c.l : c.r < l ? c.r : l;
			t = t < c.t ? c.t : c.b < t ? c.b : t;
			this.host.onMove(this, {l: l, t: t});
		},
		onFirstMove: function(){
			// summary: called once to initialize things; it is meant to be called only once
			dojo.dnd.Mover.prototype.onFirstMove.call(this);
			var c = this.constraintBox = fun.call(this);
			c.r = c.l + c.w;
			c.b = c.t + c.h;
			if(within){
				var mb = dojo.marginBox(this.node);
				c.r -= mb.w;
				c.b -= mb.h;
			}
		}
	});
	return mover;	// Object
};

dojo.dnd.move.boxConstrainedMover = function(box, within){
	// summary: a specialization of dojo.dnd.constrainedMover, which constrains to the specified box
	// box: Object: a constraint box (l, t, w, h)
	// within: Boolean: if true, constraints the whole dragged object withtin the rectangle, 
	//	otherwise the constraint is applied to the left-top corner
	dojo.deprecated("dojo.dnd.move.boxConstrainedMover, use dojo.dnd.move.boxConstrainedMoveable instead");
	return dojo.dnd.move.constrainedMover(function(){ return box; }, within);	// Object
};

dojo.dnd.move.parentConstrainedMover = function(area, within){
	// summary: a specialization of dojo.dnd.constrainedMover, which constrains to the parent node
	// area: String: "margin" to constrain within the parent's margin box, "border" for the border box,
	//	"padding" for the padding box, and "content" for the content box; "content" is the default value.
	// within: Boolean: if true, constraints the whole dragged object withtin the rectangle, 
	//	otherwise the constraint is applied to the left-top corner
	dojo.deprecated("dojo.dnd.move.parentConstrainedMover, use dojo.dnd.move.parentConstrainedMoveable instead");
	var fun = function(){
		var n = this.node.parentNode, 
			s = dojo.getComputedStyle(n), 
			mb = dojo._getMarginBox(n, s);
		if(area == "margin"){
			return mb;	// Object
		}
		var t = dojo._getMarginExtents(n, s);
		mb.l += t.l, mb.t += t.t, mb.w -= t.w, mb.h -= t.h;
		if(area == "border"){
			return mb;	// Object
		}
		t = dojo._getBorderExtents(n, s);
		mb.l += t.l, mb.t += t.t, mb.w -= t.w, mb.h -= t.h;
		if(area == "padding"){
			return mb;	// Object
		}
		t = dojo._getPadExtents(n, s);
		mb.l += t.l, mb.t += t.t, mb.w -= t.w, mb.h -= t.h;
		return mb;	// Object
	};
	return dojo.dnd.move.constrainedMover(fun, within);	// Object
};

// patching functions one level up for compatibility

dojo.dnd.constrainedMover = dojo.dnd.move.constrainedMover;
dojo.dnd.boxConstrainedMover = dojo.dnd.move.boxConstrainedMover;
dojo.dnd.parentConstrainedMover = dojo.dnd.move.parentConstrainedMover;

}

if(!dojo._hasResource["dojo.dnd.TimedMoveable"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.dnd.TimedMoveable"] = true;
dojo.provide("dojo.dnd.TimedMoveable");



(function(){
	// precalculate long expressions
	var oldOnMove = dojo.dnd.Moveable.prototype.onMove;
		
	dojo.declare("dojo.dnd.TimedMoveable", dojo.dnd.Moveable, {
		// summary:
		//	A specialized version of Moveable to support an FPS throttling.
		//	This class puts an upper restriction on FPS, which may reduce 
		//	the CPU load. The additional parameter "timeout" regulates
		//	the delay before actually moving the moveable object.
		
		// object attributes (for markup)
		timeout: 40,	// in ms, 40ms corresponds to 25 fps
	
		constructor: function(node, params){
			// summary: an object, which makes a node moveable with a timer
			// node: Node: a node (or node's id) to be moved
			// params: Object: an optional object with additional parameters.
			//	See dojo.dnd.Moveable for details on general parameters.
			//	Following parameters are specific for this class:
			//		timeout: Number: delay move by this number of ms
			//			accumulating position changes during the timeout
			
			// sanitize parameters
			if(!params){ params = {}; }
			if(params.timeout && typeof params.timeout == "number" && params.timeout >= 0){
				this.timeout = params.timeout;
			}
		},
	
		// markup methods
		markupFactory: function(params, node){
			return new dojo.dnd.TimedMoveable(node, params);
		},
	
		onMoveStop: function(/* dojo.dnd.Mover */ mover){
			if(mover._timer){
				// stop timer
				clearTimeout(mover._timer)
				// reflect the last received position
				oldOnMove.call(this, mover, mover._leftTop)
			}
			dojo.dnd.Moveable.prototype.onMoveStop.apply(this, arguments);
		},
		onMove: function(/* dojo.dnd.Mover */ mover, /* Object */ leftTop){
			mover._leftTop = leftTop;
			if(!mover._timer){
				var _t = this;	// to avoid using dojo.hitch()
				mover._timer = setTimeout(function(){
					// we don't have any pending requests
					mover._timer = null;
					// reflect the last received position
					oldOnMove.call(_t, mover, mover._leftTop);
				}, this.timeout);
			}
		}
	});
})();

}

if(!dojo._hasResource["dojo.fx.Toggler"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.fx.Toggler"] = true;
dojo.provide("dojo.fx.Toggler");

dojo.declare("dojo.fx.Toggler", null, {
	// summary:
	//		class constructor for an animation toggler. It accepts a packed
	//		set of arguments about what type of animation to use in each
	//		direction, duration, etc.
	//
	// example:
	//	|	var t = new dojo.fx.Toggler({
	//	|		node: "nodeId",
	//	|		showDuration: 500,
	//	|		// hideDuration will default to "200"
	//	|		showFunc: dojo.wipeIn, 
	//	|		// hideFunc will default to "fadeOut"
	//	|	});
	//	|	t.show(100); // delay showing for 100ms
	//	|	// ...time passes...
	//	|	t.hide();

	// FIXME: need a policy for where the toggler should "be" the next
	// time show/hide are called if we're stopped somewhere in the
	// middle.

	constructor: function(args){
		var _t = this;

		dojo.mixin(_t, args);
		_t.node = args.node;
		_t._showArgs = dojo.mixin({}, args);
		_t._showArgs.node = _t.node;
		_t._showArgs.duration = _t.showDuration;
		_t.showAnim = _t.showFunc(_t._showArgs);

		_t._hideArgs = dojo.mixin({}, args);
		_t._hideArgs.node = _t.node;
		_t._hideArgs.duration = _t.hideDuration;
		_t.hideAnim = _t.hideFunc(_t._hideArgs);

		dojo.connect(_t.showAnim, "beforeBegin", dojo.hitch(_t.hideAnim, "stop", true));
		dojo.connect(_t.hideAnim, "beforeBegin", dojo.hitch(_t.showAnim, "stop", true));
	},

	// node: DomNode
	//	the node to toggle
	node: null,

	// showFunc: Function
	//	The function that returns the dojo._Animation to show the node
	showFunc: dojo.fadeIn,

	// hideFunc: Function	
	//	The function that returns the dojo._Animation to hide the node
	hideFunc: dojo.fadeOut,

	// showDuration:
	//	Time in milliseconds to run the show Animation
	showDuration: 200,

	// hideDuration:
	//	Time in milliseconds to run the hide Animation
	hideDuration: 200,

	/*=====
	_showArgs: null,
	_showAnim: null,

	_hideArgs: null,
	_hideAnim: null,

	_isShowing: false,
	_isHiding: false,
	=====*/

	show: function(delay){
		// summary: Toggle the node to showing
		return this.showAnim.play(delay || 0);
	},

	hide: function(delay){
		// summary: Toggle the node to hidden
		return this.hideAnim.play(delay || 0);
	}
});

}

if(!dojo._hasResource["dojo.fx"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.fx"] = true;
dojo.provide("dojo.fx");

/*=====
dojo.fx = {
	// summary: Effects library on top of Base animations
};
=====*/
(function(){
	
	var d = dojo, 
		_baseObj = {
			_fire: function(evt, args){
				if(this[evt]){
					this[evt].apply(this, args||[]);
				}
				return this;
			}
		};

	var _chain = function(animations){
		this._index = -1;
		this._animations = animations||[];
		this._current = this._onAnimateCtx = this._onEndCtx = null;

		this.duration = 0;
		d.forEach(this._animations, function(a){
			this.duration += a.duration;
			if(a.delay){ this.duration += a.delay; }
		}, this);
	};
	d.extend(_chain, {
		_onAnimate: function(){
			this._fire("onAnimate", arguments);
		},
		_onEnd: function(){
			d.disconnect(this._onAnimateCtx);
			d.disconnect(this._onEndCtx);
			this._onAnimateCtx = this._onEndCtx = null;
			if(this._index + 1 == this._animations.length){
				this._fire("onEnd");
			}else{
				// switch animations
				this._current = this._animations[++this._index];
				this._onAnimateCtx = d.connect(this._current, "onAnimate", this, "_onAnimate");
				this._onEndCtx = d.connect(this._current, "onEnd", this, "_onEnd");
				this._current.play(0, true);
			}
		},
		play: function(/*int?*/ delay, /*Boolean?*/ gotoStart){
			if(!this._current){ this._current = this._animations[this._index = 0]; }
			if(!gotoStart && this._current.status() == "playing"){ return this; }
			var beforeBegin = d.connect(this._current, "beforeBegin", this, function(){
					this._fire("beforeBegin");
				}),
				onBegin = d.connect(this._current, "onBegin", this, function(arg){
					this._fire("onBegin", arguments);
				}),
				onPlay = d.connect(this._current, "onPlay", this, function(arg){
					this._fire("onPlay", arguments);
					d.disconnect(beforeBegin);
					d.disconnect(onBegin);
					d.disconnect(onPlay);
				});
			if(this._onAnimateCtx){
				d.disconnect(this._onAnimateCtx);
			}
			this._onAnimateCtx = d.connect(this._current, "onAnimate", this, "_onAnimate");
			if(this._onEndCtx){
				d.disconnect(this._onEndCtx);
			}
			this._onEndCtx = d.connect(this._current, "onEnd", this, "_onEnd");
			this._current.play.apply(this._current, arguments);
			return this;
		},
		pause: function(){
			if(this._current){
				var e = d.connect(this._current, "onPause", this, function(arg){
						this._fire("onPause", arguments);
						d.disconnect(e);
					});
				this._current.pause();
			}
			return this;
		},
		gotoPercent: function(/*Decimal*/percent, /*Boolean?*/ andPlay){
			this.pause();
			var offset = this.duration * percent;
			this._current = null;
			d.some(this._animations, function(a){
				if(a.duration <= offset){
					this._current = a;
					return true;
				}
				offset -= a.duration;
				return false;
			});
			if(this._current){
				this._current.gotoPercent(offset / this._current.duration, andPlay);
			}
			return this;
		},
		stop: function(/*boolean?*/ gotoEnd){
			if(this._current){
				if(gotoEnd){
					for(; this._index + 1 < this._animations.length; ++this._index){
						this._animations[this._index].stop(true);
					}
					this._current = this._animations[this._index];
				}
				var e = d.connect(this._current, "onStop", this, function(arg){
						this._fire("onStop", arguments);
						d.disconnect(e);
					});
				this._current.stop();
			}
			return this;
		},
		status: function(){
			return this._current ? this._current.status() : "stopped";
		},
		destroy: function(){
			if(this._onAnimateCtx){ d.disconnect(this._onAnimateCtx); }
			if(this._onEndCtx){ d.disconnect(this._onEndCtx); }
		}
	});
	d.extend(_chain, _baseObj);

	dojo.fx.chain = function(/*dojo._Animation[]*/ animations){
		// summary: Chain a list of dojo._Animation s to run in sequence
		// example:
		//	|	dojo.fx.chain([
		//	|		dojo.fadeIn({ node:node }),
		//	|		dojo.fadeOut({ node:otherNode })
		//	|	]).play();
		//
		return new _chain(animations) // dojo._Animation
	};

	var _combine = function(animations){
		this._animations = animations||[];
		this._connects = [];
		this._finished = 0;

		this.duration = 0;
		d.forEach(animations, function(a){
			var duration = a.duration;
			if(a.delay){ duration += a.delay; }
			if(this.duration < duration){ this.duration = duration; }
			this._connects.push(d.connect(a, "onEnd", this, "_onEnd"));
		}, this);
		
		this._pseudoAnimation = new d._Animation({curve: [0, 1], duration: this.duration});
		var self = this;
		d.forEach(["beforeBegin", "onBegin", "onPlay", "onAnimate", "onPause", "onStop"], 
			function(evt){
				self._connects.push(d.connect(self._pseudoAnimation, evt,
					function(){ self._fire(evt, arguments); }
				));
			}
		);
	};
	d.extend(_combine, {
		_doAction: function(action, args){
			d.forEach(this._animations, function(a){
				a[action].apply(a, args);
			});
			return this;
		},
		_onEnd: function(){
			if(++this._finished == this._animations.length){
				this._fire("onEnd");
			}
		},
		_call: function(action, args){
			var t = this._pseudoAnimation;
			t[action].apply(t, args);
		},
		play: function(/*int?*/ delay, /*Boolean?*/ gotoStart){
			this._finished = 0;
			this._doAction("play", arguments);
			this._call("play", arguments);
			return this;
		},
		pause: function(){
			this._doAction("pause", arguments);
			this._call("pause", arguments);
			return this;
		},
		gotoPercent: function(/*Decimal*/percent, /*Boolean?*/ andPlay){
			var ms = this.duration * percent;
			d.forEach(this._animations, function(a){
				a.gotoPercent(a.duration < ms ? 1 : (ms / a.duration), andPlay);
			});
			this._call("gotoPercent", arguments);
			return this;
		},
		stop: function(/*boolean?*/ gotoEnd){
			this._doAction("stop", arguments);
			this._call("stop", arguments);
			return this;
		},
		status: function(){
			return this._pseudoAnimation.status();
		},
		destroy: function(){
			d.forEach(this._connects, dojo.disconnect);
		}
	});
	d.extend(_combine, _baseObj);

	dojo.fx.combine = function(/*dojo._Animation[]*/ animations){
		// summary: Combine an array of `dojo._Animation`s to run in parallel
		//
		// description:
		//		Combine an array of `dojo._Animation`s to run in parallel, 
		//		providing a new `dojo._Animation` instance encompasing each
		//		animation, firing standard animation events.
		//
		// example:
		//	|	dojo.fx.combine([
		//	|		dojo.fadeIn({ node:node }),
		//	|		dojo.fadeOut({ node:otherNode })
		//	|	]).play();
		//
		// example:
		//	When the longest animation ends, execute a function:
		//	| 	var anim = dojo.fx.combine([
		//	|		dojo.fadeIn({ node: n, duration:700 }),
		//	|		dojo.fadeOut({ node: otherNode, duration: 300 })
		//	|	]);
		//	|	dojo.connect(anim, "onEnd", function(){
		//	|		// overall animation is done.
		//	|	});
		//	|	anim.play(); // play the animation
		//
		return new _combine(animations); // dojo._Animation
	};

	dojo.fx.wipeIn = function(/*Object*/ args){
		// summary:
		//		Returns an animation that will expand the
		//		node defined in 'args' object from it's current height to
		//		it's natural height (with no scrollbar).
		//		Node must have no margin/border/padding.
		args.node = d.byId(args.node);
		var node = args.node, s = node.style, o;

		var anim = d.animateProperty(d.mixin({
			properties: {
				height: {
					// wrapped in functions so we wait till the last second to query (in case value has changed)
					start: function(){
						// start at current [computed] height, but use 1px rather than 0
						// because 0 causes IE to display the whole panel
						o = s.overflow;
						s.overflow="hidden";
						if(s.visibility=="hidden"||s.display=="none"){
							s.height="1px";
							s.display="";
							s.visibility="";
							return 1;
						}else{
							var height = d.style(node, "height");
							return Math.max(height, 1);
						}
					},
					end: function(){
						return node.scrollHeight;
					}
				}
			}
		}, args));

		d.connect(anim, "onEnd", function(){ 
			s.height = "auto";
			s.overflow = o;
		});

		return anim; // dojo._Animation
	}

	dojo.fx.wipeOut = function(/*Object*/ args){
		// summary:
		//		Returns an animation that will shrink node defined in "args"
		//		from it's current height to 1px, and then hide it.
		var node = args.node = d.byId(args.node), s = node.style, o;
		
		var anim = d.animateProperty(d.mixin({
			properties: {
				height: {
					end: 1 // 0 causes IE to display the whole panel
				}
			}
		}, args));

		d.connect(anim, "beforeBegin", function(){
			o = s.overflow;
			s.overflow = "hidden";
			s.display = "";
		});
		d.connect(anim, "onEnd", function(){
			s.overflow = o;
			s.height = "auto";
			s.display = "none";
		});

		return anim; // dojo._Animation
	}

	dojo.fx.slideTo = function(/*Object?*/ args){
		// summary:
		//		Returns an animation that will slide "node" 
		//		defined in args Object from its current position to
		//		the position defined by (args.left, args.top).
		// example:
		//	|	dojo.fx.slideTo({ node: node, left:"40", top:"50", unit:"px" }).play()

		var node = args.node = d.byId(args.node), 
			top = null, left = null;

		var init = (function(n){
			return function(){
				var cs = d.getComputedStyle(n);
				var pos = cs.position;
				top = (pos == 'absolute' ? n.offsetTop : parseInt(cs.top) || 0);
				left = (pos == 'absolute' ? n.offsetLeft : parseInt(cs.left) || 0);
				if(pos != 'absolute' && pos != 'relative'){
					var ret = d.coords(n, true);
					top = ret.y;
					left = ret.x;
					n.style.position="absolute";
					n.style.top=top+"px";
					n.style.left=left+"px";
				}
			};
		})(node);
		init();

		var anim = d.animateProperty(d.mixin({
			properties: {
				top: args.top || 0,
				left: args.left || 0
			}
		}, args));
		d.connect(anim, "beforeBegin", anim, init);

		return anim; // dojo._Animation
	}

})();

}

if(!dojo._hasResource["dijit._DialogMixin"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit._DialogMixin"] = true;
dojo.provide("dijit._DialogMixin");

dojo.declare("dijit._DialogMixin", null,
	{
		// summary:
		//		This provides functions useful to Dialog and TooltipDialog

		attributeMap: dijit._Widget.prototype.attributeMap,

		execute: function(/*Object*/ formContents){
			// summary:
			//		Callback when the user hits the submit button.
			//		Override this method to handle Dialog execution.
			// description:
			//		After the user has pressed the submit button, the Dialog
			//		first calls onExecute() to notify the container to hide the
			//		dialog and restore focus to wherever it used to be.
			//
			//		*Then* this method is called.
			// type:
			//		callback
		},

		onCancel: function(){
			// summary:
			//	    Called when user has pressed the Dialog's cancel button, to notify container.
			// description:
			//	    Developer shouldn't override or connect to this method;
			//		it's a private communication device between the TooltipDialog
			//		and the thing that opened it (ex: `dijit.form.DropDownButton`)
			// type:
			//		protected
		},

		onExecute: function(){
			// summary:
			//	    Called when user has pressed the dialog's OK button, to notify container.
			// description:
			//	    Developer shouldn't override or connect to this method;
			//		it's a private communication device between the TooltipDialog
			//		and the thing that opened it (ex: `dijit.form.DropDownButton`)
			// type:
			//		protected
		},

		_onSubmit: function(){
			// summary:
			//		Callback when user hits submit button
			// type:
			//		protected
			this.onExecute();	// notify container that we are about to execute
			this.execute(this.attr('value'));
		},

		_getFocusItems: function(/*Node*/ dialogNode){
			// summary:
			//		Find focusable Items each time a dialog is opened,
			//		setting _firstFocusItem and _lastFocusItem
			// tags:
			//		protected
			
			var elems = dijit._getTabNavigable(dojo.byId(dialogNode));
			this._firstFocusItem = elems.lowest || elems.first || dialogNode;
			this._lastFocusItem = elems.last || elems.highest || this._firstFocusItem;
			if(dojo.isMoz && this._firstFocusItem.tagName.toLowerCase() == "input" && dojo.attr(this._firstFocusItem, "type").toLowerCase() == "file"){
					//FF doesn't behave well when first element is input type=file, set first focusable to dialog container
					dojo.attr(dialogNode, "tabindex", "0");
					this._firstFocusItem = dialogNode;
			}
		}
	}
);

}

if(!dojo._hasResource["dijit.DialogUnderlay"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.DialogUnderlay"] = true;
dojo.provide("dijit.DialogUnderlay");




dojo.declare(
	"dijit.DialogUnderlay",
	[dijit._Widget, dijit._Templated],
	{
		// summary: The component that blocks the screen behind a `dijit.Dialog`
		//
		// description:
		// 		A component used to block input behind a `dijit.Dialog`. Only a single
		//		instance of this widget is created by `dijit.Dialog`, and saved as 
		//		a reference to be shared between all Dialogs as `dijit._underlay`
		//	
		//		The underlay itself can be styled based on and id:
		//	|	#myDialog_underlay { background-color:red; }
		//
		//		In the case of `dijit.Dialog`, this id is based on the id of the Dialog,
		//		suffixed with _underlay. 
		
		// Template has two divs; outer div is used for fade-in/fade-out, and also to hold background iframe.
		// Inner div has opacity specified in CSS file.
		templateString: "<div class='dijitDialogUnderlayWrapper'><div class='dijitDialogUnderlay' dojoAttachPoint='node'></div></div>",

		// Parameters on creation or updatable later

		// dialogId: String
		//		Id of the dialog.... DialogUnderlay's id is based on this id
		dialogId: "",

		// class: String
		//		This class name is used on the DialogUnderlay node, in addition to dijitDialogUnderlay
		"class": "",

		attributeMap: { id: "domNode" },

		_setDialogIdAttr: function(id){
			dojo.attr(this.node, "id", id + "_underlay");
		},

		_setClassAttr: function(clazz){
			this.node.className = "dijitDialogUnderlay " + clazz;
		},

		postCreate: function(){
			// summary:
			//		Append the underlay to the body
			dojo.body().appendChild(this.domNode);
			this.bgIframe = new dijit.BackgroundIframe(this.domNode);
		},

		layout: function(){
			// summary:
			//		Sets the background to the size of the viewport
			//
			// description:
			//		Sets the background to the size of the viewport (rather than the size
			//		of the document) since we need to cover the whole browser window, even
			//		if the document is only a few lines long.
			// tags:
			//		private

			var is = this.node.style,
				os = this.domNode.style;

			// hide the background temporarily, so that the background itself isn't
			// causing scrollbars to appear (might happen when user shrinks browser
			// window and then we are called to resize)
			os.display = "none";

			// then resize and show
			var viewport = dijit.getViewport();
			os.top = viewport.t + "px";
			os.left = viewport.l + "px";
			is.width = viewport.w + "px";
			is.height = viewport.h + "px";
			os.display = "block";
		},

		show: function(){
			// summary:
			//		Show the dialog underlay
			this.domNode.style.display = "block";
			this.layout();
			if(this.bgIframe.iframe){
				this.bgIframe.iframe.style.display = "block";
			}
		},

		hide: function(){
			// summary:
			//		Hides the dialog underlay
			this.domNode.style.display = "none";
			if(this.bgIframe.iframe){
				this.bgIframe.iframe.style.display = "none";
			}
		},

		uninitialize: function(){
			if(this.bgIframe){
				this.bgIframe.destroy();
			}
		}
	}
);

}

if(!dojo._hasResource["dijit.TooltipDialog"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.TooltipDialog"] = true;
dojo.provide("dijit.TooltipDialog");






dojo.declare(
		"dijit.TooltipDialog",
		[dijit.layout.ContentPane, dijit._Templated, dijit.form._FormMixin, dijit._DialogMixin],
		{
			// summary:
			//		Pops up a dialog that appears like a Tooltip

			// title: String
			// 		Description of tooltip dialog (required for a11y)
			title: "",

			// doLayout: [protected] Boolean
			//		Don't change this parameter from the default value.
			//		This ContentPane parameter doesn't make sense for TooltipDialog, since TooltipDialog
			//		is never a child of a layout container, nor can you specify the size of
			//		TooltipDialog in order to control the size of an inner widget. 
			doLayout: false,

			// autofocus: Boolean
			// 		A Toggle to modify the default focus behavior of a Dialog, which
			// 		is to focus on the first dialog element after opening the dialog.
			//		False will disable autofocusing. Default: true
			autofocus: true,

			// baseClass: [protected] String
			//		The root className to use for the various states of this widget
			baseClass: "dijitTooltipDialog",

			// _firstFocusItem: [private] [readonly] DomNode
			//		The pointer to the first focusable node in the dialog.
			//		Set by `dijit._DialogMixin._getFocusItems`.
			_firstFocusItem: null,

			// _lastFocusItem: [private] [readonly] DomNode
			//		The pointer to which node has focus prior to our dialog.
			//		Set by `dijit._DialogMixin._getFocusItems`.
			_lastFocusItem: null,

			templateString: null,
			templateString:"<div waiRole=\"presentation\">\n\t<div class=\"dijitTooltipContainer\" waiRole=\"presentation\">\n\t\t<div class =\"dijitTooltipContents dijitTooltipFocusNode\" dojoAttachPoint=\"containerNode\" tabindex=\"-1\" waiRole=\"dialog\"></div>\n\t</div>\n\t<div class=\"dijitTooltipConnector\" waiRole=\"presentation\"></div>\n</div>\n",

			postCreate: function(){
				this.inherited(arguments);
				this.connect(this.containerNode, "onkeypress", "_onKey");
				this.containerNode.title = this.title;
			},

			orient: function(/*DomNode*/ node, /*String*/ aroundCorner, /*String*/ corner){
				// summary:
				//		Configure widget to be displayed in given position relative to the button.
				//		This is called from the dijit.popup code, and should not be called
				//		directly.
				// tags:
				//		protected
				var c = this._currentOrientClass;
				if(c){
					dojo.removeClass(this.domNode, c);
				}
				c = "dijitTooltipAB"+(corner.charAt(1)=='L'?"Left":"Right")+" dijitTooltip"+(corner.charAt(0)=='T' ? "Below" : "Above");
				dojo.addClass(this.domNode, c);
				this._currentOrientClass = c;
			},

			onOpen: function(/*Object*/ pos){
				// summary:
				//		Called when dialog is displayed.
				//		This is called from the dijit.popup code, and should not be called directly.
				// tags:
				//		protected
			
				this.orient(this.domNode,pos.aroundCorner, pos.corner);
				this._onShow(); // lazy load trigger
				
				if(this.autofocus){
					this._getFocusItems(this.containerNode);
					dijit.focus(this._firstFocusItem);
				}
			},
			
			_onKey: function(/*Event*/ evt){
				// summary:
				//		Handler for keyboard events
				// description:
				//		Keep keyboard focus in dialog; close dialog on escape key
				// tags:
				//		private

				var node = evt.target;
				var dk = dojo.keys;
				if (evt.charOrCode === dk.TAB){
					this._getFocusItems(this.containerNode);
				}
				var singleFocusItem = (this._firstFocusItem == this._lastFocusItem);
				if(evt.charOrCode == dk.ESCAPE){
					this.onCancel();
					dojo.stopEvent(evt);
				}else if(node == this._firstFocusItem && evt.shiftKey && evt.charOrCode === dk.TAB){
					if(!singleFocusItem){
						dijit.focus(this._lastFocusItem); // send focus to last item in dialog
					}
					dojo.stopEvent(evt);
				}else if(node == this._lastFocusItem && evt.charOrCode === dk.TAB && !evt.shiftKey){
					if(!singleFocusItem){
						dijit.focus(this._firstFocusItem); // send focus to first item in dialog
					}
					dojo.stopEvent(evt);
				}else if(evt.charOrCode === dk.TAB){
					// we want the browser's default tab handling to move focus
					// but we don't want the tab to propagate upwards
					evt.stopPropagation();
				}
			}
		}	
	);

}

if(!dojo._hasResource["dijit.Dialog"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dijit.Dialog"] = true;
dojo.provide("dijit.Dialog");













/*=====
dijit._underlay = function(kwArgs){
	// summary:
	//		A shared instance of a `dijit.DialogUnderlay`
	//
	// description: 
	//		A shared instance of a `dijit.DialogUnderlay` created and
	//		used by `dijit.Dialog`, though never created until some Dialog
	//		or subclass thereof is shown.
};
=====*/

dojo.declare(
	"dijit.Dialog",
	[dijit.layout.ContentPane, dijit._Templated, dijit.form._FormMixin, dijit._DialogMixin],
	{
		// summary:
		//		A modal dialog Widget
		//
		// description:
		//		Pops up a modal dialog window, blocking access to the screen
		//		and also graying out the screen Dialog is extended from
		//		ContentPane so it supports all the same parameters (href, etc.)
		//
		// example:
		// |	<div dojoType="dijit.Dialog" href="test.html"></div>
		//
		// example:
		// |	var foo = new dijit.Dialog({ title: "test dialog", content: "test content" };
		// |	dojo.body().appendChild(foo.domNode);
		// |	foo.startup();
		
		templateString: null,
		templateString:"<div class=\"dijitDialog\" tabindex=\"-1\" waiRole=\"dialog\" waiState=\"labelledby-${id}_title\">\n\t<div dojoAttachPoint=\"titleBar\" class=\"dijitDialogTitleBar\">\n\t<span dojoAttachPoint=\"titleNode\" class=\"dijitDialogTitle\" id=\"${id}_title\"></span>\n\t<span dojoAttachPoint=\"closeButtonNode\" class=\"dijitDialogCloseIcon\" dojoAttachEvent=\"onclick: onCancel, onmouseenter: _onCloseEnter, onmouseleave: _onCloseLeave\" title=\"${buttonCancel}\">\n\t\t<span dojoAttachPoint=\"closeText\" class=\"closeText\" title=\"${buttonCancel}\">x</span>\n\t</span>\n\t</div>\n\t\t<div dojoAttachPoint=\"containerNode\" class=\"dijitDialogPaneContent\"></div>\n</div>\n",
		attributeMap: dojo.delegate(dijit._Widget.prototype.attributeMap, {
			title: [
				{ node: "titleNode", type: "innerHTML" }, 
				{ node: "titleBar", type: "attribute" }
			]
		}),

		// open: Boolean
		//		True if Dialog is currently displayed on screen.
		open: false,

		// duration: Integer
		//		The time in milliseconds it takes the dialog to fade in and out
		duration: dijit.defaultDuration,

		// refocus: Boolean
		// 		A Toggle to modify the default focus behavior of a Dialog, which
		// 		is to re-focus the element which had focus before being opened.
		//		False will disable refocusing. Default: true
		refocus: true,
		
		// autofocus: Boolean
		// 		A Toggle to modify the default focus behavior of a Dialog, which
		// 		is to focus on the first dialog element after opening the dialog.
		//		False will disable autofocusing. Default: true
		autofocus: true,

		// _firstFocusItem: [private] [readonly] DomNode
		//		The pointer to the first focusable node in the dialog.
		//		Set by `dijit._DialogMixin._getFocusItems`.
		_firstFocusItem: null,
		
		// _lastFocusItem: [private] [readonly] DomNode
		//		The pointer to which node has focus prior to our dialog.
		//		Set by `dijit._DialogMixin._getFocusItems`.
		_lastFocusItem: null,

		// doLayout: [protected] Boolean
		//		Don't change this parameter from the default value.
		//		This ContentPane parameter doesn't make sense for Dialog, since Dialog
		//		is never a child of a layout container, nor can you specify the size of
		//		Dialog in order to control the size of an inner widget. 
		doLayout: false,

		// draggable: Boolean
		//		Toggles the moveable aspect of the Dialog. If true, Dialog
		//		can be dragged by it's title. If false it will remain centered
		//		in the viewport.
		draggable: true,

		// _fixSizes: Boolean
		//		Does this Dialog attempt to restore the width and height after becoming too small?
		_fixSizes: true,

		postMixInProperties: function(){
			var _nlsResources = dojo.i18n.getLocalization("dijit", "common");
			dojo.mixin(this, _nlsResources);
			this.inherited(arguments);
		},

		postCreate: function(){
			dojo.style(this.domNode, {
				visibility:"hidden",
				position:"absolute",
				display:"",
				top:"-9999px"
			});
			dojo.body().appendChild(this.domNode);

			this.inherited(arguments);

			this.connect(this, "onExecute", "hide");
			this.connect(this, "onCancel", "hide");
			this._modalconnects = [];
		},

		onLoad: function(){
			// summary:
			//		Called when data has been loaded from an href.
			//		Unlike most other callbacks, this function can be connected to (via `dojo.connect`)
			//		but should *not* be overriden.
			// tags:
			//		callback
			
			// when href is specified we need to reposition the dialog after the data is loaded
			this._position();
			this.inherited(arguments);
		},

		_endDrag: function(e){
			// summary:
			//		Called after dragging the Dialog. Calculates the relative offset
			//		of the Dialog in relation to the viewport.
			// tags:
			//		private
			if(e && e.node && e.node === this.domNode){
				var vp = dijit.getViewport(); 
				var p = e._leftTop || dojo.coords(e.node,true);
				this._relativePosition = {
					t: p.t - vp.t,
					l: p.l - vp.l
				}			
			}
		},
		
		_setup: function(){
			// summary: 
			//		Stuff we need to do before showing the Dialog for the first
			//		time (but we defer it until right beforehand, for
			//		performance reasons).
			// tags:
			//		private

			var node = this.domNode;

			if(this.titleBar && this.draggable){
				this._moveable = (dojo.isIE == 6) ?
					new dojo.dnd.TimedMoveable(node, { handle: this.titleBar }) :	// prevent overload, see #5285
					new dojo.dnd.Moveable(node, { handle: this.titleBar, timeout: 0 });
				dojo.subscribe("/dnd/move/stop",this,"_endDrag");
			}else{
				dojo.addClass(node,"dijitDialogFixed"); 
			}
			
			this.underlayAttrs = {
				dialogId: this.id,
				"class": dojo.map(this["class"].split(/\s/), function(s){ return s+"_underlay"; }).join(" ")
			};
			
			this._fadeIn = dojo.fadeIn({
				node: node,
				duration: this.duration,
				beforeBegin: dojo.hitch(this, function(){
					var underlay = dijit._underlay;
					if(!underlay){ 
						underlay = dijit._underlay = new dijit.DialogUnderlay(this.underlayAttrs); 
					}else{
						underlay.attr(this.underlayAttrs);
					}
					
					dojo.style(dijit._underlay.domNode, 'zIndex', 948 + dijit._dialogStack.length*2);
					dojo.style(this.domNode, 'zIndex', 949 + dijit._dialogStack.length*2);
					underlay.show();
				}),
				onEnd:	dojo.hitch(this, function(){
					if(this.autofocus){
						// find focusable Items each time dialog is shown since if dialog contains a widget the 
						// first focusable items can change
						this._getFocusItems(this.domNode);
						dijit.focus(this._firstFocusItem);
					}
				})
			 });

			this._fadeOut = dojo.fadeOut({
				node: node,
				duration: this.duration,
				onEnd: dojo.hitch(this, function(){
					node.style.visibility="hidden";
					node.style.top = "-9999px";
					
					// Restore the previous dialog in the stack, or if this is the only dialog
					// then restore to original page
					var ds = dijit._dialogStack;
					if(ds.length == 0){
						dijit._underlay.hide();
					}else{
						dojo.style(dijit._underlay.domNode, 'zIndex', 948 + ds.length*2);
						dijit._underlay.attr(ds[ds.length-1].underlayAttrs);
					}

					// Restore focus to wherever it was before this dialog was displayed
					if(this.refocus){
						var focus = this._savedFocus;

						// If we are returning control to a previous dialog but for some reason
						// that dialog didn't have a focused field, set focus to first focusable item.
						// This situation could happen if two dialogs appeared at nearly the same time, 
						// since a dialog doesn't set it's focus until the fade-in is finished.
						if(ds.length > 0){
							var pd = ds[ds.length-1];
							if(!dojo.isDescendant(focus.node, pd.domNode)){
								pd._getFocusItems(pd.domNode);
								focus = pd._firstFocusItem;
							}
						}

						dijit.focus(focus);
					}
				})
			 });
		},

		uninitialize: function(){
			var wasPlaying = false;
			if(this._fadeIn && this._fadeIn.status() == "playing"){
				wasPlaying = true;
				this._fadeIn.stop();
			}
			if(this._fadeOut && this._fadeOut.status() == "playing"){
				wasPlaying = true;
				this._fadeOut.stop();
			}
			if(this.open || wasPlaying){
				dijit._underlay.hide();
			}
			if(this._moveable){
				this._moveable.destroy();
			}
		},

		_size: function(){
			// summary:
			// 		Make sure the dialog is small enough to fit in viewport.
			// tags:
			//		private

			var mb = dojo.marginBox(this.domNode);
			var viewport = dijit.getViewport();
			if(mb.w >= viewport.w || mb.h >= viewport.h){
				dojo.style(this.containerNode, {
					width: Math.min(mb.w, Math.floor(viewport.w * 0.75))+"px",
					height: Math.min(mb.h, Math.floor(viewport.h * 0.75))+"px",
					overflow: "auto",
					position: "relative"	// workaround IE bug moving scrollbar or dragging dialog
				});
			}
		},

		_position: function(){
			// summary:
			//		Position modal dialog in the viewport. If no relative offset
			//		in the viewport has been determined (by dragging, for instance),
			//		center the node. Otherwise, use the Dialog's stored relative offset,
			//		and position the node to top: left: values based on the viewport.
			// tags:
			//		private
			if(!dojo.hasClass(dojo.body(),"dojoMove")){
				var node = this.domNode,
					viewport = dijit.getViewport(),
					p = this._relativePosition,
					mb = p ? null : dojo.marginBox(node),
					l = Math.floor(viewport.l + (p ? p.l : (viewport.w - mb.w) / 2)),
					t = Math.floor(viewport.t + (p ? p.t : (viewport.h - mb.h) / 2))
				;
				dojo.style(node,{
					left: l + "px",
					top: t + "px"
				});
			}
		},
		
		_onKey: function(/*Event*/ evt){
			// summary:
			//		Handles the keyboard events for accessibility reasons
			// tags:
			//		private

			var ds = dijit._dialogStack;		
			if(ds[ds.length-1] != this){
				// 
				return;
			}

			if(evt.charOrCode){
				var dk = dojo.keys;
				var node = evt.target;
				if (evt.charOrCode === dk.TAB){
					this._getFocusItems(this.domNode);
				}
				var singleFocusItem = (this._firstFocusItem == this._lastFocusItem);
				// see if we are shift-tabbing from first focusable item on dialog
				if(node == this._firstFocusItem && evt.shiftKey && evt.charOrCode === dk.TAB){
					if(!singleFocusItem){
						dijit.focus(this._lastFocusItem); // send focus to last item in dialog
					}
					dojo.stopEvent(evt);
				}else if(node == this._lastFocusItem && evt.charOrCode === dk.TAB && !evt.shiftKey){
					if (!singleFocusItem){
						dijit.focus(this._firstFocusItem); // send focus to first item in dialog
					}
					dojo.stopEvent(evt);
				}else{
					// see if the key is for the dialog
					while(node){
						if(node == this.domNode){
							if(evt.charOrCode == dk.ESCAPE){
								this.onCancel(); 
							}else{
								return; // just let it go
							}
						}
						node = node.parentNode;
					}
					// this key is for the disabled document window
					if(evt.charOrCode !== dk.TAB){ // allow tabbing into the dialog for a11y
						dojo.stopEvent(evt);
					// opera won't tab to a div
					}else if(!dojo.isOpera){
						try{
							this._firstFocusItem.focus();
						}catch(e){ /*squelch*/ }
					}
				}
			}
		},

		show: function(){
			// summary:
			//		Display the dialog
			if(this.open){ return; }

			// first time we show the dialog, there's some initialization stuff to do			
			if(!this._alreadyInitialized){
				this._setup();
				this._alreadyInitialized=true;
			}

			if(this._fadeOut.status() == "playing"){
				this._fadeOut.stop();
			}

			this._modalconnects.push(dojo.connect(window, "onscroll", this, "layout"));
			this._modalconnects.push(dojo.connect(window, "onresize", this, function(){
				// IE gives spurious resize events and can actually get stuck
				// in an infinite loop if we don't ignore them
				var viewport = dijit.getViewport();
				if(!this._oldViewport ||
						viewport.h != this._oldViewport.h ||
						viewport.w != this._oldViewport.w){
					this.layout();
					this._oldViewport = viewport;
				}
			}));
			this._modalconnects.push(dojo.connect(dojo.doc.documentElement, "onkeypress", this, "_onKey"));

			dojo.style(this.domNode, {
				opacity:0,
				visibility:""
			});
			
			if(this._fixSizes){
				dojo.style(this.containerNode, { // reset width and height so that _size():marginBox works correctly
					width:"auto",
					height:"auto"
				});
			}
			
			this.open = true;
			this._onShow(); // lazy load trigger

			this._size();
			this._position();
			dijit._dialogStack.push(this);
			this._fadeIn.play();

			this._savedFocus = dijit.getFocus(this);
		},

		hide: function(){
			// summary:
			//		Hide the dialog

			// if we haven't been initialized yet then we aren't showing and we can just return
			// or if we arent the active dialog, dont allow us to close yet
			var ds = dijit._dialogStack;
			if(!this._alreadyInitialized || this != ds[ds.length-1]){
				return;
			}

			if(this._fadeIn.status() == "playing"){
				this._fadeIn.stop();
			}
			
			// throw away current active dialog from stack -- making the previous dialog or the node on the original page active
			dijit._dialogStack.pop();

			this._fadeOut.play();

			if (this._scrollConnected){
				this._scrollConnected = false;
			}
			dojo.forEach(this._modalconnects, dojo.disconnect);
			this._modalconnects = [];

			if(this._relativePosition){
				delete this._relativePosition;	
			}
			this.open = false;
		},

		layout: function() {
			// summary:
			//		Position the Dialog and the underlay
			// tags:
			//		private
			if(this.domNode.style.visibility != "hidden"){
				if(dijit._underlay){	// avoid race condition during show()
					dijit._underlay.layout();
				}
				this._position();
			}
		},
		
		destroy: function(){
			dojo.forEach(this._modalconnects, dojo.disconnect);
			if(this.refocus && this.open){
				setTimeout(dojo.hitch(dijit,"focus",this._savedFocus), 25);
			}
			this.inherited(arguments);			
		},

		_onCloseEnter: function(){
			// summary:
			//		Called when user hovers over close icon
			// tags:
			//		private
			dojo.addClass(this.closeButtonNode, "dijitDialogCloseIcon-hover");
		},

		_onCloseLeave: function(){
			// summary:
			//		Called when user stops hovering over close icon
			// tags:
			//		private
			dojo.removeClass(this.closeButtonNode, "dijitDialogCloseIcon-hover");
		}
	}
);

// Stack of currenctly displayed dialogs, layered on top of each other
dijit._dialogStack = [];

// For back-compat.  TODO: remove in 2.0


}

if(!dojo._hasResource["com.ibm.customize.LotusPaletteContainer"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.customize.LotusPaletteContainer"] = true;
// This is a container which follows the one ui lotus palette spec
// must be provided with a processChange function
dojo.provide("com.ibm.customize.LotusPaletteContainer");










dojo.declare("com.ibm.customize.LotusPaletteContainer",
	[dijit._Widget, dijit._Templated],
	{
		jsonFile: null,				// a JSON configuration file
		dialog: null,				// a dijit dialog
		maxLabelLength: 16,			// the maximum length allowed for a label
		smallWidget: false,			// false if it follows the lotusLargeWidget pattern
		numRows: 4,					// the number of rows of results to be displayed
		label: "",					// a label for this palette section
		selectedClass: "lotusSelected",
		imagePath: ".",
		templateString:'<div class="lotusui">' +
							'<div class="lotusPaletteBody">' +
								'<div dojoAttachPoint="left" class="lotusPaletteNav"></div>' +
								'<div dojoAttachPoint="center" class="lotusPaletteContent lotusui"></div>' +
							'</div>' +
						'</div>',
						
		constructor: function() {
			this.nlsBundle = dojo.i18n.getLocalization("com.ibm.bundles", "Shelf");
		},
		
		postMixInProperties: function() {
			if(this.smallWidget) {
				this.dialog = new com.ibm.customize.LotusDialog({ blankImg:this.imagePath + "/blank.gif" });
				this.dialog.closeButtonNode.onclick = this.dialog.closeLinkNode.onclick = dojo.hitch(this,function(){this.dialog.cancel();return false;});
			}
		},
		
		processChange: function(/*Object*/args) {
		},
		
		getSize: function(){
			// summary: determine the width of a palette widget element on the page with all the current settings by adding one to the page, taking its width, then deleting it
			// use the palette widget to determine how many of them can fit in the ResultsList
			var paletteWidget = dojo.create("div",{className:"lotusPaletteWidget"});
			document.body.appendChild(paletteWidget);
			if (paletteWidget.currentStyle){
				marginL = paletteWidget.currentStyle["marginLeft"].match(/^\d+/);
				marginR = paletteWidget.currentStyle["marginRight"].match(/^\d+/);
			} else if (window.getComputedStyle) {
				marginL = document.defaultView.getComputedStyle(paletteWidget,null).getPropertyValue("margin-left").match(/^\d+/);
				marginR = document.defaultView.getComputedStyle(paletteWidget,null).getPropertyValue("margin-right").match(/^\d+/);
			} 
			var width = paletteWidget.offsetWidth + marginL*1 + marginR*1;
			var containerWidth = this.center.offsetWidth;
			var resultsInOneRow = Math.floor(containerWidth / width);
			dojo.destroy(paletteWidget);
			return resultsInOneRow * this.numRows;
		},
		
		setupUI: function(){
			// summary: starts the UI setup
			this.processJSON(dojo.hitch(this,this.setupUICallback));
		},
		
		setupUICallback: function(sources){
			// summary: populates the SearchBar, Menu and ResultsList widget with configuration data from the JSON file
			var resultsList = new com.ibm.customize.ResultsList({parent:this,size:this.getSize()});
			this.center.appendChild(resultsList.domNode);
				
			var searchBar = new com.ibm.customize.SearchBar({searchId:this.id,imagePath:this.imagePath});
			this.left.appendChild(searchBar.domNode);
				
			var menu = new com.ibm.customize.Menu({sources:sources,searchId:this.id,menuTitle:this.label});
			this.left.appendChild(menu.domNode);
		},
		
		processJSON: function(/*function*/callback){
			// summary: processes the JSON file associated with this controller
			// callback: function to call after the JSON is processed that uses the sourceObjects
			dojo.xhrGet ({
		        url: this.jsonFile,
		        handleAs: 'json',
		        load: dojo.hitch(this, function(data){
					// get the bundle if one is provided
					if(data.localizationPackageName && data.localizationBundleName){
						this.nlsJsonBundle = dojo.i18n.getLocalization(data.localizationPackageName, data.localizationBundleName);
					} else this.nlsJsonBundle = null;
					var sources = data.categories;
					var sourceObjects = new Array();
					for(var i = 0; i < sources.length; i++) {
						// pass the exact same sources item to the class's constructor minus the datastore and renderers properties
						var map = dojo.mixin({}, sources[i]);
						if(map.url && this.createProxyURI) map.url = this.createProxyURI(map.url);
						delete map.datastore; delete map.renderers; delete map.label;
						// create a datastore hub and a new source object
						var evalString = "new " + sources[i].datastore + "(" + dojo.toJson(map) + ")";
						var hub = dojo.eval(evalString);
						if(!hub.validateSelf()) continue;  // do not use this source if it does not validate
						if(hub.getSourceLabel()) var label = hub.getSourceLabel();  // mashups categories feeds
						else var label = this.nlsJsonBundle && this.nlsJsonBundle[sources[i].label] ? this.nlsJsonBundle[sources[i].label] : sources[i].label;  // everything else
						if(!label || (label && label.length == 0)) label = this.nlsBundle["add_content_untitled"]; 
						var searchStr = this.nlsJsonBundle && this.nlsJsonBundle[sources[i].searchStr] ? this.nlsJsonBundle[sources[i].searchStr] : sources[i].searchStr;  // everything else
						if(searchStr && searchStr.length == 0) searchStr = null;
						sourceObjects.push({label:label,hub:hub,renderers:sources[i].renderers,url:sources[i].url,searchStr:searchStr});
					}
					if(callback) callback(sourceObjects);
				}),	
		        error: dojo.hitch(this, function (/*String*/error) {
		            var errorMsg = this.createLotusMsgNode(this.nlsBundle["shelf_configError"],"Error");
					dojo.style(errorMsg,"margin","20px");
					this.domNode.innerHTML = "";
					this.domNode.appendChild(errorMsg);
		        })
		    });
		},
		
		newCell: function(/*Object*/source,/*DataItem*/item){
			// summary:  override this function to fill innerCell with information about the given datastore item
			// source: a datastore
			// item: an item in source
			var map = source.hub.mapItem(item);
			var label = (map.label.length > this.maxLabelLength)?map.label.substring(0,this.maxLabelLength) + '...':map.label;
			
			if(this.smallWidget) {
				var applyToPage = dojo.hitch(this, function() { this.processIntermediateDialogs(source,item); });
				showDetails = dojo.hitch(this, function() { this.showDetailsDialog(map,applyToPage); return false; /* to prevent onBeforeUnload event from triggering in IE */ });
				if(source.hub.noIcons){
					var widget = new com.ibm.customize.noIconSmallWidget({titleText:map.label, truncTitleText:label, imagePath:this.imagePath, apply:applyToPage, showDetails:showDetails});
				} else {
					var widget = new com.ibm.customize.smallWidget({titleText:map.label, truncTitleText:label, imagePath:this.imagePath, iconPath:map.thumbnail, apply:applyToPage, showDetails:showDetails});
				}
			}
			else {
				var applyToPage = dojo.hitch(this, function() { this.processChange({id:map.id,name:map.label}) });
				var widget = new com.ibm.customize.largeWidget({titleText:map.label, truncTitleText:label, imagePath:this.imagePath, iconPath:map.thumbnail, apply:applyToPage, id:map.id, current:map.id == this.current});
			}
			return widget.domNode;
		},
		
		createLotusMsgNode: function(/*string*/message,/*string*/type){
			// summary: returns a div node containing the given message with OneUI styles
			// msg: the error message to display
			// type: either "Warning", "Error", "Info" or "Confirm"
			var err = dojo.create("div",{className:"lotusMessage lotus" + type, style:{ marginRight:"15px" }});
			var img = dojo.create("img",{src:this.imagePath + "/icon" + type + ".gif", alt:message});
			var msg = dojo.create("span",{innerHTML:message});
			err.appendChild(img);
			err.appendChild(msg);
			return err;
		},
		
		changeSelected: function(/*string*/selected){
			// reset the look of the previously selected style/layout
			var items = dojo.query(".lotusPaletteWidget",this.center), selectedWidget = null;
			dojo.forEach(items, dojo.hitch(this, function(item){
				selectedWidget = dijit.byId(item.id);
				if(selectedWidget) selectedWidget.deselect();
			}));
			selectedWidget = dijit.byId(selected);
			if(selectedWidget) selectedWidget.select();
		},
		
		/**********************************/
		/*        DIALOG HELPERS          */
		/**********************************/
		
		processIntermediateDialogs: function(/*Object*/source,/*DataItem*/item){
			// source: a datastore
			// item: an item in source's hub
			var map = source.hub.mapItem(item);
			if(!source.renderers && this.renderers) source.renderers = this.renderers; // so Mashups can provide its renderers dynamically
			if(source.renderers.length == 0){
				// if there are no renderers defined, then this is a self renderer and we assume the item's id is the id of the piece of content to be added
				var takeoverFcn = source.hub.getValue(item,"takeover",null);
				var takeoverObject = takeoverFcn ? {submit:dojo.hitch(this,this.processChange),getInfo:dojo.hitch(this,this.getValuesFromDialog),showInfo:dojo.hitch(this,this.showWaitMsgInDialog),hub:source.hub,item:item} : {};
				var args = {id:map.id,label:map.label,map:map,takeoverFcn:takeoverFcn,takeoverObject:takeoverObject};
				this.processChange(args);
			} else if(source.renderers.length == 1){ 
				// if there is only one renderer available, add it
				var args = {id:source.renderers[0].id,label:map.label,prefsMapFcn:source.renderers[0].fcn,map:map};
				this.processChange(args);
			} else {
				// an intermediate dialog box is opened for the user to choose the desired renderer
				var content = dojo.create("div");
				var header = dojo.create("h4");
				var headerLabel = dojo.create("label",{"for":"widgetRendererSelect",innerHTML:this.nlsBundle["add_content_selectRenderer"]});
				header.appendChild(headerLabel);
				content.appendChild(header);
				var rendererSelect = dojo.create("select",{id:"widgetRendererSelect"});
				content.appendChild(rendererSelect);
				for(var i = 0; i < source.renderers.length; i++){
					var select = dojo.create("option",{innerHTML:this.nlsJsonBundle && this.nlsJsonBundle[source.renderers[i].label] ? this.nlsJsonBundle[source.renderers[i].label] : source.renderers[i].label,value:i});
					rendererSelect.appendChild(select);
				}
				var onSubmit = dojo.hitch(this, function(){ 
					this.dialog.cancel();
					var renderer = source.renderers[rendererSelect.value]; 
					var args = {id:renderer.id,label:map.label,prefsMapFcn:renderer.fcn,map:map};
					this.processChange(args);
				});
				this.dialog.setContent(content, this.nlsBundle["add_content_addToPage"], this.nlsBundle["add_content_add"], onSubmit);
			}
		},
		
		showDetailsDialog: function(/*Object*/itemMap,/*Function*/submitFcn){
			// summary: prepares the markup for the popup dialog to display details.  
			// itemMap: a map of information on the content from the mapItem function of the CatalogMixin class
			// submitFcn: the function to call when the submit button on the dialog is clicked
			var content = dojo.create("div");
			var title = dojo.create("h4",{innerHTML:(itemMap.label)?itemMap.label:this.nlsBundle["add_content_untitled"]});
			content.appendChild(title);
			if(itemMap.updated) {
				var updated = dojo.create("p",{innerHTML:dojo.string.substitute(this.nlsBundle["add_content_lastMod"], [itemMap.updated])});
				content.appendChild(updated);
			}
			if(itemMap.description){ 
				var desc = dojo.create("p",{innerHTML:itemMap.description});
				content.appendChild(desc);
			}
			if(itemMap.tags && itemMap.tags.length > 0){ 
				var tags = dojo.create("p",{innerHTML:dojo.string.substitute(this.nlsBundle["add_content_tags"], [itemMap.tags.join(", ")])});
				content.appendChild(tags);
			}
			var submit = dojo.hitch(this, function(){ this.dialog.cancel(); submitFcn(); });
			this.dialog.setContent(content, this.nlsBundle["add_content_details"], this.nlsBundle["add_content_addToPage"], submit);
		},
		
		showWaitMsgInDialog: function(/*String*/message){
			// summary: abstracts the use of the popup dialog by displaying a message
			// message: message to display in the dialog
			var dialog = new com.ibm.customize.LotusWaitingDialog({spinner:this.imagePath + "/loading.gif", message:message});
			try {
				dialog.show();
			} catch(e) {}
			return dojo.hitch(this,function(){ dialog.cancel(); });
		},
		
		getValuesFromDialog: function(/*object*/formObjs,/*String*/titleText,/*String*/submitText,/*String*/errorText,/*function*/callback){ 
			// summary: abstracts the use of the popup dialog by dislaying a form of text fields to be filled out
			// formObjs: an array of objects in the form:	label: a label for a text field 
			//												id: an id for the input field
			//												value: a value for the same text field 
			//												regex: a regular expression that the value of the field must validate against
			//												error: an error to display if the value does not validate
			// titleText: text to user as the title of the dialog
			// submitText: text to user on the submit button in the dialog
			// errorText: an optional error message to preface the entire form in the dialog, ie a "try again" error
			// callback: a function to be called when all the fields validate, it is called with an object of key value pairs
			//			 with the labels from the formObjs as keys and their corresponding values from the form as values
			var content = document.createElement("div");
			for(var i = 0; i < formObjs.length; i++){ // add an input for each item in formObjs
				var title = dojo.create("h4");
				var titleLabel = dojo.create("label",{innerHTML:formObjs[i].label, "for":formObjs[i].id});
				var error = dojo.create("div",{className:"lotusFormError"}); formObjs[i].errorDiv = error;
				var additionalClasses = "";
				if (formObjs[i].ltr)
					additionalClasses =" lotusLTR";
				var input = dojo.create("input",{type:"text", id:formObjs[i].id, className:"lotusText" + additionalClasses, value:formObjs[i].value}); formObjs[i].input = input;
				title.appendChild(titleLabel);
				content.appendChild(error);
				content.appendChild(title);
				content.appendChild(input);
			}
			if(errorText) formObjs[0].errorDiv.innerHTML = errorText;
			var validateInputs = dojo.hitch(this, function(){
				var fail = false;
				var values = {};
				for(var i = 0; i < formObjs.length; i++){
					if(!formObjs[i].input.value.match(formObjs[i].regex)){ // if the input does not match the regular expression, display an error
						fail = true;
						formObjs[i].errorDiv.innerHTML = formObjs[i].error;
					} else { // if the input does match the regex, add the input value to the return object
						values[formObjs[i].id] = formObjs[i].input.value;
						formObjs[i].errorDiv.innerHTML = "";
					}
				}
				if(!fail){ // if all the regular expressions matched, run the callback function on the values and close the dialog
					this.dialog.cancel();
					callback(values);				
				}
			});
			this.dialog.setContent(content, titleText, submitText, dojo.hitch(this, function(){ validateInputs(); }));
		}
});

dojo.provide("com.ibm.customize.smallWidget");
dojo.declare("com.ibm.customize.smallWidget",
	[dijit._Widget, dijit._Templated],
	{
		titleText: "",
		truncTitleText: "",
		imagePath: ".",
		iconPath: "",
		detailDialogInstruction: "press enter to see details dialog",
		templateString: '<div class="lotusPaletteWidget" role="gridcell">' +
							'<div class="lotusInner">' +
								'<div class="lotusIcon">' +
									'<span>' +
										'<img alt="${truncTitleText}" src="${iconPath}"/>' +
									'</span>' +
								'</div>' +
								'<div class="lotusTitle">' +
									'<h4>' +
										'<a href="javascript:void(0);" title="${titleText}" dojoAttachPoint="titleAnchor">' +
											'${truncTitleText}' +
											'<span class="ibmPortalHiddenText">${detailDialogInstruction}</span>' +
										'</a>' +
									'</h4>' +
								'</div>' +
								'<a class="lotusIcon" href="javascript:void(0)" title="${addToPage}" dojoAttachPoint="addButton">' +
									'<img width="16" height="16" src="${blankPath}" alt=""/>' +
									'<span class="lotusAltText">+</span>' +
								'</a>' +
							'</div>' +
						'</div>',
						
		postMixInProperties: function(){
			var bundle = dojo.i18n.getLocalization("com.ibm.bundles", "Shelf");
			this.addToPage = bundle["add_content_addToPage"];
			this.detailDialogInstruction = bundle["detail_dialog_instruction_text"] || this.detailDialogInstruction;
			if (!this.iconPath) this.iconPath = this.imagePath + "/portletIcon.gif";
			this.blankPath = this.imagePath + "/blank.gif";
		},
			
		postCreate: function(){	
			this.titleAnchor.onclick = dojo.hitch(this, function(){ this.showDetails(); return false; });
			this.addButton.onclick = dojo.hitch(this, function(){ this.apply(); return false; });
		},
		
		apply: function(){},
		
		showDetails: function(){},
		
		select: function(){},
		
		deselect: function(){}
	});

dojo.provide("com.ibm.customize.noIconSmallWidget");
dojo.declare("com.ibm.customize.noIconSmallWidget",
	[com.ibm.customize.smallWidget],
	{
		templateString: '<div class="lotusPaletteWidget" role="gridcell">' +
							'<div class="lotusInner">' +
								'<div class="lotusIcon"></div>' +
								'<div class="lotusTitle">' +
									'<h4>' +
										'<a href="javascript:void(0);" title="${titleText}" dojoAttachPoint="titleAnchor">${truncTitleText}</a>' +
									'</h4>' +
								'</div>' +
								'<a class="lotusIcon" href="javascript:void(0)" title="${addToPage}" dojoAttachPoint="addButton">' +
									'<img width="16" height="16" src="${blankPath}" alt=""/>' +
									'<span class="lotusAltText">+</span>' +
								'</a>' +
							'</div>' +
						'</div>'
	});
	
	dojo.provide("com.ibm.customize.largeWidget");
	dojo.declare("com.ibm.customize.largeWidget",
	[dijit._Widget, dijit._Templated],
	{
		titleText: "",
		truncTitleText: "",
		imagePath: ".",
		iconPath: "",
		current: false,
		selectedClass: "lotusSelected",
		hiddenSelectedText: "currently selected for the page",
		hiddenUnselectedText: "press enter to select",
		templateString: '<div class="lotusPaletteWidget" dojoAttachPoint="addButton" role="gridcell" aria-selected="false">' +
							'<div class="lotusInner">' +
								'<div class="lotusIcon">' +
									'<span>' +
										'<img alt="${truncTitleText}" src="${iconPath}"/>' +
									'</span>' +
								'</div>' +
								'<div class="lotusTitle">' +
									'<h4>' +
										'<a href="javascript:void(0);" title="${titleText}">' +
											'${truncTitleText}' +
											'<span class="ibmPortalHiddenText" dojoAttachPoint="hiddenSelectedTextNode">${hiddenUnselectedText}</span>' +
										'</a>' +
									'</h4>' +
								'</div>' +
							'</div>' +
						'</div>',
						
		postMixInProperties: function(){
			if (!this.iconPath) this.iconPath = this.imagePath + "/portletIcon.gif";
			this.hiddenSelectedText = dojo.i18n.getLocalization("com.ibm.bundles", "Theme")["currently_selected"] || this.hiddenSelectedText;
			this.hiddenUnselectedText = dojo.i18n.getLocalization("com.ibm.bundles", "Shelf")["selection_instructions"] || this.hiddenUnselectedText;
		},
		
		postCreate: function(){
			if(this.current) this.select();
			this.addButton.onclick = dojo.hitch(this, function(){ this.apply(); return false; });
		},
		
		apply: function(){},
		
		select: function(){
			this.current = true;
			dojo.addClass(this.domNode,this.selectedClass);
			dojo.attr(this.domNode,"aria-selected","true");
			this.hiddenSelectedTextNode.innerHTML = this.hiddenSelectedText;
		},
		
		deselect: function(){
			this.current = false;
			dojo.removeClass(this.domNode,this.selectedClass);
			dojo.attr(this.domNode,"aria-selected","false");
			this.hiddenSelectedTextNode.innerHTML = this.hiddenUnselectedText;
		}
	});
	
	dojo.provide("com.ibm.customize.LotusDialog");
	dojo.declare("com.ibm.customize.LotusDialog",
	[dijit.Dialog],
	{
		blankImg: "",
		titleText: "",
		okText: "OK",
		destroyOnClose: false,
		templateString: '<div class="lotusDialogBorder lotusui" waistate="labelledby-${id}" wairole="dialog" role="dialog" index="-1" aria-labelledby="${id}">' +
							'<div class="lotusDialog">' +
								'<h1>' +
									'<a href="javascript:void(0);" dojoAttachPoint="closeButtonNode" class="lotusBtnImg lotusClose" title="${closeText}">' +
										'<img src="${blankImg}" aria-label="${closeText}" alt=""/>' +
										'<span class="lotusAltText">X</span>' +
									'</a>' +
									'<span dojoAttachPoint="titleNode">${titleText}</span>' +
								'</h1>' +
								'<div class="lotusDialogContent" dojoAttachPoint="containerNode"></div>' +
								'<div class="lotusDialogFooter">' +
									'<input value="${okText}" class="lotusFormButton" dojoAttachPoint="submitNode" type="submit" dojoAttachEvent="onclick: submit"/> ' +
									'<a href="javascript:void(0);" dojoAttachPoint="closeLinkNode" class="lotusAction">${cancelText}</a>' +
								'</div>' +
							'</div>' +
						'</div>',
						
		postMixInProperties: function(){
			this.nlsBundle = dojo.i18n.getLocalization("com.ibm.bundles", "Shelf");
			this.closeText = this.nlsBundle["shelf_closeDialog"];
			this.cancelText = this.nlsBundle["add_content_cancel"];
		},
		
		onSubmit: function(){
		},
		
		submit: function(){
			this.onSubmit();
		},
		
		cancel: function(){
			this.hide();
			if(this.destroyOnClose) this.destroy();
		},
		
		setContent: function(content, title, okText, submitFcn){
			dojo.empty(this.containerNode);
			if (dojo.isString(content)) content = document.createTextNode(content);
			this.containerNode.appendChild(content);
			this.titleNode.innerHTML = title || this.titleText;
			this.submitNode.value = okText || this.okText;
			this.onSubmit = submitFcn || function(){};
			this.show();
		}
	});
	
	dojo.provide("com.ibm.customize.LotusWaitingDialog");
	dojo.declare("com.ibm.customize.LotusWaitingDialog",
	[com.ibm.customize.LotusDialog],
	{
		spinner: "",
		message: "",
		destroyOnClose: true,
		templateString: '<div class="lotusDialogBorder lotusui" waistate="labelledby-${id}" wairole="dialog" role="dialog" index="-1" aria-labelledby="${id}">' +
							'<div class="lotusDialog">' +
								'<div class="lotusDialogContent" dojoAttachPoint="containerNode">' +
									'<img src="${spinner}" alt="${loadingText}" title="${loadingText}"/>' +
									'${message}' +
								'</div>' +
							'</div>' +
						'</div>',
						
		postMixInProperties: function(){
			this.nlsBundle = dojo.i18n.getLocalization("com.ibm.bundles", "Shelf");
			this.loadingText = this.nlsBundle["shelf_loading"];
			this.message = "      " + this.message;
		},
		
		show: function(){
			setTimeout( dojo.hitch(this, function(){ if(this.open) dijit._underlay.show(); }), this.duration + 200 );  // make sure underlay is visible
			this.inherited(arguments);
		}
	});

}

if(!dojo._hasResource["com.ibm.customize.AddContentPaletteContainer"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.customize.AddContentPaletteContainer"] = true;
// This is Add Content
dojo.provide("com.ibm.customize.AddContentPaletteContainer");



dojo.declare("com.ibm.customize.AddContentPaletteContainer",
	[com.ibm.customize.LotusPaletteContainer],
	{
		legacy: false, 		// true if this is a legacy page
		createProxyURI: null,	// function to create a proxy url
		pendingItems: null,		// items pending creation/modification
		beforeSubmitDfds: null, // Array of Deferreds that must all get called back before submit processing can occur
		afterSubmitDfds: null, // Array of Deferreds that must all get called back before submit fires its onComplete/onError handlers
		
		constructor: function() {
			this.label = this.nlsBundle["add_content_browseContent"];
			this.tabLabel = this.nlsBundle["add_content_launchLabel"];
			this.pendingItems = {};
			this.beforeSubmitDfds = [];
			this.afterSubmitDfds = [];
		},

		startup: function(/*Object/Widget*/parent){
			this.started = true;
			this.parent = parent;
			
			// if this is not a legacy page, set up the UI as usual
			if(!this.legacy) this.setupUI();
			else{
				// display a warning message that a Page Builder layout must be applied before any content can be added to the page
				var warningMsg = this.createLotusMsgNode(this.nlsBundle["add_content_legacyError"],"Warning");
				dojo.style(warningMsg,"margin","20px");
				this.domNode.innerHTML = "";
				this.domNode.appendChild(warningMsg);
			}
		}
});

}

if(!dojo._hasResource["com.ibm.customize.ChangeLayoutController"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.customize.ChangeLayoutController"] = true;
// This is a controller that customizes the styles of a page

dojo.provide("com.ibm.customize.ChangeLayoutController");

com.ibm.customize.ChangeLayoutController = {
	current: "",			// the style currently selected on the shelf
	set: "",				// the style currently set on the page

/***********************************************/
/*       Customize Controller API			   */
/***********************************************/
	store: null,		// a datastore to save model changes
	item: null,			// an item in the store representing the current page to which changes will be made
	parent: null,		// a pointer to this controller's parent, if one exists
	dirty: false,		// true if there are changes pending
	started: false,		// true if the widget is started up
	refresh: true,		// true if a page refresh is required to show saved changes

	startup: function(/*Object?/Widget?*/parent){
		// summary: set some variable and set up the UI
		// parent: a reference to the parent of this controller
		this.started = true;
		this.current = this.set;
		this.parent = parent;
		if(this.setupUI) this.setupUI();
		this.pageId = this.store.getIdentity(this.item).substr(3);
	},
	
	_fullLMId: function(lmId) {
		return "lm:" + lmId + "@" + this.pageId;
	},
		
	makeDirty: function(/*bool*/change){
		// summary: changes the dirty attribute
		// change: value to assign to the dirty attribute
		this.dirty = change;
	},
		
	processChange: function(/*Object*/args){
		// summary: used as an event handler for when a user clicks on a result
		this.apply(args);
		if(!this.parent) {
			this.beforeSubmit().addCallback(dojo.hitch(this, function(){this.submit(args)}));
		}
	},
		
	apply: function(/*Object*/args){
		// summary: applies a change associated with a result to the page
		// args: contains args.id which is the id of the selected item
		if(args.id == this.current) return;
		if(args.id == this.set) this.makeDirty(false);
		else if(this.dirty == false) this.makeDirty(true);
		this.current = args.id;
	},
		
	undo: function(){
		// summary: reverts any changes made
		if(this.started) this.apply({id:this.set});
	},

	beforeSubmit: function(/*Object*/args){
		// summary: set the metadata for the style in the content model store. Returns a Deferred
		//		which is fired when the controller is ready to be submitted.
		var dfd = new dojo.Deferred();
		if(this.dirty){
			var cbk = dojo.hitch(this, function(){
				if(this.started) this.store.setValue(this.item, "metadata[layout]$", this.current);
				this._loadLayout(dojo.hitch(this, function(root){
					this._getTreeModel().getChildren(root, dojo.hitch(this, "_calculateLayoutChanges", root, dfd));
				}));
			});
			if(!this.store.isItemLoaded(this.item)) {
				this.store.loadItem({
					item: this.item,
					onItem: cbk,
					onError: args ? args.onError : null
				});
			}
			else cbk();
		} else dfd.callback();
		return dfd;
	},
		
	submit: function(/*Object*/args){
		// summary: saves any pending changes to the server
		// args: args may contain an onComplete handler
		if(!this.dirty) {
			if(args.onComplete) args.onComplete();
			return; 
		}
		this._saveStore(args);
	},
	
	_calculateLayoutChanges: function(layoutRoot, deferred) {
		var newNumCols = this.columnHash[this.current];
		var oldNumCols = this.columnHash[this.set];
		// change the number of containers in the backend			
		if(!oldNumCols){
			// case 0: transition away from a legacy layout
			this.removeLegacyLayout(newNumCols, layoutRoot, deferred);
		} else if(newNumCols > oldNumCols){ 
			// case 1: less to more containers; add extra containers
			this.addContainers(newNumCols-oldNumCols, layoutRoot);
		} else if(oldNumCols > newNumCols) { 
			// case 2: more to less containers
			var domContainers = dojo.query(".ibmPortalLayoutContainer"); 	// all containers on the page
			if(domContainers.length > newNumCols){  // safeguard if there are less containers than expected
				var parentContainerId = this._fullLMId(domContainers[newNumCols-1].id);			// the last container in the new layout will receive all orphaned controls
				var containersToDelete = new Array();
				var controlsToReparent = new Array();
				// loop through all containers to be deleted
				for(var i = oldNumCols; i != newNumCols; i--){
					if(domContainers[i-1]){ // safeguard in case there aren't as many layout containers as expected
						var removeContainer = domContainers[i-1].id;
						containersToDelete.push(this.store.byId(this._fullLMId(removeContainer))); // container to be deleted
						// controls to reparent
						var controls = dojo.query(".ibmPortalControlContainer",dojo.byId(removeContainer)); 
						// loop through all controls to reparent
						for(var j = 0; j < controls.length; j++){
							controlsToReparent.push(this.store.byId(this._fullLMId(controls[j].getAttribute("controlid"))));
						}
					}
				}
				// reparent the controls and then delete the containers they were in
				if(controlsToReparent.length > 0) {
					this.reparentControls(controlsToReparent, parentContainerId);
					this.deleteContainers(containersToDelete);
				} else if (containersToDelete.length > 0) {
					this.deleteContainers(containersToDelete);
				}
			}
		}
		if(oldNumCols) deferred.callback();
	},
	
	_saveStore: function(args,unfinished) {
		this.store.save({
			onComplete: dojo.hitch(this, function(){
				if(!unfinished) this.makeDirty(false);
				this.set = this.current;
				if(args.onComplete) args.onComplete();
			}),
			onError: args.onError
		});
	},
	
	_getTreeModel: function() {
		// gets the tree model for the store which contains the item
		return this.store.getValue(this.item, "layoutModel");
	},
	
	_loadLayout: function(onItem, onError) {
		// summary: this loads the root layout node, but also the entire layout tree
		this._getTreeModel().getRoot(onItem, onError);		
	},
	
	addContainers: function(/*int*/num,/*item*/rootItem){
		// summary: add containers to the layout model of the current page
		// num: the number of containers to add
		// rootItem: datastore item for the root layout node
		var first = null;
		for(var i = 0; i < num; i++){ 
			var item = this.store.newItem({
				pocType: "lm",
				type: "container"
			}, {parent:rootItem});
			if(i==0) first = item;
		}
		return first;
	},
	
	reparentControls: function(/*Array*/controlsToReparent,/*string*/parent){
		// summary: reparents given controls into a given container on the current page
		// controlsToReparent: an array of the IDs of the controls to reparent
		// parent: the ID of the container on the page which is the new parent
		for(var i = 0, control; i < controlsToReparent.length; i++){
			this.store.setValue(controlsToReparent[i], "parentId", parent); 
		}
	},
	
	deleteContainers: function(/*Array*/containersToDelete){
		// summary: deletes the given containers from the layout model of the current page
		// containersToDelete: an array of the IDs of the containers to delete off the page
		for(var i = 0; i < containersToDelete.length; i++){
			this.store.deleteItem(containersToDelete[i]);
		}
	},
	
	removeLegacyLayout: function(/*int*/num,/*item*/rootItem, deferred){ 
		// summary: removes a legacy layout by:
		//			1. creating the number of containers needed for the new layout
		//			2. moving ALL controls into the first of the newly created containers
		//			3. deleting all containers from the legacy layout which are direct children of the root layout node
		// num: the number of columns to create for the new layout
		// rootItem: datastore item for the root layout node
		var layoutModelItems = this._getTreeModel().getAll();
		var controlsToReparent = dojo.filter(layoutModelItems, function(item) {
			return this.store.getValue(item, "modelNodeType", "").toLowerCase() == "layout-control";
		}, this);
		var containersToDelete = dojo.filter(layoutModelItems, function(item) {
			return this.store.getValue(item, "parentId", "") == this.store.getValue(rootItem,"id");
		}, this);
		var newParentItem = this.addContainers(num,rootItem);
		if(controlsToReparent.length > 0) this.reparentControls(controlsToReparent,this.store.getValue(newParentItem,"id"));
		var deleteOldContainers = dojo.hitch(this, function(){
			if(containersToDelete.length > 0) this.deleteContainers(containersToDelete);
			deferred.callback();
		});
		this._saveStore({onComplete:deleteOldContainers},true);
	}
}

}

if(!dojo._hasResource["com.ibm.customize.ChangeLayoutPaletteContainer"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.customize.ChangeLayoutPaletteContainer"] = true;
// This is Change Layout
dojo.provide("com.ibm.customize.ChangeLayoutPaletteContainer");






dojo.declare("com.ibm.customize.ChangeLayoutPaletteContainer",
	[com.ibm.customize.LotusPaletteContainer],
	{
		numRows: 3,			// the number of rows of results to be displayed
		columnHash:{},		// an associative array of layout id to number of columns
		
		constructor: function() {
			this.label = this.nlsBundle["change_layout_browseLayouts"];
			this.tabLabel = this.nlsBundle["change_layout_launchLabel"];
		},
		
		postCreate: function(){
			this.inherited("postCreate",arguments);
			
			// change the size of the item results by adding a css class
			dojo.addClass(this.domNode,"lotusLargeWidgets");
			
			// when the apply function from the Customize Controller API is executed, change the visually selected item
			this.connect(this, "apply", "changeSelection");
		},
		
		setupUICallback: function(sources){
			dojo.forEach(sources, dojo.hitch(this, function(source){ 
				source.hub.fetch({
					onComplete:dojo.hitch(this, function(items){
						dojo.forEach(items, dojo.hitch(this, function(item){
							this.columnHash[item.id] = item.numCols;
						}));
					})
				});
			}));
			this.inherited(arguments);
		},
		
		changeSelection: function(/*object*/args){
			// summary: called when apply is called
			// args: contains args.id which is the newly selected item
			this.changeSelected(args.id);
		}
});

dojo.extend(com.ibm.customize.ChangeLayoutPaletteContainer, com.ibm.customize.ChangeLayoutController);

}

if(!dojo._hasResource["com.ibm.customize.ChangeStylePaletteContainer"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.customize.ChangeStylePaletteContainer"] = true;
// This is Change Style
dojo.provide("com.ibm.customize.ChangeStylePaletteContainer");



dojo.declare("com.ibm.customize.ChangeStylePaletteContainer",
	[com.ibm.customize.LotusPaletteContainer],
	{
		numRows: 3,			// the number of rows of results to be displayed
		baseCssPath: "",
		
		constructor: function() {
			this.label = this.nlsBundle["change_style_browseStyles"];
			this.tabLabel = this.nlsBundle["change_style_launchLabel"];
		},
		
		postCreate: function(){
			this.inherited("postCreate",arguments);
			
			// change the size of the item results by adding a css class
			dojo.addClass(this.domNode,"lotusLargeWidgets");
			
			// when the apply function from the Customize Controller API is executed, change the visually selected item
			this.connect(this, "apply", "changeSelection");
		},
		
		setupUICallback: function(sources){
			dojo.forEach(sources, dojo.hitch(this, function(source){ 
				source.hub.fetch({
					onComplete:dojo.hitch(this, function(items){
						dojo.forEach(items, dojo.hitch(this, function(item){
							if(dojo.query("[title~="+item.id[0]+"]").length == 0)
								this._loadCss(this.baseCssPath + item.id[0] + ".css",item.id[0],true,true);
						}));
					})
				});
			}));
			this.inherited(arguments);
		},
		
		changeSelection: function(/*object*/args){
			// summary: called when apply is called
			// args: contains args.id which is the newly selected item
			this.changeSelected(args.id);
		}
});

}

if(!dojo._hasResource["com.ibm.widgets.StatusBar"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.widgets.StatusBar"] = true;
dojo.provide( "com.ibm.widgets.StatusBar" );

dojo.require( "dojox.data.dom" );



dojo.declare( "com.ibm.widgets.StatusType", 
    null,
    {
	    constructor: function(/*int*/id,  /*String*/styleClass, /*String*/ iconPath, /*String*/ colorStr) {
	        this._id = id;
	        this._styleClass = styleClass;
	        this._iconPath = iconPath;
	        this._color = colorStr;  // status color fader start color for this class
	    }
    }
);

dojo.declare( "com.ibm.widgets.StatusMessage", 
    null,
    {
    	constructor: function(/*int*/type, /*String*/message, /*String*/details) {
	        this._type = type;
	        this._message = message;
	        this._details = details;
    	}	
    }
);


dojo.declare( "com.ibm.widgets.StatusColorFader", 
    null,
    {
    	constructor: function(/*String*/containerId, /*String*/endColorStr) {
	        this._containerId = containerId;
	        this._beginColorStr = "";
	        this._endColorStr = "";
	
	        this._redCtr = 0x00;
	        this._greenCtr = 0x00;
	        this._blueCtr = 0x00;
	
	        this._endRed = 0x00;
	        this._endGreen = 0x00;
	        this._endBlue = 0x00;
	
	        this.setEndColor(endColorStr);
	
	        this._fadeCallbackId = null;
	
	        this._enable = true;
	    },
        fade: function() {

             // adjust r, g, b counters and see if we have reached end color
             var shouldStop = true;

             // looping here rather than incrementing/decrementing by 10
             // this makes sure we approach the end value without going past it
             // and we can still support any arbitrary start and end color values
             for (var ctr = 0; ctr < 10; ctr++) {
                 if (this._redCtr < this._endRed) {
                     this._redCtr++;
                     shouldStop = false;
                 }
                 else if (this._redCtr > this._endRed) {
                     this._redCtr--;
                     shouldStop = false;
                 }
    
                 if (this._greenCtr < this._endGreen) {
                     this._greenCtr++;
                     shouldStop = false;
                 }
                 else if (this._greenCtr > this._endGreen) {
                     this._greenCtr--;
                     shouldStop = false;
                 }
    
                 if (this._blueCtr < this._endBlue) {
                     this._blueCtr++;
                     shouldStop = false;
                 }
                 else if (this._blueCtr > this._endBlue) {
                     this._blueCtr--;
                     shouldStop = false;
                 }
             }

             if (shouldStop) {
                 this.stop();
             }
             else {
                 var updateColorStr = "#" + this.getHexString(this._redCtr) + this.getHexString(this._greenCtr) + this.getHexString(this._blueCtr);
                 var header = document.getElementById(this._containerId);
                 if (header != null) {
                     header.style.backgroundColor = updateColorStr;
                     
                 }
                 else {
                     //alert("problem - header was null");
                     this.stop();
                 }
             }

        },
        start: function() {

             if (this._enable) {
                 var header = document.getElementById(this._containerId);
                 header.style.backgroundColor = this._beginColorStr;
                 var me = this;
                 this._fadeCallbackId = self.setInterval(function () { me.fade() }, 20);
             }

        },
        stop: function() {

             if (this._fadeCallbackId != null) {
                 clearInterval(this._fadeCallbackId);
             }

        },
        setBeginColor: function(/*string*/ hexString) {

             this._beginColorStr = hexString;

             this._redCtr = this.getColorValue(hexString, "r");
             this._greenCtr = this.getColorValue(hexString, "g");
             this._blueCtr = this.getColorValue(hexString, "b");

        },
        setEndColor: function(/*string*/ hexString) {

             this._endColorStr = hexString;

             this._endRed = this.getColorValue(hexString, "r");
             this._endGreen = this.getColorValue(hexString, "g");
             this._endBlue = this.getColorValue(hexString, "b");

        },
        getColorValue: function(/*string*/ hexString, /*string*/ rgb) {

             var subStr = "";
             if (rgb == "r") {
                 subStr = hexString.slice(1, 3);
             }
             else if (rgb == "g") {
                 subStr = hexString.slice(3, 5);
             }
             else if (rgb == "b") {
                 subStr = hexString.slice(5);
             }
             var rv = parseInt(subStr, 16);

             return rv;
        },
        getHexString: function(/*int*/ num) {

             var rv = 0;
             if (num >= 0x10) {
                 rv = num.toString(16);
             }
             else {
                 rv = "0" + num.toString(16);
             }
             return rv;
        },
        setEnable: function(/*boolean*/ value) {

             this._enable = value;

        }
    }
);



dojo.declare( "com.ibm.widgets.StatusBar", 
    [dijit._Widget, dijit._Templated],
    // end constructor
    {
    	uid: "statusBar",
    	locale: "en",
    	errorGifPath: "",
    	warningGifPath: "",
    	infoGifPath: "",
    	multipleMessagesGifPath: "",
    	showDetails: false,
    	isBidi: false,
    	
    	templateString:"<div class=\"statusBar\"\r\n\t><div dojoAttachEvent=\"\"\r\n\t\t\twaiRole=\"alert\" \r\n\t\t\tclass=\"ibmPortalStatusBar\" \r\n\t\t\tdojoAttachPoint=\"containerNode,focusNode\"\r\n\t></div\r\n></div>\r\n",

    	postCreate: function() {  
	        this._messages = new Array();
	        this._numMessages = 0;
	        this._baseURL = window.location.protocol+"//"+window.location.host;
	        this._statusTypesMap = { 
	            "error" : new com.ibm.widgets.StatusType(0, "ibmPortalError", this._baseURL + this.errorGifPath, "#FF0000"),
	            "warning" : new com.ibm.widgets.StatusType(1, "ibmPortalWarning", this._baseURL + this.warningGifPath, "FFFF00"),
	            "info" : new com.ibm.widgets.StatusType(2, "ibmPortalInfo", this._baseURL + this.infoGifPath, "#0077FF"),
	            "multiple" : new com.ibm.widgets.StatusType(3, "ibmPortalMultiple",this._baseURL + this.multipleMessagesGifPath, "#E9CAF9")
	        };
	        //Subscribe to status topics.
	        this._statusHandler = dojo.subscribe("/portal/status", this, this.addMessage);
	
	        // create new message status bar color fader
	        this._summaryHeaderId = "ibmPortalStatusBarHeader";
	        var endBackgroundColorStr = this._statusTypesMap["multiple"]._color;
	        this.colorFader = new com.ibm.widgets.StatusColorFader( this._summaryHeaderId, endBackgroundColorStr);
	        if(typeof(ibmPortalConfig) != "undefined") this.isBidi = ibmPortalConfig.isRTL;
			else if(typeof(ibmConfig) != "undefined") this.isBidi = ibmConfig.isBidi;
	    }, 
	    startup: function() {
			this.inherited(arguments);
		},
        _getStatusContainer: function () {
            return this.containerNode;   
        },
        setShowDetails: function (/*boolean*/showDetails) {
            this.showDetails = showDetails;    
        },
        toggleShowDetails: function() {
            this.setShowDetails(!this.showDetails);
            //var statusContainer = this._getStatusContainer();
            //dojox.data.dom.removeChildren( statusContainer );
            this.colorFader.setEnable(false);  // disable the fader when toggling details
            this.render();
            this.colorFader.setEnable(true);
        },
        clear: function () {
            //summary: clears all contents of the statusBar
            var statusContainer = this._getStatusContainer();
            dojox.data.dom.removeChildren( statusContainer );
            this._messages.length = 0;
        },
        print: function() {
            //create new window
            var printWindow=window.open( '', 'status', 'resizable=yes,scrollbars=yes,menubar=no,toolbar=yes,status=no,width=800px,height=600px,screenX=10px,screenY=10px,top=10px,left=10px');
            var printDoc = printWindow.document;
            printDoc.title="Status";
            // set base url so relative image paths will resolve correctly
            var baseElem = printWindow.document.createElement("base");
            baseElem.setAttribute("href",window.location.protocol+"//"+window.location.host);
            printDoc.documentElement.childNodes[0].appendChild(baseElem);
            //add container div
            printDoc.body.innerHTML = "<div id='statusBar' class='statusBar'></div>";
            
            for (x in this._messages) {
				var statusType = this._statusTypesMap[this._messages[x]._type];
				
				// status entry base container
				var entry = printDoc.createElement("div");
				entry.className = statusType._styleClass;
				
				// header for status bar message
				var header = printDoc.createElement("h3");
				var headerDiv = printDoc.createElement("div");
				if (this.isBidi) {
					headerDiv.className = "ibmPortalStatusHeaderRHS";
					dojo.attr(headerDiv, "dir", "rtl");
				}
				else {
					headerDiv.className = "ibmPortalStatusHeaderLHS";
				}
				var icon = printDoc.createElement("img");
				icon.src = statusType._iconPath;
				headerDiv.appendChild(icon);
				headerDiv.appendChild(printDoc.createTextNode(this._messages[x]._message));
				header.appendChild(headerDiv);
				entry.appendChild(header);
				// details of the status bar message
				var detailsDiv = printDoc.createElement("div");
				if (this.isBidi) {
					dojo.attr(detailsDiv, "dir", "rtl");
				}
				detailsDiv.className = "ibmPortalDetails";
				detailsDiv.appendChild(printDoc.createTextNode(this._messages[x]._details));
				entry.appendChild(detailsDiv);
				printWindow.document.getElementById("statusBar").appendChild(entry);
			}
        },
        addMessage: function(/*Object*/args) {
            //summary: adds a message to the message array
            if(args.uid && args.uid != this.uid) {
            	return;
            }
            var message = args.message;
            this._messages.push(message);
            // temp limit to handle infinite loops if there is an error raised in this code
            if (this._messages.length < 100){
               this.render(this._getStatusContainer());
            }
  
        },
        render: function(/*Node*/ targetContainer) {
            //summary: render the message(s) in the statusBar  
            if (targetContainer == null){
            targetContainer = this._getStatusContainer();
            }
            dojox.data.dom.removeChildren( targetContainer );
            // only render multiple header if there is more than one message.
            // in renderMessage, if their is only one message, it will render as the header
            if (this._messages.length > 1) {
                this.renderHeader(targetContainer);
            }
            else if (this._messages.length == 1) {
                this.renderMessage(targetContainer,this._messages[0], this.showDetails,0);
            }
            
            // if showing details, render all the messages
            if(this.showDetails && this._messages.length > 1){
                for (x in this._messages){
                    this.renderMessage(targetContainer, this._messages[x], this.showDetails, x);
                }
            }
            // if not showing details, only show the last one
            //else {
            //    this.renderMessage(this._messages[this._messages.length-1], this._showDetails, this._messages.length-1 );
            //}


            // if we have more than one message and we are not showing details,
            // then start a color fade based on the last message received
            if(!this.showDetails && this._messages.length > 1){
                // in case its already running for a previous message
                this.colorFader.stop();

                // get the last message type that came in to get its color
                var end = this._messages.length - 1;
                var startBackgroundColorStr = this._statusTypesMap[this._messages[end]._type]._color;
                this.colorFader.setBeginColor(startBackgroundColorStr);
                this.colorFader.start();
            }
        
   
        },
        renderHeader: function(/*Node*/ targetContainer) {
            var v3theme_Properties = dojo.i18n.getLocalization("com.ibm.portal", "v3theme", this.locale);
            
            //summary: render the main statusBar 
            //description: this is the main statusBar, which includes the main controls, and either the single status message,
            // or an indicator of the number of messages contained within the details view. 
            //
            if(this._messages.length > 1) {
                var headerMessage = new com.ibm.widgets.StatusMessage( "multiple", v3theme_Properties["itemsAvailable"], "" );
                this.renderMessage(targetContainer, headerMessage, this.showDetails, -1);
            }
            // if only one message, render it as the header
            else if(this._messages.length == 1){
               // this.renderMessage(targetContainer, this._messages[0], this._showDetails, 0);
            }
 
        },
        renderMessage: function (/*Node*/ targetContainer, /*com.ibm.widgets.StatusMessage*/message, /*boolean*/ showDetails, /*int*/index ) {
            //summary: renders a single message in the statusBar
            //description: renders the following markup:
            //<div class="ibmPortalError">
            //<h3><img src="./error.gif"/> An Error Occurred <a href="#"> 3 more...</a></h3>
            //<div class="ibmPortalDetails">Its a really really bad one</div>
            //</div>
            //var statusContainer = this._getStatusContainer();
            var statusType = this._statusTypesMap[message._type];
            //dojox.data.dom.removeChildren( statusContainer );
            
            // status entry base container
            var entry = document.createElement( "div" );
            entry.className = statusType._styleClass;
            
            // summary header - the colored area of each status message
            var header = document.createElement("h3");
            header.id = this._summaryHeaderId;   // set id for color fader
            // Lefthandside (LHS) contains icon, message, and show/hide details
            var header_LHS = document.createElement("div");
            if(!this.isBidi){
                header_LHS.className = "ibmPortalStatusHeaderLHS";
            }
            else{
                header_LHS.className = "ibmPortalStatusHeaderRHS";
            }               

            var icon = document.createElement("img");
            icon.src = statusType._iconPath;
            header_LHS.appendChild(icon);
            
            var messageText = null;
            var v3theme_Properties = dojo.i18n.getLocalization("com.ibm.portal", "v3theme", this.locale);
            
            // is this the top header status summary and we have more than one message
            if(this._messages.length > 1 && index < 0){
//                header_LHS.appendChild(document.createTextNode(''+this._messages.length+' messages are available for review.'));
                // then format the message
                if(!this.isBidi)
                    messageText = ''+this._messages.length+' '+v3theme_Properties["messagesAvailable"];
                else
                    messageText = v3theme_Properties["messagesAvailable"]+' '+this._messages.length+'';
            }
            // do we have only one message
            else if(this._messages.length == 1){
                messageText = message._message;
                // adjust the left margin for a single message which will have a style class that is normally indented
                entry.style.marginLeft="0px";
            }
            else{
                header_LHS.appendChild(document.createTextNode(message._message));
            }

            header.appendChild(header_LHS);

            // render top level multiple messages status bar header
            if((this._messages.length > 1 && index < 0)||(this._messages.length == 1)){
                var me = this;
                var detailsAnchor = document.createElement("a");
                detailsAnchor.href="javascript:void(0)";
                detailsAnchor.onclick=function (e) { me.toggleShowDetails(); return false; };

                var header_RHS = document.createElement("div");

                var clearAnchor = document.createElement("a");
                clearAnchor.href="javascript:void(0);";
                clearAnchor.onclick=function (e) { me.clear(); return false; };
                clearAnchor.appendChild(document.createTextNode(v3theme_Properties["clear"]));

                var printAnchor = document.createElement("a");
                printAnchor.href="javascript:void(0);";
                printAnchor.onclick=function(e){ me.print(); };
                printAnchor.appendChild(document.createTextNode(v3theme_Properties["print"]));

                var showDetailsText = v3theme_Properties["showDetails"];
                var hideDetailsText = v3theme_Properties["hideDetails"];
                
                if(this.isBidi){
                	header_RHS.className = "ibmPortalStatusHeaderLHS";
                }
                else {
                	header_RHS.className = "ibmPortalStatusHeaderRHS";
                }
                
                header_LHS.appendChild(document.createTextNode(messageText));
                if (showDetails){
                    detailsAnchor.appendChild(document.createTextNode(hideDetailsText));
                }
                else {
                    detailsAnchor.appendChild(document.createTextNode(showDetailsText));
                }
                header_LHS.appendChild(detailsAnchor);
                // clear link
                header_RHS.appendChild(clearAnchor);
                // print link
                header_RHS.appendChild(printAnchor);
                header.appendChild(header_RHS);
            }

            var clearingDiv = document.createElement("div");
            clearingDiv.className="wptheme-clearing ";
            header.appendChild(clearingDiv);

            entry.appendChild(header);
    
            // details
            if (showDetails && index >=0){
                var detailsDiv = document.createElement("div");
                detailsDiv.className = "ibmPortalDetails";
                detailsDiv.appendChild(document.createTextNode(message._details));
                entry.appendChild(detailsDiv);
            }
            targetContainer.appendChild(entry);
    
        }
    }
); // end declare StatusBar

}

if(!dojo._hasResource["com.ibm.widgets.PageToolbarButton"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.widgets.PageToolbarButton"] = true;
dojo.provide("com.ibm.widgets.PageToolbarButton");

dojo.declare("com.ibm.widgets.PageToolbarButton", dijit.form.Button, {
	label: "",
	btnClass: "",
	templateString: '<button class="lotusBtn ${btnClass}" dojoattachevent="onclick:onClick,onmouseenter:_onMouse,onmouseleave:_onMouse,onmousedown:_onMouse" widgetid="${id}" id="${id}" waistate="labelledby-${id}_label" wairole="button" type="button" name="" dojoattachpoint="titleNode,focusNode" role="button" aria-labelledby="${id}_label" tabindex="0" style="-moz-user-select: none;">'+
					'<span id="${id}_label" class="dijitInline dijitButtonText" dojoattachpoint="containerNode">${label}</span>'+
					'</button>',

	onClick: function(){
		// summary: stub event for when button is clicked
	}
});

}

if(!dojo._hasResource["dojo.data.ItemFileWriteStore"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["dojo.data.ItemFileWriteStore"] = true;
dojo.provide("dojo.data.ItemFileWriteStore");


dojo.declare("dojo.data.ItemFileWriteStore", dojo.data.ItemFileReadStore, {
	constructor: function(/* object */ keywordParameters){
		//	keywordParameters: {typeMap: object)
		//		The structure of the typeMap object is as follows:
		//		{
		//			type0: function || object,
		//			type1: function || object,
		//			...
		//			typeN: function || object
		//		}
		//		Where if it is a function, it is assumed to be an object constructor that takes the 
		//		value of _value as the initialization parameters.  It is serialized assuming object.toString()
		//		serialization.  If it is an object, then it is assumed
		//		to be an object of general form:
		//		{
		//			type: function, //constructor.
		//			deserialize:	function(value) //The function that parses the value and constructs the object defined by type appropriately.
		//			serialize:	function(object) //The function that converts the object back into the proper file format form.
		//		}

		// ItemFileWriteStore extends ItemFileReadStore to implement these additional dojo.data APIs
		this._features['dojo.data.api.Write'] = true;
		this._features['dojo.data.api.Notification'] = true;
		
		// For keeping track of changes so that we can implement isDirty and revert
		this._pending = {
			_newItems:{}, 
			_modifiedItems:{}, 
			_deletedItems:{}
		};

		if(!this._datatypeMap['Date'].serialize){
			this._datatypeMap['Date'].serialize = function(obj){
				return dojo.date.stamp.toISOString(obj, {zulu:true});
			};
		}
		//Disable only if explicitly set to false.
		if(keywordParameters && (keywordParameters.referenceIntegrity === false)){
			this.referenceIntegrity = false;
		}

		// this._saveInProgress is set to true, briefly, from when save() is first called to when it completes
		this._saveInProgress = false;
	},

	referenceIntegrity: true,  //Flag that defaultly enabled reference integrity tracking.  This way it can also be disabled pogrammatially or declaratively.

	_assert: function(/* boolean */ condition){
		if(!condition) {
			throw new Error("assertion failed in ItemFileWriteStore");
		}
	},

	_getIdentifierAttribute: function(){
		var identifierAttribute = this.getFeatures()['dojo.data.api.Identity'];
		// this._assert((identifierAttribute === Number) || (dojo.isString(identifierAttribute)));
		return identifierAttribute;
	},
	
	
/* dojo.data.api.Write */

	newItem: function(/* Object? */ keywordArgs, /* Object? */ parentInfo){
		// summary: See dojo.data.api.Write.newItem()

		this._assert(!this._saveInProgress);

		if (!this._loadFinished){
			// We need to do this here so that we'll be able to find out what
			// identifierAttribute was specified in the data file.
			this._forceLoad();
		}

		if(typeof keywordArgs != "object" && typeof keywordArgs != "undefined"){
			throw new Error("newItem() was passed something other than an object");
		}
		var newIdentity = null;
		var identifierAttribute = this._getIdentifierAttribute();
		if(identifierAttribute === Number){
			newIdentity = this._arrayOfAllItems.length;
		}else{
			newIdentity = keywordArgs[identifierAttribute];
			if (typeof newIdentity === "undefined"){
				throw new Error("newItem() was not passed an identity for the new item");
			}
			if (dojo.isArray(newIdentity)){
				throw new Error("newItem() was not passed an single-valued identity");
			}
		}
		
		// make sure this identity is not already in use by another item, if identifiers were 
		// defined in the file.  Otherwise it would be the item count, 
		// which should always be unique in this case.
		if(this._itemsByIdentity){
			this._assert(typeof this._itemsByIdentity[newIdentity] === "undefined");
		}
		this._assert(typeof this._pending._newItems[newIdentity] === "undefined");
		this._assert(typeof this._pending._deletedItems[newIdentity] === "undefined");
		
		var newItem = {};
		newItem[this._storeRefPropName] = this;		
		newItem[this._itemNumPropName] = this._arrayOfAllItems.length;
		if(this._itemsByIdentity){
			this._itemsByIdentity[newIdentity] = newItem;
			//We have to set the identifier now, otherwise we can't look it
			//up at calls to setValueorValues in parentInfo handling.
			newItem[identifierAttribute] = [newIdentity];
		}
		this._arrayOfAllItems.push(newItem);

		//We need to construct some data for the onNew call too...
		var pInfo = null;
		
		// Now we need to check to see where we want to assign this thingm if any.
		if(parentInfo && parentInfo.parent && parentInfo.attribute){
			pInfo = {
				item: parentInfo.parent,
				attribute: parentInfo.attribute,
				oldValue: undefined
			};

			//See if it is multi-valued or not and handle appropriately
			//Generally, all attributes are multi-valued for this store
			//So, we only need to append if there are already values present.
			var values = this.getValues(parentInfo.parent, parentInfo.attribute);
			if(values && values.length > 0){
				var tempValues = values.slice(0, values.length);
				if(values.length === 1){
					pInfo.oldValue = values[0];
				}else{
					pInfo.oldValue = values.slice(0, values.length);
				}
				tempValues.push(newItem);
				this._setValueOrValues(parentInfo.parent, parentInfo.attribute, tempValues, false);
				pInfo.newValue = this.getValues(parentInfo.parent, parentInfo.attribute);
			}else{
				this._setValueOrValues(parentInfo.parent, parentInfo.attribute, newItem, false);
				pInfo.newValue = newItem;
			}
		}else{
			//Toplevel item, add to both top list as well as all list.
			newItem[this._rootItemPropName]=true;
			this._arrayOfTopLevelItems.push(newItem);
		}
		
		this._pending._newItems[newIdentity] = newItem;
		
		//Clone over the properties to the new item
		for(var key in keywordArgs){
			if(key === this._storeRefPropName || key === this._itemNumPropName){
				// Bummer, the user is trying to do something like
				// newItem({_S:"foo"}).  Unfortunately, our superclass,
				// ItemFileReadStore, is already using _S in each of our items
				// to hold private info.  To avoid a naming collision, we 
				// need to move all our private info to some other property 
				// of all the items/objects.  So, we need to iterate over all
				// the items and do something like: 
				//    item.__S = item._S;
				//    item._S = undefined;
				// But first we have to make sure the new "__S" variable is 
				// not in use, which means we have to iterate over all the 
				// items checking for that.
				throw new Error("encountered bug in ItemFileWriteStore.newItem");
			}
			var value = keywordArgs[key];
			if(!dojo.isArray(value)){
				value = [value];
			}
			newItem[key] = value;
			if(this.referenceIntegrity){
				for(var i = 0; i < value.length; i++){
					var val = value[i];
					if(this.isItem(val)){
						this._addReferenceToMap(val, newItem, key);
					}
				}
			}
		}
		this.onNew(newItem, pInfo); // dojo.data.api.Notification call
		return newItem; // item
	},
	
	_removeArrayElement: function(/* Array */ array, /* anything */ element){
		var index = dojo.indexOf(array, element);
		if (index != -1){
			array.splice(index, 1);
			return true;
		}
		return false;
	},
	
	deleteItem: function(/* item */ item){
		// summary: See dojo.data.api.Write.deleteItem()
		this._assert(!this._saveInProgress);
		this._assertIsItem(item);

		// Remove this item from the _arrayOfAllItems, but leave a null value in place
		// of the item, so as not to change the length of the array, so that in newItem() 
		// we can still safely do: newIdentity = this._arrayOfAllItems.length;
		var indexInArrayOfAllItems = item[this._itemNumPropName];
		var identity = this.getIdentity(item);

		//If we have reference integrity on, we need to do reference cleanup for the deleted item
		if(this.referenceIntegrity){
			//First scan all the attributes of this items for references and clean them up in the map 
			//As this item is going away, no need to track its references anymore.

			//Get the attributes list before we generate the backup so it 
			//doesn't pollute the attributes list.
			var attributes = this.getAttributes(item);

			//Backup the map, we'll have to restore it potentially, in a revert.
			if(item[this._reverseRefMap]){
				item["backup_" + this._reverseRefMap] = dojo.clone(item[this._reverseRefMap]);
			}
			
			//TODO:  This causes a reversion problem.  This list won't be restored on revert since it is
			//attached to the 'value'. item, not ours.  Need to back tese up somehow too.
			//Maybe build a map of the backup of the entries and attach it to the deleted item to be restored
			//later.  Or just record them and call _addReferenceToMap on them in revert.
			dojo.forEach(attributes, function(attribute){
				dojo.forEach(this.getValues(item, attribute), function(value){
					if(this.isItem(value)){
						//We have to back up all the references we had to others so they can be restored on a revert.
						if(!item["backupRefs_" + this._reverseRefMap]){
							item["backupRefs_" + this._reverseRefMap] = [];
						}
						item["backupRefs_" + this._reverseRefMap].push({id: this.getIdentity(value), attr: attribute});
						this._removeReferenceFromMap(value, item, attribute);
					}
				}, this);
			}, this);

			//Next, see if we have references to this item, if we do, we have to clean them up too.
			var references = item[this._reverseRefMap];
			if(references){
				//Look through all the items noted as references to clean them up.
				for(var itemId in references){
					var containingItem = null;
					if(this._itemsByIdentity){
						containingItem = this._itemsByIdentity[itemId];
					}else{
						containingItem = this._arrayOfAllItems[itemId];
					}
					//We have a reference to a containing item, now we have to process the
					//attributes and clear all references to the item being deleted.
					if(containingItem){
						for(var attribute in references[itemId]){
							var oldValues = this.getValues(containingItem, attribute) || [];
							var newValues = dojo.filter(oldValues, function(possibleItem){
							   return !(this.isItem(possibleItem) && this.getIdentity(possibleItem) == identity);
							}, this);
							//Remove the note of the reference to the item and set the values on the modified attribute.
							this._removeReferenceFromMap(item, containingItem, attribute); 
							if(newValues.length < oldValues.length){
								this._setValueOrValues(containingItem, attribute, newValues, true);
							}
						}
					}
				}
			}
		}

		this._arrayOfAllItems[indexInArrayOfAllItems] = null;

		item[this._storeRefPropName] = null;
		if(this._itemsByIdentity){
			delete this._itemsByIdentity[identity];
		}
		this._pending._deletedItems[identity] = item;
		
		//Remove from the toplevel items, if necessary...
		if(item[this._rootItemPropName]){
			this._removeArrayElement(this._arrayOfTopLevelItems, item);
		}
		this.onDelete(item); // dojo.data.api.Notification call
		return true;
	},

	setValue: function(/* item */ item, /* attribute-name-string */ attribute, /* almost anything */ value){
		// summary: See dojo.data.api.Write.set()
		return this._setValueOrValues(item, attribute, value, true); // boolean
	},
	
	setValues: function(/* item */ item, /* attribute-name-string */ attribute, /* array */ values){
		// summary: See dojo.data.api.Write.setValues()
		return this._setValueOrValues(item, attribute, values, true); // boolean
	},
	
	unsetAttribute: function(/* item */ item, /* attribute-name-string */ attribute){
		// summary: See dojo.data.api.Write.unsetAttribute()
		return this._setValueOrValues(item, attribute, [], true);
	},
	
	_setValueOrValues: function(/* item */ item, /* attribute-name-string */ attribute, /* anything */ newValueOrValues, /*boolean?*/ callOnSet){
		this._assert(!this._saveInProgress);
		
		// Check for valid arguments
		this._assertIsItem(item);
		this._assert(dojo.isString(attribute));
		this._assert(typeof newValueOrValues !== "undefined");

		// Make sure the user isn't trying to change the item's identity
		var identifierAttribute = this._getIdentifierAttribute();
		if(attribute == identifierAttribute){
			throw new Error("ItemFileWriteStore does not have support for changing the value of an item's identifier.");
		}

		// To implement the Notification API, we need to make a note of what
		// the old attribute value was, so that we can pass that info when
		// we call the onSet method.
		var oldValueOrValues = this._getValueOrValues(item, attribute);

		var identity = this.getIdentity(item);
		if(!this._pending._modifiedItems[identity]){
			// Before we actually change the item, we make a copy of it to 
			// record the original state, so that we'll be able to revert if 
			// the revert method gets called.  If the item has already been
			// modified then there's no need to do this now, since we already
			// have a record of the original state.						
			var copyOfItemState = {};
			for(var key in item){
				if((key === this._storeRefPropName) || (key === this._itemNumPropName) || (key === this._rootItemPropName)){
					copyOfItemState[key] = item[key];
				}else if(key === this._reverseRefMap){
					copyOfItemState[key] = dojo.clone(item[key]);
				}else{
					copyOfItemState[key] = item[key].slice(0, item[key].length);
				}
			}
			// Now mark the item as dirty, and save the copy of the original state
			this._pending._modifiedItems[identity] = copyOfItemState;
		}
		
		// Okay, now we can actually change this attribute on the item
		var success = false;
		
		if(dojo.isArray(newValueOrValues) && newValueOrValues.length === 0){
			
			// If we were passed an empty array as the value, that counts
			// as "unsetting" the attribute, so we need to remove this 
			// attribute from the item.
			success = delete item[attribute];
			newValueOrValues = undefined; // used in the onSet Notification call below

			if(this.referenceIntegrity && oldValueOrValues){
				var oldValues = oldValueOrValues;
				if (!dojo.isArray(oldValues)){
					oldValues = [oldValues];
				}
				for(var i = 0; i < oldValues.length; i++){
					var value = oldValues[i];
					if(this.isItem(value)){
						this._removeReferenceFromMap(value, item, attribute);
					}
				}
			}
		}else{
			var newValueArray;
			if(dojo.isArray(newValueOrValues)){
				var newValues = newValueOrValues;
				// Unfortunately, it's not safe to just do this:
				//    newValueArray = newValues;
				// Instead, we need to copy the array, which slice() does very nicely.
				// This is so that our internal data structure won't  
				// get corrupted if the user mucks with the values array *after*
				// calling setValues().
				newValueArray = newValueOrValues.slice(0, newValueOrValues.length);
			}else{
				newValueArray = [newValueOrValues];
			}

			//We need to handle reference integrity if this is on. 
			//In the case of set, we need to see if references were added or removed
			//and update the reference tracking map accordingly.
			if(this.referenceIntegrity){
				if(oldValueOrValues){
					var oldValues = oldValueOrValues;
					if(!dojo.isArray(oldValues)){
						oldValues = [oldValues];
					}
					//Use an associative map to determine what was added/removed from the list.
					//Should be O(n) performant.  First look at all the old values and make a list of them
					//Then for any item not in the old list, we add it.  If it was already present, we remove it.
					//Then we pass over the map and any references left it it need to be removed (IE, no match in
					//the new values list).
					var map = {};
					dojo.forEach(oldValues, function(possibleItem){
						if(this.isItem(possibleItem)){
							var id = this.getIdentity(possibleItem);
							map[id.toString()] = true;
						}
					}, this);
					dojo.forEach(newValueArray, function(possibleItem){
						if(this.isItem(possibleItem)){
							var id = this.getIdentity(possibleItem);
							if(map[id.toString()]){
								delete map[id.toString()];
							}else{
								this._addReferenceToMap(possibleItem, item, attribute); 
							}
						}
					}, this);
					for(var rId in map){
						var removedItem;
						if(this._itemsByIdentity){
							removedItem = this._itemsByIdentity[rId];
						}else{
							removedItem = this._arrayOfAllItems[rId];
						}
						this._removeReferenceFromMap(removedItem, item, attribute);
					}
				}else{
					//Everything is new (no old values) so we have to just
					//insert all the references, if any.
					for(var i = 0; i < newValueArray.length; i++){
						var value = newValueArray[i];
						if(this.isItem(value)){
							this._addReferenceToMap(value, item, attribute);
						}
					}
				}
			}
			item[attribute] = newValueArray;
			success = true;
		}

		// Now we make the dojo.data.api.Notification call
		if(callOnSet){
			this.onSet(item, attribute, oldValueOrValues, newValueOrValues); 
		}
		return success; // boolean
	},

	_addReferenceToMap: function(/*item*/ refItem, /*item*/ parentItem, /*string*/ attribute){
		//	summary:
		//		Method to add an reference map entry for an item and attribute.
		//	description:
		//		Method to add an reference map entry for an item and attribute. 		 //
		//	refItem:
		//		The item that is referenced.
		//	parentItem:
		//		The item that holds the new reference to refItem.
		//	attribute:
		//		The attribute on parentItem that contains the new reference.
		 
		var parentId = this.getIdentity(parentItem);
		var references = refItem[this._reverseRefMap];

		if(!references){
			references = refItem[this._reverseRefMap] = {};
		}
		var itemRef = references[parentId];
		if(!itemRef){
			itemRef = references[parentId] = {};
		}
		itemRef[attribute] = true;
	},

	_removeReferenceFromMap: function(/* item */ refItem, /* item */ parentItem, /*strin*/ attribute){
		//	summary:
		//		Method to remove an reference map entry for an item and attribute.
		//	description:
		//		Method to remove an reference map entry for an item and attribute.  This will
		//		also perform cleanup on the map such that if there are no more references at all to 
		//		the item, its reference object and entry are removed.
		//
		//	refItem:
		//		The item that is referenced.
		//	parentItem:
		//		The item holding a reference to refItem.
		//	attribute:
		//		The attribute on parentItem that contains the reference.
		var identity = this.getIdentity(parentItem);
		var references = refItem[this._reverseRefMap];
		var itemId;
		if(references){
			for(itemId in references){
				if(itemId == identity){
					delete references[itemId][attribute];
					if(this._isEmpty(references[itemId])){
						delete references[itemId];
					}
				}
			}
			if(this._isEmpty(references)){
				delete refItem[this._reverseRefMap];
			}
		}
	},

	_dumpReferenceMap: function(){
		//	summary:
		//		Function to dump the reverse reference map of all items in the store for debug purposes.
		//	description:
		//		Function to dump the reverse reference map of all items in the store for debug purposes.
		var i;
		for(i = 0; i < this._arrayOfAllItems.length; i++){
			var item = this._arrayOfAllItems[i];
			if(item && item[this._reverseRefMap]){
				
			}
		}
	},
						   
	_getValueOrValues: function(/* item */ item, /* attribute-name-string */ attribute){
		var valueOrValues = undefined;
		if(this.hasAttribute(item, attribute)){
			var valueArray = this.getValues(item, attribute);
			if(valueArray.length == 1){
				valueOrValues = valueArray[0];
			}else{
				valueOrValues = valueArray;
			}
		}
		return valueOrValues;
	},
	
	_flatten: function(/* anything */ value){
		if(this.isItem(value)){
			var item = value;
			// Given an item, return an serializable object that provides a 
			// reference to the item.
			// For example, given kermit:
			//    var kermit = store.newItem({id:2, name:"Kermit"});
			// we want to return
			//    {_reference:2}
			var identity = this.getIdentity(item);
			var referenceObject = {_reference: identity};
			return referenceObject;
		}else{
			if(typeof value === "object"){
				for(var type in this._datatypeMap){
					var typeMap = this._datatypeMap[type];
					if (dojo.isObject(typeMap) && !dojo.isFunction(typeMap)){
						if(value instanceof typeMap.type){
							if(!typeMap.serialize){
								throw new Error("ItemFileWriteStore:  No serializer defined for type mapping: [" + type + "]");
							}
							return {_type: type, _value: typeMap.serialize(value)};
						}
					} else if(value instanceof typeMap){
						//SImple mapping, therefore, return as a toString serialization.
						return {_type: type, _value: value.toString()};
					}
				}
			}
			return value;
		}
	},
	
	_getNewFileContentString: function(){
		// summary: 
		//		Generate a string that can be saved to a file.
		//		The result should look similar to:
		//		http://trac.dojotoolkit.org/browser/dojo/trunk/tests/data/countries.json
		var serializableStructure = {};
		
		var identifierAttribute = this._getIdentifierAttribute();
		if(identifierAttribute !== Number){
			serializableStructure.identifier = identifierAttribute;
		}
		if(this._labelAttr){
			serializableStructure.label = this._labelAttr;
		}
		serializableStructure.items = [];
		for(var i = 0; i < this._arrayOfAllItems.length; ++i){
			var item = this._arrayOfAllItems[i];
			if(item !== null){
				var serializableItem = {};
				for(var key in item){
					if(key !== this._storeRefPropName && key !== this._itemNumPropName && key !== this._reverseRefMap && key !== this._rootItemPropName){
						var attribute = key;
						var valueArray = this.getValues(item, attribute);
						if(valueArray.length == 1){
							serializableItem[attribute] = this._flatten(valueArray[0]);
						}else{
							var serializableArray = [];
							for(var j = 0; j < valueArray.length; ++j){
								serializableArray.push(this._flatten(valueArray[j]));
								serializableItem[attribute] = serializableArray;
							}
						}
					}
				}
				serializableStructure.items.push(serializableItem);
			}
		}
		var prettyPrint = true;
		return dojo.toJson(serializableStructure, prettyPrint);
	},

	_isEmpty: function(something){
		//	summary: 
		//		Function to determine if an array or object has no properties or values.
		//	something:
		//		The array or object to examine.
		var empty = true;
		if(dojo.isObject(something)){
			var i;
			for(i in something){
				empty = false;
				break;
			}
		}else if(dojo.isArray(something)){
			if(something.length > 0){
				empty = false;
			}
		}
		return empty; //boolean
	},
	
	save: function(/* object */ keywordArgs){
		// summary: See dojo.data.api.Write.save()
		this._assert(!this._saveInProgress);
		
		// this._saveInProgress is set to true, briefly, from when save is first called to when it completes
		this._saveInProgress = true;
		
		var self = this;
		var saveCompleteCallback = function(){
			self._pending = {
				_newItems:{}, 
				_modifiedItems:{},
				_deletedItems:{}
			};

			self._saveInProgress = false; // must come after this._pending is cleared, but before any callbacks
			if(keywordArgs && keywordArgs.onComplete){
				var scope = keywordArgs.scope || dojo.global;
				keywordArgs.onComplete.call(scope);
			}
		};
		var saveFailedCallback = function(err){
			self._saveInProgress = false;
			if(keywordArgs && keywordArgs.onError){
				var scope = keywordArgs.scope || dojo.global;
				keywordArgs.onError.call(scope, err);
			}
		};
		
		if(this._saveEverything){
			var newFileContentString = this._getNewFileContentString();
			this._saveEverything(saveCompleteCallback, saveFailedCallback, newFileContentString);
		}
		if(this._saveCustom){
			this._saveCustom(saveCompleteCallback, saveFailedCallback);
		}
		if(!this._saveEverything && !this._saveCustom){
			// Looks like there is no user-defined save-handler function.
			// That's fine, it just means the datastore is acting as a "mock-write"
			// store -- changes get saved in memory but don't get saved to disk.
			saveCompleteCallback();
		}
	},
	
	revert: function(){
		// summary: See dojo.data.api.Write.revert()
		this._assert(!this._saveInProgress);

		var identity;
		for(identity in this._pending._modifiedItems){
			// find the original item and the modified item that replaced it
			var originalItem = this._pending._modifiedItems[identity];
			var modifiedItem = null;
			if(this._itemsByIdentity){
				modifiedItem = this._itemsByIdentity[identity];
			}else{
				modifiedItem = this._arrayOfAllItems[identity];
			}
			
			// make the original item into a full-fledged item again
			originalItem[this._storeRefPropName] = this;
			modifiedItem[this._storeRefPropName] = null;

			// replace the modified item with the original one
			var arrayIndex = modifiedItem[this._itemNumPropName];
			this._arrayOfAllItems[arrayIndex] = originalItem;
			
			if(modifiedItem[this._rootItemPropName]){
				var i;
				for (i = 0; i < this._arrayOfTopLevelItems.length; i++) {
					var possibleMatch = this._arrayOfTopLevelItems[i];
					if (this.getIdentity(possibleMatch) == identity){
						this._arrayOfTopLevelItems[i] = originalItem;
						break;
					}
				}
			}
			if(this._itemsByIdentity){
				this._itemsByIdentity[identity] = originalItem;
			}			
		}
		var deletedItem;
		for(identity in this._pending._deletedItems){
			deletedItem = this._pending._deletedItems[identity];
			deletedItem[this._storeRefPropName] = this;
			var index = deletedItem[this._itemNumPropName];

			//Restore the reverse refererence map, if any.
			if(deletedItem["backup_" + this._reverseRefMap]){
				deletedItem[this._reverseRefMap] = deletedItem["backup_" + this._reverseRefMap];
				delete deletedItem["backup_" + this._reverseRefMap];
			}
			this._arrayOfAllItems[index] = deletedItem;
			if (this._itemsByIdentity) {
				this._itemsByIdentity[identity] = deletedItem;
			}
			if(deletedItem[this._rootItemPropName]){
				this._arrayOfTopLevelItems.push(deletedItem);
			}	  
		}
		//We have to pass through it again and restore the reference maps after all the
		//undeletes have occurred.
		for(identity in this._pending._deletedItems){
			deletedItem = this._pending._deletedItems[identity];
			if(deletedItem["backupRefs_" + this._reverseRefMap]){
				dojo.forEach(deletedItem["backupRefs_" + this._reverseRefMap], function(reference){
					var refItem;
					if(this._itemsByIdentity){
						refItem = this._itemsByIdentity[reference.id];
					}else{
						refItem = this._arrayOfAllItems[reference.id];
					}
					this._addReferenceToMap(refItem, deletedItem, reference.attr);
				}, this);
				delete deletedItem["backupRefs_" + this._reverseRefMap]; 
			}
		}

		for(identity in this._pending._newItems){
			var newItem = this._pending._newItems[identity];
			newItem[this._storeRefPropName] = null;
			// null out the new item, but don't change the array index so
			// so we can keep using _arrayOfAllItems.length.
			this._arrayOfAllItems[newItem[this._itemNumPropName]] = null;
			if(newItem[this._rootItemPropName]){
				this._removeArrayElement(this._arrayOfTopLevelItems, newItem);
			}
			if(this._itemsByIdentity){
				delete this._itemsByIdentity[identity];
			}
		}

		this._pending = {
			_newItems:{}, 
			_modifiedItems:{}, 
			_deletedItems:{}
		};
		return true; // boolean
	},
	
	isDirty: function(/* item? */ item){
		// summary: See dojo.data.api.Write.isDirty()
		if(item){
			// return true if the item is dirty
			var identity = this.getIdentity(item);
			return new Boolean(this._pending._newItems[identity] || 
				this._pending._modifiedItems[identity] ||
				this._pending._deletedItems[identity]).valueOf(); // boolean
		}else{
			// return true if the store is dirty -- which means return true
			// if there are any new items, dirty items, or modified items
			if(!this._isEmpty(this._pending._newItems) || 
			   !this._isEmpty(this._pending._modifiedItems) ||
			   !this._isEmpty(this._pending._deletedItems)){
				return true;
			}
			return false; // boolean
		}
	},

/* dojo.data.api.Notification */

	onSet: function(/* item */ item, 
					/*attribute-name-string*/ attribute, 
					/*object | array*/ oldValue,
					/*object | array*/ newValue){
		// summary: See dojo.data.api.Notification.onSet()
		
		// No need to do anything. This method is here just so that the 
		// client code can connect observers to it.
	},

	onNew: function(/* item */ newItem, /*object?*/ parentInfo){
		// summary: See dojo.data.api.Notification.onNew()
		
		// No need to do anything. This method is here just so that the 
		// client code can connect observers to it. 
	},

	onDelete: function(/* item */ deletedItem){
		// summary: See dojo.data.api.Notification.onDelete()
		
		// No need to do anything. This method is here just so that the 
		// client code can connect observers to it. 
	},

	close: function(/* object? */ request) {
		 // summary:
		 //		Over-ride of base close function of ItemFileReadStore to add in check for store state.
		 // description:
		 //		Over-ride of base close function of ItemFileReadStore to add in check for store state.
		 //		If the store is still dirty (unsaved changes), then an error will be thrown instead of
		 //		clearing the internal state for reload from the url.

		 //Clear if not dirty ... or throw an error
		 if(this.clearOnClose){
			 if(!this.isDirty()){
				 this.inherited(arguments);
			 }else if(this._jsonFileUrl !== ""){
				 //Only throw an error if the store was dirty and we were loading from a url (cannot reload from url until state is saved).
				 throw new Error("dojo.data.ItemFileWriteStore: There are unsaved changes present in the store.  Please save or revert the changes before invoking close.");
			 }
		 }
	}
});

}

if(!dojo._hasResource["com.ibm.lang.DeferredQueue"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.lang.DeferredQueue"] = true;
/*
 * @author allenbj
 */ 
dojo.provide("com.ibm.lang.DeferredQueue");

dojo.declare("com.ibm.lang.DeferredQueue",
	null,
	{
		constructor: function(/*Deferred?*/ def) {
			this.curDef = def;
			this.firstDef = def;
		},
		_addCallbacks: function(/*Deferred*/ source, /*Deferred*/ target) {
			source.addCallbacks(
				function(res){target.callback(res); return res;},	// callback
				dojo.hitch(this, function(err){						// errback
					try{
						if(!err._raised) {
							this.raiseError(err);	// in case raiseError fails... we still guarantee all callbacks
							err._raised = true;
						}
					}catch(err2){}
					target.callback(err);
					return err;
				})
			);
		},
		addBefore: function(/*Deferred*/ def) {
			// summary: Inserts a Deferred into the front of the queue which will fire the 
			// 		Deferred that is currently in the front of the queue when it calls back.
			//		Allows preprocessing or delaying of this DeferredQueue's firing.
			//		Note, if the queue has already fired, this will cause an error when the
			//		def argument callsback.
			if(!this.firstDef) this.firstDef = def;
			else {
				var oldFirst = this.firstDef;
				this.firstDef = def;
				this._addCallbacks(def, oldFirst);
			}
		},
		add: function(/*Deferred*/ def) {
			// summary: Adds a deferred to the queue which will be fired as a callback
			//		to the previous deferred in the queue.  If this is the first deferred
			//		to be added to the queue, firing it will start the queue.
			if(!this.firstDef) this.firstDef = def;
			if(this.curDef) {
				var oldCur = this.curDef;
				this.curDef = def;
				this._addCallbacks(oldCur, def);
			}
			else {
				this.curDef = def;
			}
			return this;
		},
		fire: function(res) {
			// summary: Starts the queue by firing the first deferred in the queue
			//		passing the argument to this function to the callback function of
			//		the first deferred.
			// res: Anything
			if(this.firstDef) this.firstDef.callback(res);
			return this;
		},
		raiseError: function(err) {
			// summary: Called whenever one of the Deferreds in the queue fires its errback.
			//		If an error is raised once by this and then a subsequent Deferred is errbacked
			//		with the exact same error, it will not be raised again.  However, if the next
			//		Deferred throws or returns a new error, that will be raised only once itself.
			//		This allows any errors to be raised once and only once without losing any of them.
			//		NOOP by default, so override this or connect to it to provide implementation.
		},
		destroy: function() {
			delete this.firstDef;
			delete this.curDef;
			delete this.raiseError;
		}
	}
);

}

if(!dojo._hasResource["com.ibm.data.EnablerModelStore"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.data.EnablerModelStore"] = true;
dojo.provide("com.ibm.data.EnablerModelStore");




dojo.declare("com.ibm.data.EnablerModelStore", 
		com.ibm.data._NotificationHelper,{
	// itemClass: String the class used to represent items of this store
	
	itemClass: "com.ibm.mm.enabler.navigation.NavigationNodeImpl",
	
	_isItemCreated: false,
	
	_isDirty: false,
	
	rootNode: null,
	
	globalPage: null,
	globalPageInSpace: null,
	
	constructor: function(){		
		this.navigationUtil = com.ibm.mm.builder.utils.navigationUtil;
		this.pageUtil = com.ibm.mm.builder.utils.pageUtil;
    	this.spaceUtil = com.ibm.mm.builder.utils.spaceUtil;
    	var root = this.getRootNode();
		this.rootNode = root;
    },
    getRootNode: function(){
    	var pid = null;
    	var currentPage = com.ibm.mashups.builder.model.Factory.getRuntimeModel().getCurrentPage();
    	var items = new Array();
    	
		if(!currentPage){
			var spaceId = this.spaceUtil.getCurrentSpaceId();
			pid = spaceId ? this.pageUtil.getFirstPageInSpace(spaceId) : this.pageUtil.getFirstRootPageId();
		} else {
			pid = currentPage.getID();
		}
		if(!pid) return null;
		
		//update current page id and space id
		currentPage.setID(pid);
		
		var spaceId = this.spaceUtil.getSpaceIdByPageId(pid);
		if (spaceId !== this.spaceUtil.getCurrentSpaceId()) {
			this.spaceUtil.setSpaceId(spaceId);
		}
		//try to build model array
		var navModel = this.navigationUtil.getNavigationModel();
		var currentModel = navModel.find(pid).start();
		var rootId = this.navigationUtil.getNavigationRootNodeId();
		var currentSpaceRootId = this.navigationUtil.getNavigationRootNodeId(this.spaceUtil.getCurrentSpaceId());
		//Loop to root to build the menuModelArrays array that holds all the models of the item that need to be rendered
		while(currentModel && currentModel.getID() !== rootId && currentModel.getID() !== currentSpaceRootId) {
			items.push(currentModel);
			currentModel = navModel.getParent(currentModel.getID()).start();
		}
		return items[items.length - 1];
    },
    getFeatures: function(){
        return {'dojo.data.api.Read':true, 'dojo.data.api.Write':true, 'dojo.data.api.Identity':'id', "dojo.data.api.Notification": true };
    },

	/********************************/
	/**                            **/
	/**                            **/
	/**    dojo.data.api.Read      **/
	/**                            **/
	/**                            **/
	/********************************/
    getValue: function( /* item */ item, /* attribute-name-string */ attribute, 
                        /* value? */ defaultValue){
        var values = this.getValues(item, attribute);
        return (values.length > 0)?values[0]:defaultValue;
    },

    getValues: function(/* item */ item, /* attribute-name-string */ attribute){
		var values = null;
		switch(attribute) {
			case "id":
			    values = [item.getID()];
			    break;
			case "title":
				/* only needed in standalone mashups 
			    if (this.rootNode == item) values = ["Content Root"];
			    else*/ if (item.title) values = [item.title];
				else values = [this.pageUtil.getUnescapedPageTitle(item.getID())];
				break;
			case "description":
			    values = [this.pageUtil.getPageDescription(item.getID())];
				break;
			case "type":
			    values = item.type;
				break;
			case "parent":
				if (this.globalPage && item.openPageId && item.pageLoadedSpaceId===com.ibm.mm.builder.utils.spaceUtil.getCurrentSpaceId()){
					// to support global page, open the faked new item under current parent
					if (dojo.cookie(com.ibm.mm.builder.constant.cookieKey_previous_pid)){
						var lastNonGlobalPageId = dojo.cookie(com.ibm.mm.builder.constant.cookieKey_previous_pid);
						var lastPage = com.ibm.mm.builder.utils.pageUtil.getPageNode(lastNonGlobalPageId);
						var _navModel = this.navigationUtil.getNavigationModel();
						//TODO: need to update the logic here.
						var parent = _navModel.getParent(lastPage.getID()).start();
						values = [parent];						
					}else{
						
					}					
				}else{
					var _navModel = this.navigationUtil.getNavigationModel();
					var parent = _navModel.getParent(item.getID()).start();
				    values = [parent];					
				}
				break;
			case "parentId":
				var _navModel = this.navigationUtil.getNavigationModel();
				var parent = _navModel.getParent(item.getID()).start();
	            var parentId = parent ? parent.getID() : null;
			    values = [parentId];
				break;
			case "children":
				var _navModel = this.navigationUtil.getNavigationModel();
				var childrenIter = _navModel.getChildren(item);
				var children = new Array();
			    while (childrenIter.hasNext()) {
					var child = childrenIter.next();
					var isVisible = com.ibm.mm.builder.utils.pageUtil.isVisiable(child);
					if(isVisible){ children.push(child); }
				}
				// support global page
				if (this.globalPage && this.globalPageInSpace===com.ibm.mm.builder.utils.spaceUtil.getCurrentSpaceId()){
					children.push(this.globalPage);
				}
			    values = children;
				break;
			case "hasChildren":
				if(com.ibm.mm.builder.utils.spaceUtil.getCurrentSpaceNode() == item){ return false; }
				var _navModel = this.navigationUtil.getNavigationModel();
			    values = [_navModel.hasChildren(item)];
				break;
			default:
			    values = null;
		}
		values = (values && dojo.isArray(values)) ? values : [values];
		return values;
    },
    getAttributes: function(/* item */ item){
        return ["id", "title", "description", "type", "parent", "parentId", "children", "hasChildren"];
    },
    hasAttribute: function( /* item */ item, /* attribute-name-string */ attribute){
        return !!(this.getValue(item, attribute));
    },
    containsValue: function(/* item */ item, /* attribute-name-string */ attribute, /* anything */ value){
        return this.getValue(item, attribute) == value;
    },
    isItem: function(/* anything */ something){
    	//returns page node id if it is indeed an item
        return something.declaredClass == "com.ibm.mm.enabler.navigation.NavigationNodeImpl" && something.getID();
    },
    isItemLoaded: function(/* Object */ something) {
		// summary: All valid items in this data store are loaded all of the time as there
		//		is no support currently for stubs.  Therefore, this is effectively the same
		//		as isItem.
		return this.isItem(something) && something.loaded;
	},
	loadItem: function(/* Object */ keywordArgs){
		// summary: All valid items in this data store are loaded all of the time as there
		//			is no support currently for stubs.  Therefore, this function is a no-op. 
	},
    getLabel: function(/* item */ item){
        return this.getValue(item, "title");
    },
    getLabelAttributes: function(/* item */ item){
        return ["title"];
    },
    fetch: function(/* Object */ keywordArgs){
        if(!keywordArgs) keywordArgs = {};
        var me = this;
		keywordArgs.aborted = false;
		if(!keywordArgs.scope) keywordArgs.scope = dojo.global;
    	
        var query = keywordArgs.query;
        var items = new Array(); 
        var _navModel = this.navigationUtil.getNavigationModel();
        
        if(query === null) {
        	items.push(this.rootNode);
        } else { 
        	var spaceUtil = com.ibm.mm.builder.utils.spaceUtil;
    		var pid = query.uri;
    		if(!pid){
    			var spaceId = spaceUtil.getCurrentSpaceId();
    			pid = spaceId ? this.pageUtil.getFirstPageInSpace(spaceId) : this.pageUtil.getFirstRootPageId();
    		}
			
    		//if current page still is null, this means no page exists.
    		if(pid) {
				if(com.ibm.mm.builder.utils.spaceUtil.getCurrentSpaceId() == pid){
					// if navigating to a space with no pages, manually set up the selection path to the 
					// space root and content root, otherwise getChildren will fail
					items.push(com.ibm.mm.builder.utils.spaceUtil.getCurrentSpaceNode());
					items.push(this.navigationUtil.getNavigationRootNode());
				}else{
	    			var currentPage = com.ibm.mashups.builder.model.Factory.getRuntimeModel().getCurrentPage();
					currentPage.setID(pid);
					
					var spaceId = spaceUtil.getSpaceIdByPageId(pid);
					if (spaceId !== spaceUtil.getCurrentSpaceId()) {
						spaceUtil.setSpaceId(spaceId);
					}
					
					var navModel = this.navigationUtil.getNavigationModel();
					var currentModel = navModel.find(pid).start();
					//Loop to root to build the menuModelArrays array that holds all the models of the item that need to be rendered
					while(currentModel) {
						items.push(currentModel);
						currentModel = navModel.getParent(currentModel.getID()).start();
					}
				}
			}
        }
		items = this.processFetchedItems(items, keywordArgs);
		
		//TODO: implement getResultSize
		if(keywordArgs.onBegin) keywordArgs.onBegin.call(keywordArgs.scope, this.getResultSize(items.root, keywordArgs, items), keywordArgs);
		
		if(keywordArgs.onItem) {
			for(var i = 0; i < items.length; i++) {
				if(keywordArgs.aborted) return;
				keywordArgs.onItem.call(keywordArgs.scope, items[i], keywordArgs);
			}
		}
		
		if(keywordArgs.onComplete) {
			// call onComplete with items array if onItem wasn't specified, otherwise
			// call it with null
			if(keywordArgs.aborted) return;
			if(!keywordArgs.onItem) keywordArgs.onComplete.call(keywordArgs.scope, items, keywordArgs);
			else keywordArgs.onComplete.call(keywordArgs.scope, null, keywordArgs);
		}
	},
	processFetchedItems: function(items, keywordArgs){
		// do nothing
		return items;
	},
    getRootItem: function(){
        return this.rootNode;
    },    
	/********************************/
	/**                            **/
	/**                            **/
	/**    dojo.data.api.Identity  **/
	/**                            **/
	/**                            **/
	/********************************/
    getIdentity: function(/* item */ item){
        return this.getValue(item, "id");
    },
    getIdentityAttributes: function(/* item */ item){
        return ["id"];
    },
    fetchItemByIdentity: function(/* object */ keywordArgs){
        var node = this.pageUtil.getPageNode(getkeywordArgs.identify);
        node = node ? node : null;
        if(keywordArgs.onItem){
    		if(!keywordArgs.scope) keywordArgs.scope = dojo.global;
            keywordArgs.onItem.call(keywordArgs.scope, node);
        }
    },    
	/********************************/
	/**                            **/
	/**                            **/
	/**    dojo.data.api.Write     **/
	/**                            **/
	/**                            **/
	/********************************/
	deleteItem: function(/* item */ item){
		//	summary:
		//		Deletes an item from the store.
		//
		//	item: 
		//		The item to delete.
		//
		//	exceptions:
		//		Throws an exception if the argument *item* is not an item 
		//		(if store.isItem(item) returns false).
		//	example:
		//	|	var success = store.deleteItem(kermit);
		return false; // boolean
	},
	setValue: function(	/* item */ item, 
						/* string */ attribute,
						/* almost anything */ value){
		//	summary:
		//		Sets the value of an attribute on an item.
		//		Replaces any previous value or values.
		//
		//	item:
		//		The item to modify.
		//	attribute:
		//		The attribute of the item to change represented as a string name.
		//	value:
		//		The value to assign to the item.

		var lc = com.ibm.mashups.enabler.context.Factory.getLocalizedContext();    		
		switch(attribute) {
			case "id":
			    item.setID(value);
			    break;
			case "title":
				item.setTitle(value, lc.getLocale(item) || ibmConfig.locale);
				break;
			case "description":
			    item.setDescription(item, lc.getLocale(item) || ibmConfig.locale);
				break;
			case "type":
			    item.type = value;
				break;
			case "parent":
				// TODO?
				break;
			case "parentId":
				// TODO?
				break;
			case "children":
				// TODO?
				break;
			case "hasChildren":
				// TODO?
				break;
			case "position":
				var _navModel = com.ibm.mm.builder.utils.navigationUtil.getNavigationModel();
				_navModel.insert(item, value.newParent, value.next);
				item.loaded = false;
				item.created = true;
				if(value.oldParent == value.newParent){
					this.onSet(item, attribute, value.oldParent, value.next);
				}else if(value.next){
					this.onSet(item, "parent_next", value.oldParent, value.next);
				}else{
					this.onSet(item, "parent", value.oldParent, value.newParent);
				}
				break;
		}
	},
	newItem: function(/* Object? */ keywordArgs, /*Object?*/ parentInfo){
		// summary:
		//
        var title = keywordArgs.label;
    	var utils = com.ibm.mm.builder.utils;
    	var _navModel = utils.navigationUtil.getNavigationModel();
		
		var newPage;
		if (keywordArgs.openPageId){
			// load an existing page as an new item
			newPage = com.ibm.mm.builder.utils.pageUtil.getPageNode(keywordArgs.openPageId);
			newPage.loaded = false;
			newPage.created = false;			
			newPage.openPageId = keywordArgs.openPageId;
			newPage.pageLoadedSpaceId = keywordArgs.pageLoadedSpaceId;
			newPage.onCreate = function(){}; 
			this.globalPageInSpace = newPage.pageLoadedSpaceId;
			this.globalPage = newPage;
		}else{
	        newPage = _navModel.create(null);
	        newPage.setTitle(title, dojo.locale);
	    	newPage.setTitle(title, ibmConfig["default.locale"]);
	    	var themeId = utils.themeUtil.getThemeId(parentInfo.parent.getID());
		    if (!utils.themeUtil.getThemeModel().find(themeId).start()){
		        themeId = utils.themeUtil.getDefaultThemeId();
		    }
		    newPage.setTheme(themeId);
			newPage.title = title;
			newPage.loaded = false;
			newPage.created = false;
			newPage.onCreate = function(){};  
			_navModel.insert(newPage, parentInfo.parent, null);
	
			// create layout
			var lm = _navModel.getLayoutModel(newPage.getID());
			var lmRoot = lm.create();
			lm.insert(lmRoot);
			// set empty fragment
			lmRoot.setFragment(" ");			
		}

		this.onNew(newPage, parentInfo);
		this._isItemCreated = true;
		return newPage;
	},
	isCreated: function(item) {
		return !!item.created;
	},
	addOnCreate: function(item, callback) {
		if(this.isCreated(item)) {
			callback(item);
		}
		else {
			if(!item.onCreateDefQueue) {
				item.onCreateDefQueue = new com.ibm.lang.DeferredQueue(new dojo.Deferred());
			}
			item.onCreateDefQueue.add((new dojo.Deferred()).addCallback(callback));
		}
	},
	_fireCreated: function(item) {
		if(item.onCreateDefQueue) {
			// TODO: open a global page twice will lead an exception.
			try{
				item.onCreateDefQueue.fire(item);
			}catch(ex){
				
			}
		}
	},
	save: function(/* object */ keywordArgs){
		// summary:
    	var utils = com.ibm.mm.builder.utils;
    	var _navModel = utils.navigationUtil.getNavigationModel();
    	this.keywordArgs = keywordArgs;
		if (this.keywordArgs.openPageId){
			// just open an existing page, no need to save the page node.
			var newPage = com.ibm.mm.builder.utils.pageUtil.getPageNode(this.keywordArgs.openPageId);
			if(this._isItemCreated){
				// create new items
				this.keywordArgs = keywordArgs;
				this.keywordArgs.item.onCreate();
				this.keywordArgs.item.created = true;
				this.keywordArgs.item.setID(newPage.getID());
				this._fireCreated(this.keywordArgs.item);
				this.onSaveComplete();
				this._isItemCreated = false;
				if(this.keywordArgs.onComplete) this.keywordArgs.onComplete(this.keywordArgs);
			}
		}else{
			if(this._isItemCreated){
				// create new items
				this.keywordArgs = keywordArgs;
				this.keywordArgs.item.onCreate();
		        var deferred = _navModel.commit();	
		        deferred.addFinishedCallback( dojo.hitch(this, function(node){
					this.keywordArgs.item.created = true;
			    	var es = com.ibm.mashups.iwidget.services.ServiceManager.getService("eventService");
					es.broadcastEvent("com.ibm.mashups.builder.pageCreated", node.getID());
					this.keywordArgs.item.setID(node.getID());
					this._fireCreated(this.keywordArgs.item);
		    		this.onSaveComplete();
		    		this._isItemCreated = false;
		    		if(this.keywordArgs.onComplete) this.keywordArgs.onComplete(this.keywordArgs);
		    	}));
		        deferred.start(false);
			}
			if(this._isDirty){
				// update dirty items
	        	_navModel.commit().start(false);
	        	this._isDirty = false;
	        	if(keywordArgs.onComplete) keywordArgs.onComplete(keywordArgs);
			}			
		}
	},
	
	revert: function(){
		//	summary:
		//		Discards any unsaved changes.
		//	description:
		//		Discards any unsaved changes.
		this._isItemCreated = false;
		this._isDirty = false;
		return false; // boolean
	},
    onSaveComplete: function(args) {
		// summary: Callers can attach listeners to this function to get notified when a save operation
		//		on this store has received its last response from the server for all write operations.
		//		This is called before callback handlers to the save function itself are called but after
		// 		all the responses for the requests to the server have returned.
	}
});

}

if(!dojo._hasResource["com.ibm.data.EnablerTreeModel"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.data.EnablerTreeModel"] = true;
dojo.provide( "com.ibm.data.EnablerTreeModel" );

// This module provides the API for a data model that corresponds to any data set that contains
// parent-child relationships that can be represented as a tree.  It's exactly the same as the
// model API that's used by dijit.Tree with some functions already implemented for ease of use.
// As a result, any implementation of this API can be used as the model to a dijit.Tree widget
// or any other widget that uses a data model as its backend service provider.  This data API
// also adds some additional constraints and extension points that implementations should support
// in addition to the model API that's used by dijit.Tree, but by no means breaks the API or
// deviates from the required functions of the dijit model API.  One such addition is the
// support for additional query parameters that can be specified when instantiating a model
// that are always appended to any request to the server for data.  This allows particular instances
// of a data model to include metadata information that would not otherwise be included by certain
// data services that support it.
dojo.declare( "com.ibm.data.EnablerTreeModel",
			com.ibm.data.DataTreeModel,
			{
				// store: The dojo.data.Read/Write implementation 
				store: null,
				
				// query: The query used to retrieve the root item for this model
				query: null,
				
				// root: The root item of this model
				root: null,
				
				// addQueryParams: Object additional query parameters that should be appended
				//		to any request for items from the back end.  Is useful for getting
				// 		additional information such as metadata for each item from a data service 
				// 		that provides it.
				addQueryParams: null,
				
				constructor: function(args) {
					dojo.mixin(this, args);
					
					if(!this.addQueryParams) this.addQueryParams = {};
					
					this.connections = [];
					if(this.store.getFeatures()["dojo.data.api.Notification"]) {
						this.connections.concat([
							dojo.connect(this.store, "onNew", this, "_onNew"),
							dojo.connect(this.store, "onSet", this, "_onSet"),
							dojo.connect(this.store, "onDelete", this, "_onDelete")
						]);
					}
				},
				destroy: function() {
				        // summary: destroys this object, releasing connections to the store
				        dojo.forEach(this.connections, dojo.disconnect);
				},
				reset: function() {
					// summary: Resets the root of this model to null.
					this.root = null;
				},
				getRoot: function(onItem, onError){
					// summary:
				    //            Calls onItem with the root item for the tree, possibly a fabricated item.
				    //			  Any request for data that is sent to the server should also include
				    //			  the request parameters in addQueryParams. 
					//            Throws exception on error.
					this.root = this.store.rootNode;
					onItem(this.root);
				},
				mayHaveChildren: function(/*Object*/ item){
				        // summary:
				        //            Tells if an item has or may have children.  Implementing logic here
				        //            avoids showing +/- expando icon for nodes that we know don't have children.
				        //            (For efficiency reasons we may not want to check if an element actually
				        //            has children until user clicks the expando node)
				        return this.store.getValue(item, "hasChildren");
				
				},
				getChildren: function(/*Object*/ parentItem, /*function(items)*/ onComplete, /*function*/ onError){
				        // summary:
				        // 			  Calls onComplete() with array of child items of given parent item, all loaded.
				        //			  Any request for data that is sent to the server should also include
				    	//			  the request parameters in addQueryParams. 
				        //            Throws exception on error.
						var store = this.store;		
						if(this.mayHaveChildren(parentItem)){
							parentItem._children = this.store.getValues(parentItem, "children");
				        	if(parentItem._children && parentItem._children.length > 0){
				        		onComplete(parentItem._children);
				        	}else{
				        		//does not have children so return empty array
				        		parentItem._children = null;
				        		onComplete(parentItem._children);
				        	}
				        }else {
				        	// does not have children so return empty array
				        	parentItem._children = null;
				        	onComplete(parentItem._children);
				        }        
				},
				// =======================================================================
				// Inspecting items
				getIdentity: function(/* item */ item){
				        // summary: returns identity for an item
				        return this.store.getIdentity(item);
				},
				getLabel: function(/*dojo.data.Item*/ item){
				        // summary: get the label for an item
				        return this.store.getLabel(item);
				},
				getParent: function(/*dojo.data.Item*/ item) {
					// summary: returns the parent item of this item argument
					return this.store.getValue(item, "parent");
				},
				// =======================================================================
				// Write interface
				newItem: function(/* Object? */ args, /*Item?*/ parent){
					// summary
			        // Creates a new item.   See dojo.data.api.Write for details on args.
					if(parent.getRootNavigation)
					{
						parent = com.ibm.mm.builder.utils.navigationUtil.getNavigationRootNode(parent.getID());
					}
			        var newPage = this.store.newItem(args, {parent: parent});
					var es = com.ibm.mashups.iwidget.services.ServiceManager.getService("eventService");
					if (args.openPageId){
						this.store.save({item: newPage, onComplete: args.onComplete, onError: args.onError, scope: args.scope, openPageId:args.openPageId, pageLoadedSpaceId:args.pageLoadedSpaceId});
						// to do the real broadcast event thing, broadcast the event and open the global page
						var cb = dojo.hitch(this, function(){
							es.broadcastEvents(args.eventsArray || [],args.lastVisitedPage,args.openPageId);
						});
						com.ibm.mm.builder.utils.pageUtil.savePageWithConfirm(cb);
					}else{
						this.store.save({item: newPage, onComplete: args.onComplete, onError: args.onError, scope: args.scope});
						var cb = dojo.hitch(this, function(){
							es.broadcastEvent("com.ibm.mashups.builder.switchPage", this.getIdentity(newPage));
						});
						com.ibm.mm.builder.utils.pageUtil.savePageWithConfirm(cb);
					}
			        return newPage;
				},
				deleteItem: function(/*Object*/args, /*item*/ item){
					// This is a fake delete item method, which only will remove global page.
					var parent = this.getParent(item);
					// key to set the global page as null, so the parent and children info will back to normal
					this.store.globalPage = null;
				    this._removeChildItem(parent, item, null, dojo.hitch(this, function(){
				    	this.onTreeChange(parent, null, parent);
				    }));
					var es = com.ibm.mashups.iwidget.services.ServiceManager.getService("eventService");
					if (args.openPagePayload){
						// do not switch to the last visited non-global page, we will open another global page instead.		
					}else{
						// go to last visited non-global page
						var cb = dojo.hitch(this, function(){
							es.broadcastEvent("com.ibm.mashups.builder.switchPage", args.lastVisitedPage);
						});
						com.ibm.mm.builder.utils.pageUtil.savePageWithConfirm(cb);
					}	
				},	
				clearGlobalPageItem:function(/*Object*/args, /*item*/ item){
					var parent = this.getParent(item);
					this.store.globalPage = null;
				    this._removeChildItem(parent, item, null, dojo.hitch(this, function(){
				    	this.onTreeChange(parent, null, parent);
				    }));
				},			
				isCreated: function(/*item*/ item) {
					// summary: Indicates whether or not the item has been created on the server and
					//		the server-generated values were properly applied to the client-side
					//		object.	NOTE: Any client-side modifications	to the values of an item for 
					// 		which isCreated returns true can potentially modify the server-generated 
					// 		values to be out-of-sync with the server.
					// 		Therefore, it's important to note that isCreated merely indicates whether
					//		or not the client-side item has a server-side resource associated with it,
					// 		and any values that the server generated for the resource (such as a unique
					return this.store.isCreated(item);	
				},
				addOnCreate: function(/*item*/ item, /*Function*/ callback) {
					// summary: Register callback to be called when the given item is created on the server.
					//		If the item is already created, this will call the callback immediately.
					return this.store.addOnCreate(item, callback);			
				},
				pasteItem: function(/*Item*/ childItem, /*Item*/ oldParentItem, /*Item*/ newParentItem, /*Boolean*/ copy, /*Item*/ nextSibling, /*Boolean?*/ extra){
				        // summary:
				        //            Move an item from one parent item to another or to another position under the same parent.
				        //            Used in drag & drop.
				        // See dojo.data.api.Write for details on args.

				        this.store.setValue(childItem, "position", {newParent: newParentItem, 
				        											oldParent: oldParentItem, 
				        											next: nextSibling});	        	
				        this.store._isDirty = true;
				        this.store.save({});
				        this.store.onSaveComplete();
				},
				toString: function() {
					return "[TreeModel " + this.declaredClass + "]";
				},
				_onNew: function(item, parentInfo){
					this.newPageItem = item;
					this.newPageParent = parentInfo.parent;
				    this._insertChildItem(this.newPageParent, this.newPageItem, null, dojo.hitch(this, function(){
				    	this.onTreeChange(this.newPageItem, null, this.newPageParent);
				    }));
				},
				_onDelete: function(item){
									
				},				
				_onSet: function(/* Item */ item, /*String*/ attribute, /*Object | Array*/ oldValue, /*Object | Array*/ newValue){				
					
					if(attribute.indexOf("parent") > -1) {
						var newParent = null;
						if(attribute == "parent_next"){
							newParent = this.store.getValue(item, "parent");
						}else{
							newParent = newValue;
							newValue = null;
						}

						this._removeChildItem(oldValue, item);
		        		this._insertChildItem(newParent, item, newValue, dojo.hitch(this, function(){
		        			this.onTreeChange(item, oldValue, newParent, newValue);
		        		}));		        		
					}else if(attribute == "position"){
						// if we're not reparenting, then we can only be moving
		        		this._moveChildItem(oldValue, item, newValue, dojo.hitch(this, function(){
		        			this.onTreeChange(item, oldValue, oldValue, newValue);
		        		}));
		        	}else {
						this.onChange(item);
					}
				},
				refreshItemChildren: function(/*Item*/ item, /*Function?*/ modifier) {
					item._children = null;					
					var func = modifier ? modifier : function(items) {
							this.onChildrenChange(item, items);
						};
					this.getChildren(item, dojo.hitch(this, func));
				},
				_insertChildItem: function(/*Item*/parentItem, /*Item*/ item, /*Item*/ newNextSibling, /*Function*/callbackfn) {
					this.getChildren(parentItem, dojo.hitch(this, function(items) {
						// refresh the item children with a function that will add the item first
						if(!items){
							items = new Array();
						}
						if(!newNextSibling) {
							items.push(item);
						} else {
							var id = this.getIdentity(newNextSibling);
							for(var i = 0; i < items.length; i++) {
								if(this.getIdentity(items[i]) == id) {
									items.splice(i, 0, item);
									break;
								}
							}
						}
						if(callbackfn) callbackfn();
						this.onChildrenChange(parentItem, items);
					}));
				},
				_removeChildItem: function(/*Item*/parentItem, /*Item*/ item, /*Function*/callbackfn) {
					this.getChildren(parentItem, dojo.hitch(this, function(items) {
						var id = this.store.getIdentity(item);
						if(items){
							for(var i = 0; i < items.length; i++) {
								if(this.store.getIdentity(items[i]) == id) {
									items.splice(i,1);	// remove the item from the array
									break;	// break out of the loop since we already found ourselves
								}
							}
						}
						if(callbackfn) callbackfn();
						this.onChildrenChange(parentItem, items);
					}));
				},
				_moveChildItem: function(/*Item*/parentItem, /*Item*/ item, /*String*/ newNextSibling, /*Function*/callbackfn) {
					this.getChildren(parentItem, dojo.hitch(this, function(items) {
						var id = this.store.getIdentity(item);
						var nextIndex = items.length - 1;
						for(var i = 0; i < items.length; i++) {
							if(this.store.getIdentity(items[i]) == id) {
								items.splice(i, 1);	// remove item from index i
								i--;
							}
							else if(newNextSibling && this.store.getIdentity(items[i]) == newNextSibling) {
								// insert item at index i before the existing item at that index without deleting it
								items.splice(i, 0, item);
								i++;
							}
						}
						if(!newNextSibling) {
							// if this is null, append the item to the end of the list
							items.push(item);
						}
						if(callbackfn) callbackfn();
						this.onChildrenChange(parentItem, items);
					}));
				},
				onTreeChange: function(/*Item*/ childItem, /*Item*/ oldParentItem, /*Item*/ newParentItem, /*Item*/ nextSiblingItem) {
					
				},
				onChange: function(/*Item*/ item){
					
				},
				onChildrenChange: function(/*Item*/ parentItem, /*Array*/ items){
					
				}
			}
);

}

if(!dojo._hasResource['com.ibm.widgets.NewPageDialog']){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource['com.ibm.widgets.NewPageDialog'] = true;
dojo.provide('com.ibm.widgets.NewPageDialog');




dojo.declare('com.ibm.widgets.NewPageDialog',
	[dijit.Dialog],
    {
		shelfBundle: null,
		dialogBundle: null,
		blankImg: "",
		autofocus: false,
		showMakePrivate: true,
		showFriendlyURL: true,
		value: {},
		
		templateString: '<div class="lotusDialogBorder lotusui" waistate="labelledby-${id}" wairole="dialog" role="dialog" index="-1" aria-labelledby="${id}" dojoAttachPoint="dialogDiv">' +
						'<div class="lotusDialog">' +
							'<h1>' +
								'<a href="javascript:void(0);" dojoAttachPoint="closeButtonNode" class="lotusBtnImg lotusClose" title="${closeText}">' +
									'<img src="${_blankGif}" alt="" aria-label="${closeText}" />' +
									'<span class="lotusAltText">X</span>' +
								'</a>' +
								'<span dojoAttachPoint="titleNode">${titleText}</span>' +
							'</h1>' +
							'<form dojoAttachPoint="newPageForm" action="javascript:;">' +
								'<div dojoAttachPoint="containerNode" class="lotusDialogContent">' +
									'<div>' +
										'<div class="lotusMessage" dojoAttachPoint="newPageError" style="display: none" role="alert">' +
											'<span>${nlsTitleError}</span>' +
										'</div>' +
										'<div><label for="ibmPortalPageNameInput">${nlsPageTitle}</label></div>' +
										'<div><input id="ibmPortalPageNameInput" type="text" name="title" dojoAttachPoint="typingNode, focusNode" size="24"/></div><br />' +
										
										'<div dojoAttachPoint="divFriendlyURL">'+
											'<div><label for="ibmPortalFriendlyUrlInput">${nlsFriendlyURL}:</label></div>' +
											'<div><input id="ibmPortalFriendlyUrlInput" type="text" name="friendlyURL" dojoAttachPoint="newPageFriendlyURL" size="24"/></div>'+
										'</div><br />' +
										
										'<div dojoAttachPoint="divPrivate">' +
											'<input id="ibmPortalIsPrivateInput" type="checkbox" name="private" dojoAttachPoint="makePrivate"/><span> <label for="ibmPortalIsPrivateInput">${nlsMakePrivate}</label></span>' +
										'</div>' +
									'</div>' +
								'</div>' +
								'<div class="lotusDialogFooter" dojoAttachPoint="dialogFooter">' +
									'<input value="${okText}" class="lotusFormButton" dojoAttachPoint="submitDialog" type="submit"/> ' +
									'<a href="javascript:void(0);" class="lotusAction" dojoAttachPoint="dialogCancel">${cancelText}</a>' +
								'</div>' +
							'</form>' +
						'</div>' +
					'</div>',
								
		postMixInProperties: function() {
			this.shelfBundle = dojo.i18n.getLocalization("com.ibm.bundles", "Shelf");
			this.dialogBundle = dojo.i18n.getLocalization("com.ibm.bundles", "PageCreatorDialog");
			this.cancelText = this.shelfBundle["add_content_cancel"];
			this.closeText = this.shelfBundle["add_content_close"];
			this.okText = this.dialogBundle["page_dialog_create_page"];
			this.nlsPageTitle = this.dialogBundle["page_dialog_page_name"];
			this.nlsTitleError = this.shelfBundle["new_feed_enterTitle"];
			this.nlsFriendlyURL = this.dialogBundle["page_dialog_friendly_url_name"];
			this.nlsMakePrivate = this.dialogBundle["page_dialog_make_private"];
			this.titleText = this.dialogBundle["page_dialog_create_page"];		
		},	
		
		postCreate: function() { 
			this.inherited(arguments);
			
			this.submitDialog.onclick = dojo.hitch(this,function(){this.submit();return false;});
			this.closeButtonNode.onclick = this.dialogCancel.onclick = dojo.hitch(this,function(){this.cancel();return false;});
			
			if (!this.showMakePrivate) { dojo.destroy(this.divPrivate); delete this.divPrivate; }
			this.connect(this.typingNode, "onkeyup", function(){
				if (this.typingNode.value != "") { this.newPageError.style.display="none"; }
			});
			if (this.showFriendlyURL){
				this.connect(this.typingNode, "onkeyup", function(){ 
					this.filterFriendlyURL(this.typingNode.value);
				});
				this.connect(this.newPageFriendlyURL, "onkeyup", function(){
					this.filterFriendlyURL(this.newPageFriendlyURL.value);
				});
			} else {
				dojo.destroy(this.divFriendlyURL);
				delete this.divFriendlyURL;
			}
		},
		
		submit: function(){
			var pagename = this.typingNode.value;
			// shows error if there is no page title.
			if (pagename == "") {
				this.newPageError.style.display = "block";
				return;
			}
			//bug 13511, xss check before submit.
			if (!com.ibm.mm.builder.utils.pageUtil.validatePageName(pagename)) { return; }
			
			dojo.attr(this.submitDialog, "disabled", "disabled");
			this.hide();
			this.beforeSubmit();
			//bug 12089, fix multi click to create page multi times.
			var self = this;
			setTimeout(function(){
				self.onSubmit();
			}, 100);
		},
		
		cancel: function(){
			this.hide();
		},
		
		onChange: function(/*Object*/arg){
		},
		
		onComplete: function(){
		},
		
		beforeSubmit: function(){
		},
		
		onSubmit: function() {
			// When the user presses the Submit button.
			this.value = dojo.formToObject(this.newPageForm);
			this.value.onComplete = this.onComplete;
			this.onChange(this.value);
		},
		
		focus: function(){
			this.newPageError.style.display="none";
			if(this.showMakePrivate){this.makePrivate.checked = false;}
			this.typingNode.value = "";
			if(this.showFriendlyURL){this.newPageFriendlyURL.value = "";}
			this.submitDialog.removeAttribute("disabled");
			this.show();
			this.focusNode.focus();
		},
		
		filterFriendlyURL: function(/*String*/textToFilter) {
		// summary: filters the given text into something more acceptable for the friendly url.
		// textToFilter: text for the filter to run on.
			var friendly = textToFilter.replace(/[!\*\'\(\);:@&=+$,\/?%#\[\]\s]/g,'_');
			this.newPageFriendlyURL.value = friendly;
		}
    }
);

}

if(!dojo._hasResource["com.ibm.mm.builder.navigationHelper"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.mm.builder.navigationHelper"] = true;
dojo.provide("com.ibm.mm.builder.navigationHelper");





dojo.declare("com.ibm.mm.builder.navigationHelper",
		null,
		{
			loaded: false,
			init: function(){
				// singleton instance of data store to be used under the covers by any component using these APIs
				this.store = new com.ibm.data.EnablerModelStore();
				this.navigationUtil = com.ibm.mm.builder.utils.navigationUtil;
				this.pageUtil = com.ibm.mm.builder.utils.pageUtil;
				this.spaceUtil = com.ibm.mm.builder.utils.spaceUtil;
				
				var currentPage = com.ibm.mashups.builder.model.Factory.getRuntimeModel().getCurrentPage();
				var currentPageId = currentPage.getID();
				if(!currentPageId) {
					var spaceId = this.spaceUtil.getCurrentSpaceId();
					currentPageId = spaceId ? this.pageUtil.getFirstPageInSpace(spaceId) : this.pageUtil.getFirstRootPageId();
					
					if(!currentPageId && spaceId){
						currentPageId = spaceId;
					}else{
						currentPageID = this.navigationUtil.getNavigationRootNode().getID();
					}
				}
				
				var onComplete = dojo.hitch(this,
											function(items) {
												this.treeModel = 
													new com.ibm.data.EnablerTreeModel({
														newItem: function(args) {
															args.label = args.title;
															return this.inherited("newItem", arguments);
														},
														root: items[items.length - 1],
														store: this.store
													});
												
												this.selectionModel = 
													new com.ibm.data.SelectionModel({
														treeModel: this.treeModel,
														selectionPath: items
													});
												
												this.loaded = true;
											} );
				
				var args = { onComplete: onComplete,
							 onError: function(err) {
										console.error(err);
										throw err;
									  },
							 query: {uri: currentPageId }
						   }
				
				if(!this.treeModel || !this.selectionModel) this.store.fetch(args);
			},
			getStore: function(){
				return this.store;
			},
			getTreeModel: function(){
				return this.treeModel;
			},
			getSelectionModel: function(){
				return this.selectionModel;
			}
	}
);

com.ibm.mm.builder.navigationHelper = new com.ibm.mm.builder.navigationHelper();

}

if(!dojo._hasResource["com.ibm.portal.xpath"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.portal.xpath"] = true;
dojo.provide( "com.ibm.portal.xpath" );

// generic impl

com.ibm.portal.xpath.evaluateXPath = function(/*String*/xpathExpr, /*DOMDocument*/ doc, /*Object{prefix:ns,prefix2:ns2,...}*/namespaces) {
    if (typeof ActiveXObject != "undefined") {
        return com.ibm.portal.xpath.ie.evaluateXPath(xpathExpr, doc, namespaces);
    }
    else {
        return com.ibm.portal.xpath.gecko.evaluateXPath(xpathExpr, doc, namespaces);
    }
}

// IE Implementation

dojo.provide( "com.ibm.portal.xpath.ie" );

com.ibm.portal.xpath.ie.evaluateXPath = function(/*String*/xpathExpr, /*DOMDocument*/ doc, /*Object{prefix:ns,prefix2:ns2,...}*/namespaces) {
        if (namespaces) {        
            var ns = "";
            for (var prop in namespaces) {
                ns += "xmlns:"+prop+"='"+namespaces[prop]+"' ";
            }
            if (doc.ownerDocument) {
                doc.ownerDocument.setProperty("SelectionNamespaces", ns);
            } else {
                doc.setProperty("SelectionNamespaces", ns);
            }
        }
        var result = doc.selectNodes(xpathExpr);

        var thisResult;
        var resultSet = new Array();
        var len = 0;
        for (var i=0; i<result.length; i++) {
            thisResult = result[i];
            if (thisResult) {
                resultSet[len] = thisResult;
                len++;
            }
        }
        return resultSet;
}


// GECKO Implementation

dojo.provide( "com.ibm.portal.xpath.gecko" );

com.ibm.portal.xpath.gecko.evaluateXPath = function(/*String*/xpathExpr, /*DOMDocument*/ doc, /*Object{prefix:ns,prefix2:ns2,...}*/namespaces) {
        var result;
        try {
        	var rootDoc = doc;
        	if(!rootDoc.evaluate) rootDoc = doc.ownerDocument;
            result = rootDoc.evaluate( xpathExpr, doc, function(prefix) { return namespaces[prefix] || null;}, XPathResult.ANY_TYPE, null );
        } 
        catch (exc)
        {
            //Callers should catch this and can substitute their own error message
            throw new Error("Error with xpath expression" + exc);
        }
    
        //alert(result.resultType);
        var thisResult;
        var resultSet = new Array();
        var len = 0;
        do {
            thisResult = result.iterateNext();
            if (thisResult) {
                resultSet[len] = thisResult;
                len++;
            }
        } while ( thisResult );
        return resultSet;
}


}

if(!dojo._hasResource["com.ibm.data.XpathHelper"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.data.XpathHelper"] = true;
dojo.provide( "com.ibm.data.XpathHelper" );
// summary: This module is meant to be extended by modules that want to use XPath
//		to query DOM documents for information.  It provides read support and limited 
// 		write support.  Write support is limited in that if an xpath query is used to
//		set a node, property of a node, or DOM attribute of a node, then the write support
//		will only work if a node that matches that query already exists and is returned.
//		If no node matches the query and the Xpath query returns null, the all write operations
//		provided by this module will return false to indicate that the caller needs to handle
//		them in a different way like creating the node from scratch.
//
//		This module provides cross-browser methods for reading and writing to DOM nodes,
//		properties of DOM nodes, and DOM attributes of DOM nodes.  It also supports extensions
//		so that special constructs can be returned by a query instead of a DOM node or String value
//		of a property or attribute.  By default, no constructs are defined by this module.


dojo.require( "com.ibm.portal.xpath" );
dojo.require( "com.ibm.portal.xslt" );
dojo.require( "com.ibm.domUtilities" );

dojo.declare( "com.ibm.data.XpathHelper",
			null,
			{
				// namespaces: A map of prefix - namespace URI pairs used to specify what namespaces
				//		are used by this XpathHelper to query nodes in a DOM document
				namespaces: {},
				
				_getNodesByXpath: function(/*Object*/ context, /*String*/expr, /*String?*/prop) {
					// summary: Gets an array of DOM nodes or String node properties using the XPath expr relative 
					// 		to the context (not relative to the document root itself).  Returns an object allowing
					//		the caller to determine if the actual value requested is null or if there were no nodes
					//		found at all.
					// context: The XML element to use as the root context for the XPath query
					// expr: XPath expression used to find the nodes
					// prop: Optional prop to specify to get a property of the nodes instead of the nodes themselves.
					// returns: Object with two properties:
					//		-	{
					//		-		found: Boolean indicating if any nodes were found matching the XPath expression
					//		-		value: Array the actual nodes found by the expression, or the properties of the nodes
					// 		-			found by the expression as specified by the prop argument
					// 		-	} 
					var results = com.ibm.portal.xpath.evaluateXPath(expr, context, this.namespaces);
					var found = results && results.length > 0;
					if(prop) {
						var nodes = results;
						results = new Array();
						for(var i = 0; i < nodes.length; i++) {
							results[i] = this._getNodeProp(nodes[i], prop);
						}
					}
					return {found: found, value: results};
				},
				_getNodeByXpath: function(/*Object*/ context, /*String*/expr, /*String?*/ prop) {
					// summary: Gets a node using the XPath expr relative to 
					// 		the context	(not relative to the document root itself).  Returns an object allowing
					//		the caller to determine if the actual value requested is null or if there were no nodes
					//		found at all.
					// context: The XML element to use as the root context for the XPath query
					// expr: XPath expression used to find the node
					// prop: Optional prop to specify to get an property of the node instead of the node itself.
					// returns: Object with two properties:
					//		-	{
					//		-		found: Boolean indicating if any nodes were found matching the XPath expression
					//		-		value: DOMNode|Object the first node found by the expression, or the property of the first
					// 		-			node found by the expression as specified by the prop argument
					// 		-	}
					var result = this._getNodesByXpath(context, expr);
					var found = result.found;
					if(!found) return {found: found};
					var nodes = result.value;
					if(nodes.length > 0) {
						if(prop) return {found: true, value: this._getNodeProp(nodes[0], prop)};
						else return {found: true, value: nodes[0]};
					}
					return {found: false};
				},
				_getNodeProp: function(/*DOMNode*/ node, /*String*/ prop) {
					// summary:  Function to provide cross-browser support for properties of a queried
					//		node.  If the prop string is not special, control will be passed to the 
					//		handleConstructs function for this object.
					//		Currently only supports textContent as a special property since not
					//		all browsers implement the textContent property of DOM nodes.
					switch(prop) {
						case "textContent":
							return dojox.data.dom.textContent(node);
						default:
							return this.handleConstructs(node, prop);
					}
				},
				handleConstructs: function(/*DOMNode*/ node, /*String*/ prop) {
					// summary: Allows a data store to return complex javascript objects
					//		or alternative values when a specific non-standard property of a node 
					// 		is requested.  Example: An Atom Feed data store may create a special 
					// 		Person Construct when querying an <atom:author> element.  This construct
					//		may provide accessor functions to the name, email, and URI of the author.
					//		See http://tools.ietf.org/html/rfc4287#section-3.2
					//		Constructs that are created here should implement and handle write functionality
					//		themselves as this module will not handle writes to constructs natively.
					
					return node[prop];
				},
				_setNodeProp: function(/*DOMNode*/ node, /*String*/ prop, /*Object*/ value) {
					// summary: Allows a data store to set properties of a node in a cross-browser
					//		way for properties that may be non-standard.
					//		Currently only supports textContent as a special property since not
					//		all browsers implement the textContent property of DOM nodes.
					//		Note that for special constructs that are created using the handleConstructs
					// 		function, write support is handled by the returned construct object not by
					//		this module's functions.
					switch(prop) {
						case "textContent":
							dojox.data.dom.textContent(node, value);
						default:
							node[prop] = value;
					}
				},
				_getAttrsByXpath: function(/*Object*/ context, /*String*/ expr, /*String*/attrName) {
					// summary: Gets an array of attribute values for the nodes returned 
					// 		using the XPath expr relative to the context (not relative to the 
					// 		document root itself).  The attributes are retrieved using the 
					// 		getAttributeNS/getAttribute	functions of the nodes.  Returns an object allowing
					//		the caller to determine if the actual value requested is null or if there were no nodes
					//		found at all.
					// context: The XML element to use as the root context for the XPath query
					// expr: XPath expression used to find the nodes
					// attrName: The name of the attribute to get from each node returned by the XPath expr.
					//		If the attribute is namespaced, it will be split into its parts using the : delimiter
					//		and the namespace used during lookup will be the one keyed in this item or store's 
					// 		namespace map.
					// returns: Object with two properties:
					//		-	{
					//		-		found: Boolean indicating if any nodes were found matching the XPath expression
					//		-		value: Array the attribute values of the nodes found by the expression
					// 		-	}
					var result = this._getNodesByXpath(context, expr);
					var found = result.found;
					if(!found) return {found: found};
					var nodes = result.value;
					var attrs = [];
					for(var i = 0; i < nodes.length; i++) {
						attrs[i] = this._getAttribute(nodes[i], attrName);
					}
                    return {found: found, value: attrs};
				},
				_getAttrByXpath: function(/*Object*/ context, /*String*/expr, /*String*/ attrName) {
					// summary: Gets the attribute value of the first node returned 
					// 		using the XPath expr relative to the context (not relative to the 
					// 		document root itself).  The attribute is retrieved using the 
					// 		getAttributeNS/getAttribute	functions of the node.  Returns an object allowing
					//		the caller to determine if the actual value requested is null or if there were no nodes
					//		found at all.
					// context: The XML element to use as the root context for the XPath query
					// expr: XPath expression used to find the node
					// attrName: The name of the attribute to get from the node returned by the XPath expr.
					//		If the attribute is namespaced, it will be split into its parts using the : delimiter
					//		and the namespace used during lookup will be the one keyed in this item or store's 
					// 		namespace map.
					// returns: Object with two properties:
					//		-	{
					//		-		found: Boolean indicating if any nodes were found matching the XPath expression
					//		-		value: Array the attribute value of the first node found by the expression
					// 		-	}
					var result = this._getNodeByXpath(context, expr);
					var found = result.found;
					if(!found) return {found: found}; 
					var node = result.value;
                    return {found: found, value: this._getAttribute(node, attrName)};
				},
				_extractNSInfo: function(str) {
					// summary: Extracts the namespace URI, prefix, and local name of a QName according to this
					//		object's namespaces map that includes known prefixes and their namespace URIs.  If
					//		the string is not namespaced, then the namespaceURI and prefix are set to null, and
					//		the localName is set to the str as-is.
					// str: QName to extract namespace from
					// returns: Map - {namespaceURI: namespaceURI, prefix: prefix, localName: localName}
					return com.ibm.domUtilities.nsInfo(str, this.namespaces);
				},
				_getAttribute: function(/*DOMNode*/ node, /*String*/ attrName) {
					// summary: Gets an attribute of the given node, supporting namespaced and 
					// 		non-namespaced attributes.
					// node: Node to retrieve the attribute value from
					// attrName: The name of the attribute to get from the node.
					//		If the attribute is namespaced, it will be split into its parts using the : delimiter
					//		and the namespace used during lookup will be the one keyed in this item or store's 
					// 		namespace map.
					return com.ibm.domUtilities.getAttribute(node, attrName, this.namespaces);
				},
				_setAttribute: function(/*DOMNode*/ node, /*String*/ attrName, /*String*/ value) {
					// summary: Sets an attribute of the given node, supporting namespaced and 
					// 		non-namespaced attributes.
					// node: Node to set the attribute value on
					// attrName: The name of the attribute to set on the node.
					//		If the attribute is namespaced, it will be split into its parts using the : delimiter
					//		and the namespace used during lookup will be the one keyed in this item or store's 
					// 		namespace map.
					// value: The actual value to store in the node at the key attribute specified by attrName.
					if(value) com.ibm.domUtilities.setAttribute(node, attrName, value, this.namespaces);
					else com.ibm.domUtilities.removeAttribute(node, attrName, this.namespaces);
				},
				_setNodesByXpath: function(/*Object*/ context, /*String*/expr, /*String*/ prop, /*Array*/values) {
					// Empty for now since there's little use for this type of function, particularly due to 
					// mismatches between the number of values and number of returned nodes.
					//var nodes = this._getNodesByXpath(context, expr);
					
					return false;
				},
				_setNodeByXpath: function(/*Object*/ context, /*String*/expr, /*String*/ prop, /*Object*/value) {
					// summary: Will replace a node returned by the xpath expr query with the value object
					// 		if prop is null.  If prop exists, the specified property on the returned node
					// 		will be set to the value.
					// 		If no node is found that matches the xpath expr, this function returns false to indicate
					//		failure to the caller for further processing if necessary.
					// context: The DOM element to use as the root context for the XPath query
					// expr: XPath expression used to find the node
					// prop: Optional prop to specify to set a property of the node instead of the node itself.
					// returns: true if the set operation was successful, false otherwise
					var result = this._getNodeByXpath(context, expr);
					var found = result.found;
					if(!found) return false; 
					var node = result.value;
					if(prop) {
						this._setNodeProp(node, prop, value);
					}
					else {
						dojo.place(value, node, "before");
						node.parentNode.removeChild(node);
						delete node;
					}
					return true;
				},
				_setAttrsByXpath: function(/*Object*/ context, /*String*/expr, /*String*/ attrName, /*Array*/values) {
					// Empty for now since there's little use for this type of function, particularly due to 
					// mismatches between the number of values and number of returned nodes.
					//var nodes = this._getNodesByXpath(context, expr);
					
					return false;
				},
				_setAttrByXpath: function(/*Object*/ context, /*String*/expr, /*String*/ attrName, /*String*/value) {
					// summary: The specified DOM attribute on the returned node will be set to the value.
					// 		If no node is found that matches the xpath expr, this function returns false to indicate
					//		failure to the caller for further processing if necessary.
					// context: The DOM element to use as the root context for the XPath query
					// expr: XPath expression used to find the node
					// attrName: The name of the attribute to get from the node returned by the XPath expr.
					//		If the attribute is namespaced, it will be split into its parts using the : delimiter
					//		and the namespace used during lookup will be the one keyed in this item or store's 
					// 		namespace map.
					// returns: true if the set operation was successful, false otherwise
					var result = this._getNodeByXpath(context, expr);
					var found = result.found;
					if(!found) return false;
					var node = result.value;
					this._setAttribute(node, attrName, value);
					return true;
				},
				_createNSElement: function(doc, tagName, attrMap) {
					// summary: Cross-browser implementation for creating a namespaced node using the namespace
					//		map in this object to resolve prefixes to namespace URIs.
					//		If the tagName is not namespaced or a namespace URI cannot be resolved
					// 		using this object's namespaces map, a non-namespaced element will be created instead.
					// doc: DOMDoc document object to use to create the DOM node.
					// tagName: String name for the tag name of the element to create.  
					// 		Can be namespaced like prefix:localName or not like localName.
					// attrMap: Optional argument specifying a key-value map of attributes to be
					// 		set on the node before returning it. 
					// returns: DOMNode A new DOM node that was created by doc
					return com.ibm.domUtilities.createElement(doc, tagName, this.namespaces, attrMap);
				},
				__getClassName: function() {
					var cls = this.declaredClass;
					if(!cls) return "Object";
					var idx = cls.lastIndexOf(".");
					if(idx > -1 && (idx < cls.length - 1)) cls = cls.substring(idx + 1);
					return cls;
				}
			}
);

dojo.declare( "com.ibm.data._XmlConstruct",
			com.ibm.data.XpathHelper,
			{
				// summary: Provides a base construct for modules to extend when building constructs
				//		to be returned by queries using this module's APIs.
				isConstruct: true,
				toString: function() {
					// summary: Default toString method for this object so that it can be inserted
					//		in a string and be properly represented.  Overridable by extensions of this
					//		module.
					return "<"   + this.__getClassName() + ">";
				}
			}
);


}

if(!dojo._hasResource["com.ibm.data.AtomFeedStore"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.data.AtomFeedStore"] = true;
dojo.provide( "com.ibm.data.AtomFeedStore" );

dojo.require( "com.ibm.data.XpathHelper" );
dojo.require( "dojo.date.stamp" );

dojo.declare( "com.ibm.data.AtomFeedStore",
			com.ibm.data.XpathHelper,
			{
				// namespaces: Map
				//		Map of namespaces used by the ATOM feeds
				namespaces: {
		            "atom" : "http://www.w3.org/2005/Atom"
		        },
		        // _features: Map
				//		Map of features that this store supports.
				//		This generic AtomFeedStore only supports Read and Identity.
				_features: {
					'dojo.data.api.Read': true,
					'dojo.data.api.Write': false,
					'dojo.data.api.Identity': false,
					'dojo.data.api.Notification': false
				},
				attrMappings: {
					title: {xpath: "./atom:title", targetName: "textContent", type: "node", setter: 
						function(item, rule, value){
							var elem = this._createNSElement(item.element.ownerDocument, "atom:title");
							this._setNodeProp(elem, rule.targetName, value);
							item.element.appendChild(elem);
							return true;
						}
					},
					id: {xpath: "./atom:id", targetName: "textContent", type: "node", setter: 
						function(item, rule, value){
							var elem = this._createNSElement(item.element.ownerDocument, "atom:id");
							this._setNodeProp(elem, rule.targetName, value);
							item.element.appendChild(elem);
							return true;
						}
					},
					updated: {xpath: "./atom:updated", targetName: "AtomDateConstruct", type: "node"},
					category: {xpath: "./atom:category", targetName: "term", type: "attr", setter: 
						function(item, rule, value){
							var elem = this._createNSElement(item.element.ownerDocument, "atom:category");
							this._setAttribute(elem, rule.targetName, value);
							item.element.appendChild(elem);
							return true;
						}
					},
					categoryScheme: {xpath: "./atom:category", targetName: "scheme", type: "attr", setter: 
						function(item, rule, value){
							var elem = this._createNSElement(item.element.ownerDocument, "atom:category");
							this._setAttribute(elem, rule.targetName, value);
							item.element.appendChild(elem);
							return true;
						}
					},
					categoryLabel: {xpath: "./atom:category", targetName: "label", type: "attr", setter: 
						function(item, rule, value){
							var elem = this._createNSElement(item.element.ownerDocument, "atom:category");
							this._setAttribute(elem, rule.targetName, value);
							item.element.appendChild(elem);
							return true;
						}
					},
					contributer: {xpath: "./atom:contributer", targetName: "AtomPersonConstruct", type: "node"},
					author: {xpath: "./atom:author", targetName: "AtomPersonConstruct", type: "node"},
					summary: {xpath: "./atom:summary", targetName: "textContent", type: "node", setter: 
						function(item, rule, value){
							var elem = this._createNSElement(item.element.ownerDocument, "atom:summary");
							this._setNodeProp(elem, rule.targetName, value);
							item.element.appendChild(elem);
							return true;
						}
					},
					source: {xpath: "./atom:source", type: "node", setter: 
						function(item, rule, value){
							item.element.appendChild(value);
							return true;
						}
					},
					rights: {xpath: "./atom:rights", targetName: "textContent", type: "node", setter: 
						function(item, rule, value){
							var elem = this._createNSElement(item.element.ownerDocument, "atom:rights");
							this._setNodeProp(elem, rule.targetName, value);
							item.element.appendChild(elem);
							return true;
						}
					},
					selfLink: {xpath: "./atom:link[@rel='self']", targetName: "href", type: "attr", setter: 
						function(item, rule, value){
							var elem = this._createNSElement(item.element.ownerDocument, "atom:link");
							this._setAttribute(elem, "rel", "self");
							this._setAttribute(elem, rule.targetName, value);
							item.element.appendChild(elem);
							return true;
						}
					},
					link: {xpath: "./atom:link[@href]", targetName: "href", type: "attr", setter: 
						function(item, rule, value){
							var elem = this._createNSElement(item.element.ownerDocument, "atom:link");
							this._setAttribute(elem, rule.targetName, value);
							item.element.appendChild(elem);
							return true;
						}
					},
					content: {xpath: "./atom:content", type: "node", setter: 
						function(item, rule, value){
							item.element.appendChild(value);
							return true;
						}
					}
				},
				
				// timeout: Number milliseconds to wait for a response for any request
				//		sent by this data store.
				timeout: null,
				
				// itemClass: String the class used to represent items of this store
				itemClass: "com.ibm.data.AtomEntryItem",
								
				constructor: function( /*Map*/ args ) {
					// summary: Creates a new instance of a com.ibm.data.AtomFeedStore
					// args: Map
					//		The args map will be used to replace any default values of this store with the
					//		values specified in the args map.
					dojo.mixin(this, args);
					this._dirtyItems = new Array();
					this._deletedItems = new Array();
					this._newItems = new Array();
				},
				toString: function() {
					return "<" + this.__getClassName() + ": " + this.url + ">";
				},
				handleConstructs: function(/*DOMNode*/ node, /*String*/ prop) {
					switch(prop) {
						case "AtomPersonConstruct": return new com.ibm.data.AtomPersonConstruct(node);
						case "AtomDateConstruct": return new com.ibm.data.AtomDateConstruct(node);
						default: return this.inherited(arguments);
					}
				},
				
				_assertIsItem: function(/*Object*/ something) {
					// summary: Throws an exception if the argument is not a valid item in this store.
					// something: Object to check to determine if it is an item in this store.
					if(!this.isItem(something)) throw new Error(something + " is not an item in this store");
					return true;
				},
				_assertIsString: function(/*Object*/ something) {
					// summary: Throws an exception if the argument is not a string.
					// something: Object to check to determine if it is a string.
					if(!dojo.isString(something)) throw new Error(something + " is not a string");
					return true;
				},
				_getItem: function(args) {
					// summary: Overridable function to create a new item in this store based on the args map.
					var cls = this.itemClass;
					if(dojo.isString(cls)) {
						cls = dojo.getObject(this.itemClass);
					}
					return new cls({store: this, element: args.element, loaded: true}); 
				},
				/********************************/
				/**                            **/
				/**                            **/
				/**    		 Public  		   **/
				/**                            **/
				/**                            **/
				/********************************/
								
				getFeedValue: function( /*String*/ attribute, /*Value?*/ defaultValue) {
					var ret = defaultValue;
					this._assertIsString(attribute);
					var mapRule = this.getMapRule(attribute, this.attrMappings);
					// if mapRule is null here, then we couldn't find one in the map, 
					// so we can't proceed successfully
					if(mapRule) {
						ret = this.getValueByMapping(null, mapRule, defaultValue);
					}
					
					return ret;
				},
				getFeedValues: function( /*String*/ attribute) {
					var ret = [];
					this._assertIsString(attribute);
					var mapRule = this.getMapRule(attribute, this.attrMappings);
					// if mapRule is null here, then we couldn't find one in the map, 
					// so we can't proceed successfully
					if(mapRule) {
						ret = this.getValuesByMapping(null, mapRule);
					}
					
					return ret;
				},
				extractEmptyFeed: function() {
					var toClone = this._getNodeByXpath(this._feed, "//atom:feed").value;
					var feedDOM = toClone.cloneNode(false);
					// get all non-entry nodes
					var result = this._getNodesByXpath(toClone, "/atom:feed/*");
					var nodes = result.value;
					for(var i = 0; i < nodes.length; i++) {
						if(nodes[i].nodeName != "atom:entry") {
							feedDOM.appendChild(nodes[i].cloneNode(true));
						}
					}
					return feedDOM;
				},
				extractSingleEntryFeed: function(/* com.ibm.data.AtomEntryItem */ item ) {
					var ret = this.extractEmptyFeed();
					ret.appendChild(item.element.cloneNode(true));
					return ret;
				},
				extractMultipleEntryFeed: function(/* Array */ items ) {
					var ret = this.extractEmptyFeed();
					dojo.forEach(items, function(item){
						ret.appendChild(item.element.cloneNode(true));
					});
					return ret;
				},
				
				/********************************/
				/**                            **/
				/**                            **/
				/**   dojo.data.api.Identity   **/
				/**                            **/
				/**                            **/
				/********************************/				
				getIdentity: function(/* item */ item) {
					// summary: See dojo.data.api.Identity.getIdentity()
					// returns: The entry's unique identifier
					if(item._id) return item._id;
					// this is a common operation... so cache this on the item itself
					var attrs = this.getIdentityAttributes(item);
					var id = "";
					dojo.forEach(attrs, function(attr){
						id += this.getValue(item, attr, "");
					}, this);
					item._id = id;
					return id;
				},
				
				getIdentityAttributes: function(/* item */ item){
					//	summary:
					//		Returns an array of attribute names that are used to generate the identity. 
					//		For most stores, this is a single attribute, but for some complex stores
					//		such as RDB backed stores that use compound (multi-attribute) identifiers
					//		it can be more than one.  If the identity is not composed of attributes
					//		on the item, it will return null.  This function is intended to identify
					//		the attributes that comprise the identity so that so that during a render
					//		of all attributes, the UI can hide the the identity information if it 
					//		chooses.
					//	item:
					//		The item from the store from which to obtain the array of public attributes that 
					//		compose the identifier, if any.
					return ['id']; // Array
				},
			
				fetchItemByIdentity: function(/* object */ keywordArgs){
					//	summary:
					//		Given the identity of an item, this method returns the item that has 
					//		that identity through the onItem callback.  Conforming implementations 
					//		should return null if there is no item with the given identity.  
					//		Implementations of fetchItemByIdentity() may sometimes return an item 
					//		from a local cache and may sometimes fetch an item from a remote server, 
					//
					// 	keywordArgs:
					//		An anonymous object that defines the item to locate and callbacks to invoke when the 
					//		item has been located and load has completed.  The format of the object is as follows:
					//		{
					//			identity: string|object,
					//			onItem: Function,
					//			onError: Function,
					//			scope: object
					//		}
					//	The *identity* parameter.
					//		The identity parameter is the identity of the item you wish to locate and load
					//		This attribute is required.  It should be a string or an object that toString() 
					//		can be called on.
					//		
					//	The *onItem* parameter.
					//		Function(item)
					//		The onItem parameter is the callback to invoke when the item has been loaded.  It takes only one
					//		parameter, the item located, or null if none found.
					//
					//	The *onError* parameter.
					//		Function(error)
					//		The onError parameter is the callback to invoke when the item load encountered an error.  It takes only one
					//		parameter, the error object
					//
					//	The *scope* parameter.
					//		If a scope object is provided, all of the callback functions (onItem, 
					//		onError, etc) will be invoked in the context of the scope object.
					//		In the body of the callback function, the value of the "this"
					//		keyword will be the scope object.   If no scope object is provided,
					//		the callback functions will be called in the context of dojo.global.
					//		For example, onItem.call(scope, item, request) vs. 
					//		onItem.call(dojo.global, item, request)
					
					
					// not implemented by the AtomFeedStore since this supports generic Atom Feeds and therefore
					// can't generate a URL to get a particular item by its identity without additional knowledge
					// of how the feed URLs are created... however, this can be overridden by a application consuming
					// an instance of this store that does have knowledge of the particular feed URLs
					return false;
				},
				/********************************/
				/**                            **/
				/**                            **/
				/**     dojo.data.api.Read     **/
				/**                            **/
				/**                            **/
				/********************************/
				getValue: function(	/* com.ibm.data.AtomEntryItem */ item, 
						/* String */ attribute, 
						/* Value? */ defaultValue){
					var ret = null;
					if(this.hasAttribute(item, attribute)) {
						var mapRule = this.getMapRule(attribute, item.attrMappings);
						// if mapRule is null here, then we couldn't find one in the map, 
						// so we return the defaultValue 
						if(!mapRule) return ret;
						ret = this.getValueByMapping(item, mapRule, defaultValue);
					}
					if(!ret) ret = defaultValue;
					return ret;
				},
				
				getValues: function(/* com.ibm.data.AtomEntryItem */ item,
						/* String */ attribute){
					if(this.hasAttribute(item, attribute)) {
						var mapRule = this.getMapRule(attribute, item.attrMappings);
						// if mapRule is null here, then we couldn't find one in the map, 
						// so we return an empty list
						if(!mapRule) return [];
						return this.getValuesByMapping(item, mapRule);
					}
					return [];
				},
				_extractParameterizedMapKey: function( /*String*/ mapKey ) {
					// summary: Expands a mapKey and determines if it is a key to a parameterizable map rule.
					//		If it is, extract the parameters from the argument and return the base key name
					//		used to look up the correct map rule in this object's attrMappings without the parameter
					// 		values, and also return the parameters as an array of strings.  
					// 		If the mapKey is not the key of a parameterizable map rule, just return the key and a 
					// 		null parameter array.
					// returns: Object {key: stringMapKey, parameters: arrayOfParameterValues}
					if(mapKey.charAt(mapKey.length - 1) == '$') {
						var start = mapKey.indexOf('[');
						var end = mapKey.lastIndexOf(']');
						if(start > -1 && end > start) {
							var baseName = mapKey.substring(0, start) + "$";
							var parms = mapKey.substring(start + 1, end).split(',');
							return {key: baseName, parameters: parms};
						}
					}
					return {key: mapKey, parameters: null};
				},
				
				getMapRule: function( /*String*/ mapKey, /*Object*/map, /*Boolean?*/ multiValued ) {
					// summary: Takes a mapKey string that ends in '$' to key into this object's 
					// 		attrMappings, and then parameterizes the map it finds according
					// 		to the parameters found within the '[...]' block of the mapKey.
					// 		Example: A mapKey of 'localizedName[edward, tj]$' would lookup
					// 			the key 'localizedName$' in this.attrMappings.
					// 			The resulting map rule would be used as a template for the returned
					//			map rule.  The parameters used to parameterize the template would
					//			be ['edward', 'tj'] and would match the ${0} and ${1} parameters
					//			in the map rule respectively.
					// returns: The map rule specified by this mapKey after all parameters have been
					//			bound to their values as specified by the caller.
					var obj = this._extractParameterizedMapKey(mapKey);
					var rule = map[obj.key];
					
					if(!rule) return rule;
					// if this is not a parameterized map rule, just return the map rule as-is
					if(!obj.parameters) {
						rule._ruleKey = obj.key;
						return rule;
					}
					
					// otherwise, parameterize the map by using the array of parameters passed into the attribute
					// like this ->  attribute[parm1, parm2, parm3]$
					// parameterized attributes always end with $
					var expRule = new Object();
					for(var prop in rule) {
						if(dojo.isString(rule[prop])) {
							expRule[prop] = dojo.string.substitute(rule[prop], obj.parameters, function(part){
								return dojo.string.trim(part);
							});
						}
						else {
							expRule[prop] = rule[prop];
						}
					}
					expRule._parameters = obj.parameters;
					expRule._ruleKey = obj.key;
					expRule.multiValued = !!multiValued;
					return expRule;
				},
				
				getValuesByMapping: function( /* com.ibm.data.AtomEntryItem */ item, 
						/* Object */ mapping){
					// summary: Executes the correct query API using the mapping argument to
					//		retrieve the desired attribute value for the item as specified by the 
					// 		mapping.
					// mapping: A mapping object from this object's attrMappings
					var ret = null;
					var xpath = mapping.xpath;
					var type = mapping.type;
					var targetName = mapping.targetName;
					var context = this._feed;
					if(item) {
						this._assertIsItem(item);
						context = item.element;
					}
					if(type == "attr") {
						ret = this._getAttrsByXpath(context, xpath, targetName);
					}
					else {
						ret = this._getNodesByXpath(context, xpath, targetName);
					}
					
					if(!ret.found && item._backup) {
						// we didn't find any nodes matching the xpath query, and
						// this item has been copied from its original for modification,
						// so perhaps we explicitly removed it in the modified version for
						// performance reasons... so lets look it up in the original unmodified version						
						context = item._backup;
						if(type == "attr") {
							ret = this._getAttrsByXpath(context, xpath, targetName);
						}
						else {
							ret = this._getNodesByXpath(context, xpath, targetName);
						}
						
						// if ret.found is still false, then just return the defaultValue
						if(!ret.found) ret.value = new Array();
					}
					
					return ret.value;
				},
				
				getValueByMapping: function( /* com.ibm.data.AtomEntryItem */ item, 
						/* Object */ mapping, 
						/* Value? */ defaultValue){
					// summary: Executes the correct query API using the mapping argument to
					//		retrieve the desired attribute value for the item as specified by the 
					// 		mapping.
					// mapping: A mapping object from this object's attrMappings
					// defaultValue: The default value to return if no value exists for the mapping.
					//		If null is returned by the query, the defaultValue will be returned
					//		instead.
					var ret = null;
					var xpath = mapping.xpath;
					var type = mapping.type;
					var targetName = mapping.targetName;
					var context = this._feed;
					if(item) {
						this._assertIsItem(item);
						context = item.element;
					}
					if(type == "attr") {
						ret = this._getAttrByXpath(context, xpath, targetName);
					}
					else {
						ret = this._getNodeByXpath(context, xpath, targetName);
					}
					
					if(!ret.found && item && item._backup) {
						// we didn't find any nodes matching the xpath query, and
						// this item has been copied from its original for modification,
						// so perhaps we explicitly removed it in the modified version for
						// performance reasons... so lets look it up in the original unmodified version						
						context = item._backup;
						if(type == "attr") {
							ret = this._getAttrByXpath(context, xpath, targetName);
						}
						else {
							ret = this._getNodeByXpath(context, xpath, targetName);
						}
						
						// if ret.found is still false, then just return the defaultValue
						if(!ret.found && defaultValue) ret.value = defaultValue;
					}
					
					if(type == "attr" && ret.value && ret.value.length == 0) ret.value = null;
					
					return ret.value;
				},
				
				setValueByMapping: function( /* com.ibm.data.AtomEntryItem */ item, 
						/* Object */ mapping, 
						/* Value */ value){
					// summary: Executes the correct query API using the mapping argument to
					//		retrieve the desired attribute value for the item as specified by the 
					// 		mapping.
					// mapping: A mapping object from this object's attrMappings
					// value: The value to set that matches the mapping rule on the item.
					var xpath = mapping.xpath;
					var type = mapping.type;
					var targetName = mapping.targetName;
					var context = this._feed;
					var ret = false;
					if(item) {
						this._assertIsItem(item);
						context = item.element;
					}
					if(type == "attr") {
						ret = this._setAttrByXpath(context, xpath, targetName, value);
					}
					else {
						ret = this._setNodeByXpath(context, xpath, targetName, value);
					}
					
					if(!ret && mapping.setter) {
						return mapping.setter.apply(this, arguments);
					}
					return ret;
				},
				
				setValuesByMapping: function( /* com.ibm.data.AtomEntryItem */ item, 
						/* Object */ mapping, 
						/* Array */ values){
					// summary: Executes the correct query API using the mapping argument to
					//		retrieve the desired attribute value for the item as specified by the 
					// 		mapping.
					// mapping: A mapping object from this object's attrMappings
					// values: The value to set that matches the mapping rule on the item.
					var xpath = mapping.xpath;
					var type = mapping.type;
					var targetName = mapping.targetName;
					var context = this._feed;
					var ret = false;
					if(item) {
						this._assertIsItem(item);
						context = item.element;
					}
					if(type == "attr") {
						ret = this._setAttrsByXpath(context, xpath, targetName, value);
					}
					else {
						ret = this._setNodesByXpath(context, xpath, targetName, value);
					}
					
					if(!ret && mapping.setter) {
						return mapping.setter.apply(this, arguments);
					}					
					return ret;
				},
				
				getAttributes: function(/* com.ibm.data.AtomEntryItem? */ item){
					// summary: Gets the valid attributes for the given item if one is provided and
					//		returns an array of attribute names in String format.  If the item is
					//		null, it returns an array of attributes on the current feed that can
					//		be retrieved via the getFeedValue function.
					// item: Optional argument to get the list of attributes from.
					var attrs = [];
					if(item) {
						this._assertIsItem(item);
						for(var x in item.attrMappings) {
							attrs.push(x);
						}
					}
					else {
						for(var x in this.attrMappings) {
							attrs.push(x);
						}
					}
					
					return attrs;
				},
				
				hasAttribute: function(	/* com.ibm.data.AtomEntryItem */ item,
							/* String */ attribute){
					// summary: Returns true if the attribute is a valid attribute on the given item,
					//		false otherwise.  This does not check if the attribute value on the item
					//		is null or empty, but just checks if the item supports that attribute.
					// item: Item to check if the attribute is valid
					// attribute: Name of the attribute to check
					this._assertIsItem(item);
					this._assertIsString(attribute);
					if(attribute.charAt(attribute.length - 1) == '$') {
						// this looks like an attribute whose map rule is parameterizable
						// so lets defer checking if its valid until later so we don't
						// duplicate any string processing
						return true;
					}
					if(item.attrMappings[attribute]) return true;
					else return false;
				},
				
				containsValue: function(/* com.ibm.data.AtomEntryItem */ item,
							/* String */ attribute, 
							/* Object */ value){
					// summary: Returns true if the value of the attribute on the given item is
					//		equal to the value argument, false otherwise.  If the attribute is a
					//		multi-valued attribute, it will check all the values of the attribute.
					// item: Item to check if the attribute is valid
					// attribute: Name of the attribute to check
					// value: Value to compare the actual value(s) to.
					var values = this.getValues(item, attribute);
					for(var i = 0; i < values.length; i++) {
						if(values[i] == value) return true;
					}
					return false;
				},
				
				isItem: function(/* Object */ something){
					// summary: Returns true if the argument is a valid item in this store, false otherwise.
					// something: Object to check to determine if it is an item in this store.
					return something.store == this && something.element && !something._isDeleted;
				},
				
				isItemLoaded: function(/* Object */ something) {
					// summary: All valid items in this data store are loaded all of the time as there
					//		is no support currently for stubs.  Therefore, this is effectively the same
					//		as isItem.
					return this.isItem(something) && something.loaded;
				},
				
				loadItem: function(/* Object */ keywordArgs){
					// summary: All valid items in this data store are loaded all of the time as there
					//		is no support currently for stubs.  Therefore, this function is a no-op. 
				},
				getResultSize: function(/*DOMDoc*/ doc, /*Request*/ request, /*Array*/ items) {
					// summary: Gets the total number of items retrieved by the query, which is not
					//		necessarily the number of items returned to the callbacks to fetch.
					//		This can be used for paging purposes to get the total number of items
					//		on the server that match the query, where subsequent fetch requests can
					//		be made to retrieve additional pages.
					return items.length;
				},
				processFetchedItems: function(/*Array*/ items, /*Request*/ request) {
					// summary: Extension point for descendants or consumers of this store to preprocess
					// 		the list of items that the store returns from a fetch call.  Allows a store
					// 		to filter the list or implement caching techniques on the client, or sort
					// 		the items, or anything else.
					// items: Array items of this data store found in the response of a fetch call
					// returns: Array items of this data store after processing
					return items;
				},		
				processResponse: function(/*DOMDoc*/ xmlDoc, /*Request*/ request) {
					// summary: Extension point for descendants or consumers of this store to handle
					//		responses from server requests for data.  Most subclasses can leave this
					// 		function as-is, but if special handling is required that cannot be done
					// 		with other extension points, this can be overridden as well.
					// 		Must call onBegin, onItem, and onComplete callbacks correctly as 
					// 		specified by dojo.data.api.Read.  The onError callback is handled elsewhere.
					// xmlDoc: DOMDoc of the response from an IO request
					// request: Request used to fetch the result
					if(request.aborted) return;
					var composite = this._parseFeed(request, xmlDoc); 
					var items = composite.items;
					this._feed = composite.root;
					items = this.processFetchedItems(items, request);
					if(request.onBegin) request.onBegin.call(request.scope, this.getResultSize(composite.root, request, items), request);
					if(request.onItem) {
						for(var i = 0; i < items.length; i++) {
							if(request.aborted) return;
							request.onItem.call(request.scope, items[i], request);
						}
					}
					if(request.onComplete) {
						// call onComplete with items array if onItem wasn't specified, otherwise
						// call it with null
						if(request.aborted) return;
						if(!request.onItem) request.onComplete.call(request.scope, items, request);
						else request.onComplete.call(request.scope, null, request);
					}
				},
				fetch: function( keywordArgs ) {
					//    summary:
			        //        Given a query and set of defined options, such as a start and count of items to return,
			        //        this method executes the query and makes the results available as data items.
			        //        The format and expectations of stores is that they operate in a generally asynchronous 
			        //        manner, therefore callbacks are always used to return items located by the fetch parameters.
			        //
			        //    description:
			        //        A Request object will always be returned and is returned immediately.
			        //        The basic request is nothing more than the keyword args passed to fetch and 
			        //        an additional function attached, abort().  The returned request object may then be used 
			        //        to cancel a fetch.  All data items returns are passed through the callbacks defined in the 
			        //        fetch parameters and are not present on the 'request' object.
			        //
			        //        This does not mean that custom stores can not add methods and properties to the request object
			        //        returned, only that the API does not require it.  For more info about the Request API, 
			        //        see dojo.data.api.Request
			        //
			        //    keywordArgs:
			        //        The keywordArgs parameter may either be an instance of 
			        //        conforming to dojo.data.api.Request or may be a simple anonymous object
			        //        that may contain any of the following:
			        //        { 
			        //            query: query-string or query-object,
			        //            queryOptions: object,
			        //            onBegin: Function,
			        //            onItem: Function,
			        //            onComplete: Function,
			        //            onError: Function,
			        //            scope: object,
			        //            start: int
			        //            count: int
			        //            sort: array
			        //        }
			        //        All implementations should accept keywordArgs objects with any of
			        //        the 9 standard properties: query, onBegin, onItem, onComplete, onError 
			        //        scope, sort, start, and count.  Some implementations may accept additional 
			        //        properties in the keywordArgs object as valid parameters, such as 
			        //        {includeOutliers:true}.         
			        //
					//	The *query* parameter.
					//        The query may be optional in some data store implementations.
					//        The dojo.data.api.Read API does not specify the syntax or semantics
					//        of the query itself -- each different data store implementation
					//        may have its own notion of what a query should look like.
					//        However, as of dojo 0.9, 1.0, and 1.1, all the provided datastores in dojo.data
					//        and dojox.data support an object structure query, where the object is a set of 
					//        name/value parameters such as { attrFoo: valueBar, attrFoo1: valueBar1}.  Most of the
					//        dijit widgets, such as ComboBox assume this to be the case when working with a datastore 
					//        when they dynamically update the query.  Therefore, for maximum compatibility with dijit 
					//        widgets the recommended query parameter is a key/value object.  That does not mean that the
					//        the datastore may not take alternative query forms, such as a simple string, a Date, a number, 
					//        or a mix of such.  Ultimately, The dojo.data.api.Read API is agnostic about what the query 
					//        format.  
					//        Further note:  In general for query objects that accept strings as attribute 
					//        value matches, the store should also support basic filtering capability, such as * 
					//        (match any character) and ? (match single character).  An example query that is a query object
					//        would be like: { attrFoo: "value*"}.  Which generally means match all items where they have 
					//        an attribute named attrFoo, with a value that starts with 'value'.
			        //
			        //    The *queryOptions* parameter
			        //        The queryOptions parameter is an optional parameter used to specify optiosn that may modify
			        //        the query in some fashion, such as doing a case insensitive search, or doing a deep search
			        //        where all items in a hierarchical representation of data are scanned instead of just the root 
			        //        items.  It currently defines two options that all datastores should attempt to honor if possible:
			        //        {
			        //            ignoreCase: boolean, //Whether or not the query should match case sensitively or not.  Default behaviour is false.
			        //            deep: boolean     //Whether or not a fetch should do a deep search of items and all child 
			        //                            //items instead of just root-level items in a datastore.  Default is false.
			        //        }
			        //
			        //    The *onBegin* parameter.
			        //        function(size, request);
			        //        If an onBegin callback function is provided, the callback function
			        //        will be called just once, before the first onItem callback is called.
			        //        The onBegin callback function will be passed two arguments, the
			        //        the total number of items identified and the Request object.  If the total number is
			        //        unknown, then size will be -1.  Note that size is not necessarily the size of the 
			        //        collection of items returned from the query, as the request may have specified to return only a 
			        //        subset of the total set of items through the use of the start and count parameters.
			        //
			        //    The *onItem* parameter.
			        //        function(item, request);
			        //        If an onItem callback function is provided, the callback function
			        //        will be called as each item in the result is received. The callback 
			        //        function will be passed two arguments: the item itself, and the
			        //        Request object.
			        //
			        //    The *onComplete* parameter.
			        //        function(items, request);
			        //
			        //        If an onComplete callback function is provided, the callback function
			        //        will be called just once, after the last onItem callback is called.
			        //        Note that if the onItem callback is not present, then onComplete will be passed
			        //        an array containing all items which matched the query and the request object.  
			        //        If the onItem callback is present, then onComplete is called as: 
			        //        onComplete(null, request).
			        //
			        //    The *onError* parameter.
			        //        function(errorData, request); 
			        //        If an onError callback function is provided, the callback function
			        //        will be called if there is any sort of error while attempting to
			        //        execute the query.
			        //        The onError callback function will be passed two arguments:
			        //        an Error object and the Request object.
			        //
			        //    The *scope* parameter.
			        //        If a scope object is provided, all of the callback functions (onItem, 
			        //        onComplete, onError, etc) will be invoked in the context of the scope
			        //        object.  In the body of the callback function, the value of the "this"
			        //        keyword will be the scope object.   If no scope object is provided,
			        //        the callback functions will be called in the context of dojo.global().  
			        //        For example, onItem.call(scope, item, request) vs. 
			        //        onItem.call(dojo.global(), item, request)
			        //
			        //    The *start* parameter.
			        //        If a start parameter is specified, this is a indication to the datastore to 
			        //        only start returning items once the start number of items have been located and
			        //        skipped.  When this parameter is paired withh 'count', the store should be able
			        //        to page across queries with millions of hits by only returning subsets of the 
			        //        hits for each query
			        //
			        //    The *count* parameter.
			        //        If a count parameter is specified, this is a indication to the datastore to 
			        //        only return up to that many items.  This allows a fetch call that may have 
			        //        millions of item matches to be paired down to something reasonable.  
			        //
			        //    The *sort* parameter.
			        //        If a sort parameter is specified, this is a indication to the datastore to 
			        //        sort the items in some manner before returning the items.  The array is an array of 
			        //        javascript objects that must conform to the following format to be applied to the
			        //        fetching of items:
			        //        {
			        //            attribute: attribute || attribute-name-string,
			        //            descending: true|false;   // Optional.  Default is false.
			        //        }
			        //        Note that when comparing attributes, if an item contains no value for the attribute
			        //        (undefined), then it the default ascending sort logic should push it to the bottom 
			        //        of the list.  In the descending order case, it such items should appear at the top of the list.
			        // 
			        //    returns:
			        //        The fetch() method will return a javascript object conforming to the API
			        //        defined in dojo.data.api.Request.  In general, it will be the keywordArgs
			        //        object returned with the required functions in Request.js attached.
			        //        Its general purpose is to provide a convenient way for a caller to abort an
			        //        ongoing fetch.  
			        // 
			        //        The Request object may also have additional properties when it is returned
			        //        such as request.store property, which is a pointer to the datastore object that 
			        //        fetch() is a method of.
			        //
			        //    exceptions:
			        //        Throws an exception if the query is not valid, or if the query
			        //        is required but was not supplied.
					if(!keywordArgs) keywordArgs = {};
			        var me = this;
					keywordArgs.aborted = false;
					if(!keywordArgs.scope) keywordArgs.scope = dojo.global;
					var preventCache = false;
					if(keywordArgs.queryOptions && keywordArgs.queryOptions.preventCache) {
						preventCache = true; 
					}
					var url = this._buildUrl(keywordArgs, this.url);
					keywordArgs.url = url;
					var loadHandler = function(response, ioArgs) {
						if(keywordArgs.aborted) return;
						if(dojo.isIE) response = com.ibm.domUtilities.docFromString(response);
						me.doc = response;
						me.processResponse(response, keywordArgs);
					};
					var errorHandler = function(error, ioArgs) {
						if(keywordArgs.onError) keywordArgs.onError.call(keywordArgs.scope, error, keywordArgs);
					};
					var args = {
						preventCache: preventCache,
						content: {},
						url: url,
						handleAs: "xml"
					}
					if(keywordArgs.queryOptions && keywordArgs.queryOptions.timeout) {
						args.timeout = keywordArgs.queryOptions.timeout;
					}
					else if(this.timeout) {
						args.timeout = this.timeout;
					}
					if(dojo.isIE) {
						args.handleAs = "text";
						args.content["ibm.web2.contentType"] = "text/xml";
					}
					
					var handle = null;
					keywordArgs.abort = function() {
						keywordArgs.aborted = true;
						handle.cancel();
					};
					args = this.modifyRequestArgs(args, keywordArgs);
					
					handle = dojo.xhrGet(args);
					handle.addCallback(loadHandler);
					handle.addErrback(errorHandler);

					this._lastRequest = keywordArgs;
					return keywordArgs;
				},
				modifyRequestArgs: function(ioArgs, request) {
					// summary: Allows modification to request arguments before sending a request
					//		to the server.  Subclasses may override this to modify arguments
					//		like setting headers, manipulating the url, overriding a handleAs argument,
					//		or anything else.  Returns the modified request args.
					// ioArgs: dojo.__XhrArgs request args to be sent to the server
					// request: dojo.data.api.Request object
					// returns: dojo.__XhrArgs modified request arguments
					return ioArgs;
				},
				_queryUrlToObject: function(queryStr) {
					if(!queryStr || queryStr.length == 0) return {};
					var start = queryStr.indexOf("?");
					var str = queryStr;
					if(start > -1 && (start < str.length - 1)) { 
						// extract only the query part of the queryStr URL
						str = queryStr.substring(start + 1);
					}
					return dojo.queryToObject(str);
				},
				_prepareQuery: function(keywordArgs) {
					var query = keywordArgs.query;
					if(!query) keywordArgs.query = {};
					else if(dojo.isString(query)) {
						keywordArgs.query = this._queryUrlToObject(query);
					}
					return this.prepareQuery(keywordArgs);
				},
				prepareQuery: function(keywordArgs) {
					// summary: User overridable function to modify the keywordArgs object
					// 		used to fetch results from the back end after the keywordArgs.query
					//		property has been normalized to an object map but before any other
					//		processing has taken place to build the URL.  This can be used to
					//		extract other parts of the keywordArgs map to add properties to the
					//		query object that are dependent on the back end implementation.  One
					//		example includes extracting the keywordArgs.sort parameters and appending
					//		appropriate properties to the keywordArgs.query property that will end
					//		up being built into the generated URL to the server.
					// returns: Object Modified keywordArgs object.
					return keywordArgs;
				},
				_buildUrl: function(keywordArgs, baseUrl) {
					// summary: Builds a url string from this store's base url and the
					// 		query argument.
					// keywordArgs: Object
					//		A request object map as sent to the fetch function
					// returns: String The constructed url.
					var ret = "";
					var keywordArgs = this._prepareQuery(keywordArgs);
					var queryPart = dojo.objectToQuery(keywordArgs.query);
					if(baseUrl.indexOf("?") > -1) {
						ret = baseUrl + "&" + queryPart; // String
					}
					else ret = baseUrl + "?" + queryPart; // String
					
					return (this.modifyUrl(keywordArgs, ret));
				},
				modifyUrl: function(keywordArgs, url) {
					return url;
				},
				_parseFeed: function(request, xmlDoc) {
					var items = new Array();
					var root = null;
					var result = this._getNodeByXpath(xmlDoc, "/atom:feed");
					if(!result.found) {
						result = this._getNodeByXpath(xmlDoc, "/atom:entry");
						if(!result.found) {
							// the root is not an atom:feed or atom:entry
							throw new Error("Illegal atom feed format: the root element is not an ATOM feed or entry element.");
						}
						else {
							// the root is an atom:entry element, so there's only one item
							root = result.value;
							var query = this._queryUrlToObject(request.url);
							items.push(this._getItem({element: root, query: query}));
						}
					}
					else {
						// the root is an atom:feed element
						root = result.value;
						var query = this._queryUrlToObject(request.url);
						result = this._getNodesByXpath(root ? root : xmlDoc, "./atom:entry");
						if(result.found) {
							var nodes = result.value;
							for(var i = 0; i < nodes.length; i++) {
								items.push(this._getItem({element: nodes[i], query: query}));
							}
						}
					}
					
					return {items: items, root: root};
				},
				
				getFeatures: function () {
					//	summary:
					//		Return supported data APIs
					//	returns:
					//		Map of supported data APIs with keys as API classes and values as true/false to indicate support
					//		by this store.
					return this._features; //returns Map
				},
				
				close: function(/*dojo.data.api.Request || keywordArgs || null */ request){
					if(request && request.abort) request.abort();
				},
				
				getLabel: function(/* com.ibm.data.AtomEntryItem */ item){
					return this.getValue(item, "title");
				},
				
				getLabelAttributes: function(/* com.ibm.data.AtomEntryItem */ item){
					return ['title'];
				},
				
				/********************************/
				/**                            **/
				/**                            **/
				/**    dojo.data.api.Write     **/
				/**                            **/
				/**                            **/
				/********************************/
				newItem: function(/* Object? */ keywordArgs, /*Object?*/ parentInfo){
					// summary: Must be overridden by stores that extend this but support writes,
					//		like ATOM services that support APP.
					return null;
				},
				
				deleteItem: function(/* com.ibm.data.AtomEntryItem */ item){
					// summary: Deletes an item from the store.  Does not persist to the server until save is called.
					// item: The item to delete.
					// returns: Boolean true if successful, false otherwise.							
					if(!this._deletedItems) this._deletedItems = new Array();
					item.backup();
					this._deletedItems.push(item);
					// storing identity into item since we need it later and can't access it through store APIs
					// after it's been marked as deleted
					item.id = this.getIdentity(item);
					item._isDeleted = true;
					// we are assuming that order does not matter, so we don't have to save the item's
					// current position in the list of entries in this feed
					return true;
				},
				
				setValue: function(	/* com.ibm.data.AtomEntryItem */ item, 
						/* String */ attribute,
						/* almost anything */ value){
					var ret = false;
					var oldValue = null;
					if(this.hasAttribute(item, attribute)) {
						var mapRule = this.getMapRule(attribute, item.attrMappings);
						// if mapRule is null here, then we didn't find one
						// in the map, so we can't proceed successfully
						if(mapRule) {
							item.backup();
							oldValue = this.getValueByMapping(item, mapRule);
							ret = this.setValueByMapping(item, mapRule, value);
							if(ret) {
								this._addDirtyItem(item);
								item.logWrite({attribute: attribute, value: value});
							}
						}
					}
					else {
						throw new Error(attribute + " is not an attribute of any item in this store");
					}
					return {success: ret, oldValue: oldValue, newValue: value};
				},
				
				setValues: function(/* com.ibm.data.AtomEntryItem */ item,
						/* String */ attribute, 
						/* array */ values){
					var ret = false;
					var oldValue = null;
					if(this.hasAttribute(item, attribute)) {
						var mapRule = this.getMapRule(attribute, item.attrMappings, true);
						// if mapRule is null here, then we didn't find one
						// in the map, so we can't proceed successfully
						if(mapRule) {
							item.backup();
							oldValue = this.getValueByMapping(item, mapRule);
							ret = this.setValuesByMapping(item, mapRule, values);
							if(ret) {
								this._addDirtyItem(item);
								item.logWrite({attribute: attribute, values: values});
							}
						}
					}
					else {
						throw new Error(attribute + " is not an attribute of any item in this store");
					}
					return {success: ret, oldValue: oldValue, newValue: values};
				},
				
				unsetAttribute: function(/* com.ibm.data.AtomEntryItem */ item, 
								/* String */ attribute){
					var ret = false;
					var oldValue = null;
					var value = null;
					if(this.hasAttribute(item, attribute)) {
						var mapRule = this.getMapRule(attribute, item.attrMappings);
						// if mapRule is null here, then we didn't find one
						// in the map, so we can't proceed successfully
						if(mapRule) {
							item.backup();
							oldValue = this.getValueByMapping(item, mapRule);
							if(mapRule.type == "attr") {
								ret = this.setValueByMapping(item, mapRule, "");
								value = "";
							}
							else {
								// it's a node or node property
								if(mapRule.targetName) ret = this.setValueByMapping(item, mapRule, null);
								// if targetName, then it's a property
								else if(oldValue) {
									// if no targetName, then it's a node... so remove the node				
									oldValue.parentNode.removeChild(oldValue);
									ret = true;
								}
							}
							
							if(ret) {
								this._addDirtyItem(item);
								item.logWrite({attribute: attribute, value: value});
							}
						}
					}
					return {success: ret, oldValue: oldValue, newValue: value};
				},
				
				save: function(/* Object */ keywordArgs){
					var it = null;
					for(var d = 0; d < this._deletedItems.length; d++) {
						it = this._deletedItems[d];
						it.persist();
						delete it.element;
					}
					for(var i = 0; i < this._dirtyItems.length; i++) {
						this._dirtyItems[i].persist();
					}
					for(var i = 0; i < this._newItems.length; i++) {
						this._newItems[i].persist();
					}
					
					// the persist operation of the above items set some values on their backups
					// which may have updated the dirtyItems list... by putting this below here
					// we're removing those immediately if they are here 
					
					// instead of just reinitializing these pointers,
					// splice these so that we can keep the same array references forever in case others have
					// pointers to these still (so that they won't break)
					this._newItems.splice(0, this._newItems.length);
					this._dirtyItems.splice(0, this._dirtyItems.length);
					this._deletedItems.splice(0, this._deletedItems.length);
				},
				_addDirtyItem: function(/* com.ibm.portal.data.ContentModelItem */ item) {
					if(item._isDirty) return;
					item._isDirty = true;
					
					// need to check this
					for(var i = 0; i < this._dirtyItems.length; i++) {
						if(this._dirtyItems[i] == item) return;
					}
					
					this._dirtyItems.push(item);
				},
				
				revert: function(){
					var it = null;
					for(var d = 0; d < this._deletedItems.length; d++) {
						it = this._deletedItems[d];
						it.restore();
						delete item._isDeleted;
					}
					for(var i = 0; i < this._dirtyItems.length; i++) {
						this._dirtyItems[i].restore();
					}
					this._dirtyItems = new Array();
					this._deletedItems = new Array();
				},
				
				isDirty: function(/* com.ibm.data.AtomEntryItem? */ item){
					// summary: Determines whether or not an item is dirty or if this store in general has dirty items.
					//		If item is specified, it returns true if that item is dirty, and false otherwise.
					//		If no item is specified, it returns an array of all the dirty items in this store (modified,
					//		deleted, and new), and false if there are none.
					// item: Optional argument to check if a particular item is dirty.  Leaving this null
					if(item && this._assertIsItem(item)) return item._isDirty;
					else {
						var array = this._dirtyItems.concat(this._deletedItems).concat(this._newItems);
						if(!array || array.length == 0) return false;
						else return array;
					}
				}
			}
);	


dojo.declare( "com.ibm.data.AtomEntryItem",
			com.ibm.data.XpathHelper, 
			{
				namespaces: dojo.mixin({}, com.ibm.data.AtomFeedStore.prototype.namespaces),
		        // attrMappings: This maps attribute names to a query object consisting of an 
		        // 		xpath expression used to find the relevant node(s), an attr name, and a type.
		        // 		The map contains key-value pairs in this format:
		        //		{
		        //			attributeName: {xpath: "./this/is/the/xpath/expr", targetName: "attrName"|null, type: "node"|"attr"}  
		        //		}
		        //		The xpath expression is resolved from the context of the atom:entry node 
		        // 		assigned to this atom feed entry item.  The attr property is an optional property
		        //		used to specify whether to get an object property of the returned DOM node object or 
		        // 		an attribute of the returned DOM node.  The type specifies what type the lookup
		        //		will perform in conjunction with the attr.  If the lookup is an attribute of the
		        // 		DOM node, it will attempt to resolve any namespacing it encounters when looking
		        // 		up the attribute.  The following explains the possible combinations of lookup 
		        // 		mechanisms.
		        // 		
		        // 		xpath: "./node", targetName: "textContent", type: "node" = node["textContent"]
		        //		xpath: "./node", targetName: "href", type: "attr" = node.getAttribute("href")
		        // 		xpath: "./node", targetName: "textContent", type: "node" = cross browser node["textContent"] property
		        // 		xpath: "./node", targetName: null, type: "node" = node
		        //  	xpath: "./node", targetName: null, type: "attr" = invalid query, requires the attribute name
		        //
		        //		Map rules can be parameterized by substituting parameters specified by the caller into the
		        //		rule template.  Parameterized map rules MUST end with a $ character to mark them as such.
		        // 		Example:
		        //	 		pAttribute$: {xpath: "./${0}['${1}']", targetName: "${2}", type: "node", customRuleProperty: "${1}"}
		        //
		        //		Callers supply a comma-separated list of parameter values to be bound to subsequent numerical
		        //		parameter keys in the template respectively surrounded by brackets immediately following the
		        //		name of the attribute key but before the $ character.
		        //		Example:
		        // 			To request the value of pAttribute$ with values set for the parameters, the caller would 
		        // 			use code like this -
		        //		store.getValue(item, "pAttribute[div, id, nodeValue]$");
		        //
		        attrMappings: dojo.mixin({}, com.ibm.data.AtomFeedStore.prototype.attrMappings, { 		
					subtitle: {xpath: "./atom:subtitle", targetName: "textContent", type: "node", setter: 
						function(item, rule, value){
							var elem = this._createNSElement(item.element.ownerDocument, "atom:subtitle");
							this._setNodeProp(elem, rule.targetName, value);
							item.element.appendChild(elem);
							return true;
						}
					},
					generator: {xpath: "./atom:generator", targetName: "textContent", type: "node", setter: 
						function(item, rule, value){
							var elem = this._createNSElement(item.element.ownerDocument, "atom:generator");
							this._setNodeProp(elem, rule.targetName, value);
							item.element.appendChild(elem);
							return true;
						}
					},
					icon: {xpath: "./atom:icon", targetName: "textContent", type: "node", setter: 
						function(item, rule, value){
							var elem = this._createNSElement(item.element.ownerDocument, "atom:icon");
							this._setNodeProp(elem, rule.targetName, value);
							item.element.appendChild(elem);
							return true;
						}
					},
					logo: {xpath: "./atom:logo", targetName: "textContent", type: "node", setter: 
						function(item, rule, value){
							var elem = this._createNSElement(item.element.ownerDocument, "atom:logo");
							this._setNodeProp(elem, rule.targetName, value);
							item.element.appendChild(elem);
							return true;
						}
					}
				}), 
				
				constructor: function( /*Map*/ args ) {
					dojo.mixin(this, args);
					this._writeLog = new Array();
				},
				toString: function() {
					return "<" + this.__getClassName() + ">";
				},
				_onCreate: function() {
					// summary: Called internally to indicate an item has been created.  Should
					//		be called immediately on creation for stores that do not save to
					//		a backend server, but should be called on a valid server response for
					// 		an item that was created and saved to the server successfully.  This
					// 		calls onCreate to notify listeners of the event and can therefore be
					// 		overriden if custom logic needs to be applied to handle cases where
					// 		other conditions need to be satisfied before the onCreate event is called.
					this.onCreate();
				},
				onCreate: function() {
					// summary: Called when this item is created.  This callback is reserved
					// 		for sending notifications when a new item stub has been created
					// 		on the actual server.  This will be called when a new item has been
					//		created, saved to the server, and the server responds back with
					//		a verification of the created item.  Some stores may not have any
					// 		notion of creating items on the server and should call this immediately
					// 		when the item is created on the client, while others actually defer 
					// 		the full creation of a new item from the newItem call until after the 
					// 		save operation has persisted to the backend.  This allows interested 
					// 		parties to get notified when an item they've created is actually saved
					// 		on the server.  This is especially useful if the server has to generate
					//		something like a unique ID for the item which is not available on the
					//		item until the server response comes back.
				},
				_makeModifiable: function() {
					// summary: Modifies the element of this item to become modifiable
					//		for writing back to the server.  Subclasses can override this
					//		to do things like prune an item to only include necessary information
					//		for updates and nothing more.  This is called by backup once after
					//		backing up the original element first.  After this returns,
					//		this item's element may have been modified.  Any queries against
					//		this item should now include logic to check the backup copy as well
					//		if a query doesn't return anything as it could have been deleted by
					//		this function.  Care should be taken to ensure that the query result
					//		specifically detects if nothing was found or if the actual value was
					//		null or empty.
				},
				backup: function() {
					// summary: Creates a single backup copy of this item on the client for
					//		later restoration if necessary.  Calling this function multiple
					//		times before restore() or persist() is called on this item will do nothing
					//		after the initial backup, effectively maintaining only the first
					//		version of the item before any changes were made.
					if(!this._backup) {
						this._backup = this.element.cloneNode(true);
						this._makeModifiable();
						this._logEnabled = true;
						return true;
					}
					return false;
				},
				restore: function() {
					// summary: Restores the single backup copy of this item on the client,
					//		erasing all modifications made since backup() was called.
					if(!this._backup) {
						dojo.place(this._backup, this.element, "before");
						this.element.parentNode.removeChild(this.element);
						delete this.element;
						this.element = this._backup;
						this.backup = null;
						this._writeLog.splice(0, this._writeLog.length);
						return true;
					}
					return false;
				},
				persist: function() {
					// summary: Persists the changes made to this item since the backup() was
					// 		called.  After this is called, there is no way to restore the backup
					//		as it is erased completely.
					this._writeLogToBackup();
					this._isDirty = false;
					delete this._backup;
				},
				logWrite: function(map) {
					// summary: Logs write operations to this item so that they can later
					//		be repeated to the backup during persistence.
					if(this._logEnabled) this._writeLog.push(map);
				},
				_writeLogToBackup: function() {
					// summary: Repeates the write log for this item to the original backup
					// 		node.  Used mainly for persisting changes to support a 2-phase
					//		write operation (write, commit).
					if(this._backup) {
						this.element = this._backup;
						this._logEnabled = false;
						for(var i = 0; i < this._writeLog.length; i++) {
							var op = this._writeLog[i];
							if(op.values) {
								this.store.setValues(this, op.attribute, op.values);
							}
							else {
								this.store.setValue(this, op.attribute, op.value);
							}
						}
						this._writeLog.splice(0, this._writeLog.length);
					}
				}
			}
);


dojo.declare( "com.ibm.data.AtomPersonConstruct",
			com.ibm.data._XmlConstruct,
			{
				// summary: Construct for retrieving appropriate information
				// 		from an Atom Person Construct as defined in 
				// 		http://tools.ietf.org/html/rfc4287#section-3.2.
				
				namespaces: dojo.mixin({}, com.ibm.data.AtomFeedStore.prototype.namespaces),
		        
				constructor: function(/*DOMNode*/ root) {
					this.root = root;
				},
				getName: function() {
					// summary: Gets the name specified by this Atom person construct.
					// returns: String
					var result = this._getNodeByXpath(this.root, "./atom:name", "textContent");
					if(!result.found) result.value = "";
					return result.value;
				},
				getEmail: function() {
					// summary: Gets the email specified by this Atom person construct.
					// returns: String
					var result = this._getNodeByXpath(this.root, "./atom:email", "textContent");
					if(!result.found) result.value = "";
					return result.value;
				},
				getURI: function() {
					// summary: Gets the name specified by this Atom person construct.
					// returns: String
					var result = this._getNodeByXpath(this.root, "./atom:uri", "textContent");
					if(!result.found) result.value = "";
					return result.value;
				},
				toString: function() {
					// summary: Gets the name string specified by this Atom person construct.
					// returns: String
					return this.getName();
				}
			}
);

dojo.declare( "com.ibm.data.AtomDateConstruct",
			com.ibm.data._XmlConstruct,
			{
				// summary: Construct for retrieving javascript-appropriate information
				// 		from an Atom Date Construct as defined in 
				// 		http://tools.ietf.org/html/rfc4287#section-3.3.
				
				namespaces: dojo.mixin({}, com.ibm.data.AtomFeedStore.prototype.namespaces),
		        
				// Supports date strings in the following formats - 
				//		2003-12-13T18:30:02Z
				//		2003-12-13T18:30:02.25Z
				//		2003-12-13T18:30:02+01:00
				//		2003-12-13T18:30:02.25+01:00
				
				constructor: function(/*DOMNode*/ root) {
					this.root = root;
				},
				getDate: function() {
					// summary: Parses and retrieves a javascript Date object from a date string
					//		specified in an Atom feed according to the allowable string formats
					//		by the Atom spec itself (http://tools.ietf.org/html/rfc4287#section-3.3)
					// returns: Date
					if(this.date) return this.date;
					
					var d = this._getNodeProp(this.root, "textContent");
					if(!d) return null;
					
					this.date = dojo.date.stamp.fromISOString(d);
					return this.date;
				},
				getTime: function() {
					// summary: Gets the time specified by this Atom date construct.
					// returns: int
					this.getDate();
					if(this.date) return this.date.getTime();
					
					return null;
				},
				toString: function() {
					// summary: Gets a string representation of the date specified by this
					//		Atom data construct.
					this.getDate();
					if(this.date) return this.date.toString();
					return "";
				}
			}
);

}

if(!dojo._hasResource["com.ibm.data.OpenSearchFeedStore"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.data.OpenSearchFeedStore"] = true;
dojo.provide( "com.ibm.data.OpenSearchFeedStore" );

dojo.require( "com.ibm.data.AtomFeedStore" );
dojo.require( "dojox.data.dom" );

dojo.declare( "com.ibm.data.OpenSearchFeedStore",
			com.ibm.data.AtomFeedStore,
			{
				// namespaces: Map
				//		Map of namespaces used by the MashupHub feeds
				namespaces: dojo.mixin({}, com.ibm.data.AtomFeedStore.prototype.namespaces, {
		            "xhtml" : "http://www.w3.org/1999/xhtml",
		            "os" : "http://a9.com/-/spec/opensearch/1.1/"
		        }),
		        
		        attrMappings: dojo.mixin({}, com.ibm.data.AtomFeedStore.prototype.attrMappings, {
					nextLink: {xpath: "./atom:link[@rel='next']", targetName: "href", type: "attr"},
					startIndex: {xpath: "./os:startIndex", targetName: "textContent", type: "node"},
					itemsPerPage: {xpath: "./os:itemsPerPage", targetName: "textContent", type: "node"},
					totalResults: {xpath: "./os:totalResults", targetName: "textContent", type: "node"},
					query: {xpath: "./os:Query", type: "OpenSearchQueryConstruct"}
				}),
				
				// itemClass: String the class used to represent items of this store
				itemClass: "com.ibm.data.OpenSearchFeedItem",
				
				constructor: function( /*Map*/ args ) {
					// summary: Creates a new instance of a com.ibm.portal.data._PortalModelStore
					// args: Map
					//		The args map will be used to replace any default values of this store with the
					//		values specified in the args map.
					this._features['dojo.data.api.Identity'] = true;
				},
				
				handleConstructs: function(/*DOMNode*/ node, /*String*/ prop) {
					switch(prop) {
						case "OpenSearchQueryConstruct": return new com.ibm.data.OpenSearchQueryConstruct(node);
						default: return this.inherited(arguments);
					}
				},
				
				getResultSize: function(/*DOMDoc*/ doc, /*Request*/ request, /*Array*/ items) {
					// summary: Gets the total number of items retrieved by the query, which is not
					//		necessarily the number of items returned to the callbacks to fetch.
					//		This can be used for paging purposes to get the total number of items
					//		on the server that match the query, where subsequent fetch requests can
					//		be made to retrieve additional pages.
					var rule = this.attrMappings.totalResults;
					var ret = null;
					if(rule.type == "attr") ret = this._getAttrByXpath(doc, rule.xpath, rule.targetName);
					else ret = this._getNodeByXpath(doc, rule.xpath, rule.targetName);
					// if we found total results, return it as a number
					if(ret.found) return ret.value - 0;
					// otherwise, return -1 to indicate that we don't know
					else return -1;
				},
				
				/********************************/
				/**                            **/
				/**                            **/
				/**   dojo.data.api.Identity   **/
				/**                            **/
				/**                            **/
				/********************************/			
				fetchItemByIdentity: function(/* object */ keywordArgs){
					//	summary:
					//		Given the identity of an item, this method returns the item that has 
					//		that identity through the onItem callback.  Conforming implementations 
					//		should return null if there is no item with the given identity.  
					//		Implementations of fetchItemByIdentity() may sometimes return an item 
					//		from a local cache and may sometimes fetch an item from a remote server, 
					//
					// 	keywordArgs:
					//		An anonymous object that defines the item to locate and callbacks to invoke when the 
					//		item has been located and load has completed.  The format of the object is as follows:
					//		{
					//			identity: string|object,
					//			onItem: Function,
					//			onError: Function,
					//			scope: object
					//		}
					//	The *identity* parameter.
					//		The identity parameter is the identity of the item you wish to locate and load
					//		This attribute is required.  It should be a string or an object that toString() 
					//		can be called on.
					//		
					//	The *onItem* parameter.
					//		Function(item)
					//		The onItem parameter is the callback to invoke when the item has been loaded.  It takes only one
					//		parameter, the item located, or null if none found.
					//
					//	The *onError* parameter.
					//		Function(error)
					//		The onError parameter is the callback to invoke when the item load encountered an error.  It takes only one
					//		parameter, the error object
					//
					//	The *scope* parameter.
					//		If a scope object is provided, all of the callback functions (onItem, 
					//		onError, etc) will be invoked in the context of the scope object.
					//		In the body of the callback function, the value of the "this"
					//		keyword will be the scope object.   If no scope object is provided,
					//		the callback functions will be called in the context of dojo.global.
					//		For example, onItem.call(scope, item, request) vs. 
					//		onItem.call(dojo.global, item, request)
					return false;
				}
			}
);

dojo.declare( "com.ibm.data.OpenSearchFeedItem",
			com.ibm.data.AtomEntryItem, 
			{
				// namespaces: Map
				//		Map of namespaces used by the MashupHub feeds
				namespaces: dojo.mixin({}, com.ibm.data.OpenSearchFeedStore.prototype.namespaces)
			}
);


dojo.declare( "com.ibm.data.OpenSearchQueryConstruct",
			com.ibm.data._XmlConstruct,
			{
				namespaces: dojo.mixin({}, com.ibm.data.OpenSearchFeedStore.prototype.namespaces),
				
				constructor: function(/*DOMNode*/ root) {
					this.root = root;
				},
				getRole: function() {
					return this._getAttribute(this.root, "role");
				},
				getTitle: function() {
					return this._getAttribute(this.root, "title");
				},
				getTotalResults: function() {
					return this._getAttribute(this.root, "totalResults");
				},
				getSearchTerms: function() {
					return this._getAttribute(this.root, "searchTerms");
				},
				getCount: function() {
					return this._getAttribute(this.root, "count");
				},
				getStartIndex: function() {
					return this._getAttribute(this.root, "startIndex");
				},
				getStartPage: function() {
					return this._getAttribute(this.root, "startPage");
				},
				getLanguage: function() {
					return this._getAttribute(this.root, "language");
				},
				getInputEncoding: function() {
					return this._getAttribute(this.root, "inputEncoding");
				},
				getOutputEncoding: function() {
					return this._getAttribute(this.root, "outputEncoding");
				},
				toString: function() {
					return com.ibm.domUtilities.stringFromDoc(this.root);
				}
			}
);

}

if(!dojo._hasResource["com.ibm.data.MashupCatalogFeedStore"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.data.MashupCatalogFeedStore"] = true;
dojo.provide("com.ibm.data.MashupCatalogFeedStore");




dojo.declare("com.ibm.data.MashupCatalogFeedStore", 
		[com.ibm.data.OpenSearchFeedStore,com.ibm.data.CatalogMixin],
		{
			itemClass: "com.ibm.data.MashupCatalogFeedItem",
			searchable: false, 
			
			namespaces: dojo.mixin({}, com.ibm.data.OpenSearchFeedStore.prototype.namespaces, {
		        "ext" : "http://www.ibm.com/xmlns/prod/lotus/mashups/v1.0/extensions",
				"model" : "http://www.ibm.com/xmlns/prod/lotus/mashups/v1.0/model-elements",
				"base" : "http://www.ibm.com/xmlns/prod/lotus/mashups/v1.0/base"
		    }),
		       
			constructor: function( /*Map*/ args ) {
				this._features['dojo.data.api.Identity'] = true;
				var serviceDoc = com.ibm.mm.enabler.model.ServiceDocumentModel.SERVICE_CATALOG;
				var serviceJson = com.ibm.mm.enabler.model.ServiceDocumentModel.getCollectionData(serviceDoc);
				this.isPortal = (serviceJson.idprefix == "id") ? false : true;
				
				this.url = serviceJson.url + "@"+ serviceJson.idprefix + ":" + this.category;
				var catalog = this.catalog ? this.catalog : "default";
				var mashupsIdPostfix = this.isPortal ? "" : "_c_" + catalog;
				this.url = this.url + mashupsIdPostfix;
			},
				
			mapItem: function(/*item*/item){
				var map = {};
				var bigId = this.getValue(item, "id", null);
				if(this.isPortal) var ids = /^catalog:oid:(.+)@oid:.+/.exec(bigId);
				else var ids = /^catalog:id:(.+)@/.exec(bigId);
				map["id"] = ids.length > 1 ? ids[1] : "";
				map["label"] = this.getValue(item, "title", "untitled");
				map["description"] = this.getValue(item, "summary", "");
				map["thumbnail"] = this.getValue(item, "thumbnail", "");
				if(!map.thumbnail && builderConfig.builderPath) map["thumbnail"] = builderConfig.builderPath + "/images/gray_generic_widget_icon.png";
				return map;
			},
				
			prepareQuery: function(keywordArgs) {
				if(keywordArgs.count) {
					if(this.isPortal) keywordArgs.query["max-results"] = keywordArgs.count;
					else keywordArgs.query.num = keywordArgs.count;
					if(keywordArgs.start == null) {
						keywordArgs.start = 0;
					}
					if(this.isPortal) keywordArgs.query["start-index"] = keywordArgs.start;
					else keywordArgs.query.start = keywordArgs.start;
				}
				return keywordArgs;
			},
			
			getSourceLabel: function(){
				var categories = com.ibm.mm.builder.utils.toolboxUtil.getCategories();
				for (var i = 0; i < categories.length; i++) {
					var category = categories[i];
					var id = category.getID();
					if(id.indexOf(this.category) == 0) return com.ibm.mm.builder.utils.enablerUtil.getNodeTitle(category);
				}
				return false;
			}
});

dojo.declare( "com.ibm.data.MashupCatalogFeedItem",
		com.ibm.data.OpenSearchFeedItem, 
		{
			namespaces: dojo.mixin({}, com.ibm.data.MashupCatalogFeedStore.prototype.namespaces),
			
	        attrMappings: dojo.mixin({}, com.ibm.data.OpenSearchFeedItem.prototype.attrMappings, {
				thumbnail: {xpath: "./atom:content/model:catalog-entry/atom:link[@ext:rel='icon']", targetName: "href", type: "attr"}
			})
		}
);

}

if(!dojo._hasResource["com.ibm.customize.MashupsAddContentController"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.customize.MashupsAddContentController"] = true;
 // This is a controller that customizes the content on a page

dojo.provide("com.ibm.customize.MashupsAddContentController");



com.ibm.customize.MashupsAddContentController = {
	eventService: null,
	
	filterAdd: function(map){
		if(map.type == "mashup" || map.type == "iwidgetURL" || map.type == "feed" || !map.type) return true
		else return false;
	},

/***********************************************/
/*       Customize Controller API			   */
/***********************************************/

	parent: null,		// a pointer to this controller's parent, if one exists
	dirty: false,		// true if there are changes pending
	added: false,		// true if there were widgets added
	started: false,		// true if the widget is started up
	refresh: false,		// true if a page refresh is required to show saved changes

	startup: function(/*Object/Widget*/parent){		
		// get predefined renderers from the catalog model
		var renderers = new Array();
		var priorityRenderers = new Array();
		var catModel = com.ibm.mm.builder.utils.toolboxUtil.getCatalogModel();
		var catIterator = catModel.getChildren();
		while(catIterator.hasNext()) {
			var categoryModel = catModel.getCatalogEntryModel(catIterator.next());
			var elemIterator = categoryModel.iterator();
			elemIterator.setCursorPosition(0);
			while (elemIterator.hasNext()){
				var entry = elemIterator.next();
				priority = entry.getMetadata("com.ibm.lotus.widget.renderer");
				if(priority == "priority") priorityRenderers.push({id:entry.getID(),label:com.ibm.mm.builder.utils.enablerUtil.getNodeTitle(entry)});
				else renderers.push({id:entry.getID(),label:com.ibm.mm.builder.utils.enablerUtil.getNodeTitle(entry)});
			}
		}
		this.renderers = priorityRenderers.concat(renderers);
		
		this.started = true;
		this.parent = parent;
		this.setupUI();
	},

	makeDirty: function(/*bool*/change){
		// summary: changes the dirty attribute
		// change: value to assign to the dirty attribute
		this.dirty = change;
	},

	processChange: function(/*Object*/args){
		// summary: used as an event handler for when a user clicks on a result
		// args: 	id: the unique id of the piece of content
		//			label: the display name of the piece of content
		//			fcn (optional): a function or the name of a function in dot notation which retrieves a map of the preferences for the piece of content
		//			map (optional): an object of parameters to be passed to fcn
		//			takeoverFcn (optional): a function or the name of a function in dot notation which will be run instead of the body of this submit function
		//			takeoverObject (optional): an object of parameters to be passed to takeoverFcn
				
		// check for takeover function
		if(args.takeoverFcn) {
			if(dojo.isString(args.takeoverFcn)) dojo.getObject(args.takeoverFcn)(args.takeoverObject);
			else args.takeoverFcn(args.takeoverObject);
			return;
		}
		this.apply(args);
		if(!this.parent) this.beforeSubmit().addCallback(dojo.hitch(this, function(){this.submit(args)}));
	},

	apply: function(/*Object*/args){
		if(!this.dirty) this.makeDirty(true);
		var data = args.map;
		if(data.type == "feed" || data.type == "mashup"){
			var ieventArgs = {};
			ieventArgs.id = args.id;
			ieventArgs.itemSet = {};
			ieventArgs.itemSet.feedURL = data.url;			// feed reader and data viewer
			ieventArgs.itemSet.dataSourceURL = data.url;	// chart
			this.eventService.broadcastEvent("com.ibm.mashups.builder.addWidget",ieventArgs);
		} else if (data.type == "iwidgetURL"){
			dojo.xhrGet ({
		        url: this.createProxyURI(data.url),
		        load: dojo.hitch(this, function(xml){
					var start = xml.indexOf('url');
					var end = xml.indexOf('xml');
					if(start < 0 || end < 0) return;
					var definitionURL = xml.substring(start+4,end+3);
					var ieventArgs = {};
					ieventArgs.widgetMetadata = {};
					ieventArgs.widgetMetadata.id = args.id;
					ieventArgs.widgetMetadata.definition = definitionURL;
					ieventArgs.widgetMetadata.icon = data.icon;
					ieventArgs.widgetMetadata.title = {}; ieventArgs.widgetMetadata.title[djConfig.locale] = args.label;
					ieventArgs.widgetMetadata.onNewWire = "";
					var feedWidgetParam = data.widgetParam;
					if (feedWidgetParam && feedWidgetParam.length > 2 && feedWidgetParam.charAt(0) == '[') {
						// widgetParam is defined
						ieventArgs.widgetMetadata.widgetParam = feedWidgetParam;
					} else {
						ieventArgs.widgetMetadata.widgetParam = "[]";
					}
					this.eventService.broadcastEvent("com.ibm.mashups.builder.addWidget",ieventArgs);
				}),
				error: function(e){
					console.error(e);
				}
			});
		} else {
			this.eventService.broadcastEvent("com.ibm.mashups.builder.addWidget",data.id);
		}
	},

	undo: function(/*Object*/args){ 
		// refresh the page so the unsaved widgets will be removed from the DOM
		var pageId = com.ibm.mm.builder.utils.pageUtil.getCurrentPageId();
		this.eventService.broadcastEvent("com.ibm.mashups.builder.switchPage", pageId);
	},

	beforeSubmit: function(/*Object*/args){
		var dfd = new dojo.Deferred();
		dfd.callback();
		return dfd;
	},

	submit: function(/*Object*/args){
		// summary: saves any pending changes to the server
		// args: may contain an onComplete handler
		if(this.dirty) this.makeDirty(false);
		if(args.onComplete) args.onComplete();
	}
}

}

if(!dojo._hasResource["com.ibm.customize.MashupsChangeStyleController"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.customize.MashupsChangeStyleController"] = true;
 // This is a controller that customizes the styles of a page

dojo.provide("com.ibm.customize.MashupsChangeStyleController");
com.ibm.customize.MashupsChangeStyleController = {
	current: "",			// the style currently selected on the shelf
	set: "",				// the style currently set on the page
	eventService: null,		// enabler event service

	/***********************************************/
	/*       Customize Controller API			   */
	/***********************************************/ 

	parent: null,			// a pointer to this controller's parent, if one exists
	dirty: false,			// true if there are changes pending
	started: false,		// true if the widget is started up
	refresh: false,		// true if a page refresh is required to show saved changes

	startup: function(/*Object?/Widget?*/parent){
		// summary: sets some variables, sets up the UI and prepares the stylesheet links so they can be switched out smoothly
		// parent: a reference to the parent of this controller
		this.started = true;
		this.current = this.set;
		this.parent = parent;
		if(this.setupUI) this.setupUI();
	},
			
	makeDirty: function(/*bool*/change){
		// summary: changes the dirty attribute
		// change: value to assign to the dirty attribute
		this.dirty = change;
	},
			
	processChange: function(/*Object*/args){
		// summary: used as an event handler for when a user clicks on a result
		this.apply(args);
		if(!this.parent) {
			this.beforeSubmit().addCallback(dojo.hitch(this, function(){this.submit(args)}));
		}
	},
			
	apply: function(/*Object*/args){
		// summary: applies a change associated with a result to the page
		// args: contains args.id which is the id of the selected item
		if(args.id == this.current) return;
		if(args.id == this.set) this.makeDirty(false);
		else if(this.dirty == false) this.makeDirty(true);
		com.ibm.mashups.builder.model.Factory.getRuntimeModel().getCurrentPage().setDirty(true);
		if(!args.noReset) this.eventService.broadcastEvent("com.ibm.mashups.builder.resetStyle");
		this.current = args.id;	
		this._switchStylesheet(this.current);
	},
			
	undo: function(){
		// summary: reverts any changes made
		this.apply({id:this.set,noReset:true});
	},

	beforeSubmit: function(/*Object*/args){
		var dfd = new dojo.Deferred();
		dfd.callback();
		return dfd;
	},
			
	submit: function(/*Object*/args){
		// summary: saves any pending changes to the server
		// args: args may contain an onComplete handler
		if(!this.dirty) { if(args.onComplete) args.onComplete(); return; }
		com.ibm.mm.builder.utils.enablerUtil.setPageMetaData("com/ibm/customize/changeStyleController/style",this.current);
		this.makeDirty(false); 
		this.set = this.current; 
		if(args.onComplete) args.onComplete();
	},
			
	/***********************************************/
	/*              Helper functions   		       */
	/***********************************************/

	_switchStylesheet: function(title){
		// summary: switch to the stylesheet with the given title
		var i, currLink, found = false;
		for(i = 0; (currLink = document.getElementsByTagName("link")[i]); i++) {
			// if the link is a perferred stylesheet
			if(currLink.getAttribute("rel").indexOf("style") >= 0 && currLink.getAttribute("title")) { 
				// if the chosen theme is found
				if(currLink.getAttribute("title") == title) {
					currLink.disabled = false;
					found = true;
				}
				else currLink.disabled = true; 
			}
	    }
		if(!found) {
			this._loadCss(this.baseCssPath + title + ".css",title,true,true); 
			this._switchStylesheet(title);
		}
	},

	_loadCss: function(path, title, alternate, disabled){
		var link = dojo.create("link",{type:"text/css",rel:(alternate)?"alternate stylesheet":"stylesheet",href:path,media:"screen",disabled:disabled});
		if(title) link.title = title;
		var head = document.getElementsByTagName("head")[0];
		head.appendChild(link);
	}
}

}

if(!dojo._hasResource["com.ibm.data.MashupHubStore"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.data.MashupHubStore"] = true;
dojo.provide( "com.ibm.data.MashupHubStore" );


dojo.require( "com.ibm.data.ProxyHelper" );

dojo.declare( "com.ibm.data.MashupHubStore",
			[com.ibm.data.OpenSearchFeedStore, com.ibm.data.ProxyHelper],
			{
				// namespaces: Map
				//		Map of namespaces used by the MashupHub feeds
				namespaces: dojo.mixin({}, com.ibm.data.OpenSearchFeedStore.prototype.namespaces, {
		            "catalog" : "http://www.ibm.com/xmlns/atom/opensearch/catalog/1.0/"
		        }),
		        
		        // itemClass: String the class used to represent items of this store
				itemClass: "com.ibm.data.MashupHubItem",
				
				constructor: function( /*Map*/ args ) {
					// summary: Creates a new instance of a this data store
					// args: Map
					//		The args map will be used to replace any default values of this store with the
					//		values specified in the args map.
					this._features['dojo.data.api.Identity'] = true;
					//this.url = this.urlThroughProxy(this.url);
				},
				
				handleConstructs: function(/*DOMNode*/ node, /*String*/ prop) {
					switch(prop) {
						case "OpenSearchQueryConstruct": return new com.ibm.data.MashupHubQueryConstruct(node);
						default: return this.inherited(arguments);
					}
				},
			
				fetchItemByIdentity: function(/* object */ keywordArgs){
					//	summary:
					//		Given the identity of an item, this method returns the item that has 
					//		that identity through the onItem callback.  Conforming implementations 
					//		should return null if there is no item with the given identity.  
					//		Implementations of fetchItemByIdentity() may sometimes return an item 
					//		from a local cache and may sometimes fetch an item from a remote server, 
					//
					// 	keywordArgs:
					//		An anonymous object that defines the item to locate and callbacks to invoke when the 
					//		item has been located and load has completed.  The format of the object is as follows:
					//		{
					//			identity: string|object,
					//			onItem: Function,
					//			onError: Function,
					//			scope: object
					//		}
					//	The *identity* parameter.
					//		The identity parameter is the identity of the item you wish to locate and load
					//		This attribute is required.  It should be a string or an object that toString() 
					//		can be called on.
					//		
					//	The *onItem* parameter.
					//		Function(item)
					//		The onItem parameter is the callback to invoke when the item has been loaded.  It takes only one
					//		parameter, the item located, or null if none found.
					//
					//	The *onError* parameter.
					//		Function(error)
					//		The onError parameter is the callback to invoke when the item load encountered an error.  It takes only one
					//		parameter, the error object
					//
					//	The *scope* parameter.
					//		If a scope object is provided, all of the callback functions (onItem, 
					//		onError, etc) will be invoked in the context of the scope object.
					//		In the body of the callback function, the value of the "this"
					//		keyword will be the scope object.   If no scope object is provided,
					//		the callback functions will be called in the context of dojo.global.
					//		For example, onItem.call(scope, item, request) vs. 
					//		onItem.call(dojo.global, item, request)
					var id = keywordArgs.identity;
					
					// our IDs may come in as urn:id:# and all we want is the # part
					if(id.indexOf(":") > -1) id = id.substring(id.lastIndexOf(":") + 1);
					var scope = keywordArgs.scope ? keywordArgs.scope : dojo.global;
					var args = {
						query: {
							id: id,
							collection: "ui.all"
						},
						onComplete: dojo.hitch(this, 
							function(items) {
								if(items.length == 0 && keywordArgs.onError) {
									keywordArgs.onError.call(scope, "No items returned matching identity " + id);
								}
								else {
									keywordArgs.onItem.call(scope, items[0]);
								}
							}
						)
					};
					if(keywordArgs.onError) args.onError = dojo.hitch(scope, keywordArgs.onError);

					return this.fetch(args);
				}
			}
);

dojo.declare( "com.ibm.data.MashupHubItem",
		com.ibm.data.OpenSearchFeedItem, 
		{
			// namespaces: Map
			//		Map of namespaces used by the MashupHub feeds
			namespaces: dojo.mixin({}, com.ibm.data.MashupHubStore.prototype.namespaces),
			
	        attrMappings: dojo.mixin({}, com.ibm.data.OpenSearchFeedItem.prototype.attrMappings, {
				editLink: {xpath: "./atom:link[@rel='self']", targetName: "href", type: "attr"},
				category: {xpath: "./atom:category", targetName: "term", type: "attr"},
				catalogVersion: {xpath: "./atom:content/catalog:catalog/catalog:version", targetName: "textContent", type: "node"},
				catalogName: {xpath: "./atom:content/catalog:catalog/catalog:name", targetName: "textContent", type: "node"},
				catalogAuthor: {xpath: "./atom:content/catalog:catalog/catalog:author", targetName: "textContent", type: "node"},
				catalogDescription: {xpath: "./atom:content/catalog:catalog/catalog:description", targetName: "textContent", type: "node"},
				catalogRating: {xpath: "./atom:content/catalog:catalog/catalog:rating", targetName: "textContent", type: "node"},
				catalogUseCount: {xpath: "./atom:content/catalog:catalog/catalog:useCount", targetName: "textContent", type: "node"},
				catalogDateModified: {xpath: "./atom:content/catalog:catalog/catalog:dateModified", targetName: "textContent", type: "node"},
				catalogNumComments: {xpath: "./atom:content/catalog:catalog/catalog:numComments", targetName: "textContent", type: "node"},
				catalogTags: {xpath: "./atom:content/catalog:catalog/catalog:tags/catalog:tag", targetName: "textContent", type: "node"},
				catalogCategories: {xpath: "./atom:content/catalog:catalog/catalog:categories", targetName: "textContent", type: "node"},
				catalogDocumentationURL: {xpath: "./atom:content/catalog:catalog/catalog:documentationURL", targetName: "textContent", type: "node"},
				catalogDownloadURL: {xpath: "./atom:content/catalog:catalog/catalog:downloadURL", targetName: "textContent", type: "node"},
				catalogIcon: {xpath: "./atom:content/catalog:catalog/catalog:icon", targetName: "textContent", type: "node"},
				catalogWidgetParam: {xpath: "./atom:content/catalog:catalog/catalog:objectmeta/catalog:metadata[@name='widgetParam']", targetName: "value", type: "attr"}
			})
		}
);

dojo.declare( "com.ibm.data.MashupHubQueryConstruct",
			com.ibm.data.OpenSearchQueryConstruct,
			{
				namespaces: dojo.mixin({}, com.ibm.data.MashupHubStore.prototype.namespaces),
				
				getSearchType: function() {
					return this._getAttribute(this.root, "catalog:searchType");
				},
				getCollection: function() {
					return this._getAttribute(this.root, "catalog:collection");
				}
			}
);

}

if(!dojo._hasResource["com.ibm.data.MashupFileDataStore"]){ //_hasResource checks added by build. Do not use _hasResource directly in your code.
dojo._hasResource["com.ibm.data.MashupFileDataStore"] = true;
dojo.provide("com.ibm.data.MashupFileDataStore");

dojo.require( "com.ibm.data.CatalogMixin" );


dojo.declare("com.ibm.data.MashupFileDataStore", 
		[com.ibm.data.MashupHubStore,com.ibm.data.CatalogMixin],
		{	
				/********************************/
				/**                            **/
				/**                            **/
				/**  catalog extension point   **/
				/**                            **/
				/**                            **/
				/********************************/
				
			mapItem: function(/*item*/item){
				var map = {};
				map["id"] = this.getValue(item, "id", null);
				map["label"] = this.getValue(item, "catalogName", "untitled");
				map["description"] = this.getValue(item, "catalogDescription", "");
				map["tags"] = this.getValues(item, "catalogTags", "");
				map["rating"] = this.getValue(item, "catalogRating", 0.0);
				map["url"] = this.getValue(item, "catalogDownloadURL", "");
				map["type"] = this.getValue(item, "category", "");
				map["thumbnail"] = this.getValue(item, "catalogIcon", "");
				map["widgetParam"] = this.getValue(item, "catalogWidgetParam", "");
				if(!map.thumbnail && builderConfig.builderPath) map["thumbnail"] = builderConfig.builderPath + "/images/gray_generic_feed_icon.png";
				return map;
			},
				
			prepareQuery: function(keywordArgs) {
				if(keywordArgs.query.keywords) {
					keywordArgs.query.searchTerms = keywordArgs.query.keywords.join(" ");
					keywordArgs.query.searchType = "";
					delete keywordArgs.query.keywords;
				}
				else if(keywordArgs.query.tags && keywordArgs.query.tags.length > 0) {
					keywordArgs.query.searchTerms = keywordArgs.query.tags[0];
					keywordArgs.query.searchType = "tag";
					delete keywordArgs.query.tags;
				}
				else {
					keywordArgs.query.searchTerms = "*";
					keywordArgs.query.searchType = "";
				}

				keywordArgs.query.nologin = "true";
				
				if(keywordArgs.sort&& keywordArgs.sort.length > 0) {
					switch(keywordArgs.sort[0].attribute) {
						case "date": 
							keywordArgs.query.sortBy = "updated";
							break;
						default:
							keywordArgs.query.sortBy = keywordArgs.sort[0].attribute;
					}
					keywordArgs.query.sortOrder = "asc";
					if(keywordArgs.sort[0].descending == true) {
						keywordArgs.query.sortOrder = "desc";
					}
				}
				
				if(keywordArgs.count) {
					keywordArgs.query.count = keywordArgs.count;
					if(keywordArgs.start == null) {
						keywordArgs.start = 0;
					}
					keywordArgs.query.startIndex = keywordArgs.start;
				}
				
				return keywordArgs;
			},
			
			validateSelf: function(){
				// summary: validates this datastore, if it does not validate the source will not be used
				// returns true for validation and false otherwise
				if(this.url.indexOf("undefined") < 0) return true
				else return false;
			}
});

}


dojo.i18n._preloadLocalizations("com.ibm.nls.sharedWidgets", ["ROOT","ar","ca","cs","da","de","de-de","el","en","en-gb","en-us","es","es-es","fi","fi-fi","fr","fr-fr","he","he-il","hr","hu","it","it-it","ja","ja-jp","ko","ko-kr","nl","nl-be","nl-nl","no","pl","pt","pt-br","pt-pt","ro","ro-ro","ru","sk","sl","sv","th","tr","uk","xx","zh","zh-cn","zh-tw"]);
